
try {

var init = (function (gio2, glib2, shell0, clutter10, gobject2, st1, gsound1, gdkpixbuf2, cogl2, meta10, gda6, pango1, graphene1, soup3) {
    'use strict';

    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }

    // Taken from https://github.com/material-shell/material-shell/blob/main/src/utils/gjs.ts
    /// Decorator function to call `GObject.registerClass` with the given class.
    /// Use like
    /// ```
    /// @registerGObjectClass
    /// export class MyThing extends GObject.Object { ... }
    /// ```
    function registerGObjectClass(target) {
        // Note that we use 'hasOwnProperty' because otherwise we would get inherited meta infos.
        // This would be bad because we would inherit the GObjectName too, which is supposed to be unique.
        if (Object.prototype.hasOwnProperty.call(target, 'metaInfo')) {
            // eslint-disable-next-line
            // @ts-ignore
            // eslint-disable-next-line
            return gobject2.registerClass(target.metaInfo, target);
        }
        else {
            // eslint-disable-next-line
            // @ts-ignore
            return gobject2.registerClass(target);
        }
    }

    const logger = (prefix) => (content) => log(`[pano] [${prefix}] ${content}`);
    const debug$7 = logger('shell-utils');
    const deleteFile = (file) => {
        return new Promise((resolve, reject) => {
            file.delete_async(glib2.PRIORITY_DEFAULT, null, (_file, res) => {
                try {
                    resolve(file.delete_finish(res));
                }
                catch (e) {
                    reject(e);
                }
            });
        });
    };
    const deleteDirectory = async (file) => {
        try {
            const iter = await new Promise((resolve, reject) => {
                file.enumerate_children_async('standard::type', gio2.FileQueryInfoFlags.NOFOLLOW_SYMLINKS, glib2.PRIORITY_DEFAULT, null, (file, res) => {
                    try {
                        resolve(file?.enumerate_children_finish(res));
                    }
                    catch (e) {
                        reject(e);
                    }
                });
            });
            if (!iter) {
                return;
            }
            const branches = [];
            while (true) {
                const infos = await new Promise((resolve, reject) => {
                    iter.next_files_async(10, glib2.PRIORITY_DEFAULT, null, (it, res) => {
                        try {
                            resolve(it ? it.next_files_finish(res) : []);
                        }
                        catch (e) {
                            reject(e);
                        }
                    });
                });
                if (infos.length === 0) {
                    break;
                }
                for (const info of infos) {
                    const child = iter.get_child(info);
                    const type = info.get_file_type();
                    let branch;
                    switch (type) {
                        case gio2.FileType.REGULAR:
                        case gio2.FileType.SYMBOLIC_LINK:
                            branch = deleteFile(child);
                            break;
                        case gio2.FileType.DIRECTORY:
                            branch = deleteDirectory(child);
                            break;
                        default:
                            continue;
                    }
                    branches.push(branch);
                }
            }
            await Promise.all(branches);
        }
        catch (e) {
        }
        finally {
            return deleteFile(file);
        }
    };
    const getAppDataPath = () => `${glib2.get_user_data_dir()}/${getCurrentExtension().metadata.uuid}`;
    const getImagesPath = () => `${getAppDataPath()}/images`;
    const getCachePath = () => `${glib2.get_user_cache_dir()}/${getCurrentExtension().metadata.uuid}`;
    const setupAppDirs = () => {
        const imagePath = gio2.File.new_for_path(getImagesPath());
        if (!imagePath.query_exists(null)) {
            imagePath.make_directory_with_parents(null);
        }
        const cachePath = gio2.File.new_for_path(getCachePath());
        if (!cachePath.query_exists(null)) {
            cachePath.make_directory_with_parents(null);
        }
        const dbPath = gio2.File.new_for_path(`${getDbPath()}`);
        if (!dbPath.query_exists(null)) {
            dbPath.make_directory_with_parents(null);
        }
    };
    const moveDbFile = (from, to) => {
        if (from === to) {
            return;
        }
        const oldDb = gio2.File.new_for_path(`${from}/pano.db`);
        const newDb = gio2.File.new_for_path(`${to}/pano.db`);
        if (oldDb.query_exists(null) && !newDb.query_exists(null)) {
            const newDBParent = gio2.File.new_for_path(to);
            if (!newDBParent.query_exists(null)) {
                newDBParent.make_directory_with_parents(null);
            }
            oldDb.move(newDb, gio2.FileCopyFlags.ALL_METADATA, null, null);
        }
    };
    const deleteAppDirs = async () => {
        const appDataPath = gio2.File.new_for_path(getAppDataPath());
        if (appDataPath.query_exists(null)) {
            await deleteDirectory(appDataPath);
        }
        const cachePath = gio2.File.new_for_path(getCachePath());
        if (cachePath.query_exists(null)) {
            await deleteDirectory(cachePath);
        }
        const dbPath = gio2.File.new_for_path(`${getDbPath()}/pano.db`);
        if (dbPath.query_exists(null)) {
            dbPath.delete(null);
        }
    };
    const getDbPath = () => {
        const path = getCurrentExtensionSettings().get_string('database-location');
        if (!path) {
            return getAppDataPath();
        }
        return path;
    };
    const getCurrentExtension = () => imports.misc.extensionUtils.getCurrentExtension();
    const getCurrentExtensionSettings = () => imports.misc.extensionUtils.getSettings();
    const loadInterfaceXML = (iface) => {
        const uri = `file:///${getCurrentExtension().path}/dbus/${iface}.xml`;
        const file = gio2.File.new_for_uri(uri);
        try {
            const [, bytes] = file.load_contents(null);
            return imports.byteArray.toString(bytes);
        }
        catch (e) {
            debug$7(`Failed to load D-Bus interface ${iface}`);
        }
        return null;
    };
    let soundContext = null;
    const playAudio = () => {
        try {
            if (!soundContext) {
                soundContext = new gsound1.Context();
                soundContext.init(null);
            }
            soundContext.play_simple({
                [gsound1.ATTR_EVENT_ID]: 'message',
            }, null);
        }
        catch (err) {
            debug$7(`failed to play audio: ${err}`);
        }
    };
    const removeSoundContext = () => {
        if (soundContext) {
            soundContext.run_dispose();
            soundContext = null;
        }
    };
    const initTranslations = () => imports.misc.extensionUtils.initTranslations(getCurrentExtension().metadata.uuid);
    const _ = imports.gettext.domain(getCurrentExtension().metadata.uuid).gettext;
    imports.gettext.domain(getCurrentExtension().metadata.uuid).ngettext;
    let debounceIds = [];
    function debounce(func, wait) {
        let sourceId;
        return function (...args) {
            const debouncedFunc = function () {
                debounceIds = debounceIds.filter((id) => id !== sourceId);
                sourceId = null;
                func.apply(this, args);
                return glib2.SOURCE_REMOVE;
            };
            if (sourceId) {
                glib2.Source.remove(sourceId);
                debounceIds = debounceIds.filter((id) => id !== sourceId);
            }
            sourceId = glib2.timeout_add(glib2.PRIORITY_DEFAULT, wait, debouncedFunc);
            debounceIds.push(sourceId);
        };
    }
    const openUrlInBrowser = (url) => {
        try {
            gio2.app_info_launch_default_for_uri(url, null);
        }
        catch (e) {
            debug$7(`Failed to open url ${url}`);
        }
    };

    const global$2 = shell0.Global.get();
    const notify = (text, body, iconOrPixbuf, pixelFormat) => {
        const source = new imports.ui.messageTray.Source(_('Pano'), 'edit-copy-symbolic');
        imports.ui.main.messageTray.add(source);
        let notification;
        if (iconOrPixbuf) {
            if (iconOrPixbuf instanceof gdkpixbuf2.Pixbuf) {
                const content = st1.ImageContent.new_with_preferred_size(iconOrPixbuf.width, iconOrPixbuf.height);
                content.set_bytes(iconOrPixbuf.read_pixel_bytes(), pixelFormat || cogl2.PixelFormat.RGBA_8888, iconOrPixbuf.width, iconOrPixbuf.height, iconOrPixbuf.rowstride);
                notification = new imports.ui.messageTray.Notification(source, text, body, {
                    datetime: glib2.DateTime.new_now_local(),
                    gicon: content,
                });
            }
            else {
                notification = new imports.ui.messageTray.Notification(source, text, body, {
                    datetime: glib2.DateTime.new_now_local(),
                    gicon: iconOrPixbuf,
                });
            }
        }
        else {
            notification = new imports.ui.messageTray.Notification(source, text, body);
        }
        notification.setTransient(true);
        source.showNotification(notification);
    };
    const wm = imports.ui.main.wm;
    const getMonitors = () => imports.ui.main.layoutManager.monitors;
    const getMonitorIndexForPointer = () => {
        const [x, y] = global$2.get_pointer();
        const monitors = getMonitors();
        for (let i = 0; i <= monitors.length; i++) {
            const monitor = monitors[i];
            if (x >= monitor.x && x < monitor.x + monitor.width && y >= monitor.y && y < monitor.y + monitor.height) {
                return i;
            }
        }
        return imports.ui.main.layoutManager.primaryIndex;
    };
    const getMonitorConstraint = () => new imports.ui.layout.MonitorConstraint({
        index: getMonitorIndexForPointer(),
    });
    const addTopChrome = (actor, options) => imports.ui.main.layoutManager.addTopChrome(actor, options);
    const removeChrome = (actor) => imports.ui.main.layoutManager.removeChrome(actor);
    let virtualKeyboard = null;
    const getVirtualKeyboard = () => {
        if (virtualKeyboard) {
            return virtualKeyboard;
        }
        virtualKeyboard = clutter10.get_default_backend().get_default_seat().create_virtual_device(clutter10.InputDeviceType.KEYBOARD_DEVICE);
        return virtualKeyboard;
    };
    const removeVirtualKeyboard = () => {
        if (virtualKeyboard) {
            virtualKeyboard.run_dispose();
            virtualKeyboard = null;
        }
    };
    const addToStatusArea = (button) => {
        imports.ui.main.panel.addToStatusArea(getCurrentExtension().metadata.uuid, button, 1, 'right');
    };
    const openExtensionPrefs = () => imports.misc.extensionUtils.openPrefs();

    const { ModalDialog } = imports.ui.modalDialog;
    const { MessageDialogContent } = imports.ui.dialog;
    const debug$6 = logger('clear-history-dialog');
    let ClearHistoryDialog = class ClearHistoryDialog extends ModalDialog {
        constructor(onClear) {
            super();
            this.onClear = onClear;
            this.cancelButton = this.addButton({
                label: _('Cancel'),
                action: this.onCancelButtonPressed.bind(this),
                key: clutter10.KEY_Escape,
                default: true,
            });
            this.clearButton = this.addButton({
                label: _('Clear'),
                action: this.onClearButtonPressed.bind(this),
            });
            const content = new MessageDialogContent({
                title: _('Clear History'),
                description: _('Are you sure you want to clear history?'),
            });
            this.contentLayout.add(content);
        }
        onCancelButtonPressed() {
            this.close();
        }
        async onClearButtonPressed() {
            this.cancelButton.set_reactive(false);
            this.clearButton.set_reactive(false);
            this.clearButton.set_label('Clearing...');
            try {
                await this.onClear();
            }
            catch (err) {
                debug$6(`err: ${err}`);
            }
            this.close();
        }
    };
    ClearHistoryDialog = __decorate([
        registerGObjectClass
    ], ClearHistoryDialog);

    const { PopupMenuItem, PopupSwitchMenuItem, PopupSeparatorMenuItem } = imports.ui.popupMenu;
    const { Button: PopupMenuButton } = imports.ui.panelMenu;
    let SettingsMenu = class SettingsMenu extends PopupMenuButton {
        constructor(onClear, onToggle) {
            super(0.5, 'Pano Indicator', false);
            this.onToggle = onToggle;
            this.settings = getCurrentExtensionSettings();
            const isInIncognito = this.settings.get_boolean('is-in-incognito');
            const icon = new st1.Icon({
                gicon: gio2.icon_new_for_string(`${getCurrentExtension().path}/icons/hicolor/scalable/actions/indicator${isInIncognito ? '-incognito-symbolic' : '-symbolic'}.svg`),
                style_class: 'system-status-icon indicator-icon',
            });
            this.add_child(icon);
            const switchMenuItem = new PopupSwitchMenuItem(_('Incognito Mode'), this.settings.get_boolean('is-in-incognito'));
            switchMenuItem.connect('toggled', (item) => {
                this.settings.set_boolean('is-in-incognito', item.state);
            });
            this.incognitoChangeId = this.settings.connect('changed::is-in-incognito', () => {
                const isInIncognito = this.settings.get_boolean('is-in-incognito');
                switchMenuItem.setToggleState(isInIncognito);
                icon.set_gicon(gio2.icon_new_for_string(`${getCurrentExtension().path}/icons/hicolor/scalable/actions/indicator${isInIncognito ? '-incognito-symbolic' : '-symbolic'}.svg`));
            });
            this.menu.addMenuItem(switchMenuItem);
            this.menu.addMenuItem(new PopupSeparatorMenuItem());
            const clearHistoryItem = new PopupMenuItem(_('Clear History'));
            clearHistoryItem.connect('activate', () => {
                const dialog = new ClearHistoryDialog(onClear);
                dialog.open();
            });
            this.menu.addMenuItem(clearHistoryItem);
            this.menu.addMenuItem(new PopupSeparatorMenuItem());
            const settingsItem = new PopupMenuItem(_('Settings'));
            settingsItem.connect('activate', () => {
                openExtensionPrefs();
            });
            this.menu.addMenuItem(settingsItem);
        }
        vfunc_event(event) {
            if (!this.menu || event.type() !== clutter10.EventType.BUTTON_PRESS) {
                return clutter10.EVENT_PROPAGATE;
            }
            if (event.get_button() === clutter10.BUTTON_PRIMARY || event.get_button() === clutter10.BUTTON_MIDDLE) {
                this.onToggle();
            }
            else if (event.get_button() === clutter10.BUTTON_SECONDARY) {
                this.menu.toggle();
            }
            return clutter10.EVENT_PROPAGATE;
        }
        destroy() {
            this.settings.disconnect(this.incognitoChangeId);
            super.destroy();
        }
    };
    SettingsMenu.metaInfo = {
        GTypeName: 'SettingsButton',
        Signals: {
            'item-selected': {},
            'menu-state-changed': {
                param_types: [gobject2.TYPE_BOOLEAN],
                accumulator: 0,
            },
        },
    };
    SettingsMenu = __decorate([
        registerGObjectClass
    ], SettingsMenu);

    const { Lightbox } = imports.ui.lightbox;
    let MonitorBox = class MonitorBox extends st1.BoxLayout {
        constructor() {
            super({
                name: 'PanoMonitorBox',
                visible: false,
                reactive: true,
                x: 0,
                y: 0,
            });
            this.connect('button-press-event', () => {
                this.emit('hide');
                return clutter10.EVENT_STOP;
            });
            const constraint = new clutter10.BindConstraint({
                source: shell0.Global.get().stage,
                coordinate: clutter10.BindCoordinate.ALL,
            });
            this.add_constraint(constraint);
            const backgroundStack = new st1.Widget({
                layout_manager: new clutter10.BinLayout(),
                x_expand: true,
                y_expand: true,
            });
            const _backgroundBin = new st1.Bin({ child: backgroundStack });
            const _monitorConstraint = new imports.ui.layout.MonitorConstraint();
            _backgroundBin.add_constraint(_monitorConstraint);
            this.add_actor(_backgroundBin);
            this._lightbox = new Lightbox(this, {
                inhibitEvents: true,
                radialEffect: false,
            });
            this._lightbox.highlight(_backgroundBin);
            this._lightbox.set({ style_class: 'pano-monitor-box' });
            const _eventBlocker = new clutter10.Actor({ reactive: true });
            backgroundStack.add_actor(_eventBlocker);
            imports.ui.main.uiGroup.add_actor(this);
        }
        open() {
            this._lightbox.lightOn();
            this.show();
        }
        close() {
            this._lightbox.lightOff();
            this.hide();
        }
        destroy() {
            super.destroy();
        }
    };
    MonitorBox.metaInfo = {
        GTypeName: 'MonitorBox',
        Signals: {
            hide: {},
        },
    };
    MonitorBox = __decorate([
        registerGObjectClass
    ], MonitorBox);

    const global$1 = shell0.Global.get();
    const debug$5 = logger('clipboard-manager');
    const MimeType = {
        TEXT: ['text/plain', 'text/plain;charset=utf-8', 'UTF8_STRING'],
        IMAGE: ['image/png'],
        GNOME_FILE: ['x-special/gnome-copied-files'],
        SENSITIVE: ['x-kde-passwordManagerHint'],
    };
    var ContentType;
    (function (ContentType) {
        ContentType[ContentType["IMAGE"] = 0] = "IMAGE";
        ContentType[ContentType["FILE"] = 1] = "FILE";
        ContentType[ContentType["TEXT"] = 2] = "TEXT";
    })(ContentType || (ContentType = {}));
    const FileOperation = {
        CUT: 'cut',
        COPY: 'copy',
    };
    let ClipboardContent = class ClipboardContent extends gobject2.Object {
        constructor(content) {
            super();
            this.content = content;
        }
    };
    ClipboardContent.metaInfo = {
        GTypeName: 'ClipboardContent',
    };
    ClipboardContent = __decorate([
        registerGObjectClass
    ], ClipboardContent);
    const arraybufferEqual = (buf1, buf2) => {
        if (buf1 === buf2) {
            return true;
        }
        if (buf1.byteLength !== buf2.byteLength) {
            return false;
        }
        const view1 = new DataView(buf1);
        const view2 = new DataView(buf2);
        let i = buf1.byteLength;
        while (i--) {
            if (view1.getUint8(i) !== view2.getUint8(i)) {
                return false;
            }
        }
        return true;
    };
    const compareClipboardContent = (content1, content2) => {
        if (!content2) {
            return false;
        }
        if (content1.type !== content2.type) {
            return false;
        }
        if (content1.type === ContentType.TEXT) {
            return content1.value === content2.value;
        }
        if (content1.type === ContentType.IMAGE && content2.type === ContentType.IMAGE) {
            return arraybufferEqual(content1.value, content2.value);
        }
        if (content1.type === ContentType.FILE && content2.type === ContentType.FILE) {
            return (content1.value.operation === content2.value.operation &&
                content1.value.fileList.length === content2.value.fileList.length &&
                content1.value.fileList.every((file, index) => file === content2.value.fileList[index]));
        }
        return false;
    };
    let ClipboardManager = class ClipboardManager extends gobject2.Object {
        constructor() {
            super();
            this.settings = getCurrentExtensionSettings();
            this.clipboard = st1.Clipboard.get_default();
            this.selection = global$1.get_display().get_selection();
            this.lastCopiedContent = null;
        }
        startTracking() {
            this.lastCopiedContent = null;
            this.isTracking = true;
            const primaryTracker = debounce(async () => {
                const result = await this.getContent(st1.ClipboardType.PRIMARY);
                if (!result) {
                    return;
                }
                if (compareClipboardContent(result.content, this.lastCopiedContent?.content)) {
                    return;
                }
                this.lastCopiedContent = result;
                this.emit('changed', result);
            }, 500);
            this.selectionChangedId = this.selection.connect('owner-changed', async (_selection, selectionType, _selectionSource) => {
                if (this.settings.get_boolean('is-in-incognito')) {
                    return;
                }
                if (selectionType === meta10.SelectionType.SELECTION_CLIPBOARD) {
                    try {
                        const result = await this.getContent(st1.ClipboardType.CLIPBOARD);
                        if (!result) {
                            return;
                        }
                        if (compareClipboardContent(result.content, this.lastCopiedContent?.content)) {
                            return;
                        }
                        this.lastCopiedContent = result;
                        this.emit('changed', result);
                    }
                    catch (err) {
                        debug$5(`error: ${err}`);
                    }
                }
                else if (selectionType === meta10.SelectionType.SELECTION_PRIMARY) {
                    try {
                        if (this.settings.get_boolean('sync-primary')) {
                            primaryTracker();
                        }
                    }
                    catch (err) {
                        debug$5(`error: ${err}`);
                    }
                }
            });
        }
        stopTracking() {
            this.selection.disconnect(this.selectionChangedId);
            this.isTracking = false;
            this.lastCopiedContent = null;
        }
        setContent({ content }) {
            const syncPrimary = this.settings.get_boolean('sync-primary');
            if (content.type === ContentType.TEXT) {
                if (syncPrimary) {
                    this.clipboard.set_text(st1.ClipboardType.PRIMARY, content.value);
                }
                this.clipboard.set_text(st1.ClipboardType.CLIPBOARD, content.value);
            }
            else if (content.type === ContentType.IMAGE) {
                if (syncPrimary) {
                    this.clipboard.set_content(st1.ClipboardType.PRIMARY, MimeType.IMAGE[0], content.value);
                }
                this.clipboard.set_content(st1.ClipboardType.CLIPBOARD, MimeType.IMAGE[0], content.value);
            }
            else if (content.type === ContentType.FILE) {
                if (syncPrimary) {
                    this.clipboard.set_content(st1.ClipboardType.PRIMARY, MimeType.GNOME_FILE[0], new TextEncoder().encode([content.value.operation, ...content.value.fileList].join('\n')));
                }
                this.clipboard.set_content(st1.ClipboardType.CLIPBOARD, MimeType.GNOME_FILE[0], new TextEncoder().encode([content.value.operation, ...content.value.fileList].join('\n')));
            }
        }
        haveMimeType(clipboardMimeTypes, targetMimeTypes) {
            return clipboardMimeTypes.find((m) => targetMimeTypes.indexOf(m) >= 0) !== undefined;
        }
        getCurrentMimeType(clipboardMimeTypes, targetMimeTypes) {
            return clipboardMimeTypes.find((m) => targetMimeTypes.indexOf(m) >= 0);
        }
        async getContent(clipboardType) {
            return new Promise((resolve) => {
                const cbMimeTypes = this.clipboard.get_mimetypes(clipboardType);
                if (this.haveMimeType(cbMimeTypes, MimeType.SENSITIVE)) {
                    resolve(null);
                    return;
                }
                else if (this.haveMimeType(cbMimeTypes, MimeType.GNOME_FILE)) {
                    const currentMimeType = this.getCurrentMimeType(cbMimeTypes, MimeType.GNOME_FILE);
                    if (!currentMimeType) {
                        resolve(null);
                        return;
                    }
                    this.clipboard.get_content(clipboardType, currentMimeType, (_, bytes) => {
                        const data = bytes instanceof glib2.Bytes ? bytes.get_data() : bytes;
                        if (data && data.length > 0) {
                            const content = new TextDecoder().decode(data);
                            const fileContent = content.split('\n').filter((c) => !!c);
                            const hasOperation = fileContent[0] === FileOperation.CUT || fileContent[0] === FileOperation.COPY;
                            resolve(new ClipboardContent({
                                type: ContentType.FILE,
                                value: {
                                    operation: hasOperation ? fileContent[0] : FileOperation.COPY,
                                    fileList: hasOperation ? fileContent.slice(1) : fileContent,
                                },
                            }));
                            return;
                        }
                        resolve(null);
                    });
                }
                else if (this.haveMimeType(cbMimeTypes, MimeType.IMAGE)) {
                    const currentMimeType = this.getCurrentMimeType(cbMimeTypes, MimeType.IMAGE);
                    if (!currentMimeType) {
                        resolve(null);
                        return;
                    }
                    this.clipboard.get_content(clipboardType, currentMimeType, (_, bytes) => {
                        const data = bytes instanceof glib2.Bytes ? bytes.get_data() : bytes;
                        if (data && data.length > 0) {
                            resolve(new ClipboardContent({
                                type: ContentType.IMAGE,
                                value: data,
                            }));
                            return;
                        }
                        resolve(null);
                    });
                }
                else if (this.haveMimeType(cbMimeTypes, MimeType.TEXT)) {
                    this.clipboard.get_text(clipboardType, (_, text) => {
                        if (text && text.trim()) {
                            resolve(new ClipboardContent({
                                type: ContentType.TEXT,
                                value: text.trim(),
                            }));
                            return;
                        }
                        resolve(null);
                    });
                }
                else {
                    resolve(null);
                }
            });
        }
    };
    ClipboardManager.metaInfo = {
        GTypeName: 'PanoClipboardManager',
        Signals: {
            changed: {
                param_types: [ClipboardContent.$gtype],
                accumulator: 0,
            },
        },
    };
    ClipboardManager = __decorate([
        registerGObjectClass
    ], ClipboardManager);
    const clipboardManager = new ClipboardManager();

    const debug$4 = logger('database');
    class ClipboardQuery {
        constructor(statement) {
            this.statement = statement;
        }
    }
    /**
     * This is hack for libgda6 <> libgda5 compatibility.
     *
     * @param value any
     * @returns expr id
     */
    const add_expr_value = (builder, value) => {
        if (builder.add_expr_value.length === 1) {
            return builder.add_expr_value(value);
        }
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        return builder.add_expr_value(null, value);
    };
    class ClipboardQueryBuilder {
        constructor() {
            this.conditions = [];
            this.builder = new gda6.SqlBuilder({
                stmt_type: gda6.SqlStatementType.SELECT,
            });
            this.builder.select_add_field('id', 'clipboard', 'id');
            this.builder.select_add_field('itemType', 'clipboard', 'itemType');
            this.builder.select_add_field('content', 'clipboard', 'content');
            this.builder.select_add_field('copyDate', 'clipboard', 'copyDate');
            this.builder.select_add_field('isFavorite', 'clipboard', 'isFavorite');
            this.builder.select_add_field('matchValue', 'clipboard', 'matchValue');
            this.builder.select_add_field('searchValue', 'clipboard', 'searchValue');
            this.builder.select_add_field('metaData', 'clipboard', 'metaData');
            this.builder.select_order_by(this.builder.add_field_id('copyDate', 'clipboard'), false, null);
            this.builder.select_add_target('clipboard', null);
        }
        withLimit(limit, offset) {
            this.builder.select_set_limit(add_expr_value(this.builder, limit), add_expr_value(this.builder, offset));
            return this;
        }
        withId(id) {
            if (id !== null && id !== undefined) {
                this.conditions.push(this.builder.add_cond(gda6.SqlOperatorType.EQ, this.builder.add_field_id('id', 'clipboard'), add_expr_value(this.builder, id), 0));
            }
            return this;
        }
        withItemTypes(itemTypes) {
            if (itemTypes !== null && itemTypes !== undefined) {
                const orConditions = itemTypes.map((itemType) => this.builder.add_cond(gda6.SqlOperatorType.EQ, this.builder.add_field_id('itemType', 'clipboard'), add_expr_value(this.builder, itemType), 0));
                this.conditions.push(this.builder.add_cond_v(gda6.SqlOperatorType.OR, orConditions));
            }
            return this;
        }
        withContent(content) {
            if (content !== null && content !== undefined) {
                this.conditions.push(this.builder.add_cond(gda6.SqlOperatorType.EQ, this.builder.add_field_id('content', 'clipboard'), add_expr_value(this.builder, content), 0));
            }
            return this;
        }
        withMatchValue(matchValue) {
            if (matchValue !== null && matchValue !== undefined) {
                this.conditions.push(this.builder.add_cond(gda6.SqlOperatorType.EQ, this.builder.add_field_id('matchValue', 'clipboard'), add_expr_value(this.builder, matchValue), 0));
            }
            return this;
        }
        withContainingContent(content) {
            if (content !== null && content !== undefined) {
                this.conditions.push(this.builder.add_cond(gda6.SqlOperatorType.LIKE, this.builder.add_field_id('content', 'clipboard'), add_expr_value(this.builder, `%${content}%`), 0));
            }
            return this;
        }
        withContainingSearchValue(searchValue) {
            if (searchValue !== null && searchValue !== undefined) {
                this.conditions.push(this.builder.add_cond(gda6.SqlOperatorType.LIKE, this.builder.add_field_id('searchValue', 'clipboard'), add_expr_value(this.builder, `%${searchValue}%`), 0));
            }
            return this;
        }
        withFavorites(include) {
            if (include !== null && include !== undefined) {
                this.conditions.push(this.builder.add_cond(gda6.SqlOperatorType.EQ, this.builder.add_field_id('isFavorite', 'clipboard'), add_expr_value(this.builder, +include), 0));
            }
            return this;
        }
        build() {
            if (this.conditions.length > 0) {
                this.builder.set_where(this.builder.add_cond_v(gda6.SqlOperatorType.AND, this.conditions));
            }
            return new ClipboardQuery(this.builder.get_statement());
        }
    }
    class Database {
        init() {
            this.settings = getCurrentExtensionSettings();
            this.connection = new gda6.Connection({
                provider: gda6.Config.get_provider('SQLite'),
                cnc_string: `DB_DIR=${getDbPath()};DB_NAME=pano`,
            });
            this.connection.open();
        }
        setup() {
            this.init();
            if (!this.connection || !this.connection.is_opened()) {
                debug$4('connection is not opened');
                return;
            }
            this.connection.execute_non_select_command(`
      create table if not exists clipboard
      (
          id          integer not null constraint clipboard_pk primary key autoincrement,
          itemType    text not null,
          content     text not null,
          copyDate    text not null,
          isFavorite  integer not null,
          matchValue  text not null,
          searchValue text,
          metaData    text
      );
    `);
            this.connection.execute_non_select_command(`
      create unique index if not exists clipboard_id_uindex on clipboard (id);
    `);
        }
        save(dbItem) {
            if (!this.connection || !this.connection.is_opened()) {
                debug$4('connection is not opened');
                return null;
            }
            const builder = new gda6.SqlBuilder({
                stmt_type: gda6.SqlStatementType.INSERT,
            });
            builder.set_table('clipboard');
            builder.add_field_value_as_gvalue('itemType', dbItem.itemType);
            builder.add_field_value_as_gvalue('content', dbItem.content);
            builder.add_field_value_as_gvalue('copyDate', dbItem.copyDate.toISOString());
            builder.add_field_value_as_gvalue('isFavorite', +dbItem.isFavorite);
            builder.add_field_value_as_gvalue('matchValue', dbItem.matchValue);
            if (dbItem.searchValue) {
                builder.add_field_value_as_gvalue('searchValue', dbItem.searchValue);
            }
            if (dbItem.metaData) {
                builder.add_field_value_as_gvalue('metaData', dbItem.metaData);
            }
            const [_, row] = this.connection.statement_execute_non_select(builder.get_statement(), null);
            const id = row?.get_nth_holder(0).get_value();
            if (!id) {
                return null;
            }
            return {
                id,
                itemType: dbItem.itemType,
                content: dbItem.content,
                copyDate: dbItem.copyDate,
                isFavorite: dbItem.isFavorite,
                matchValue: dbItem.matchValue,
                searchValue: dbItem.searchValue,
                metaData: dbItem.metaData,
            };
        }
        update(dbItem) {
            if (!this.connection || !this.connection.is_opened()) {
                debug$4('connection is not opened');
                return null;
            }
            const builder = new gda6.SqlBuilder({
                stmt_type: gda6.SqlStatementType.UPDATE,
            });
            builder.set_table('clipboard');
            builder.add_field_value_as_gvalue('itemType', dbItem.itemType);
            builder.add_field_value_as_gvalue('content', dbItem.content);
            builder.add_field_value_as_gvalue('copyDate', dbItem.copyDate.toISOString());
            builder.add_field_value_as_gvalue('isFavorite', +dbItem.isFavorite);
            builder.add_field_value_as_gvalue('matchValue', dbItem.matchValue);
            if (dbItem.searchValue) {
                builder.add_field_value_as_gvalue('searchValue', dbItem.searchValue);
            }
            if (dbItem.metaData) {
                builder.add_field_value_as_gvalue('metaData', dbItem.metaData);
            }
            builder.set_where(builder.add_cond(gda6.SqlOperatorType.EQ, builder.add_field_id('id', 'clipboard'), add_expr_value(builder, dbItem.id), 0));
            this.connection.statement_execute_non_select(builder.get_statement(), null);
            return dbItem;
        }
        delete(id) {
            if (!this.connection || !this.connection.is_opened()) {
                debug$4('connection is not opened');
                return;
            }
            const builder = new gda6.SqlBuilder({
                stmt_type: gda6.SqlStatementType.DELETE,
            });
            builder.set_table('clipboard');
            builder.set_where(builder.add_cond(gda6.SqlOperatorType.EQ, builder.add_field_id('id', 'clipboard'), add_expr_value(builder, id), 0));
            this.connection.statement_execute_non_select(builder.get_statement(), null);
        }
        query(clipboardQuery) {
            if (!this.connection || !this.connection.is_opened()) {
                return [];
            }
            // debug(`${clipboardQuery.statement.to_sql_extended(this.connection, null, StatementSqlFlag.PRETTY)}`);
            const dm = this.connection.statement_execute_select(clipboardQuery.statement, null);
            const iter = dm.create_iter();
            const itemList = [];
            while (iter.move_next()) {
                const id = iter.get_value_for_field('id');
                const itemType = iter.get_value_for_field('itemType');
                const content = iter.get_value_for_field('content');
                const copyDate = iter.get_value_for_field('copyDate');
                const isFavorite = iter.get_value_for_field('isFavorite');
                const matchValue = iter.get_value_for_field('matchValue');
                const searchValue = iter.get_value_for_field('searchValue');
                const metaData = iter.get_value_for_field('metaData');
                itemList.push({
                    id,
                    itemType,
                    content,
                    copyDate: new Date(copyDate),
                    isFavorite: !!isFavorite,
                    matchValue,
                    searchValue,
                    metaData,
                });
            }
            return itemList;
        }
        start() {
            if (!this.connection) {
                this.init();
            }
            if (this.connection && !this.connection.is_opened()) {
                this.connection.open();
            }
        }
        shutdown() {
            if (this.connection && this.connection.is_opened()) {
                this.connection.close();
                this.connection = null;
            }
        }
    }
    const db = new Database();

    var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

    var isUrl_1 = isUrl;
    var protocolAndDomainRE = /^(?:\w+:)?\/\/(\S+)$/;
    var localhostDomainRE = /^localhost[\:?\d]*(?:[^\:?\d]\S*)?$/;
    var nonLocalhostDomainRE = /^[^\s\.]+\.\S{2,}$/;
    function isUrl(string){
      if (typeof string !== 'string') {
        return false;
      }
      var match = string.match(protocolAndDomainRE);
      if (!match) {
        return false;
      }
      var everythingAfterProtocol = match[1];
      if (!everythingAfterProtocol) {
        return false;
      }
      if (localhostDomainRE.test(everythingAfterProtocol) ||
          nonLocalhostDomainRE.test(everythingAfterProtocol)) {
        return true;
      }
      return false;
    }

    var lib$2=function(e){var r={};function n(t){if(r[t])return r[t].exports;var a=r[t]={i:t,l:!1,exports:{}};return e[t].call(a.exports,a,a.exports,n),a.l=!0,a.exports}return n.m=e,n.c=r,n.d=function(e,r,t){n.o(e,r)||Object.defineProperty(e,r,{enumerable:!0,get:t});},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0});},n.t=function(e,r){if(1&r&&(e=n(e)),8&r)return e;if(4&r&&"object"==typeof e&&e&&e.__esModule)return e;var t=Object.create(null);if(n.r(t),Object.defineProperty(t,"default",{enumerable:!0,value:e}),2&r&&"string"!=typeof e)for(var a in e)n.d(t,a,function(r){return e[r]}.bind(null,a));return t},n.n=function(e){var r=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(r,"a",r),r},n.o=function(e,r){return Object.prototype.hasOwnProperty.call(e,r)},n.p="",n(n.s=0)}([function(e,r,n){n.r(r),n.d(r,"validateHTMLColorName",(function(){return l})),n.d(r,"validateHTMLColorSpecialName",(function(){return i})),n.d(r,"validateHTMLColorHex",(function(){return u})),n.d(r,"validateHTMLColorRgb",(function(){return d})),n.d(r,"validateHTMLColorHsl",(function(){return f})),n.d(r,"validateHTMLColorHwb",(function(){return h})),n.d(r,"validateHTMLColorLab",(function(){return g})),n.d(r,"validateHTMLColor",(function(){return m}));const t=e=>e&&"string"==typeof e,a=["AliceBlue","AntiqueWhite","Aqua","Aquamarine","Azure","Beige","Bisque","Black","BlanchedAlmond","Blue","BlueViolet","Brown","BurlyWood","CadetBlue","Chartreuse","Chocolate","Coral","CornflowerBlue","Cornsilk","Crimson","Cyan","DarkBlue","DarkCyan","DarkGoldenrod","DarkGray","DarkGreen","DarkKhaki","DarkMagenta","DarkOliveGreen","DarkOrange","DarkOrchid","DarkRed","DarkSalmon","DarkSeaGreen","DarkSlateBlue","DarkSlateGray","DarkTurquoise","DarkViolet","DeepPink","DeepSkyBlue","DimGray","DodgerBlue","FireBrick","FloralWhite","ForestGreen","Fuchsia","Gainsboro","GhostWhite","Gold","Goldenrod","Gray","Green","GreenYellow","HoneyDew","HotPink","IndianRed","Indigo","Ivory","Khaki","Lavender","LavenderBlush","LawnGreen","LemonChiffon","LightBlue","LightCoral","LightCyan","LightGoldenrodYellow","LightGray","LightGreen","LightPink","LightSalmon","LightSalmon","LightSeaGreen","LightSkyBlue","LightSlateGray","LightSteelBlue","LightYellow","Lime","LimeGreen","Linen","Magenta","Maroon","MediumAquamarine","MediumBlue","MediumOrchid","MediumPurple","MediumSeaGreen","MediumSlateBlue","MediumSlateBlue","MediumSpringGreen","MediumTurquoise","MediumVioletRed","MidnightBlue","MintCream","MistyRose","Moccasin","NavajoWhite","Navy","OldLace","Olive","OliveDrab","Orange","OrangeRed","Orchid","PaleGoldenrod","PaleGreen","PaleTurquoise","PaleVioletRed","PapayaWhip","PeachPuff","Peru","Pink","Plum","PowderBlue","Purple","RebeccaPurple","Red","RosyBrown","RoyalBlue","SaddleBrown","Salmon","SandyBrown","SeaGreen","SeaShell","Sienna","Silver","SkyBlue","SlateBlue","SlateGray","Snow","SpringGreen","SteelBlue","Tan","Teal","Thistle","Tomato","Turquoise","Violet","Wheat","White","WhiteSmoke","Yellow","YellowGreen"],o=["currentColor","inherit","transparent"],l=e=>{let r=!1;return t(e)&&a.map(n=>(e.toLowerCase()===n.toLowerCase()&&(r=!0),null)),r},i=e=>{let r=!1;return t(e)&&o.map(n=>(e.toLowerCase()===n.toLowerCase()&&(r=!0),null)),r},u=e=>{if(t(e)){const r=/^#([\da-f]{3}){1,2}$|^#([\da-f]{4}){1,2}$/i;return e&&r.test(e)}},d=e=>{if(t(e)){const r=/(rgb)a?\((\s*\d+%?\s*?,?\s*){2}(\s*\d+%?\s*?,?\s*\)?)(\s*,?\s*\/?\s*(0?\.?\d+%?\s*)?|1|0)?\)$/i;return e&&r.test(e)}},s="(([0-9]|[1-9][0-9]|100)%)",c=`\\s*?\\)?)(\\s*?(\\/?)\\s+${`(((${s}))|(0?(\\.\\d+)?)|1))?`}\\s*?\\)$`,f=e=>{if(t(e)){const r=new RegExp(`(hsl)a?\\((\\s*?(${"(-?([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-9][0-9]|3[0-5][0-9]|360)(deg)?)"}|${"(([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-9][0-9]|3[0-9][0-9]|400)gra)"}|${"((([0-5])?\\.\\d+|6\\.([0-9]|1[0-9]|2[0-8])|[0-6])rad)"}|${"((0?(\\.\\d+)?|1)turn)"})((\\s*,\\s*)|(\\s+)))(\\s*?(0|${s})((\\s*,\\s*)|(\\s+)))(\\s*?(0|${s})\\s*?\\)?)(\\s*?(\\/?|,?)\\s*?(((${s}))|(0?(\\.\\d+)?)|1))?\\)$`);return e&&r.test(e)}},h=e=>{if(t(e)){const r=new RegExp(`(hwb\\(\\s*?${"(-?([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-9][0-9]|3[0-5][0-9]|360)(deg)?)"}\\s+)((0|${s})\\s+)((0|${s})${c}`);return e&&r.test(e)}},g=e=>{if(t(e)){const r="(-?(([0-9]|[1-9][0-9]|1[0-5][0-9])(\\.\\d+)??|160))",n=new RegExp(`(lab\\(\\s*?((\\d*(\\.\\d+)?)%)\\s+${r}\\s+${r}${c}`);return e&&n.test(e)}},m=e=>!!(e&&u(e)||d(e)||f(e)||h(e)||g(e));r.default=e=>!!(e&&u(e)||l(e)||i(e)||d(e)||f(e)||h(e)||g(e));}]);

    function toInteger(dirtyNumber) {
      if (dirtyNumber === null || dirtyNumber === true || dirtyNumber === false) {
        return NaN;
      }
      var number = Number(dirtyNumber);
      if (isNaN(number)) {
        return number;
      }
      return number < 0 ? Math.ceil(number) : Math.floor(number);
    }

    function requiredArgs(required, args) {
      if (args.length < required) {
        throw new TypeError(required + ' argument' + (required > 1 ? 's' : '') + ' required, but only ' + args.length + ' present');
      }
    }

    function toDate(argument) {
      requiredArgs(1, arguments);
      var argStr = Object.prototype.toString.call(argument);
      if (argument instanceof Date || typeof argument === 'object' && argStr === '[object Date]') {
        return new Date(argument.getTime());
      } else if (typeof argument === 'number' || argStr === '[object Number]') {
        return new Date(argument);
      } else {
        if ((typeof argument === 'string' || argStr === '[object String]') && typeof console !== 'undefined') {
          console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#string-arguments");
          console.warn(new Error().stack);
        }
        return new Date(NaN);
      }
    }

    var defaultOptions = {};
    function getDefaultOptions() {
      return defaultOptions;
    }

    function getTimezoneOffsetInMilliseconds(date) {
      var utcDate = new Date(Date.UTC(date.getFullYear(), date.getMonth(), date.getDate(), date.getHours(), date.getMinutes(), date.getSeconds(), date.getMilliseconds()));
      utcDate.setUTCFullYear(date.getFullYear());
      return date.getTime() - utcDate.getTime();
    }

    function compareAsc(dirtyDateLeft, dirtyDateRight) {
      requiredArgs(2, arguments);
      var dateLeft = toDate(dirtyDateLeft);
      var dateRight = toDate(dirtyDateRight);
      var diff = dateLeft.getTime() - dateRight.getTime();
      if (diff < 0) {
        return -1;
      } else if (diff > 0) {
        return 1;
      } else {
        return diff;
      }
    }

    var millisecondsInMinute = 60000;
    var millisecondsInHour = 3600000;
    var millisecondsInSecond = 1000;

    function differenceInCalendarMonths(dirtyDateLeft, dirtyDateRight) {
      requiredArgs(2, arguments);
      var dateLeft = toDate(dirtyDateLeft);
      var dateRight = toDate(dirtyDateRight);
      var yearDiff = dateLeft.getFullYear() - dateRight.getFullYear();
      var monthDiff = dateLeft.getMonth() - dateRight.getMonth();
      return yearDiff * 12 + monthDiff;
    }

    function differenceInMilliseconds(dateLeft, dateRight) {
      requiredArgs(2, arguments);
      return toDate(dateLeft).getTime() - toDate(dateRight).getTime();
    }

    var roundingMap = {
      ceil: Math.ceil,
      round: Math.round,
      floor: Math.floor,
      trunc: function (value) {
        return value < 0 ? Math.ceil(value) : Math.floor(value);
      }
    };
    var defaultRoundingMethod = 'trunc';
    function getRoundingMethod(method) {
      return method ? roundingMap[method] : roundingMap[defaultRoundingMethod];
    }

    function endOfDay(dirtyDate) {
      requiredArgs(1, arguments);
      var date = toDate(dirtyDate);
      date.setHours(23, 59, 59, 999);
      return date;
    }

    function endOfMonth(dirtyDate) {
      requiredArgs(1, arguments);
      var date = toDate(dirtyDate);
      var month = date.getMonth();
      date.setFullYear(date.getFullYear(), month + 1, 0);
      date.setHours(23, 59, 59, 999);
      return date;
    }

    function isLastDayOfMonth(dirtyDate) {
      requiredArgs(1, arguments);
      var date = toDate(dirtyDate);
      return endOfDay(date).getTime() === endOfMonth(date).getTime();
    }

    function differenceInMonths(dirtyDateLeft, dirtyDateRight) {
      requiredArgs(2, arguments);
      var dateLeft = toDate(dirtyDateLeft);
      var dateRight = toDate(dirtyDateRight);
      var sign = compareAsc(dateLeft, dateRight);
      var difference = Math.abs(differenceInCalendarMonths(dateLeft, dateRight));
      var result;
      if (difference < 1) {
        result = 0;
      } else {
        if (dateLeft.getMonth() === 1 && dateLeft.getDate() > 27) {
          dateLeft.setDate(30);
        }
        dateLeft.setMonth(dateLeft.getMonth() - sign * difference);
        var isLastMonthNotFull = compareAsc(dateLeft, dateRight) === -sign;
        if (isLastDayOfMonth(toDate(dirtyDateLeft)) && difference === 1 && compareAsc(dirtyDateLeft, dateRight) === 1) {
          isLastMonthNotFull = false;
        }
        result = sign * (difference - Number(isLastMonthNotFull));
      }
      return result === 0 ? 0 : result;
    }

    function differenceInSeconds(dateLeft, dateRight, options) {
      requiredArgs(2, arguments);
      var diff = differenceInMilliseconds(dateLeft, dateRight) / 1000;
      return getRoundingMethod(options === null || options === void 0 ? void 0 : options.roundingMethod)(diff);
    }

    function startOfUTCISOWeek(dirtyDate) {
      requiredArgs(1, arguments);
      var weekStartsOn = 1;
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
      date.setUTCDate(date.getUTCDate() - diff);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    }

    function getUTCISOWeekYear(dirtyDate) {
      requiredArgs(1, arguments);
      var date = toDate(dirtyDate);
      var year = date.getUTCFullYear();
      var fourthOfJanuaryOfNextYear = new Date(0);
      fourthOfJanuaryOfNextYear.setUTCFullYear(year + 1, 0, 4);
      fourthOfJanuaryOfNextYear.setUTCHours(0, 0, 0, 0);
      var startOfNextYear = startOfUTCISOWeek(fourthOfJanuaryOfNextYear);
      var fourthOfJanuaryOfThisYear = new Date(0);
      fourthOfJanuaryOfThisYear.setUTCFullYear(year, 0, 4);
      fourthOfJanuaryOfThisYear.setUTCHours(0, 0, 0, 0);
      var startOfThisYear = startOfUTCISOWeek(fourthOfJanuaryOfThisYear);
      if (date.getTime() >= startOfNextYear.getTime()) {
        return year + 1;
      } else if (date.getTime() >= startOfThisYear.getTime()) {
        return year;
      } else {
        return year - 1;
      }
    }

    function startOfUTCISOWeekYear(dirtyDate) {
      requiredArgs(1, arguments);
      var year = getUTCISOWeekYear(dirtyDate);
      var fourthOfJanuary = new Date(0);
      fourthOfJanuary.setUTCFullYear(year, 0, 4);
      fourthOfJanuary.setUTCHours(0, 0, 0, 0);
      var date = startOfUTCISOWeek(fourthOfJanuary);
      return date;
    }

    var MILLISECONDS_IN_WEEK$1 = 604800000;
    function getUTCISOWeek(dirtyDate) {
      requiredArgs(1, arguments);
      var date = toDate(dirtyDate);
      var diff = startOfUTCISOWeek(date).getTime() - startOfUTCISOWeekYear(date).getTime();
      return Math.round(diff / MILLISECONDS_IN_WEEK$1) + 1;
    }

    function startOfUTCWeek(dirtyDate, options) {
      var _ref, _ref2, _ref3, _options$weekStartsOn, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;
      requiredArgs(1, arguments);
      var defaultOptions = getDefaultOptions();
      var weekStartsOn = toInteger((_ref = (_ref2 = (_ref3 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.weekStartsOn) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.weekStartsOn) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.weekStartsOn) !== null && _ref !== void 0 ? _ref : 0);
      if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
        throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
      }
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
      date.setUTCDate(date.getUTCDate() - diff);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    }

    function getUTCWeekYear(dirtyDate, options) {
      var _ref, _ref2, _ref3, _options$firstWeekCon, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;
      requiredArgs(1, arguments);
      var date = toDate(dirtyDate);
      var year = date.getUTCFullYear();
      var defaultOptions = getDefaultOptions();
      var firstWeekContainsDate = toInteger((_ref = (_ref2 = (_ref3 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref !== void 0 ? _ref : 1);
      if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
        throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
      }
      var firstWeekOfNextYear = new Date(0);
      firstWeekOfNextYear.setUTCFullYear(year + 1, 0, firstWeekContainsDate);
      firstWeekOfNextYear.setUTCHours(0, 0, 0, 0);
      var startOfNextYear = startOfUTCWeek(firstWeekOfNextYear, options);
      var firstWeekOfThisYear = new Date(0);
      firstWeekOfThisYear.setUTCFullYear(year, 0, firstWeekContainsDate);
      firstWeekOfThisYear.setUTCHours(0, 0, 0, 0);
      var startOfThisYear = startOfUTCWeek(firstWeekOfThisYear, options);
      if (date.getTime() >= startOfNextYear.getTime()) {
        return year + 1;
      } else if (date.getTime() >= startOfThisYear.getTime()) {
        return year;
      } else {
        return year - 1;
      }
    }

    function startOfUTCWeekYear(dirtyDate, options) {
      var _ref, _ref2, _ref3, _options$firstWeekCon, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;
      requiredArgs(1, arguments);
      var defaultOptions = getDefaultOptions();
      var firstWeekContainsDate = toInteger((_ref = (_ref2 = (_ref3 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref !== void 0 ? _ref : 1);
      var year = getUTCWeekYear(dirtyDate, options);
      var firstWeek = new Date(0);
      firstWeek.setUTCFullYear(year, 0, firstWeekContainsDate);
      firstWeek.setUTCHours(0, 0, 0, 0);
      var date = startOfUTCWeek(firstWeek, options);
      return date;
    }

    var MILLISECONDS_IN_WEEK = 604800000;
    function getUTCWeek(dirtyDate, options) {
      requiredArgs(1, arguments);
      var date = toDate(dirtyDate);
      var diff = startOfUTCWeek(date, options).getTime() - startOfUTCWeekYear(date, options).getTime();
      return Math.round(diff / MILLISECONDS_IN_WEEK) + 1;
    }

    var formatDistanceLocale$1h = {
      lessThanXSeconds: {
        one: 'less than a second',
        other: 'less than {{count}} seconds'
      },
      xSeconds: {
        one: '1 second',
        other: '{{count}} seconds'
      },
      halfAMinute: 'half a minute',
      lessThanXMinutes: {
        one: 'less than a minute',
        other: 'less than {{count}} minutes'
      },
      xMinutes: {
        one: '1 minute',
        other: '{{count}} minutes'
      },
      aboutXHours: {
        one: 'about 1 hour',
        other: 'about {{count}} hours'
      },
      xHours: {
        one: '1 hour',
        other: '{{count}} hours'
      },
      xDays: {
        one: '1 day',
        other: '{{count}} days'
      },
      aboutXWeeks: {
        one: 'about 1 week',
        other: 'about {{count}} weeks'
      },
      xWeeks: {
        one: '1 week',
        other: '{{count}} weeks'
      },
      aboutXMonths: {
        one: 'about 1 month',
        other: 'about {{count}} months'
      },
      xMonths: {
        one: '1 month',
        other: '{{count}} months'
      },
      aboutXYears: {
        one: 'about 1 year',
        other: 'about {{count}} years'
      },
      xYears: {
        one: '1 year',
        other: '{{count}} years'
      },
      overXYears: {
        one: 'over 1 year',
        other: 'over {{count}} years'
      },
      almostXYears: {
        one: 'almost 1 year',
        other: 'almost {{count}} years'
      }
    };
    var formatDistance$1j = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$1h[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'in ' + result;
        } else {
          return result + ' ago';
        }
      }
      return result;
    };

    function buildFormatLongFn(args) {
      return function () {
        var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
        var width = options.width ? String(options.width) : args.defaultWidth;
        var format = args.formats[width] || args.formats[args.defaultWidth];
        return format;
      };
    }

    var dateFormats$1q = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$1q = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$1q = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1q = {
      date: buildFormatLongFn({
        formats: dateFormats$1q,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1q,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1q,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1i = {
      lastWeek: "'last' eeee 'at' p",
      yesterday: "'yesterday at' p",
      today: "'today at' p",
      tomorrow: "'tomorrow at' p",
      nextWeek: "eeee 'at' p",
      other: 'P'
    };
    var formatRelative$1i = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1i[token];
    };

    function buildLocalizeFn(args) {
      return function (dirtyIndex, options) {
        var context = options !== null && options !== void 0 && options.context ? String(options.context) : 'standalone';
        var valuesArray;
        if (context === 'formatting' && args.formattingValues) {
          var defaultWidth = args.defaultFormattingWidth || args.defaultWidth;
          var width = options !== null && options !== void 0 && options.width ? String(options.width) : defaultWidth;
          valuesArray = args.formattingValues[width] || args.formattingValues[defaultWidth];
        } else {
          var _defaultWidth = args.defaultWidth;
          var _width = options !== null && options !== void 0 && options.width ? String(options.width) : args.defaultWidth;
          valuesArray = args.values[_width] || args.values[_defaultWidth];
        }
        var index = args.argumentCallback ? args.argumentCallback(dirtyIndex) : dirtyIndex;
        return valuesArray[index];
      };
    }

    var eraValues$1i = {
      narrow: ['B', 'A'],
      abbreviated: ['BC', 'AD'],
      wide: ['Before Christ', 'Anno Domini']
    };
    var quarterValues$1i = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1st quarter', '2nd quarter', '3rd quarter', '4th quarter']
    };
    var monthValues$1i = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      wide: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
    };
    var dayValues$1i = {
      narrow: ['S', 'M', 'T', 'W', 'T', 'F', 'S'],
      short: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
      abbreviated: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      wide: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']
    };
    var dayPeriodValues$1i = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mi',
        noon: 'n',
        morning: 'morning',
        afternoon: 'afternoon',
        evening: 'evening',
        night: 'night'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'morning',
        afternoon: 'afternoon',
        evening: 'evening',
        night: 'night'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'morning',
        afternoon: 'afternoon',
        evening: 'evening',
        night: 'night'
      }
    };
    var formattingDayPeriodValues$13 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mi',
        noon: 'n',
        morning: 'in the morning',
        afternoon: 'in the afternoon',
        evening: 'in the evening',
        night: 'at night'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'in the morning',
        afternoon: 'in the afternoon',
        evening: 'in the evening',
        night: 'at night'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'in the morning',
        afternoon: 'in the afternoon',
        evening: 'in the evening',
        night: 'at night'
      }
    };
    var ordinalNumber$1i = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      var rem100 = number % 100;
      if (rem100 > 20 || rem100 < 10) {
        switch (rem100 % 10) {
          case 1:
            return number + 'st';
          case 2:
            return number + 'nd';
          case 3:
            return number + 'rd';
        }
      }
      return number + 'th';
    };
    var localize$1i = {
      ordinalNumber: ordinalNumber$1i,
      era: buildLocalizeFn({
        values: eraValues$1i,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1i,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1i,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1i,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1i,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$13,
        defaultFormattingWidth: 'wide'
      })
    };

    function buildMatchFn(args) {
      return function (string) {
        var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
        var width = options.width;
        var matchPattern = width && args.matchPatterns[width] || args.matchPatterns[args.defaultMatchWidth];
        var matchResult = string.match(matchPattern);
        if (!matchResult) {
          return null;
        }
        var matchedString = matchResult[0];
        var parsePatterns = width && args.parsePatterns[width] || args.parsePatterns[args.defaultParseWidth];
        var key = Array.isArray(parsePatterns) ? findIndex(parsePatterns, function (pattern) {
          return pattern.test(matchedString);
        }) : findKey(parsePatterns, function (pattern) {
          return pattern.test(matchedString);
        });
        var value;
        value = args.valueCallback ? args.valueCallback(key) : key;
        value = options.valueCallback ? options.valueCallback(value) : value;
        var rest = string.slice(matchedString.length);
        return {
          value: value,
          rest: rest
        };
      };
    }
    function findKey(object, predicate) {
      for (var key in object) {
        if (object.hasOwnProperty(key) && predicate(object[key])) {
          return key;
        }
      }
      return undefined;
    }
    function findIndex(array, predicate) {
      for (var key = 0; key < array.length; key++) {
        if (predicate(array[key])) {
          return key;
        }
      }
      return undefined;
    }

    function buildMatchPatternFn(args) {
      return function (string) {
        var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
        var matchResult = string.match(args.matchPattern);
        if (!matchResult) return null;
        var matchedString = matchResult[0];
        var parseResult = string.match(args.parsePattern);
        if (!parseResult) return null;
        var value = args.valueCallback ? args.valueCallback(parseResult[0]) : parseResult[0];
        value = options.valueCallback ? options.valueCallback(value) : value;
        var rest = string.slice(matchedString.length);
        return {
          value: value,
          rest: rest
        };
      };
    }

    var matchOrdinalNumberPattern$1h = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$1h = /\d+/i;
    var matchEraPatterns$1h = {
      narrow: /^(b|a)/i,
      abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
      wide: /^(before christ|before common era|anno domini|common era)/i
    };
    var parseEraPatterns$1h = {
      any: [/^b/i, /^(a|c)/i]
    };
    var matchQuarterPatterns$1h = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](th|st|nd|rd)? quarter/i
    };
    var parseQuarterPatterns$1h = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1h = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,
      wide: /^(january|february|march|april|may|june|july|august|september|october|november|december)/i
    };
    var parseMonthPatterns$1h = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^may/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$1h = {
      narrow: /^[smtwf]/i,
      short: /^(su|mo|tu|we|th|fr|sa)/i,
      abbreviated: /^(sun|mon|tue|wed|thu|fri|sat)/i,
      wide: /^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i
    };
    var parseDayPatterns$1h = {
      narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
      any: [/^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$1h = {
      narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
      any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
    };
    var parseDayPeriodPatterns$1h = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mi/i,
        noon: /^no/i,
        morning: /morning/i,
        afternoon: /afternoon/i,
        evening: /evening/i,
        night: /night/i
      }
    };
    var match$1h = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1h,
        parsePattern: parseOrdinalNumberPattern$1h,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1h,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1h,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1h,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1h,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1h,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1h,
        defaultParseWidth: 'any'
      })
    };

    var locale$1s = {
      code: 'en-US',
      formatDistance: formatDistance$1j,
      formatLong: formatLong$1q,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    function assign(target, object) {
      if (target == null) {
        throw new TypeError('assign requires that input parameter not be null or undefined');
      }
      for (var property in object) {
        if (Object.prototype.hasOwnProperty.call(object, property)) {
          target[property] = object[property];
        }
      }
      return target;
    }

    function cloneObject(object) {
      return assign({}, object);
    }

    var MINUTES_IN_DAY = 1440;
    var MINUTES_IN_ALMOST_TWO_DAYS = 2520;
    var MINUTES_IN_MONTH = 43200;
    var MINUTES_IN_TWO_MONTHS = 86400;
    function formatDistance$1i(dirtyDate, dirtyBaseDate, options) {
      var _ref, _options$locale;
      requiredArgs(2, arguments);
      var defaultOptions = getDefaultOptions();
      var locale = (_ref = (_options$locale = options === null || options === void 0 ? void 0 : options.locale) !== null && _options$locale !== void 0 ? _options$locale : defaultOptions.locale) !== null && _ref !== void 0 ? _ref : locale$1s;
      if (!locale.formatDistance) {
        throw new RangeError('locale must contain formatDistance property');
      }
      var comparison = compareAsc(dirtyDate, dirtyBaseDate);
      if (isNaN(comparison)) {
        throw new RangeError('Invalid time value');
      }
      var localizeOptions = assign(cloneObject(options), {
        addSuffix: Boolean(options === null || options === void 0 ? void 0 : options.addSuffix),
        comparison: comparison
      });
      var dateLeft;
      var dateRight;
      if (comparison > 0) {
        dateLeft = toDate(dirtyBaseDate);
        dateRight = toDate(dirtyDate);
      } else {
        dateLeft = toDate(dirtyDate);
        dateRight = toDate(dirtyBaseDate);
      }
      var seconds = differenceInSeconds(dateRight, dateLeft);
      var offsetInSeconds = (getTimezoneOffsetInMilliseconds(dateRight) - getTimezoneOffsetInMilliseconds(dateLeft)) / 1000;
      var minutes = Math.round((seconds - offsetInSeconds) / 60);
      var months;
      if (minutes < 2) {
        if (options !== null && options !== void 0 && options.includeSeconds) {
          if (seconds < 5) {
            return locale.formatDistance('lessThanXSeconds', 5, localizeOptions);
          } else if (seconds < 10) {
            return locale.formatDistance('lessThanXSeconds', 10, localizeOptions);
          } else if (seconds < 20) {
            return locale.formatDistance('lessThanXSeconds', 20, localizeOptions);
          } else if (seconds < 40) {
            return locale.formatDistance('halfAMinute', 0, localizeOptions);
          } else if (seconds < 60) {
            return locale.formatDistance('lessThanXMinutes', 1, localizeOptions);
          } else {
            return locale.formatDistance('xMinutes', 1, localizeOptions);
          }
        } else {
          if (minutes === 0) {
            return locale.formatDistance('lessThanXMinutes', 1, localizeOptions);
          } else {
            return locale.formatDistance('xMinutes', minutes, localizeOptions);
          }
        }
      } else if (minutes < 45) {
        return locale.formatDistance('xMinutes', minutes, localizeOptions);
      } else if (minutes < 90) {
        return locale.formatDistance('aboutXHours', 1, localizeOptions);
      } else if (minutes < MINUTES_IN_DAY) {
        var hours = Math.round(minutes / 60);
        return locale.formatDistance('aboutXHours', hours, localizeOptions);
      } else if (minutes < MINUTES_IN_ALMOST_TWO_DAYS) {
        return locale.formatDistance('xDays', 1, localizeOptions);
      } else if (minutes < MINUTES_IN_MONTH) {
        var days = Math.round(minutes / MINUTES_IN_DAY);
        return locale.formatDistance('xDays', days, localizeOptions);
      } else if (minutes < MINUTES_IN_TWO_MONTHS) {
        months = Math.round(minutes / MINUTES_IN_MONTH);
        return locale.formatDistance('aboutXMonths', months, localizeOptions);
      }
      months = differenceInMonths(dateRight, dateLeft);
      if (months < 12) {
        var nearestMonth = Math.round(minutes / MINUTES_IN_MONTH);
        return locale.formatDistance('xMonths', nearestMonth, localizeOptions);
      } else {
        var monthsSinceStartOfYear = months % 12;
        var years = Math.floor(months / 12);
        if (monthsSinceStartOfYear < 3) {
          return locale.formatDistance('aboutXYears', years, localizeOptions);
        } else if (monthsSinceStartOfYear < 9) {
          return locale.formatDistance('overXYears', years, localizeOptions);
        } else {
          return locale.formatDistance('almostXYears', years + 1, localizeOptions);
        }
      }
    }

    function formatDistanceToNow(dirtyDate, options) {
      requiredArgs(1, arguments);
      return formatDistance$1i(dirtyDate, Date.now(), options);
    }

    function _defineProperty$w(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class Setter {
      constructor() {
        _defineProperty$w(this, "priority", void 0);
        _defineProperty$w(this, "subPriority", 0);
      }
      validate(_utcDate, _options) {
        return true;
      }
    }
    class ValueSetter extends Setter {
      constructor(value, validateValue, setValue, priority, subPriority) {
        super();
        this.value = value;
        this.validateValue = validateValue;
        this.setValue = setValue;
        this.priority = priority;
        if (subPriority) {
          this.subPriority = subPriority;
        }
      }
      validate(utcDate, options) {
        return this.validateValue(utcDate, this.value, options);
      }
      set(utcDate, flags, options) {
        return this.setValue(utcDate, flags, this.value, options);
      }
    }

    function _defineProperty$v(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class Parser$1 {
      constructor() {
        _defineProperty$v(this, "incompatibleTokens", void 0);
        _defineProperty$v(this, "priority", void 0);
        _defineProperty$v(this, "subPriority", void 0);
      }
      run(dateString, token, match, options) {
        var result = this.parse(dateString, token, match, options);
        if (!result) {
          return null;
        }
        return {
          setter: new ValueSetter(result.value, this.validate, this.set, this.priority, this.subPriority),
          rest: result.rest
        };
      }
      validate(_utcDate, _value, _options) {
        return true;
      }
    }

    function _defineProperty$u(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class EraParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$u(this, "priority", 140);
        _defineProperty$u(this, "incompatibleTokens", ['R', 'u', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'G':
          case 'GG':
          case 'GGG':
            return match.era(dateString, {
              width: 'abbreviated'
            }) || match.era(dateString, {
              width: 'narrow'
            });
          case 'GGGGG':
            return match.era(dateString, {
              width: 'narrow'
            });
          case 'GGGG':
          default:
            return match.era(dateString, {
              width: 'wide'
            }) || match.era(dateString, {
              width: 'abbreviated'
            }) || match.era(dateString, {
              width: 'narrow'
            });
        }
      }
      set(date, flags, value) {
        flags.era = value;
        date.setUTCFullYear(value, 0, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    var numericPatterns = {
      month: /^(1[0-2]|0?\d)/,
      date: /^(3[0-1]|[0-2]?\d)/,
      dayOfYear: /^(36[0-6]|3[0-5]\d|[0-2]?\d?\d)/,
      week: /^(5[0-3]|[0-4]?\d)/,
      hour23h: /^(2[0-3]|[0-1]?\d)/,
      hour24h: /^(2[0-4]|[0-1]?\d)/,
      hour11h: /^(1[0-1]|0?\d)/,
      hour12h: /^(1[0-2]|0?\d)/,
      minute: /^[0-5]?\d/,
      second: /^[0-5]?\d/,
      singleDigit: /^\d/,
      twoDigits: /^\d{1,2}/,
      threeDigits: /^\d{1,3}/,
      fourDigits: /^\d{1,4}/,
      anyDigitsSigned: /^-?\d+/,
      singleDigitSigned: /^-?\d/,
      twoDigitsSigned: /^-?\d{1,2}/,
      threeDigitsSigned: /^-?\d{1,3}/,
      fourDigitsSigned: /^-?\d{1,4}/
    };
    var timezonePatterns = {
      basicOptionalMinutes: /^([+-])(\d{2})(\d{2})?|Z/,
      basic: /^([+-])(\d{2})(\d{2})|Z/,
      basicOptionalSeconds: /^([+-])(\d{2})(\d{2})((\d{2}))?|Z/,
      extended: /^([+-])(\d{2}):(\d{2})|Z/,
      extendedOptionalSeconds: /^([+-])(\d{2}):(\d{2})(:(\d{2}))?|Z/
    };

    function mapValue(parseFnResult, mapFn) {
      if (!parseFnResult) {
        return parseFnResult;
      }
      return {
        value: mapFn(parseFnResult.value),
        rest: parseFnResult.rest
      };
    }
    function parseNumericPattern(pattern, dateString) {
      var matchResult = dateString.match(pattern);
      if (!matchResult) {
        return null;
      }
      return {
        value: parseInt(matchResult[0], 10),
        rest: dateString.slice(matchResult[0].length)
      };
    }
    function parseTimezonePattern(pattern, dateString) {
      var matchResult = dateString.match(pattern);
      if (!matchResult) {
        return null;
      }
      if (matchResult[0] === 'Z') {
        return {
          value: 0,
          rest: dateString.slice(1)
        };
      }
      var sign = matchResult[1] === '+' ? 1 : -1;
      var hours = matchResult[2] ? parseInt(matchResult[2], 10) : 0;
      var minutes = matchResult[3] ? parseInt(matchResult[3], 10) : 0;
      var seconds = matchResult[5] ? parseInt(matchResult[5], 10) : 0;
      return {
        value: sign * (hours * millisecondsInHour + minutes * millisecondsInMinute + seconds * millisecondsInSecond),
        rest: dateString.slice(matchResult[0].length)
      };
    }
    function parseAnyDigitsSigned(dateString) {
      return parseNumericPattern(numericPatterns.anyDigitsSigned, dateString);
    }
    function parseNDigits(n, dateString) {
      switch (n) {
        case 1:
          return parseNumericPattern(numericPatterns.singleDigit, dateString);
        case 2:
          return parseNumericPattern(numericPatterns.twoDigits, dateString);
        case 3:
          return parseNumericPattern(numericPatterns.threeDigits, dateString);
        case 4:
          return parseNumericPattern(numericPatterns.fourDigits, dateString);
        default:
          return parseNumericPattern(new RegExp('^\\d{1,' + n + '}'), dateString);
      }
    }
    function parseNDigitsSigned(n, dateString) {
      switch (n) {
        case 1:
          return parseNumericPattern(numericPatterns.singleDigitSigned, dateString);
        case 2:
          return parseNumericPattern(numericPatterns.twoDigitsSigned, dateString);
        case 3:
          return parseNumericPattern(numericPatterns.threeDigitsSigned, dateString);
        case 4:
          return parseNumericPattern(numericPatterns.fourDigitsSigned, dateString);
        default:
          return parseNumericPattern(new RegExp('^-?\\d{1,' + n + '}'), dateString);
      }
    }
    function dayPeriodEnumToHours(dayPeriod) {
      switch (dayPeriod) {
        case 'morning':
          return 4;
        case 'evening':
          return 17;
        case 'pm':
        case 'noon':
        case 'afternoon':
          return 12;
        case 'am':
        case 'midnight':
        case 'night':
        default:
          return 0;
      }
    }
    function normalizeTwoDigitYear(twoDigitYear, currentYear) {
      var isCommonEra = currentYear > 0;
      var absCurrentYear = isCommonEra ? currentYear : 1 - currentYear;
      var result;
      if (absCurrentYear <= 50) {
        result = twoDigitYear || 100;
      } else {
        var rangeEnd = absCurrentYear + 50;
        var rangeEndCentury = Math.floor(rangeEnd / 100) * 100;
        var isPreviousCentury = twoDigitYear >= rangeEnd % 100;
        result = twoDigitYear + rangeEndCentury - (isPreviousCentury ? 100 : 0);
      }
      return isCommonEra ? result : 1 - result;
    }
    function isLeapYearIndex(year) {
      return year % 400 === 0 || year % 4 === 0 && year % 100 !== 0;
    }

    function _defineProperty$t(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class YearParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$t(this, "priority", 130);
        _defineProperty$t(this, "incompatibleTokens", ['Y', 'R', 'u', 'w', 'I', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        var valueCallback = function (year) {
          return {
            year: year,
            isTwoDigitYear: token === 'yy'
          };
        };
        switch (token) {
          case 'y':
            return mapValue(parseNDigits(4, dateString), valueCallback);
          case 'yo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'year'
            }), valueCallback);
          default:
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
        }
      }
      validate(_date, value) {
        return value.isTwoDigitYear || value.year > 0;
      }
      set(date, flags, value) {
        var currentYear = date.getUTCFullYear();
        if (value.isTwoDigitYear) {
          var normalizedTwoDigitYear = normalizeTwoDigitYear(value.year, currentYear);
          date.setUTCFullYear(normalizedTwoDigitYear, 0, 1);
          date.setUTCHours(0, 0, 0, 0);
          return date;
        }
        var year = !('era' in flags) || flags.era === 1 ? value.year : 1 - value.year;
        date.setUTCFullYear(year, 0, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$s(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class LocalWeekYearParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$s(this, "priority", 130);
        _defineProperty$s(this, "incompatibleTokens", ['y', 'R', 'u', 'Q', 'q', 'M', 'L', 'I', 'd', 'D', 'i', 't', 'T']);
      }
      parse(dateString, token, match) {
        var valueCallback = function (year) {
          return {
            year: year,
            isTwoDigitYear: token === 'YY'
          };
        };
        switch (token) {
          case 'Y':
            return mapValue(parseNDigits(4, dateString), valueCallback);
          case 'Yo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'year'
            }), valueCallback);
          default:
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
        }
      }
      validate(_date, value) {
        return value.isTwoDigitYear || value.year > 0;
      }
      set(date, flags, value, options) {
        var currentYear = getUTCWeekYear(date, options);
        if (value.isTwoDigitYear) {
          var normalizedTwoDigitYear = normalizeTwoDigitYear(value.year, currentYear);
          date.setUTCFullYear(normalizedTwoDigitYear, 0, options.firstWeekContainsDate);
          date.setUTCHours(0, 0, 0, 0);
          return startOfUTCWeek(date, options);
        }
        var year = !('era' in flags) || flags.era === 1 ? value.year : 1 - value.year;
        date.setUTCFullYear(year, 0, options.firstWeekContainsDate);
        date.setUTCHours(0, 0, 0, 0);
        return startOfUTCWeek(date, options);
      }
    }

    function _defineProperty$r(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class ISOWeekYearParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$r(this, "priority", 130);
        _defineProperty$r(this, "incompatibleTokens", ['G', 'y', 'Y', 'u', 'Q', 'q', 'M', 'L', 'w', 'd', 'D', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token) {
        if (token === 'R') {
          return parseNDigitsSigned(4, dateString);
        }
        return parseNDigitsSigned(token.length, dateString);
      }
      set(_date, _flags, value) {
        var firstWeekOfYear = new Date(0);
        firstWeekOfYear.setUTCFullYear(value, 0, 4);
        firstWeekOfYear.setUTCHours(0, 0, 0, 0);
        return startOfUTCISOWeek(firstWeekOfYear);
      }
    }

    function _defineProperty$q(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class ExtendedYearParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$q(this, "priority", 130);
        _defineProperty$q(this, "incompatibleTokens", ['G', 'y', 'Y', 'R', 'w', 'I', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token) {
        if (token === 'u') {
          return parseNDigitsSigned(4, dateString);
        }
        return parseNDigitsSigned(token.length, dateString);
      }
      set(date, _flags, value) {
        date.setUTCFullYear(value, 0, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$p(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class QuarterParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$p(this, "priority", 120);
        _defineProperty$p(this, "incompatibleTokens", ['Y', 'R', 'q', 'M', 'L', 'w', 'I', 'd', 'D', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'Q':
          case 'QQ':
            return parseNDigits(token.length, dateString);
          case 'Qo':
            return match.ordinalNumber(dateString, {
              unit: 'quarter'
            });
          case 'QQQ':
            return match.quarter(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'QQQQQ':
            return match.quarter(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'QQQQ':
          default:
            return match.quarter(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.quarter(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }
      validate(_date, value) {
        return value >= 1 && value <= 4;
      }
      set(date, _flags, value) {
        date.setUTCMonth((value - 1) * 3, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$o(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class StandAloneQuarterParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$o(this, "priority", 120);
        _defineProperty$o(this, "incompatibleTokens", ['Y', 'R', 'Q', 'M', 'L', 'w', 'I', 'd', 'D', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'q':
          case 'qq':
            return parseNDigits(token.length, dateString);
          case 'qo':
            return match.ordinalNumber(dateString, {
              unit: 'quarter'
            });
          case 'qqq':
            return match.quarter(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          case 'qqqqq':
            return match.quarter(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          case 'qqqq':
          default:
            return match.quarter(dateString, {
              width: 'wide',
              context: 'standalone'
            }) || match.quarter(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
        }
      }
      validate(_date, value) {
        return value >= 1 && value <= 4;
      }
      set(date, _flags, value) {
        date.setUTCMonth((value - 1) * 3, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$n(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class MonthParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$n(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'L', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']);
        _defineProperty$n(this, "priority", 110);
      }
      parse(dateString, token, match) {
        var valueCallback = function (value) {
          return value - 1;
        };
        switch (token) {
          case 'M':
            return mapValue(parseNumericPattern(numericPatterns.month, dateString), valueCallback);
          case 'MM':
            return mapValue(parseNDigits(2, dateString), valueCallback);
          case 'Mo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'month'
            }), valueCallback);
          case 'MMM':
            return match.month(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'MMMMM':
            return match.month(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'MMMM':
          default:
            return match.month(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.month(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 11;
      }
      set(date, _flags, value) {
        date.setUTCMonth(value, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$m(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class StandAloneMonthParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$m(this, "priority", 110);
        _defineProperty$m(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'M', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        var valueCallback = function (value) {
          return value - 1;
        };
        switch (token) {
          case 'L':
            return mapValue(parseNumericPattern(numericPatterns.month, dateString), valueCallback);
          case 'LL':
            return mapValue(parseNDigits(2, dateString), valueCallback);
          case 'Lo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'month'
            }), valueCallback);
          case 'LLL':
            return match.month(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          case 'LLLLL':
            return match.month(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          case 'LLLL':
          default:
            return match.month(dateString, {
              width: 'wide',
              context: 'standalone'
            }) || match.month(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 11;
      }
      set(date, _flags, value) {
        date.setUTCMonth(value, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function setUTCWeek(dirtyDate, dirtyWeek, options) {
      requiredArgs(2, arguments);
      var date = toDate(dirtyDate);
      var week = toInteger(dirtyWeek);
      var diff = getUTCWeek(date, options) - week;
      date.setUTCDate(date.getUTCDate() - diff * 7);
      return date;
    }

    function _defineProperty$l(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class LocalWeekParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$l(this, "priority", 100);
        _defineProperty$l(this, "incompatibleTokens", ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'i', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'w':
            return parseNumericPattern(numericPatterns.week, dateString);
          case 'wo':
            return match.ordinalNumber(dateString, {
              unit: 'week'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 1 && value <= 53;
      }
      set(date, _flags, value, options) {
        return startOfUTCWeek(setUTCWeek(date, value, options), options);
      }
    }

    function setUTCISOWeek(dirtyDate, dirtyISOWeek) {
      requiredArgs(2, arguments);
      var date = toDate(dirtyDate);
      var isoWeek = toInteger(dirtyISOWeek);
      var diff = getUTCISOWeek(date) - isoWeek;
      date.setUTCDate(date.getUTCDate() - diff * 7);
      return date;
    }

    function _defineProperty$k(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class ISOWeekParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$k(this, "priority", 100);
        _defineProperty$k(this, "incompatibleTokens", ['y', 'Y', 'u', 'q', 'Q', 'M', 'L', 'w', 'd', 'D', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'I':
            return parseNumericPattern(numericPatterns.week, dateString);
          case 'Io':
            return match.ordinalNumber(dateString, {
              unit: 'week'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 1 && value <= 53;
      }
      set(date, _flags, value) {
        return startOfUTCISOWeek(setUTCISOWeek(date, value));
      }
    }

    function _defineProperty$j(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    var DAYS_IN_MONTH = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    var DAYS_IN_MONTH_LEAP_YEAR = [31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    class DateParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$j(this, "priority", 90);
        _defineProperty$j(this, "subPriority", 1);
        _defineProperty$j(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'd':
            return parseNumericPattern(numericPatterns.date, dateString);
          case 'do':
            return match.ordinalNumber(dateString, {
              unit: 'date'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(date, value) {
        var year = date.getUTCFullYear();
        var isLeapYear = isLeapYearIndex(year);
        var month = date.getUTCMonth();
        if (isLeapYear) {
          return value >= 1 && value <= DAYS_IN_MONTH_LEAP_YEAR[month];
        } else {
          return value >= 1 && value <= DAYS_IN_MONTH[month];
        }
      }
      set(date, _flags, value) {
        date.setUTCDate(value);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$i(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class DayOfYearParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$i(this, "priority", 90);
        _defineProperty$i(this, "subpriority", 1);
        _defineProperty$i(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'M', 'L', 'w', 'I', 'd', 'E', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'D':
          case 'DD':
            return parseNumericPattern(numericPatterns.dayOfYear, dateString);
          case 'Do':
            return match.ordinalNumber(dateString, {
              unit: 'date'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(date, value) {
        var year = date.getUTCFullYear();
        var isLeapYear = isLeapYearIndex(year);
        if (isLeapYear) {
          return value >= 1 && value <= 366;
        } else {
          return value >= 1 && value <= 365;
        }
      }
      set(date, _flags, value) {
        date.setUTCMonth(0, value);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function setUTCDay(dirtyDate, dirtyDay, options) {
      var _ref, _ref2, _ref3, _options$weekStartsOn, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;
      requiredArgs(2, arguments);
      var defaultOptions = getDefaultOptions();
      var weekStartsOn = toInteger((_ref = (_ref2 = (_ref3 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.weekStartsOn) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.weekStartsOn) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.weekStartsOn) !== null && _ref !== void 0 ? _ref : 0);
      if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
        throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
      }
      var date = toDate(dirtyDate);
      var day = toInteger(dirtyDay);
      var currentDay = date.getUTCDay();
      var remainder = day % 7;
      var dayIndex = (remainder + 7) % 7;
      var diff = (dayIndex < weekStartsOn ? 7 : 0) + day - currentDay;
      date.setUTCDate(date.getUTCDate() + diff);
      return date;
    }

    function _defineProperty$h(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class DayParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$h(this, "priority", 90);
        _defineProperty$h(this, "incompatibleTokens", ['D', 'i', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'E':
          case 'EE':
          case 'EEE':
            return match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'EEEEE':
            return match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'EEEEEE':
            return match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'EEEE':
          default:
            return match.day(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 6;
      }
      set(date, _flags, value, options) {
        date = setUTCDay(date, value, options);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$g(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class LocalDayParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$g(this, "priority", 90);
        _defineProperty$g(this, "incompatibleTokens", ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'E', 'i', 'c', 't', 'T']);
      }
      parse(dateString, token, match, options) {
        var valueCallback = function (value) {
          var wholeWeekDays = Math.floor((value - 1) / 7) * 7;
          return (value + options.weekStartsOn + 6) % 7 + wholeWeekDays;
        };
        switch (token) {
          case 'e':
          case 'ee':
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
          case 'eo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'day'
            }), valueCallback);
          case 'eee':
            return match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'eeeee':
            return match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'eeeeee':
            return match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'eeee':
          default:
            return match.day(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 6;
      }
      set(date, _flags, value, options) {
        date = setUTCDay(date, value, options);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$f(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class StandAloneLocalDayParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$f(this, "priority", 90);
        _defineProperty$f(this, "incompatibleTokens", ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'E', 'i', 'e', 't', 'T']);
      }
      parse(dateString, token, match, options) {
        var valueCallback = function (value) {
          var wholeWeekDays = Math.floor((value - 1) / 7) * 7;
          return (value + options.weekStartsOn + 6) % 7 + wholeWeekDays;
        };
        switch (token) {
          case 'c':
          case 'cc':
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
          case 'co':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'day'
            }), valueCallback);
          case 'ccc':
            return match.day(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'short',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          case 'ccccc':
            return match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          case 'cccccc':
            return match.day(dateString, {
              width: 'short',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          case 'cccc':
          default:
            return match.day(dateString, {
              width: 'wide',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'short',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 6;
      }
      set(date, _flags, value, options) {
        date = setUTCDay(date, value, options);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function setUTCISODay(dirtyDate, dirtyDay) {
      requiredArgs(2, arguments);
      var day = toInteger(dirtyDay);
      if (day % 7 === 0) {
        day = day - 7;
      }
      var weekStartsOn = 1;
      var date = toDate(dirtyDate);
      var currentDay = date.getUTCDay();
      var remainder = day % 7;
      var dayIndex = (remainder + 7) % 7;
      var diff = (dayIndex < weekStartsOn ? 7 : 0) + day - currentDay;
      date.setUTCDate(date.getUTCDate() + diff);
      return date;
    }

    function _defineProperty$e(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class ISODayParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$e(this, "priority", 90);
        _defineProperty$e(this, "incompatibleTokens", ['y', 'Y', 'u', 'q', 'Q', 'M', 'L', 'w', 'd', 'D', 'E', 'e', 'c', 't', 'T']);
      }
      parse(dateString, token, match) {
        var valueCallback = function (value) {
          if (value === 0) {
            return 7;
          }
          return value;
        };
        switch (token) {
          case 'i':
          case 'ii':
            return parseNDigits(token.length, dateString);
          case 'io':
            return match.ordinalNumber(dateString, {
              unit: 'day'
            });
          case 'iii':
            return mapValue(match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
          case 'iiiii':
            return mapValue(match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
          case 'iiiiii':
            return mapValue(match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
          case 'iiii':
          default:
            return mapValue(match.day(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
        }
      }
      validate(_date, value) {
        return value >= 1 && value <= 7;
      }
      set(date, _flags, value) {
        date = setUTCISODay(date, value);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$d(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class AMPMParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$d(this, "priority", 80);
        _defineProperty$d(this, "incompatibleTokens", ['b', 'B', 'H', 'k', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'a':
          case 'aa':
          case 'aaa':
            return match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'aaaaa':
            return match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'aaaa':
          default:
            return match.dayPeriod(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }
      set(date, _flags, value) {
        date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$c(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class AMPMMidnightParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$c(this, "priority", 80);
        _defineProperty$c(this, "incompatibleTokens", ['a', 'B', 'H', 'k', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'b':
          case 'bb':
          case 'bbb':
            return match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'bbbbb':
            return match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'bbbb':
          default:
            return match.dayPeriod(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }
      set(date, _flags, value) {
        date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$b(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class DayPeriodParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$b(this, "priority", 80);
        _defineProperty$b(this, "incompatibleTokens", ['a', 'b', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'B':
          case 'BB':
          case 'BBB':
            return match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'BBBBB':
            return match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          case 'BBBB':
          default:
            return match.dayPeriod(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }
      set(date, _flags, value) {
        date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$a(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class Hour1to12Parser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$a(this, "priority", 70);
        _defineProperty$a(this, "incompatibleTokens", ['H', 'K', 'k', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'h':
            return parseNumericPattern(numericPatterns.hour12h, dateString);
          case 'ho':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 1 && value <= 12;
      }
      set(date, _flags, value) {
        var isPM = date.getUTCHours() >= 12;
        if (isPM && value < 12) {
          date.setUTCHours(value + 12, 0, 0, 0);
        } else if (!isPM && value === 12) {
          date.setUTCHours(0, 0, 0, 0);
        } else {
          date.setUTCHours(value, 0, 0, 0);
        }
        return date;
      }
    }

    function _defineProperty$9(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class Hour0to23Parser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$9(this, "priority", 70);
        _defineProperty$9(this, "incompatibleTokens", ['a', 'b', 'h', 'K', 'k', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'H':
            return parseNumericPattern(numericPatterns.hour23h, dateString);
          case 'Ho':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 23;
      }
      set(date, _flags, value) {
        date.setUTCHours(value, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$8(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class Hour0To11Parser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$8(this, "priority", 70);
        _defineProperty$8(this, "incompatibleTokens", ['h', 'H', 'k', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'K':
            return parseNumericPattern(numericPatterns.hour11h, dateString);
          case 'Ko':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 11;
      }
      set(date, _flags, value) {
        var isPM = date.getUTCHours() >= 12;
        if (isPM && value < 12) {
          date.setUTCHours(value + 12, 0, 0, 0);
        } else {
          date.setUTCHours(value, 0, 0, 0);
        }
        return date;
      }
    }

    function _defineProperty$7(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class Hour1To24Parser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$7(this, "priority", 70);
        _defineProperty$7(this, "incompatibleTokens", ['a', 'b', 'h', 'H', 'K', 't', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'k':
            return parseNumericPattern(numericPatterns.hour24h, dateString);
          case 'ko':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 1 && value <= 24;
      }
      set(date, _flags, value) {
        var hours = value <= 24 ? value % 24 : value;
        date.setUTCHours(hours, 0, 0, 0);
        return date;
      }
    }

    function _defineProperty$6(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class MinuteParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$6(this, "priority", 60);
        _defineProperty$6(this, "incompatibleTokens", ['t', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 'm':
            return parseNumericPattern(numericPatterns.minute, dateString);
          case 'mo':
            return match.ordinalNumber(dateString, {
              unit: 'minute'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 59;
      }
      set(date, _flags, value) {
        date.setUTCMinutes(value, 0, 0);
        return date;
      }
    }

    function _defineProperty$5(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class SecondParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$5(this, "priority", 50);
        _defineProperty$5(this, "incompatibleTokens", ['t', 'T']);
      }
      parse(dateString, token, match) {
        switch (token) {
          case 's':
            return parseNumericPattern(numericPatterns.second, dateString);
          case 'so':
            return match.ordinalNumber(dateString, {
              unit: 'second'
            });
          default:
            return parseNDigits(token.length, dateString);
        }
      }
      validate(_date, value) {
        return value >= 0 && value <= 59;
      }
      set(date, _flags, value) {
        date.setUTCSeconds(value, 0);
        return date;
      }
    }

    function _defineProperty$4(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class FractionOfSecondParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$4(this, "priority", 30);
        _defineProperty$4(this, "incompatibleTokens", ['t', 'T']);
      }
      parse(dateString, token) {
        var valueCallback = function (value) {
          return Math.floor(value * Math.pow(10, -token.length + 3));
        };
        return mapValue(parseNDigits(token.length, dateString), valueCallback);
      }
      set(date, _flags, value) {
        date.setUTCMilliseconds(value);
        return date;
      }
    }

    function _defineProperty$3(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class ISOTimezoneWithZParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$3(this, "priority", 10);
        _defineProperty$3(this, "incompatibleTokens", ['t', 'T', 'x']);
      }
      parse(dateString, token) {
        switch (token) {
          case 'X':
            return parseTimezonePattern(timezonePatterns.basicOptionalMinutes, dateString);
          case 'XX':
            return parseTimezonePattern(timezonePatterns.basic, dateString);
          case 'XXXX':
            return parseTimezonePattern(timezonePatterns.basicOptionalSeconds, dateString);
          case 'XXXXX':
            return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds, dateString);
          case 'XXX':
          default:
            return parseTimezonePattern(timezonePatterns.extended, dateString);
        }
      }
      set(date, flags, value) {
        if (flags.timestampIsSet) {
          return date;
        }
        return new Date(date.getTime() - value);
      }
    }

    function _defineProperty$2(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class ISOTimezoneParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$2(this, "priority", 10);
        _defineProperty$2(this, "incompatibleTokens", ['t', 'T', 'X']);
      }
      parse(dateString, token) {
        switch (token) {
          case 'x':
            return parseTimezonePattern(timezonePatterns.basicOptionalMinutes, dateString);
          case 'xx':
            return parseTimezonePattern(timezonePatterns.basic, dateString);
          case 'xxxx':
            return parseTimezonePattern(timezonePatterns.basicOptionalSeconds, dateString);
          case 'xxxxx':
            return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds, dateString);
          case 'xxx':
          default:
            return parseTimezonePattern(timezonePatterns.extended, dateString);
        }
      }
      set(date, flags, value) {
        if (flags.timestampIsSet) {
          return date;
        }
        return new Date(date.getTime() - value);
      }
    }

    function _defineProperty$1(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class TimestampSecondsParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty$1(this, "priority", 40);
        _defineProperty$1(this, "incompatibleTokens", '*');
      }
      parse(dateString) {
        return parseAnyDigitsSigned(dateString);
      }
      set(_date, _flags, value) {
        return [new Date(value * 1000), {
          timestampIsSet: true
        }];
      }
    }

    function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
    class TimestampMillisecondsParser extends Parser$1 {
      constructor() {
        super(...arguments);
        _defineProperty(this, "priority", 20);
        _defineProperty(this, "incompatibleTokens", '*');
      }
      parse(dateString) {
        return parseAnyDigitsSigned(dateString);
      }
      set(_date, _flags, value) {
        return [new Date(value), {
          timestampIsSet: true
        }];
      }
    }

    ({
      G: new EraParser(),
      y: new YearParser(),
      Y: new LocalWeekYearParser(),
      R: new ISOWeekYearParser(),
      u: new ExtendedYearParser(),
      Q: new QuarterParser(),
      q: new StandAloneQuarterParser(),
      M: new MonthParser(),
      L: new StandAloneMonthParser(),
      w: new LocalWeekParser(),
      I: new ISOWeekParser(),
      d: new DateParser(),
      D: new DayOfYearParser(),
      E: new DayParser(),
      e: new LocalDayParser(),
      c: new StandAloneLocalDayParser(),
      i: new ISODayParser(),
      a: new AMPMParser(),
      b: new AMPMMidnightParser(),
      B: new DayPeriodParser(),
      h: new Hour1to12Parser(),
      H: new Hour0to23Parser(),
      K: new Hour0To11Parser(),
      k: new Hour1To24Parser(),
      m: new MinuteParser(),
      s: new SecondParser(),
      S: new FractionOfSecondParser(),
      X: new ISOTimezoneWithZParser(),
      x: new ISOTimezoneParser(),
      t: new TimestampSecondsParser(),
      T: new TimestampMillisecondsParser()
    });

    var formatDistanceLocale$1g = {
      lessThanXSeconds: {
        one: "minder as 'n sekonde",
        other: 'minder as {{count}} sekondes'
      },
      xSeconds: {
        one: '1 sekonde',
        other: '{{count}} sekondes'
      },
      halfAMinute: "'n halwe minuut",
      lessThanXMinutes: {
        one: "minder as 'n minuut",
        other: 'minder as {{count}} minute'
      },
      xMinutes: {
        one: "'n minuut",
        other: '{{count}} minute'
      },
      aboutXHours: {
        one: 'ongeveer 1 uur',
        other: 'ongeveer {{count}} ure'
      },
      xHours: {
        one: '1 uur',
        other: '{{count}} ure'
      },
      xDays: {
        one: '1 dag',
        other: '{{count}} dae'
      },
      aboutXWeeks: {
        one: 'ongeveer 1 week',
        other: 'ongeveer {{count}} weke'
      },
      xWeeks: {
        one: '1 week',
        other: '{{count}} weke'
      },
      aboutXMonths: {
        one: 'ongeveer 1 maand',
        other: 'ongeveer {{count}} maande'
      },
      xMonths: {
        one: '1 maand',
        other: '{{count}} maande'
      },
      aboutXYears: {
        one: 'ongeveer 1 jaar',
        other: 'ongeveer {{count}} jaar'
      },
      xYears: {
        one: '1 jaar',
        other: '{{count}} jaar'
      },
      overXYears: {
        one: 'meer as 1 jaar',
        other: 'meer as {{count}} jaar'
      },
      almostXYears: {
        one: 'byna 1 jaar',
        other: 'byna {{count}} jaar'
      }
    };
    var formatDistance$1h = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$1g[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'oor ' + result;
        } else {
          return result + ' gelede';
        }
      }
      return result;
    };

    var dateFormats$1p = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'yyyy/MM/dd'
    };
    var timeFormats$1p = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$1p = {
      full: "{{date}} 'om' {{time}}",
      long: "{{date}} 'om' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1p = {
      date: buildFormatLongFn({
        formats: dateFormats$1p,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1p,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1p,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1h = {
      lastWeek: "'verlede' eeee 'om' p",
      yesterday: "'gister om' p",
      today: "'vandag om' p",
      tomorrow: "'môre om' p",
      nextWeek: "eeee 'om' p",
      other: 'P'
    };
    var formatRelative$1h = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1h[token];
    };

    var eraValues$1h = {
      narrow: ['vC', 'nC'],
      abbreviated: ['vC', 'nC'],
      wide: ['voor Christus', 'na Christus']
    };
    var quarterValues$1h = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1ste kwartaal', '2de kwartaal', '3de kwartaal', '4de kwartaal']
    };
    var monthValues$1h = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mrt', 'Apr', 'Mei', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Des'],
      wide: ['Januarie', 'Februarie', 'Maart', 'April', 'Mei', 'Junie', 'Julie', 'Augustus', 'September', 'Oktober', 'November', 'Desember']
    };
    var dayValues$1h = {
      narrow: ['S', 'M', 'D', 'W', 'D', 'V', 'S'],
      short: ['So', 'Ma', 'Di', 'Wo', 'Do', 'Vr', 'Sa'],
      abbreviated: ['Son', 'Maa', 'Din', 'Woe', 'Don', 'Vry', 'Sat'],
      wide: ['Sondag', 'Maandag', 'Dinsdag', 'Woensdag', 'Donderdag', 'Vrydag', 'Saterdag']
    };
    var dayPeriodValues$1h = {
      narrow: {
        am: 'vm',
        pm: 'nm',
        midnight: 'middernag',
        noon: 'middaguur',
        morning: 'oggend',
        afternoon: 'middag',
        evening: 'laat middag',
        night: 'aand'
      },
      abbreviated: {
        am: 'vm',
        pm: 'nm',
        midnight: 'middernag',
        noon: 'middaguur',
        morning: 'oggend',
        afternoon: 'middag',
        evening: 'laat middag',
        night: 'aand'
      },
      wide: {
        am: 'vm',
        pm: 'nm',
        midnight: 'middernag',
        noon: 'middaguur',
        morning: 'oggend',
        afternoon: 'middag',
        evening: 'laat middag',
        night: 'aand'
      }
    };
    var formattingDayPeriodValues$12 = {
      narrow: {
        am: 'vm',
        pm: 'nm',
        midnight: 'middernag',
        noon: 'uur die middag',
        morning: 'uur die oggend',
        afternoon: 'uur die middag',
        evening: 'uur die aand',
        night: 'uur die aand'
      },
      abbreviated: {
        am: 'vm',
        pm: 'nm',
        midnight: 'middernag',
        noon: 'uur die middag',
        morning: 'uur die oggend',
        afternoon: 'uur die middag',
        evening: 'uur die aand',
        night: 'uur die aand'
      },
      wide: {
        am: 'vm',
        pm: 'nm',
        midnight: 'middernag',
        noon: 'uur die middag',
        morning: 'uur die oggend',
        afternoon: 'uur die middag',
        evening: 'uur die aand',
        night: 'uur die aand'
      }
    };
    var ordinalNumber$1h = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      var rem100 = number % 100;
      if (rem100 < 20) {
        switch (rem100) {
          case 1:
          case 8:
            return number + 'ste';
          default:
            return number + 'de';
        }
      }
      return number + 'ste';
    };
    var localize$1h = {
      ordinalNumber: ordinalNumber$1h,
      era: buildLocalizeFn({
        values: eraValues$1h,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1h,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1h,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1h,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1h,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$12,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1g = /^(\d+)(ste|de)?/i;
    var parseOrdinalNumberPattern$1g = /\d+/i;
    var matchEraPatterns$1g = {
      narrow: /^([vn]\.? ?C\.?)/,
      abbreviated: /^([vn]\. ?C\.?)/,
      wide: /^((voor|na) Christus)/
    };
    var parseEraPatterns$1g = {
      any: [/^v/, /^n/]
    };
    var matchQuarterPatterns$1g = {
      narrow: /^[1234]/i,
      abbreviated: /^K[1234]/i,
      wide: /^[1234](st|d)e kwartaal/i
    };
    var parseQuarterPatterns$1g = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1g = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(Jan|Feb|Mrt|Apr|Mei|Jun|Jul|Aug|Sep|Okt|Nov|Dec)\.?/i,
      wide: /^(Januarie|Februarie|Maart|April|Mei|Junie|Julie|Augustus|September|Oktober|November|Desember)/i
    };
    var parseMonthPatterns$1g = {
      narrow: [/^J/i, /^F/i, /^M/i, /^A/i, /^M/i, /^J/i, /^J/i, /^A/i, /^S/i, /^O/i, /^N/i, /^D/i],
      any: [/^Jan/i, /^Feb/i, /^Mrt/i, /^Apr/i, /^Mei/i, /^Jun/i, /^Jul/i, /^Aug/i, /^Sep/i, /^Okt/i, /^Nov/i, /^Dec/i]
    };
    var matchDayPatterns$1g = {
      narrow: /^[smdwv]/i,
      short: /^(So|Ma|Di|Wo|Do|Vr|Sa)/i,
      abbreviated: /^(Son|Maa|Din|Woe|Don|Vry|Sat)/i,
      wide: /^(Sondag|Maandag|Dinsdag|Woensdag|Donderdag|Vrydag|Saterdag)/i
    };
    var parseDayPatterns$1g = {
      narrow: [/^S/i, /^M/i, /^D/i, /^W/i, /^D/i, /^V/i, /^S/i],
      any: [/^So/i, /^Ma/i, /^Di/i, /^Wo/i, /^Do/i, /^Vr/i, /^Sa/i]
    };
    var matchDayPeriodPatterns$1g = {
      any: /^(vm|nm|middernag|(?:uur )?die (oggend|middag|aand))/i
    };
    var parseDayPeriodPatterns$1g = {
      any: {
        am: /^vm/i,
        pm: /^nm/i,
        midnight: /^middernag/i,
        noon: /^middaguur/i,
        morning: /oggend/i,
        afternoon: /middag/i,
        evening: /laat middag/i,
        night: /aand/i
      }
    };
    var match$1g = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1g,
        parsePattern: parseOrdinalNumberPattern$1g,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1g,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1g,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1g,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1g,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1g,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1g,
        defaultParseWidth: 'any'
      })
    };

    var locale$1r = {
      code: 'af',
      formatDistance: formatDistance$1h,
      formatLong: formatLong$1p,
      formatRelative: formatRelative$1h,
      localize: localize$1h,
      match: match$1g,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$1f = {
      lessThanXSeconds: {
        one: 'أقل من ثانية',
        two: 'أقل من ثانيتين',
        threeToTen: 'أقل من {{count}} ثواني',
        other: 'أقل من {{count}} ثانية'
      },
      xSeconds: {
        one: 'ثانية واحدة',
        two: 'ثانيتان',
        threeToTen: '{{count}} ثواني',
        other: '{{count}} ثانية'
      },
      halfAMinute: 'نصف دقيقة',
      lessThanXMinutes: {
        one: 'أقل من دقيقة',
        two: 'أقل من دقيقتين',
        threeToTen: 'أقل من {{count}} دقائق',
        other: 'أقل من {{count}} دقيقة'
      },
      xMinutes: {
        one: 'دقيقة واحدة',
        two: 'دقيقتان',
        threeToTen: '{{count}} دقائق',
        other: '{{count}} دقيقة'
      },
      aboutXHours: {
        one: 'ساعة واحدة تقريباً',
        two: 'ساعتين تقريبا',
        threeToTen: '{{count}} ساعات تقريباً',
        other: '{{count}} ساعة تقريباً'
      },
      xHours: {
        one: 'ساعة واحدة',
        two: 'ساعتان',
        threeToTen: '{{count}} ساعات',
        other: '{{count}} ساعة'
      },
      xDays: {
        one: 'يوم واحد',
        two: 'يومان',
        threeToTen: '{{count}} أيام',
        other: '{{count}} يوم'
      },
      aboutXWeeks: {
        one: 'أسبوع واحد تقريبا',
        two: 'أسبوعين تقريبا',
        threeToTen: '{{count}} أسابيع تقريبا',
        other: '{{count}} أسبوعا تقريبا'
      },
      xWeeks: {
        one: 'أسبوع واحد',
        two: 'أسبوعان',
        threeToTen: '{{count}} أسابيع',
        other: '{{count}} أسبوعا'
      },
      aboutXMonths: {
        one: 'شهر واحد تقريباً',
        two: 'شهرين تقريبا',
        threeToTen: '{{count}} أشهر تقريبا',
        other: '{{count}} شهرا تقريباً'
      },
      xMonths: {
        one: 'شهر واحد',
        two: 'شهران',
        threeToTen: '{{count}} أشهر',
        other: '{{count}} شهرا'
      },
      aboutXYears: {
        one: 'سنة واحدة تقريباً',
        two: 'سنتين تقريبا',
        threeToTen: '{{count}} سنوات تقريباً',
        other: '{{count}} سنة تقريباً'
      },
      xYears: {
        one: 'سنة واحد',
        two: 'سنتان',
        threeToTen: '{{count}} سنوات',
        other: '{{count}} سنة'
      },
      overXYears: {
        one: 'أكثر من سنة',
        two: 'أكثر من سنتين',
        threeToTen: 'أكثر من {{count}} سنوات',
        other: 'أكثر من {{count}} سنة'
      },
      almostXYears: {
        one: 'ما يقارب سنة واحدة',
        two: 'ما يقارب سنتين',
        threeToTen: 'ما يقارب {{count}} سنوات',
        other: 'ما يقارب {{count}} سنة'
      }
    };
    var formatDistance$1g = function (token, count, options) {
      var usageGroup = formatDistanceLocale$1f[token];
      var result;
      if (typeof usageGroup === 'string') {
        result = usageGroup;
      } else if (count === 1) {
        result = usageGroup.one;
      } else if (count === 2) {
        result = usageGroup.two;
      } else if (count <= 10) {
        result = usageGroup.threeToTen.replace('{{count}}', String(count));
      } else {
        result = usageGroup.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'خلال ' + result;
        } else {
          return 'منذ ' + result;
        }
      }
      return result;
    };

    var dateFormats$1o = {
      full: 'EEEE، do MMMM y',
      long: 'do MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$1o = {
      full: 'HH:mm:ss',
      long: 'HH:mm:ss',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$1o = {
      full: "{{date}} 'عند الساعة' {{time}}",
      long: "{{date}} 'عند الساعة' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1o = {
      date: buildFormatLongFn({
        formats: dateFormats$1o,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1o,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1o,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1g = {
      lastWeek: "eeee 'الماضي عند الساعة' p",
      yesterday: "'الأمس عند الساعة' p",
      today: "'اليوم عند الساعة' p",
      tomorrow: "'غدا عند الساعة' p",
      nextWeek: "eeee 'القادم عند الساعة' p",
      other: 'P'
    };
    var formatRelative$1g = function (token) {
      return formatRelativeLocale$1g[token];
    };

    var eraValues$1g = {
      narrow: ['ق', 'ب'],
      abbreviated: ['ق.م.', 'ب.م.'],
      wide: ['قبل الميلاد', 'بعد الميلاد']
    };
    var quarterValues$1g = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ر1', 'ر2', 'ر3', 'ر4'],
      wide: ['الربع الأول', 'الربع الثاني', 'الربع الثالث', 'الربع الرابع']
    };
    var monthValues$1g = {
      narrow: ['ي', 'ف', 'م', 'أ', 'م', 'ي', 'ي', 'أ', 'س', 'أ', 'ن', 'د'],
      abbreviated: ['يناير', 'فبراير', 'مارس', 'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'],
      wide: ['يناير', 'فبراير', 'مارس', 'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر']
    };
    var dayValues$1g = {
      narrow: ['ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
      short: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      abbreviated: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      wide: ['الأحد', 'الاثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت']
    };
    var dayPeriodValues$1g = {
      narrow: {
        am: 'ص',
        pm: 'م',
        morning: 'الصباح',
        noon: 'الظهر',
        afternoon: 'بعد الظهر',
        evening: 'المساء',
        night: 'الليل',
        midnight: 'منتصف الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        morning: 'الصباح',
        noon: 'الظهر',
        afternoon: 'بعد الظهر',
        evening: 'المساء',
        night: 'الليل',
        midnight: 'منتصف الليل'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        morning: 'الصباح',
        noon: 'الظهر',
        afternoon: 'بعد الظهر',
        evening: 'المساء',
        night: 'الليل',
        midnight: 'منتصف الليل'
      }
    };
    var formattingDayPeriodValues$11 = {
      narrow: {
        am: 'ص',
        pm: 'م',
        morning: 'في الصباح',
        noon: 'الظهر',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل',
        midnight: 'منتصف الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        morning: 'في الصباح',
        noon: 'الظهر',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل',
        midnight: 'منتصف الليل'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        morning: 'في الصباح',
        noon: 'الظهر',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل',
        midnight: 'منتصف الليل'
      }
    };
    var ordinalNumber$1g = function (num) {
      return String(num);
    };
    var localize$1g = {
      ordinalNumber: ordinalNumber$1g,
      era: buildLocalizeFn({
        values: eraValues$1g,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1g,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1g,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1g,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1g,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$11,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1f = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$1f = /\d+/i;
    var matchEraPatterns$1f = {
      narrow: /[قب]/,
      abbreviated: /[قب]\.م\./,
      wide: /(قبل|بعد) الميلاد/
    };
    var parseEraPatterns$1f = {
      any: [/قبل/, /بعد/]
    };
    var matchQuarterPatterns$1f = {
      narrow: /^[1234]/i,
      abbreviated: /ر[1234]/,
      wide: /الربع (الأول|الثاني|الثالث|الرابع)/
    };
    var parseQuarterPatterns$1f = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1f = {
      narrow: /^[أيفمسند]/,
      abbreviated: /^(يناير|فبراير|مارس|أبريل|مايو|يونيو|يوليو|أغسطس|سبتمبر|أكتوبر|نوفمبر|ديسمبر)/,
      wide: /^(يناير|فبراير|مارس|أبريل|مايو|يونيو|يوليو|أغسطس|سبتمبر|أكتوبر|نوفمبر|ديسمبر)/
    };
    var parseMonthPatterns$1f = {
      narrow: [/^ي/i, /^ف/i, /^م/i, /^أ/i, /^م/i, /^ي/i, /^ي/i, /^أ/i, /^س/i, /^أ/i, /^ن/i, /^د/i],
      any: [/^يناير/i, /^فبراير/i, /^مارس/i, /^أبريل/i, /^مايو/i, /^يونيو/i, /^يوليو/i, /^أغسطس/i, /^سبتمبر/i, /^أكتوبر/i, /^نوفمبر/i, /^ديسمبر/i]
    };
    var matchDayPatterns$1f = {
      narrow: /^[حنثرخجس]/i,
      short: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/i,
      abbreviated: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/i,
      wide: /^(الأحد|الاثنين|الثلاثاء|الأربعاء|الخميس|الجمعة|السبت)/i
    };
    var parseDayPatterns$1f = {
      narrow: [/^ح/i, /^ن/i, /^ث/i, /^ر/i, /^خ/i, /^ج/i, /^س/i],
      wide: [/^الأحد/i, /^الاثنين/i, /^الثلاثاء/i, /^الأربعاء/i, /^الخميس/i, /^الجمعة/i, /^السبت/i],
      any: [/^أح/i, /^اث/i, /^ث/i, /^أر/i, /^خ/i, /^ج/i, /^س/i]
    };
    var matchDayPeriodPatterns$1f = {
      narrow: /^(ص|م|منتصف الليل|الظهر|بعد الظهر|في الصباح|في المساء|في الليل)/,
      any: /^(ص|م|منتصف الليل|الظهر|بعد الظهر|في الصباح|في المساء|في الليل)/
    };
    var parseDayPeriodPatterns$1f = {
      any: {
        am: /^ص/,
        pm: /^م/,
        midnight: /منتصف الليل/,
        noon: /الظهر/,
        afternoon: /بعد الظهر/,
        morning: /في الصباح/,
        evening: /في المساء/,
        night: /في الليل/
      }
    };
    var match$1f = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1f,
        parsePattern: parseOrdinalNumberPattern$1f,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1f,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1f,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1f,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1f,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1f,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1f,
        defaultParseWidth: 'any'
      })
    };

    var locale$1q = {
      code: 'ar',
      formatDistance: formatDistance$1g,
      formatLong: formatLong$1o,
      formatRelative: formatRelative$1g,
      localize: localize$1g,
      match: match$1f,
      options: {
        weekStartsOn: 6
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$1e = {
      lessThanXSeconds: {
        one: 'أقل من ثانية واحدة',
        two: 'أقل من ثانتين',
        threeToTen: 'أقل من {{count}} ثواني',
        other: 'أقل من {{count}} ثانية'
      },
      xSeconds: {
        one: 'ثانية واحدة',
        two: 'ثانتين',
        threeToTen: '{{count}} ثواني',
        other: '{{count}} ثانية'
      },
      halfAMinute: 'نصف دقيقة',
      lessThanXMinutes: {
        one: 'أقل من دقيقة',
        two: 'أقل من دقيقتين',
        threeToTen: 'أقل من {{count}} دقائق',
        other: 'أقل من {{count}} دقيقة'
      },
      xMinutes: {
        one: 'دقيقة واحدة',
        two: 'دقيقتين',
        threeToTen: '{{count}} دقائق',
        other: '{{count}} دقيقة'
      },
      aboutXHours: {
        one: 'ساعة واحدة تقريباً',
        two: 'ساعتين تقريباً',
        threeToTen: '{{count}} ساعات تقريباً',
        other: '{{count}} ساعة تقريباً'
      },
      xHours: {
        one: 'ساعة واحدة',
        two: 'ساعتين',
        threeToTen: '{{count}} ساعات',
        other: '{{count}} ساعة'
      },
      xDays: {
        one: 'يوم واحد',
        two: 'يومين',
        threeToTen: '{{count}} أيام',
        other: '{{count}} يوم'
      },
      aboutXWeeks: {
        one: 'أسبوع واحد تقريباً',
        two: 'أسبوعين تقريباً',
        threeToTen: '{{count}} أسابيع تقريباً',
        other: '{{count}} أسبوع تقريباً'
      },
      xWeeks: {
        one: 'أسبوع واحد',
        two: 'أسبوعين',
        threeToTen: '{{count}} أسابيع',
        other: '{{count}} أسبوع'
      },
      aboutXMonths: {
        one: 'شهر واحد تقريباً',
        two: 'شهرين تقريباً',
        threeToTen: '{{count}} أشهر تقريباً',
        other: '{{count}} شهر تقريباً'
      },
      xMonths: {
        one: 'شهر واحد',
        two: 'شهرين',
        threeToTen: '{{count}} أشهر',
        other: '{{count}} شهر'
      },
      aboutXYears: {
        one: 'عام واحد تقريباً',
        two: 'عامين تقريباً',
        threeToTen: '{{count}} أعوام تقريباً',
        other: '{{count}} عام تقريباً'
      },
      xYears: {
        one: 'عام واحد',
        two: 'عامين',
        threeToTen: '{{count}} أعوام',
        other: '{{count}} عام'
      },
      overXYears: {
        one: 'أكثر من عام',
        two: 'أكثر من عامين',
        threeToTen: 'أكثر من {{count}} أعوام',
        other: 'أكثر من {{count}} عام'
      },
      almostXYears: {
        one: 'عام واحد تقريباً',
        two: 'عامين تقريباً',
        threeToTen: '{{count}} أعوام تقريباً',
        other: '{{count}} عام تقريباً'
      }
    };
    var formatDistance$1f = function (token, count, options) {
      options = options || {};
      var usageGroup = formatDistanceLocale$1e[token];
      var result;
      if (typeof usageGroup === 'string') {
        result = usageGroup;
      } else if (count === 1) {
        result = usageGroup.one;
      } else if (count === 2) {
        result = usageGroup.two;
      } else if (count <= 10) {
        result = usageGroup.threeToTen.replace('{{count}}', String(count));
      } else {
        result = usageGroup.other.replace('{{count}}', String(count));
      }
      if (options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'في خلال ' + result;
        } else {
          return 'منذ ' + result;
        }
      }
      return result;
    };

    var dateFormats$1n = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$1n = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$1n = {
      full: "{{date}} 'عند' {{time}}",
      long: "{{date}} 'عند' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1n = {
      date: buildFormatLongFn({
        formats: dateFormats$1n,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1n,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1n,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1f = {
      lastWeek: "'أخر' eeee 'عند' p",
      yesterday: "'أمس عند' p",
      today: "'اليوم عند' p",
      tomorrow: "'غداً عند' p",
      nextWeek: "eeee 'عند' p",
      other: 'P'
    };
    var formatRelative$1f = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1f[token];
    };

    var eraValues$1f = {
      narrow: ['ق', 'ب'],
      abbreviated: ['ق.م.', 'ب.م.'],
      wide: ['قبل الميلاد', 'بعد الميلاد']
    };
    var quarterValues$1f = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ر1', 'ر2', 'ر3', 'ر4'],
      wide: ['الربع الأول', 'الربع الثاني', 'الربع الثالث', 'الربع الرابع']
    };
    var monthValues$1f = {
      narrow: ['ج', 'ف', 'م', 'أ', 'م', 'ج', 'ج', 'أ', 'س', 'أ', 'ن', 'د'],
      abbreviated: ['جانـ', 'فيفـ', 'مارس', 'أفريل', 'مايـ', 'جوانـ', 'جويـ', 'أوت', 'سبتـ', 'أكتـ', 'نوفـ', 'ديسـ'],
      wide: ['جانفي', 'فيفري', 'مارس', 'أفريل', 'ماي', 'جوان', 'جويلية', 'أوت', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر']
    };
    var dayValues$1f = {
      narrow: ['ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
      short: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      abbreviated: ['أحد', 'اثنـ', 'ثلا', 'أربـ', 'خميـ', 'جمعة', 'سبت'],
      wide: ['الأحد', 'الاثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت']
    };
    var dayPeriodValues$1f = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      }
    };
    var formattingDayPeriodValues$10 = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'في الصباح',
        afternoon: 'بعد الظـهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'في الصباح',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظـهر',
        evening: 'في المساء',
        night: 'في الليل'
      }
    };
    var ordinalNumber$1f = function (dirtyNumber) {
      return String(dirtyNumber);
    };
    var localize$1f = {
      ordinalNumber: ordinalNumber$1f,
      era: buildLocalizeFn({
        values: eraValues$1f,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1f,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1f,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1f,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1f,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$10,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1e = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$1e = /\d+/i;
    var matchEraPatterns$1e = {
      narrow: /^(ق|ب)/i,
      abbreviated: /^(ق\.?\s?م\.?|ق\.?\s?م\.?\s?|a\.?\s?d\.?|c\.?\s?)/i,
      wide: /^(قبل الميلاد|قبل الميلاد|بعد الميلاد|بعد الميلاد)/i
    };
    var parseEraPatterns$1e = {
      any: [/^قبل/i, /^بعد/i]
    };
    var matchQuarterPatterns$1e = {
      narrow: /^[1234]/i,
      abbreviated: /^ر[1234]/i,
      wide: /^الربع [1234]/i
    };
    var parseQuarterPatterns$1e = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1e = {
      narrow: /^[جفمأسند]/i,
      abbreviated: /^(جان|فيف|مار|أفر|ماي|جوا|جوي|أوت|سبت|أكت|نوف|ديس)/i,
      wide: /^(جانفي|فيفري|مارس|أفريل|ماي|جوان|جويلية|أوت|سبتمبر|أكتوبر|نوفمبر|ديسمبر)/i
    };
    var parseMonthPatterns$1e = {
      narrow: [/^ج/i, /^ف/i, /^م/i, /^أ/i, /^م/i, /^ج/i, /^ج/i, /^أ/i, /^س/i, /^أ/i, /^ن/i, /^د/i],
      any: [/^جان/i, /^فيف/i, /^مار/i, /^أفر/i, /^ماي/i, /^جوا/i, /^جوي/i, /^أوت/i, /^سبت/i, /^أكت/i, /^نوف/i, /^ديس/i]
    };
    var matchDayPatterns$1e = {
      narrow: /^[حنثرخجس]/i,
      short: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/i,
      abbreviated: /^(أحد|اثن|ثلا|أرب|خمي|جمعة|سبت)/i,
      wide: /^(الأحد|الاثنين|الثلاثاء|الأربعاء|الخميس|الجمعة|السبت)/i
    };
    var parseDayPatterns$1e = {
      narrow: [/^ح/i, /^ن/i, /^ث/i, /^ر/i, /^خ/i, /^ج/i, /^س/i],
      wide: [/^الأحد/i, /^الاثنين/i, /^الثلاثاء/i, /^الأربعاء/i, /^الخميس/i, /^الجمعة/i, /^السبت/i],
      any: [/^أح/i, /^اث/i, /^ث/i, /^أر/i, /^خ/i, /^ج/i, /^س/i]
    };
    var matchDayPeriodPatterns$1e = {
      narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
      any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
    };
    var parseDayPeriodPatterns$1e = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mi/i,
        noon: /^no/i,
        morning: /morning/i,
        afternoon: /afternoon/i,
        evening: /evening/i,
        night: /night/i
      }
    };
    var match$1e = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1e,
        parsePattern: parseOrdinalNumberPattern$1e,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1e,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1e,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return Number(index) + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1e,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1e,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1e,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1e,
        defaultParseWidth: 'any'
      })
    };

    var locale$1p = {
      code: 'ar-DZ',
      formatDistance: formatDistance$1f,
      formatLong: formatLong$1n,
      formatRelative: formatRelative$1f,
      localize: localize$1f,
      match: match$1e,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$1d = {
      lessThanXSeconds: {
        one: 'أقل من ثانية',
        two: 'أقل من ثانيتين',
        threeToTen: 'أقل من {{count}} ثواني',
        other: 'أقل من {{count}} ثانية'
      },
      xSeconds: {
        one: 'ثانية',
        two: 'ثانيتين',
        threeToTen: '{{count}} ثواني',
        other: '{{count}} ثانية'
      },
      halfAMinute: 'نص دقيقة',
      lessThanXMinutes: {
        one: 'أقل من دقيقة',
        two: 'أقل من دقيقتين',
        threeToTen: 'أقل من {{count}} دقايق',
        other: 'أقل من {{count}} دقيقة'
      },
      xMinutes: {
        one: 'دقيقة',
        two: 'دقيقتين',
        threeToTen: '{{count}} دقايق',
        other: '{{count}} دقيقة'
      },
      aboutXHours: {
        one: 'حوالي ساعة',
        two: 'حوالي ساعتين',
        threeToTen: 'حوالي {{count}} ساعات',
        other: 'حوالي {{count}} ساعة'
      },
      xHours: {
        one: 'ساعة',
        two: 'ساعتين',
        threeToTen: '{{count}} ساعات',
        other: '{{count}} ساعة'
      },
      xDays: {
        one: 'يوم',
        two: 'يومين',
        threeToTen: '{{count}} أيام',
        other: '{{count}} يوم'
      },
      aboutXWeeks: {
        one: 'حوالي أسبوع',
        two: 'حوالي أسبوعين',
        threeToTen: 'حوالي {{count}} أسابيع',
        other: 'حوالي {{count}} أسبوع'
      },
      xWeeks: {
        one: 'أسبوع',
        two: 'أسبوعين',
        threeToTen: '{{count}} أسابيع',
        other: '{{count}} أسبوع'
      },
      aboutXMonths: {
        one: 'حوالي شهر',
        two: 'حوالي شهرين',
        threeToTen: 'حوالي {{count}} أشهر',
        other: 'حوالي {{count}} شهر'
      },
      xMonths: {
        one: 'شهر',
        two: 'شهرين',
        threeToTen: '{{count}} أشهر',
        other: '{{count}} شهر'
      },
      aboutXYears: {
        one: 'حوالي سنة',
        two: 'حوالي سنتين',
        threeToTen: 'حوالي {{count}} سنين',
        other: 'حوالي {{count}} سنة'
      },
      xYears: {
        one: 'عام',
        two: 'عامين',
        threeToTen: '{{count}} أعوام',
        other: '{{count}} عام'
      },
      overXYears: {
        one: 'أكثر من سنة',
        two: 'أكثر من سنتين',
        threeToTen: 'أكثر من {{count}} سنين',
        other: 'أكثر من {{count}} سنة'
      },
      almostXYears: {
        one: 'عام تقريبًا',
        two: 'عامين تقريبًا',
        threeToTen: '{{count}} أعوام تقريبًا',
        other: '{{count}} عام تقريبًا'
      }
    };
    var formatDistance$1e = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$1d[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else if (count === 2) {
        result = tokenValue.two;
      } else if (count <= 10) {
        result = tokenValue.threeToTen.replace('{{count}}', String(count));
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return "\u0641\u064A \u062E\u0644\u0627\u0644 ".concat(result);
        } else {
          return "\u0645\u0646\u0630 ".concat(result);
        }
      }
      return result;
    };

    var dateFormats$1m = {
      full: 'EEEE، do MMMM y',
      long: 'do MMMM y',
      medium: 'dd/MMM/y',
      short: 'd/MM/y'
    };
    var timeFormats$1m = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$1m = {
      full: "{{date}} 'الساعة' {{time}}",
      long: "{{date}} 'الساعة' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1m = {
      date: buildFormatLongFn({
        formats: dateFormats$1m,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1m,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1m,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1e = {
      lastWeek: "eeee 'اللي جاي الساعة' p",
      yesterday: "'إمبارح الساعة' p",
      today: "'النهاردة الساعة' p",
      tomorrow: "'بكرة الساعة' p",
      nextWeek: "eeee 'الساعة' p",
      other: 'P'
    };
    var formatRelative$1e = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1e[token];
    };

    var eraValues$1e = {
      narrow: ['ق', 'ب'],
      abbreviated: ['ق.م', 'ب.م'],
      wide: ['قبل الميلاد', 'بعد الميلاد']
    };
    var quarterValues$1e = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ر1', 'ر2', 'ر3', 'ر4'],
      wide: ['الربع الأول', 'الربع الثاني', 'الربع الثالث', 'الربع الرابع']
    };
    var monthValues$1e = {
      narrow: ['ي', 'ف', 'م', 'أ', 'م', 'ي', 'ي', 'أ', 'س', 'أ', 'ن', 'د'],
      abbreviated: ['ينا', 'فبر', 'مارس', 'أبريل', 'مايو', 'يونـ', 'يولـ', 'أغسـ', 'سبتـ', 'أكتـ', 'نوفـ', 'ديسـ'],
      wide: ['يناير', 'فبراير', 'مارس', 'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر']
    };
    var dayValues$1e = {
      narrow: ['ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
      short: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      abbreviated: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      wide: ['الأحد', 'الاثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت']
    };
    var dayPeriodValues$1e = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءً',
        night: 'ليلاً'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهراً',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءً',
        night: 'ليلاً'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهراً',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءً',
        night: 'ليلاً'
      }
    };
    var formattingDayPeriodValues$$ = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'في الصباح',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهراً',
        morning: 'في الصباح',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        morning: 'في الصباح',
        noon: 'ظهراً',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل'
      }
    };
    var ordinalNumber$1e = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$1e = {
      ordinalNumber: ordinalNumber$1e,
      era: buildLocalizeFn({
        values: eraValues$1e,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1e,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1e,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1e,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1e,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$$,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1d = /^(\d+)/;
    var parseOrdinalNumberPattern$1d = /\d+/i;
    var matchEraPatterns$1d = {
      narrow: /^(ق|ب)/g,
      abbreviated: /^(ق.م|ب.م)/g,
      wide: /^(قبل الميلاد|بعد الميلاد)/g
    };
    var parseEraPatterns$1d = {
      any: [/^ق/g, /^ب/g]
    };
    var matchQuarterPatterns$1d = {
      narrow: /^[1234]/,
      abbreviated: /^ر[1234]/,
      wide: /^الربع (الأول|الثاني|الثالث|الرابع)/
    };
    var parseQuarterPatterns$1d = {
      wide: [/الربع الأول/, /الربع الثاني/, /الربع الثالث/, /الربع الرابع/],
      any: [/1/, /2/, /3/, /4/]
    };
    var matchMonthPatterns$1d = {
      narrow: /^(ي|ف|م|أ|س|ن|د)/,
      abbreviated: /^(ينا|فبر|مارس|أبريل|مايو|يونـ|يولـ|أغسـ|سبتـ|أكتـ|نوفـ|ديسـ)/,
      wide: /^(يناير|فبراير|مارس|أبريل|مايو|يونيو|يوليو|أغسطس|سبتمبر|أكتوبر|نوفمبر|ديسمبر)/
    };
    var parseMonthPatterns$1d = {
      narrow: [/^ي/, /^ف/, /^م/, /^أ/, /^م/, /^ي/, /^ي/, /^أ/, /^س/, /^أ/, /^ن/, /^د/],
      any: [/^ينا/, /^فبر/, /^مارس/, /^أبريل/, /^مايو/, /^يون/, /^يول/, /^أغس/, /^سبت/, /^أكت/, /^نوف/, /^ديس/]
    };
    var matchDayPatterns$1d = {
      narrow: /^(ح|ن|ث|ر|خ|ج|س)/,
      short: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/,
      abbreviated: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/,
      wide: /^(الأحد|الاثنين|الثلاثاء|الأربعاء|الخميس|الجمعة|السبت)/
    };
    var parseDayPatterns$1d = {
      narrow: [/^ح/, /^ن/, /^ث/, /^ر/, /^خ/, /^ج/, /^س/],
      any: [/أحد/, /اثنين/, /ثلاثاء/, /أربعاء/, /خميس/, /جمعة/, /سبت/]
    };
    var matchDayPeriodPatterns$1d = {
      narrow: /^(ص|م|ن|ظ|في الصباح|بعد الظهر|في المساء|في الليل)/,
      abbreviated: /^(ص|م|نصف الليل|ظهراً|في الصباح|بعد الظهر|في المساء|في الليل)/,
      wide: /^(ص|م|نصف الليل|في الصباح|ظهراً|بعد الظهر|في المساء|في الليل)/,
      any: /^(ص|م|صباح|ظهر|مساء|ليل)/
    };
    var parseDayPeriodPatterns$1d = {
      any: {
        am: /^ص/,
        pm: /^م/,
        midnight: /^ن/,
        noon: /^ظ/,
        morning: /^ص/,
        afternoon: /^بعد/,
        evening: /^م/,
        night: /^ل/
      }
    };
    var match$1d = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1d,
        parsePattern: parseOrdinalNumberPattern$1d,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1d,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1d,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1d,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1d,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1d,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1d,
        defaultParseWidth: 'any'
      })
    };

    var locale$1o = {
      code: 'ar-EG',
      formatDistance: formatDistance$1e,
      formatLong: formatLong$1m,
      formatRelative: formatRelative$1e,
      localize: localize$1e,
      match: match$1d,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$1c = {
      lessThanXSeconds: {
        one: 'أقل من ثانية واحدة',
        two: 'أقل من ثانتين',
        threeToTen: 'أقل من {{count}} ثواني',
        other: 'أقل من {{count}} ثانية'
      },
      xSeconds: {
        one: 'ثانية واحدة',
        two: 'ثانتين',
        threeToTen: '{{count}} ثواني',
        other: '{{count}} ثانية'
      },
      halfAMinute: 'نصف دقيقة',
      lessThanXMinutes: {
        one: 'أقل من دقيقة',
        two: 'أقل من دقيقتين',
        threeToTen: 'أقل من {{count}} دقائق',
        other: 'أقل من {{count}} دقيقة'
      },
      xMinutes: {
        one: 'دقيقة واحدة',
        two: 'دقيقتين',
        threeToTen: '{{count}} دقائق',
        other: '{{count}} دقيقة'
      },
      aboutXHours: {
        one: 'ساعة واحدة تقريباً',
        two: 'ساعتين تقريباً',
        threeToTen: '{{count}} ساعات تقريباً',
        other: '{{count}} ساعة تقريباً'
      },
      xHours: {
        one: 'ساعة واحدة',
        two: 'ساعتين',
        threeToTen: '{{count}} ساعات',
        other: '{{count}} ساعة'
      },
      xDays: {
        one: 'يوم واحد',
        two: 'يومين',
        threeToTen: '{{count}} أيام',
        other: '{{count}} يوم'
      },
      aboutXWeeks: {
        one: 'أسبوع واحد تقريباً',
        two: 'أسبوعين تقريباً',
        threeToTen: '{{count}} أسابيع تقريباً',
        other: '{{count}} أسبوع تقريباً'
      },
      xWeeks: {
        one: 'أسبوع واحد',
        two: 'أسبوعين',
        threeToTen: '{{count}} أسابيع',
        other: '{{count}} أسبوع'
      },
      aboutXMonths: {
        one: 'شهر واحد تقريباً',
        two: 'شهرين تقريباً',
        threeToTen: '{{count}} أشهر تقريباً',
        other: '{{count}} شهر تقريباً'
      },
      xMonths: {
        one: 'شهر واحد',
        two: 'شهرين',
        threeToTen: '{{count}} أشهر',
        other: '{{count}} شهر'
      },
      aboutXYears: {
        one: 'عام واحد تقريباً',
        two: 'عامين تقريباً',
        threeToTen: '{{count}} أعوام تقريباً',
        other: '{{count}} عام تقريباً'
      },
      xYears: {
        one: 'عام واحد',
        two: 'عامين',
        threeToTen: '{{count}} أعوام',
        other: '{{count}} عام'
      },
      overXYears: {
        one: 'أكثر من عام',
        two: 'أكثر من عامين',
        threeToTen: 'أكثر من {{count}} أعوام',
        other: 'أكثر من {{count}} عام'
      },
      almostXYears: {
        one: 'عام واحد تقريباً',
        two: 'عامين تقريباً',
        threeToTen: '{{count}} أعوام تقريباً',
        other: '{{count}} عام تقريباً'
      }
    };
    var formatDistance$1d = function (token, count, options) {
      options = options || {};
      var usageGroup = formatDistanceLocale$1c[token];
      var result;
      if (typeof usageGroup === 'string') {
        result = usageGroup;
      } else if (count === 1) {
        result = usageGroup.one;
      } else if (count === 2) {
        result = usageGroup.two;
      } else if (count <= 10) {
        result = usageGroup.threeToTen.replace('{{count}}', String(count));
      } else {
        result = usageGroup.other.replace('{{count}}', String(count));
      }
      if (options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'في خلال ' + result;
        } else {
          return 'منذ ' + result;
        }
      }
      return result;
    };

    var dateFormats$1l = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$1l = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$1l = {
      full: "{{date}} 'عند' {{time}}",
      long: "{{date}} 'عند' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1l = {
      date: buildFormatLongFn({
        formats: dateFormats$1l,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1l,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1l,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1d = {
      lastWeek: "'أخر' eeee 'عند' p",
      yesterday: "'أمس عند' p",
      today: "'اليوم عند' p",
      tomorrow: "'غداً عند' p",
      nextWeek: "eeee 'عند' p",
      other: 'P'
    };
    var formatRelative$1d = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1d[token];
    };

    var eraValues$1d = {
      narrow: ['ق', 'ب'],
      abbreviated: ['ق.م.', 'ب.م.'],
      wide: ['قبل الميلاد', 'بعد الميلاد']
    };
    var quarterValues$1d = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ر1', 'ر2', 'ر3', 'ر4'],
      wide: ['الربع الأول', 'الربع الثاني', 'الربع الثالث', 'الربع الرابع']
    };
    var monthValues$1d = {
      narrow: ['ي', 'ف', 'م', 'أ', 'م', 'ي', 'ي', 'غ', 'ش', 'أ', 'ن', 'د'],
      abbreviated: ['ينا', 'فبر', 'مارس', 'أبريل', 'ماي', 'يونـ', 'يولـ', 'غشت', 'شتنـ', 'أكتـ', 'نونـ', 'دجنـ'],
      wide: ['يناير', 'فبراير', 'مارس', 'أبريل', 'ماي', 'يونيو', 'يوليوز', 'غشت', 'شتنبر', 'أكتوبر', 'نونبر', 'دجنبر']
    };
    var dayValues$1d = {
      narrow: ['ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
      short: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      abbreviated: ['أحد', 'اثنـ', 'ثلا', 'أربـ', 'خميـ', 'جمعة', 'سبت'],
      wide: ['الأحد', 'الإثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت']
    };
    var dayPeriodValues$1d = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      }
    };
    var formattingDayPeriodValues$_ = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'في الصباح',
        afternoon: 'بعد الظـهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'في الصباح',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظـهر',
        evening: 'في المساء',
        night: 'في الليل'
      }
    };
    var ordinalNumber$1d = function (dirtyNumber) {
      return String(dirtyNumber);
    };
    var localize$1d = {
      ordinalNumber: ordinalNumber$1d,
      era: buildLocalizeFn({
        values: eraValues$1d,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1d,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1d,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1d,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1d,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$_,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1c = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$1c = /\d+/i;
    var matchEraPatterns$1c = {
      narrow: /^(ق|ب)/i,
      abbreviated: /^(ق\.?\s?م\.?|ق\.?\s?م\.?\s?|a\.?\s?d\.?|c\.?\s?)/i,
      wide: /^(قبل الميلاد|قبل الميلاد|بعد الميلاد|بعد الميلاد)/i
    };
    var parseEraPatterns$1c = {
      any: [/^قبل/i, /^بعد/i]
    };
    var matchQuarterPatterns$1c = {
      narrow: /^[1234]/i,
      abbreviated: /^ر[1234]/i,
      wide: /^الربع [1234]/i
    };
    var parseQuarterPatterns$1c = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1c = {
      narrow: /^[يفمأمسند]/i,
      abbreviated: /^(ين|ف|مار|أب|ماي|يون|يول|غش|شت|أك|ن|د)/i,
      wide: /^(ين|ف|مار|أب|ماي|يون|يول|غش|شت|أك|ن|د)/i
    };
    var parseMonthPatterns$1c = {
      narrow: [/^ي/i, /^ف/i, /^م/i, /^أ/i, /^م/i, /^ي/i, /^ي/i, /^غ/i, /^ش/i, /^أ/i, /^ن/i, /^د/i],
      any: [/^ين/i, /^فب/i, /^مار/i, /^أب/i, /^ماي/i, /^يون/i, /^يول/i, /^غشت/i, /^ش/i, /^أك/i, /^ن/i, /^د/i]
    };
    var matchDayPatterns$1c = {
      narrow: /^[حنثرخجس]/i,
      short: /^(أحد|إثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/i,
      abbreviated: /^(أحد|إثن|ثلا|أرب|خمي|جمعة|سبت)/i,
      wide: /^(الأحد|الإثنين|الثلاثاء|الأربعاء|الخميس|الجمعة|السبت)/i
    };
    var parseDayPatterns$1c = {
      narrow: [/^ح/i, /^ن/i, /^ث/i, /^ر/i, /^خ/i, /^ج/i, /^س/i],
      wide: [/^الأحد/i, /^الإثنين/i, /^الثلاثاء/i, /^الأربعاء/i, /^الخميس/i, /^الجمعة/i, /^السبت/i],
      any: [/^أح/i, /^إث/i, /^ث/i, /^أر/i, /^خ/i, /^ج/i, /^س/i]
    };
    var matchDayPeriodPatterns$1c = {
      narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
      any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
    };
    var parseDayPeriodPatterns$1c = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mi/i,
        noon: /^no/i,
        morning: /morning/i,
        afternoon: /afternoon/i,
        evening: /evening/i,
        night: /night/i
      }
    };
    var match$1c = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1c,
        parsePattern: parseOrdinalNumberPattern$1c,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1c,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1c,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return Number(index) + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1c,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1c,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1c,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1c,
        defaultParseWidth: 'any'
      })
    };

    var locale$1n = {
      code: 'ar-MA',
      formatDistance: formatDistance$1d,
      formatLong: formatLong$1l,
      formatRelative: formatRelative$1d,
      localize: localize$1d,
      match: match$1c,
      options: {
        weekStartsOn: 1,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$1b = {
      lessThanXSeconds: {
        one: 'أقل من ثانية واحدة',
        two: 'أقل من ثانتين',
        threeToTen: 'أقل من {{count}} ثواني',
        other: 'أقل من {{count}} ثانية'
      },
      xSeconds: {
        one: 'ثانية واحدة',
        two: 'ثانتين',
        threeToTen: '{{count}} ثواني',
        other: '{{count}} ثانية'
      },
      halfAMinute: 'نصف دقيقة',
      lessThanXMinutes: {
        one: 'أقل من دقيقة',
        two: 'أقل من دقيقتين',
        threeToTen: 'أقل من {{count}} دقائق',
        other: 'أقل من {{count}} دقيقة'
      },
      xMinutes: {
        one: 'دقيقة واحدة',
        two: 'دقيقتين',
        threeToTen: '{{count}} دقائق',
        other: '{{count}} دقيقة'
      },
      aboutXHours: {
        one: 'ساعة واحدة تقريباً',
        two: 'ساعتين تقريباً',
        threeToTen: '{{count}} ساعات تقريباً',
        other: '{{count}} ساعة تقريباً'
      },
      xHours: {
        one: 'ساعة واحدة',
        two: 'ساعتين',
        threeToTen: '{{count}} ساعات',
        other: '{{count}} ساعة'
      },
      xDays: {
        one: 'يوم واحد',
        two: 'يومين',
        threeToTen: '{{count}} أيام',
        other: '{{count}} يوم'
      },
      aboutXWeeks: {
        one: 'أسبوع واحد تقريباً',
        two: 'أسبوعين تقريباً',
        threeToTen: '{{count}} أسابيع تقريباً',
        other: '{{count}} أسبوع تقريباً'
      },
      xWeeks: {
        one: 'أسبوع واحد',
        two: 'أسبوعين',
        threeToTen: '{{count}} أسابيع',
        other: '{{count}} أسبوع'
      },
      aboutXMonths: {
        one: 'شهر واحد تقريباً',
        two: 'شهرين تقريباً',
        threeToTen: '{{count}} أشهر تقريباً',
        other: '{{count}} شهر تقريباً'
      },
      xMonths: {
        one: 'شهر واحد',
        two: 'شهرين',
        threeToTen: '{{count}} أشهر',
        other: '{{count}} شهر'
      },
      aboutXYears: {
        one: 'عام واحد تقريباً',
        two: 'عامين تقريباً',
        threeToTen: '{{count}} أعوام تقريباً',
        other: '{{count}} عام تقريباً'
      },
      xYears: {
        one: 'عام واحد',
        two: 'عامين',
        threeToTen: '{{count}} أعوام',
        other: '{{count}} عام'
      },
      overXYears: {
        one: 'أكثر من عام',
        two: 'أكثر من عامين',
        threeToTen: 'أكثر من {{count}} أعوام',
        other: 'أكثر من {{count}} عام'
      },
      almostXYears: {
        one: 'عام واحد تقريباً',
        two: 'عامين تقريباً',
        threeToTen: '{{count}} أعوام تقريباً',
        other: '{{count}} عام تقريباً'
      }
    };
    var formatDistance$1c = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$1b[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else if (count === 2) {
        result = tokenValue.two;
      } else if (count <= 10) {
        result = tokenValue.threeToTen.replace('{{count}}', String(count));
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'في خلال ' + result;
        } else {
          return 'منذ ' + result;
        }
      }
      return result;
    };

    var dateFormats$1k = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$1k = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$1k = {
      full: "{{date}} 'عند' {{time}}",
      long: "{{date}} 'عند' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1k = {
      date: buildFormatLongFn({
        formats: dateFormats$1k,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1k,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1k,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1c = {
      lastWeek: "'أخر' eeee 'عند' p",
      yesterday: "'أمس عند' p",
      today: "'اليوم عند' p",
      tomorrow: "'غداً عند' p",
      nextWeek: "eeee 'عند' p",
      other: 'P'
    };
    var formatRelative$1c = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1c[token];
    };

    var eraValues$1c = {
      narrow: ['ق', 'ب'],
      abbreviated: ['ق.م.', 'ب.م.'],
      wide: ['قبل الميلاد', 'بعد الميلاد']
    };
    var quarterValues$1c = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ر1', 'ر2', 'ر3', 'ر4'],
      wide: ['الربع الأول', 'الربع الثاني', 'الربع الثالث', 'الربع الرابع']
    };
    var monthValues$1c = {
      narrow: ['ي', 'ف', 'م', 'أ', 'م', 'ي', 'ي', 'أ', 'س', 'أ', 'ن', 'د'],
      abbreviated: ['ينا', 'فبر', 'مارس', 'أبريل', 'مايو', 'يونـ', 'يولـ', 'أغسـ', 'سبتـ', 'أكتـ', 'نوفـ', 'ديسـ'],
      wide: ['يناير', 'فبراير', 'مارس', 'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر']
    };
    var dayValues$1c = {
      narrow: ['ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
      short: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      abbreviated: ['أحد', 'اثنـ', 'ثلا', 'أربـ', 'خميـ', 'جمعة', 'سبت'],
      wide: ['الأحد', 'الاثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت']
    };
    var dayPeriodValues$1c = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظهر',
        evening: 'مساءاً',
        night: 'ليلاً'
      }
    };
    var formattingDayPeriodValues$Z = {
      narrow: {
        am: 'ص',
        pm: 'م',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'في الصباح',
        afternoon: 'بعد الظـهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'في الصباح',
        afternoon: 'بعد الظهر',
        evening: 'في المساء',
        night: 'في الليل'
      },
      wide: {
        am: 'ص',
        pm: 'م',
        midnight: 'نصف الليل',
        noon: 'ظهر',
        morning: 'صباحاً',
        afternoon: 'بعد الظـهر',
        evening: 'في المساء',
        night: 'في الليل'
      }
    };
    var ordinalNumber$1c = function (dirtyNumber) {
      return String(dirtyNumber);
    };
    var localize$1c = {
      ordinalNumber: ordinalNumber$1c,
      era: buildLocalizeFn({
        values: eraValues$1c,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1c,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1c,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1c,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1c,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$Z,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1b = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$1b = /\d+/i;
    var matchEraPatterns$1b = {
      narrow: /^(ق|ب)/i,
      abbreviated: /^(ق\.?\s?م\.?|ق\.?\s?م\.?\s?|a\.?\s?d\.?|c\.?\s?)/i,
      wide: /^(قبل الميلاد|قبل الميلاد|بعد الميلاد|بعد الميلاد)/i
    };
    var parseEraPatterns$1b = {
      any: [/^قبل/i, /^بعد/i]
    };
    var matchQuarterPatterns$1b = {
      narrow: /^[1234]/i,
      abbreviated: /^ر[1234]/i,
      wide: /^الربع [1234]/i
    };
    var parseQuarterPatterns$1b = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1b = {
      narrow: /^[يفمأمسند]/i,
      abbreviated: /^(ين|ف|مار|أب|ماي|يون|يول|أغ|س|أك|ن|د)/i,
      wide: /^(ين|ف|مار|أب|ماي|يون|يول|أغ|س|أك|ن|د)/i
    };
    var parseMonthPatterns$1b = {
      narrow: [/^ي/i, /^ف/i, /^م/i, /^أ/i, /^م/i, /^ي/i, /^ي/i, /^أ/i, /^س/i, /^أ/i, /^ن/i, /^د/i],
      any: [/^ين/i, /^ف/i, /^مار/i, /^أب/i, /^ماي/i, /^يون/i, /^يول/i, /^أغ/i, /^س/i, /^أك/i, /^ن/i, /^د/i]
    };
    var matchDayPatterns$1b = {
      narrow: /^[حنثرخجس]/i,
      short: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/i,
      abbreviated: /^(أحد|اثن|ثلا|أرب|خمي|جمعة|سبت)/i,
      wide: /^(الأحد|الاثنين|الثلاثاء|الأربعاء|الخميس|الجمعة|السبت)/i
    };
    var parseDayPatterns$1b = {
      narrow: [/^ح/i, /^ن/i, /^ث/i, /^ر/i, /^خ/i, /^ج/i, /^س/i],
      wide: [/^الأحد/i, /^الاثنين/i, /^الثلاثاء/i, /^الأربعاء/i, /^الخميس/i, /^الجمعة/i, /^السبت/i],
      any: [/^أح/i, /^اث/i, /^ث/i, /^أر/i, /^خ/i, /^ج/i, /^س/i]
    };
    var matchDayPeriodPatterns$1b = {
      narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
      any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
    };
    var parseDayPeriodPatterns$1b = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mi/i,
        noon: /^no/i,
        morning: /morning/i,
        afternoon: /afternoon/i,
        evening: /evening/i,
        night: /night/i
      }
    };
    var match$1b = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1b,
        parsePattern: parseOrdinalNumberPattern$1b,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1b,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1b,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1b,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1b,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1b,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1b,
        defaultParseWidth: 'any'
      })
    };

    var locale$1m = {
      code: 'ar-SA',
      formatDistance: formatDistance$1c,
      formatLong: formatLong$1k,
      formatRelative: formatRelative$1c,
      localize: localize$1c,
      match: match$1b,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$1a = {
      lessThanXSeconds: {
        one: 'أقل من ثانية',
        two: 'أقل من زوز ثواني',
        threeToTen: 'أقل من {{count}} ثواني',
        other: 'أقل من {{count}} ثانية'
      },
      xSeconds: {
        one: 'ثانية',
        two: 'زوز ثواني',
        threeToTen: '{{count}} ثواني',
        other: '{{count}} ثانية'
      },
      halfAMinute: 'نص دقيقة',
      lessThanXMinutes: {
        one: 'أقل من دقيقة',
        two: 'أقل من دقيقتين',
        threeToTen: 'أقل من {{count}} دقايق',
        other: 'أقل من {{count}} دقيقة'
      },
      xMinutes: {
        one: 'دقيقة',
        two: 'دقيقتين',
        threeToTen: '{{count}} دقايق',
        other: '{{count}} دقيقة'
      },
      aboutXHours: {
        one: 'ساعة تقريب',
        two: 'ساعتين تقريب',
        threeToTen: '{{count}} سوايع تقريب',
        other: '{{count}} ساعة تقريب'
      },
      xHours: {
        one: 'ساعة',
        two: 'ساعتين',
        threeToTen: '{{count}} سوايع',
        other: '{{count}} ساعة'
      },
      xDays: {
        one: 'نهار',
        two: 'نهارين',
        threeToTen: '{{count}} أيام',
        other: '{{count}} يوم'
      },
      aboutXWeeks: {
        one: 'جمعة تقريب',
        two: 'جمعتين تقريب',
        threeToTen: '{{count}} جماع تقريب',
        other: '{{count}} جمعة تقريب'
      },
      xWeeks: {
        one: 'جمعة',
        two: 'جمعتين',
        threeToTen: '{{count}} جماع',
        other: '{{count}} جمعة'
      },
      aboutXMonths: {
        one: 'شهر تقريب',
        two: 'شهرين تقريب',
        threeToTen: '{{count}} أشهرة تقريب',
        other: '{{count}} شهر تقريب'
      },
      xMonths: {
        one: 'شهر',
        two: 'شهرين',
        threeToTen: '{{count}} أشهرة',
        other: '{{count}} شهر'
      },
      aboutXYears: {
        one: 'عام تقريب',
        two: 'عامين تقريب',
        threeToTen: '{{count}} أعوام تقريب',
        other: '{{count}} عام تقريب'
      },
      xYears: {
        one: 'عام',
        two: 'عامين',
        threeToTen: '{{count}} أعوام',
        other: '{{count}} عام'
      },
      overXYears: {
        one: 'أكثر من عام',
        two: 'أكثر من عامين',
        threeToTen: 'أكثر من {{count}} أعوام',
        other: 'أكثر من {{count}} عام'
      },
      almostXYears: {
        one: 'عام تقريب',
        two: 'عامين تقريب',
        threeToTen: '{{count}} أعوام تقريب',
        other: '{{count}} عام تقريب'
      }
    };
    var formatDistance$1b = function (token, count, options) {
      var usageGroup = formatDistanceLocale$1a[token];
      var result;
      if (typeof usageGroup === 'string') {
        result = usageGroup;
      } else if (count === 1) {
        result = usageGroup.one;
      } else if (count === 2) {
        result = usageGroup.two;
      } else if (count <= 10) {
        result = usageGroup.threeToTen.replace('{{count}}', String(count));
      } else {
        result = usageGroup.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'في ' + result;
        } else {
          return 'عندو ' + result;
        }
      }
      return result;
    };

    var dateFormats$1j = {
      full: 'EEEE، do MMMM y',
      long: 'do MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$1j = {
      full: 'HH:mm:ss',
      long: 'HH:mm:ss',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$1j = {
      full: "{{date}} 'مع' {{time}}",
      long: "{{date}} 'مع' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1j = {
      date: buildFormatLongFn({
        formats: dateFormats$1j,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1j,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1j,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1b = {
      lastWeek: "eeee 'إلي فات مع' p",
      yesterday: "'البارح مع' p",
      today: "'اليوم مع' p",
      tomorrow: "'غدوة مع' p",
      nextWeek: "eeee 'الجمعة الجاية مع' p 'نهار'",
      other: 'P'
    };
    var formatRelative$1b = function (token) {
      return formatRelativeLocale$1b[token];
    };

    var eraValues$1b = {
      narrow: ['ق', 'ب'],
      abbreviated: ['ق.م.', 'ب.م.'],
      wide: ['قبل الميلاد', 'بعد الميلاد']
    };
    var quarterValues$1b = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ر1', 'ر2', 'ر3', 'ر4'],
      wide: ['الربع الأول', 'الربع الثاني', 'الربع الثالث', 'الربع الرابع']
    };
    var monthValues$1b = {
      narrow: ['د', 'ن', 'أ', 'س', 'أ', 'ج', 'ج', 'م', 'أ', 'م', 'ف', 'ج'],
      abbreviated: ['جانفي', 'فيفري', 'مارس', 'أفريل', 'ماي', 'جوان', 'جويلية', 'أوت', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'],
      wide: ['جانفي', 'فيفري', 'مارس', 'أفريل', 'ماي', 'جوان', 'جويلية', 'أوت', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر']
    };
    var dayValues$1b = {
      narrow: ['ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
      short: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      abbreviated: ['أحد', 'اثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
      wide: ['الأحد', 'الاثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت']
    };
    var dayPeriodValues$1b = {
      narrow: {
        am: 'ص',
        pm: 'ع',
        morning: 'الصباح',
        noon: 'القايلة',
        afternoon: 'بعد القايلة',
        evening: 'العشية',
        night: 'الليل',
        midnight: 'نص الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'ع',
        morning: 'الصباح',
        noon: 'القايلة',
        afternoon: 'بعد القايلة',
        evening: 'العشية',
        night: 'الليل',
        midnight: 'نص الليل'
      },
      wide: {
        am: 'ص',
        pm: 'ع',
        morning: 'الصباح',
        noon: 'القايلة',
        afternoon: 'بعد القايلة',
        evening: 'العشية',
        night: 'الليل',
        midnight: 'نص الليل'
      }
    };
    var formattingDayPeriodValues$Y = {
      narrow: {
        am: 'ص',
        pm: 'ع',
        morning: 'في الصباح',
        noon: 'في القايلة',
        afternoon: 'بعد القايلة',
        evening: 'في العشية',
        night: 'في الليل',
        midnight: 'نص الليل'
      },
      abbreviated: {
        am: 'ص',
        pm: 'ع',
        morning: 'في الصباح',
        noon: 'في القايلة',
        afternoon: 'بعد القايلة',
        evening: 'في العشية',
        night: 'في الليل',
        midnight: 'نص الليل'
      },
      wide: {
        am: 'ص',
        pm: 'ع',
        morning: 'في الصباح',
        noon: 'في القايلة',
        afternoon: 'بعد القايلة',
        evening: 'في العشية',
        night: 'في الليل',
        midnight: 'نص الليل'
      }
    };
    var ordinalNumber$1b = function (num) {
      return String(num);
    };
    var localize$1b = {
      ordinalNumber: ordinalNumber$1b,
      era: buildLocalizeFn({
        values: eraValues$1b,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1b,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1b,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1b,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1b,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$Y,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1a = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$1a = /\d+/i;
    var matchEraPatterns$1a = {
      narrow: /[قب]/,
      abbreviated: /[قب]\.م\./,
      wide: /(قبل|بعد) الميلاد/
    };
    var parseEraPatterns$1a = {
      any: [/قبل/, /بعد/]
    };
    var matchQuarterPatterns$1a = {
      narrow: /^[1234]/i,
      abbreviated: /ر[1234]/,
      wide: /الربع (الأول|الثاني|الثالث|الرابع)/
    };
    var parseQuarterPatterns$1a = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1a = {
      narrow: /^[جفمأسند]/,
      abbreviated: /^(جانفي|فيفري|مارس|أفريل|ماي|جوان|جويلية|أوت|سبتمبر|أكتوبر|نوفمبر|ديسمبر)/,
      wide: /^(جانفي|فيفري|مارس|أفريل|ماي|جوان|جويلية|أوت|سبتمبر|أكتوبر|نوفمبر|ديسمبر)/
    };
    var parseMonthPatterns$1a = {
      narrow: [/^ج/i, /^ف/i, /^م/i, /^أ/i, /^م/i, /^ج/i, /^ج/i, /^أ/i, /^س/i, /^أ/i, /^ن/i, /^د/i],
      any: [/^جانفي/i, /^فيفري/i, /^مارس/i, /^أفريل/i, /^ماي/i, /^جوان/i, /^جويلية/i, /^أوت/i, /^سبتمبر/i, /^أكتوبر/i, /^نوفمبر/i, /^ديسمبر/i]
    };
    var matchDayPatterns$1a = {
      narrow: /^[حنثرخجس]/i,
      short: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/i,
      abbreviated: /^(أحد|اثنين|ثلاثاء|أربعاء|خميس|جمعة|سبت)/i,
      wide: /^(الأحد|الاثنين|الثلاثاء|الأربعاء|الخميس|الجمعة|السبت)/i
    };
    var parseDayPatterns$1a = {
      narrow: [/^ح/i, /^ن/i, /^ث/i, /^ر/i, /^خ/i, /^ج/i, /^س/i],
      wide: [/^الأحد/i, /^الاثنين/i, /^الثلاثاء/i, /^الأربعاء/i, /^الخميس/i, /^الجمعة/i, /^السبت/i],
      any: [/^أح/i, /^اث/i, /^ث/i, /^أر/i, /^خ/i, /^ج/i, /^س/i]
    };
    var matchDayPeriodPatterns$1a = {
      narrow: /^(ص|ع|ن ل|ل|(في|مع) (صباح|قايلة|عشية|ليل))/,
      any: /^([صع]|نص الليل|قايلة|(في|مع) (صباح|قايلة|عشية|ليل))/
    };
    var parseDayPeriodPatterns$1a = {
      any: {
        am: /^ص/,
        pm: /^ع/,
        midnight: /نص الليل/,
        noon: /قايلة/,
        afternoon: /بعد القايلة/,
        morning: /صباح/,
        evening: /عشية/,
        night: /ليل/
      }
    };
    var match$1a = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1a,
        parsePattern: parseOrdinalNumberPattern$1a,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1a,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1a,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1a,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1a,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1a,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1a,
        defaultParseWidth: 'any'
      })
    };

    var locale$1l = {
      code: 'ar-TN',
      formatDistance: formatDistance$1b,
      formatLong: formatLong$1j,
      formatRelative: formatRelative$1b,
      localize: localize$1b,
      match: match$1a,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$19 = {
      lessThanXSeconds: {
        one: 'bir saniyədən az',
        other: '{{count}} bir saniyədən az'
      },
      xSeconds: {
        one: '1 saniyə',
        other: '{{count}} saniyə'
      },
      halfAMinute: 'yarım dəqiqə',
      lessThanXMinutes: {
        one: 'bir dəqiqədən az',
        other: '{{count}} bir dəqiqədən az'
      },
      xMinutes: {
        one: 'bir dəqiqə',
        other: '{{count}} dəqiqə'
      },
      aboutXHours: {
        one: 'təxminən 1 saat',
        other: 'təxminən {{count}} saat'
      },
      xHours: {
        one: '1 saat',
        other: '{{count}} saat'
      },
      xDays: {
        one: '1 gün',
        other: '{{count}} gün'
      },
      aboutXWeeks: {
        one: 'təxminən 1 həftə',
        other: 'təxminən {{count}} həftə'
      },
      xWeeks: {
        one: '1 həftə',
        other: '{{count}} həftə'
      },
      aboutXMonths: {
        one: 'təxminən 1 ay',
        other: 'təxminən {{count}} ay'
      },
      xMonths: {
        one: '1 ay',
        other: '{{count}} ay'
      },
      aboutXYears: {
        one: 'təxminən 1 il',
        other: 'təxminən {{count}} il'
      },
      xYears: {
        one: '1 il',
        other: '{{count}} il'
      },
      overXYears: {
        one: '1 ildən çox',
        other: '{{count}} ildən çox'
      },
      almostXYears: {
        one: 'demək olar ki 1 il',
        other: 'demək olar ki {{count}} il'
      }
    };
    var formatDistance$1a = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$19[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' sonra';
        } else {
          return result + ' əvvəl';
        }
      }
      return result;
    };

    var dateFormats$1i = {
      full: "EEEE, do MMMM y 'il'",
      long: "do MMMM y 'il'",
      medium: "d MMM y 'il'",
      short: 'dd.MM.yyyy'
    };
    var timeFormats$1i = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$1i = {
      full: "{{date}} {{time}} - 'də'",
      long: "{{date}} {{time}} - 'də'",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1i = {
      date: buildFormatLongFn({
        formats: dateFormats$1i,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1i,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1i,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1a = {
      lastWeek: "'sonuncu' eeee p -'də'",
      yesterday: "'dünən' p -'də'",
      today: "'bugün' p -'də'",
      tomorrow: "'sabah' p -'də'",
      nextWeek: "eeee p -'də'",
      other: 'P'
    };
    var formatRelative$1a = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1a[token];
    };

    var eraValues$1a = {
      narrow: ['e.ə', 'b.e'],
      abbreviated: ['e.ə', 'b.e'],
      wide: ['eramızdan əvvəl', 'bizim era']
    };
    var quarterValues$1a = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1ci kvartal', '2ci kvartal', '3cü kvartal', '4cü kvartal']
    };
    var monthValues$1a = {
      narrow: ['Y', 'F', 'M', 'A', 'M', 'İ', 'İ', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Yan', 'Fev', 'Mar', 'Apr', 'May', 'İyun', 'İyul', 'Avq', 'Sen', 'Okt', 'Noy', 'Dek'],
      wide: ['Yanvar', 'Fevral', 'Mart', 'Aprel', 'May', 'İyun', 'İyul', 'Avqust', 'Sentyabr', 'Oktyabr', 'Noyabr', 'Dekabr']
    };
    var dayValues$1a = {
      narrow: ['B.', 'B.e', 'Ç.a', 'Ç.', 'C.a', 'C.', 'Ş.'],
      short: ['B.', 'B.e', 'Ç.a', 'Ç.', 'C.a', 'C.', 'Ş.'],
      abbreviated: ['Baz', 'Baz.e', 'Çər.a', 'Çər', 'Cüm.a', 'Cüm', 'Şə'],
      wide: ['Bazar', 'Bazar ertəsi', 'Çərşənbə axşamı', 'Çərşənbə', 'Cümə axşamı', 'Cümə', 'Şənbə']
    };
    var dayPeriodValues$1a = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'gecəyarı',
        noon: 'gün',
        morning: 'səhər',
        afternoon: 'gündüz',
        evening: 'axşam',
        night: 'gecə'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'gecəyarı',
        noon: 'gün',
        morning: 'səhər',
        afternoon: 'gündüz',
        evening: 'axşam',
        night: 'gecə'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'gecəyarı',
        noon: 'gün',
        morning: 'səhər',
        afternoon: 'gündüz',
        evening: 'axşam',
        night: 'gecə'
      }
    };
    var formattingDayPeriodValues$X = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'gecəyarı',
        noon: 'gün',
        morning: 'səhər',
        afternoon: 'gündüz',
        evening: 'axşam',
        night: 'gecə'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'gecəyarı',
        noon: 'gün',
        morning: 'səhər',
        afternoon: 'gündüz',
        evening: 'axşam',
        night: 'gecə'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'gecəyarı',
        noon: 'gün',
        morning: 'səhər',
        afternoon: 'gündüz',
        evening: 'axşam',
        night: 'gecə'
      }
    };
    var suffixes$1 = {
      1: '-inci',
      5: '-inci',
      8: '-inci',
      70: '-inci',
      80: '-inci',
      2: '-nci',
      7: '-nci',
      20: '-nci',
      50: '-nci',
      3: '-üncü',
      4: '-üncü',
      100: '-üncü',
      6: '-ncı',
      9: '-uncu',
      10: '-uncu',
      30: '-uncu',
      60: '-ıncı',
      90: '-ıncı'
    };
    var getSuffix = function (number) {
      if (number === 0) {
        return number + '-ıncı';
      }
      var a = number % 10;
      var b = number % 100 - a;
      var c = number >= 100 ? 100 : null;
      if (suffixes$1[a]) {
        return suffixes$1[a];
      } else if (suffixes$1[b]) {
        return suffixes$1[b];
      } else if (c !== null) {
        return suffixes$1[c];
      }
      return '';
    };
    var ordinalNumber$1a = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      var suffix = getSuffix(number);
      return number + suffix;
    };
    var localize$1a = {
      ordinalNumber: ordinalNumber$1a,
      era: buildLocalizeFn({
        values: eraValues$1a,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1a,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1a,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1a,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1a,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$X,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$19 = /^(\d+)(-?(ci|inci|nci|uncu|üncü|ncı))?/i;
    var parseOrdinalNumberPattern$19 = /\d+/i;
    var matchEraPatterns$19 = {
      narrow: /^(b|a)$/i,
      abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)$/i,
      wide: /^(bizim eradan əvvəl|bizim era)$/i
    };
    var parseEraPatterns$19 = {
      any: [/^b$/i, /^(a|c)$/i]
    };
    var matchQuarterPatterns$19 = {
      narrow: /^[1234]$/i,
      abbreviated: /^K[1234]$/i,
      wide: /^[1234](ci)? kvartal$/i
    };
    var parseQuarterPatterns$19 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$19 = {
      narrow: /^[(?-i)yfmaisond]$/i,
      abbreviated: /^(Yan|Fev|Mar|Apr|May|İyun|İyul|Avq|Sen|Okt|Noy|Dek)$/i,
      wide: /^(Yanvar|Fevral|Mart|Aprel|May|İyun|İyul|Avgust|Sentyabr|Oktyabr|Noyabr|Dekabr)$/i
    };
    var parseMonthPatterns$19 = {
      narrow: [/^[(?-i)y]$/i, /^[(?-i)f]$/i, /^[(?-i)m]$/i, /^[(?-i)a]$/i, /^[(?-i)m]$/i, /^[(?-i)i]$/i, /^[(?-i)i]$/i, /^[(?-i)a]$/i, /^[(?-i)s]$/i, /^[(?-i)o]$/i, /^[(?-i)n]$/i, /^[(?-i)d]$/i],
      abbreviated: [/^Yan$/i, /^Fev$/i, /^Mar$/i, /^Apr$/i, /^May$/i, /^İyun$/i, /^İyul$/i, /^Avg$/i, /^Sen$/i, /^Okt$/i, /^Noy$/i, /^Dek$/i],
      wide: [/^Yanvar$/i, /^Fevral$/i, /^Mart$/i, /^Aprel$/i, /^May$/i, /^İyun$/i, /^İyul$/i, /^Avgust$/i, /^Sentyabr$/i, /^Oktyabr$/i, /^Noyabr$/i, /^Dekabr$/i]
    };
    var matchDayPatterns$19 = {
      narrow: /^(B\.|B\.e|Ç\.a|Ç\.|C\.a|C\.|Ş\.)$/i,
      short: /^(B\.|B\.e|Ç\.a|Ç\.|C\.a|C\.|Ş\.)$/i,
      abbreviated: /^(Baz\.e|Çər|Çər\.a|Cüm|Cüm\.a|Şə)$/i,
      wide: /^(Bazar|Bazar ertəsi|Çərşənbə axşamı|Çərşənbə|Cümə axşamı|Cümə|Şənbə)$/i
    };
    var parseDayPatterns$19 = {
      narrow: [/^B\.$/i, /^B\.e$/i, /^Ç\.a$/i, /^Ç\.$/i, /^C\.a$/i, /^C\.$/i, /^Ş\.$/i],
      abbreviated: [/^Baz$/i, /^Baz\.e$/i, /^Çər\.a$/i, /^Çər$/i, /^Cüm\.a$/i, /^Cüm$/i, /^Şə$/i],
      wide: [/^Bazar$/i, /^Bazar ertəsi$/i, /^Çərşənbə axşamı$/i, /^Çərşənbə$/i, /^Cümə axşamı$/i, /^Cümə$/i, /^Şənbə$/i],
      any: [/^B\.$/i, /^B\.e$/i, /^Ç\.a$/i, /^Ç\.$/i, /^C\.a$/i, /^C\.$/i, /^Ş\.$/i]
    };
    var matchDayPeriodPatterns$19 = {
      narrow: /^(a|p|gecəyarı|gün|səhər|gündüz|axşam|gecə)$/i,
      any: /^(am|pm|a\.m\.|p\.m\.|AM|PM|gecəyarı|gün|səhər|gündüz|axşam|gecə)$/i
    };
    var parseDayPeriodPatterns$19 = {
      any: {
        am: /^a$/i,
        pm: /^p$/i,
        midnight: /^gecəyarı$/i,
        noon: /^gün$/i,
        morning: /səhər$/i,
        afternoon: /gündüz$/i,
        evening: /axşam$/i,
        night: /gecə$/i
      }
    };
    var match$19 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$19,
        parsePattern: parseOrdinalNumberPattern$19,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$19,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$19,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$19,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$19,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$19,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$19,
        defaultParseWidth: 'narrow'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$19,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$19,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$19,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$19,
        defaultParseWidth: 'any'
      })
    };

    var locale$1k = {
      code: 'az',
      formatDistance: formatDistance$1a,
      formatLong: formatLong$1i,
      formatRelative: formatRelative$1a,
      localize: localize$1a,
      match: match$19,
      options: {
        weekStartsOn: 1,
        firstWeekContainsDate: 1
      }
    };

    function declension$6(scheme, count) {
      if (scheme.one !== undefined && count === 1) {
        return scheme.one;
      }
      var rem10 = count % 10;
      var rem100 = count % 100;
      if (rem10 === 1 && rem100 !== 11) {
        return scheme.singularNominative.replace('{{count}}', String(count));
      } else if (rem10 >= 2 && rem10 <= 4 && (rem100 < 10 || rem100 > 20)) {
        return scheme.singularGenitive.replace('{{count}}', String(count));
      } else {
        return scheme.pluralGenitive.replace('{{count}}', String(count));
      }
    }
    function buildLocalizeTokenFn$4(scheme) {
      return function (count, options) {
        if (options && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            if (scheme.future) {
              return declension$6(scheme.future, count);
            } else {
              return 'праз ' + declension$6(scheme.regular, count);
            }
          } else {
            if (scheme.past) {
              return declension$6(scheme.past, count);
            } else {
              return declension$6(scheme.regular, count) + ' таму';
            }
          }
        } else {
          return declension$6(scheme.regular, count);
        }
      };
    }
    var halfAMinute$1 = function (_, options) {
      if (options && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'праз паўхвіліны';
        } else {
          return 'паўхвіліны таму';
        }
      }
      return 'паўхвіліны';
    };
    var formatDistanceLocale$18 = {
      lessThanXSeconds: buildLocalizeTokenFn$4({
        regular: {
          one: 'менш за секунду',
          singularNominative: 'менш за {{count}} секунду',
          singularGenitive: 'менш за {{count}} секунды',
          pluralGenitive: 'менш за {{count}} секунд'
        },
        future: {
          one: 'менш, чым праз секунду',
          singularNominative: 'менш, чым праз {{count}} секунду',
          singularGenitive: 'менш, чым праз {{count}} секунды',
          pluralGenitive: 'менш, чым праз {{count}} секунд'
        }
      }),
      xSeconds: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: '{{count}} секунда',
          singularGenitive: '{{count}} секунды',
          pluralGenitive: '{{count}} секунд'
        },
        past: {
          singularNominative: '{{count}} секунду таму',
          singularGenitive: '{{count}} секунды таму',
          pluralGenitive: '{{count}} секунд таму'
        },
        future: {
          singularNominative: 'праз {{count}} секунду',
          singularGenitive: 'праз {{count}} секунды',
          pluralGenitive: 'праз {{count}} секунд'
        }
      }),
      halfAMinute: halfAMinute$1,
      lessThanXMinutes: buildLocalizeTokenFn$4({
        regular: {
          one: 'менш за хвіліну',
          singularNominative: 'менш за {{count}} хвіліну',
          singularGenitive: 'менш за {{count}} хвіліны',
          pluralGenitive: 'менш за {{count}} хвілін'
        },
        future: {
          one: 'менш, чым праз хвіліну',
          singularNominative: 'менш, чым праз {{count}} хвіліну',
          singularGenitive: 'менш, чым праз {{count}} хвіліны',
          pluralGenitive: 'менш, чым праз {{count}} хвілін'
        }
      }),
      xMinutes: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: '{{count}} хвіліна',
          singularGenitive: '{{count}} хвіліны',
          pluralGenitive: '{{count}} хвілін'
        },
        past: {
          singularNominative: '{{count}} хвіліну таму',
          singularGenitive: '{{count}} хвіліны таму',
          pluralGenitive: '{{count}} хвілін таму'
        },
        future: {
          singularNominative: 'праз {{count}} хвіліну',
          singularGenitive: 'праз {{count}} хвіліны',
          pluralGenitive: 'праз {{count}} хвілін'
        }
      }),
      aboutXHours: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: 'каля {{count}} гадзіны',
          singularGenitive: 'каля {{count}} гадзін',
          pluralGenitive: 'каля {{count}} гадзін'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} гадзіну',
          singularGenitive: 'прыблізна праз {{count}} гадзіны',
          pluralGenitive: 'прыблізна праз {{count}} гадзін'
        }
      }),
      xHours: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: '{{count}} гадзіна',
          singularGenitive: '{{count}} гадзіны',
          pluralGenitive: '{{count}} гадзін'
        },
        past: {
          singularNominative: '{{count}} гадзіну таму',
          singularGenitive: '{{count}} гадзіны таму',
          pluralGenitive: '{{count}} гадзін таму'
        },
        future: {
          singularNominative: 'праз {{count}} гадзіну',
          singularGenitive: 'праз {{count}} гадзіны',
          pluralGenitive: 'праз {{count}} гадзін'
        }
      }),
      xDays: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: '{{count}} дзень',
          singularGenitive: '{{count}} дні',
          pluralGenitive: '{{count}} дзён'
        }
      }),
      aboutXWeeks: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: 'каля {{count}} месяца',
          singularGenitive: 'каля {{count}} месяцаў',
          pluralGenitive: 'каля {{count}} месяцаў'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} месяц',
          singularGenitive: 'прыблізна праз {{count}} месяцы',
          pluralGenitive: 'прыблізна праз {{count}} месяцаў'
        }
      }),
      xWeeks: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: '{{count}} месяц',
          singularGenitive: '{{count}} месяцы',
          pluralGenitive: '{{count}} месяцаў'
        }
      }),
      aboutXMonths: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: 'каля {{count}} месяца',
          singularGenitive: 'каля {{count}} месяцаў',
          pluralGenitive: 'каля {{count}} месяцаў'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} месяц',
          singularGenitive: 'прыблізна праз {{count}} месяцы',
          pluralGenitive: 'прыблізна праз {{count}} месяцаў'
        }
      }),
      xMonths: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: '{{count}} месяц',
          singularGenitive: '{{count}} месяцы',
          pluralGenitive: '{{count}} месяцаў'
        }
      }),
      aboutXYears: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: 'каля {{count}} года',
          singularGenitive: 'каля {{count}} гадоў',
          pluralGenitive: 'каля {{count}} гадоў'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} год',
          singularGenitive: 'прыблізна праз {{count}} гады',
          pluralGenitive: 'прыблізна праз {{count}} гадоў'
        }
      }),
      xYears: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: '{{count}} год',
          singularGenitive: '{{count}} гады',
          pluralGenitive: '{{count}} гадоў'
        }
      }),
      overXYears: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: 'больш за {{count}} год',
          singularGenitive: 'больш за {{count}} гады',
          pluralGenitive: 'больш за {{count}} гадоў'
        },
        future: {
          singularNominative: 'больш, чым праз {{count}} год',
          singularGenitive: 'больш, чым праз {{count}} гады',
          pluralGenitive: 'больш, чым праз {{count}} гадоў'
        }
      }),
      almostXYears: buildLocalizeTokenFn$4({
        regular: {
          singularNominative: 'амаль {{count}} год',
          singularGenitive: 'амаль {{count}} гады',
          pluralGenitive: 'амаль {{count}} гадоў'
        },
        future: {
          singularNominative: 'амаль праз {{count}} год',
          singularGenitive: 'амаль праз {{count}} гады',
          pluralGenitive: 'амаль праз {{count}} гадоў'
        }
      })
    };
    var formatDistance$19 = function (token, count, options) {
      options = options || {};
      return formatDistanceLocale$18[token](count, options);
    };

    var dateFormats$1h = {
      full: "EEEE, d MMMM y 'г.'",
      long: "d MMMM y 'г.'",
      medium: "d MMM y 'г.'",
      short: 'dd.MM.y'
    };
    var timeFormats$1h = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$1h = {
      any: '{{date}}, {{time}}'
    };
    var formatLong$1h = {
      date: buildFormatLongFn({
        formats: dateFormats$1h,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1h,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1h,
        defaultWidth: 'any'
      })
    };

    function isSameUTCWeek(dirtyDateLeft, dirtyDateRight, options) {
      requiredArgs(2, arguments);
      var dateLeftStartOfWeek = startOfUTCWeek(dirtyDateLeft, options);
      var dateRightStartOfWeek = startOfUTCWeek(dirtyDateRight, options);
      return dateLeftStartOfWeek.getTime() === dateRightStartOfWeek.getTime();
    }

    var accusativeWeekdays$7 = ['нядзелю', 'панядзелак', 'аўторак', 'сераду', 'чацвер', 'пятніцу', 'суботу'];
    function lastWeek$8(day) {
      var weekday = accusativeWeekdays$7[day];
      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у мінулую " + weekday + " а' p";
        case 1:
        case 2:
        case 4:
          return "'у мінулы " + weekday + " а' p";
      }
    }
    function thisWeek$8(day) {
      var weekday = accusativeWeekdays$7[day];
      return "'у " + weekday + " а' p";
    }
    function nextWeek$8(day) {
      var weekday = accusativeWeekdays$7[day];
      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у наступную " + weekday + " а' p";
        case 1:
        case 2:
        case 4:
          return "'у наступны " + weekday + " а' p";
      }
    }
    var lastWeekFormat$2 = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$8(day);
      } else {
        return lastWeek$8(day);
      }
    };
    var nextWeekFormat$2 = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$8(day);
      } else {
        return nextWeek$8(day);
      }
    };
    var formatRelativeLocale$19 = {
      lastWeek: lastWeekFormat$2,
      yesterday: "'учора а' p",
      today: "'сёння а' p",
      tomorrow: "'заўтра а' p",
      nextWeek: nextWeekFormat$2,
      other: 'P'
    };
    var formatRelative$19 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$19[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$19 = {
      narrow: ['да н.э.', 'н.э.'],
      abbreviated: ['да н. э.', 'н. э.'],
      wide: ['да нашай эры', 'нашай эры']
    };
    var quarterValues$19 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-ы кв.', '2-і кв.', '3-і кв.', '4-ы кв.'],
      wide: ['1-ы квартал', '2-і квартал', '3-і квартал', '4-ы квартал']
    };
    var monthValues$19 = {
      narrow: ['С', 'Л', 'С', 'К', 'М', 'Ч', 'Л', 'Ж', 'В', 'К', 'Л', 'С'],
      abbreviated: ['студз.', 'лют.', 'сак.', 'крас.', 'май', 'чэрв.', 'ліп.', 'жн.', 'вер.', 'кастр.', 'ліст.', 'снеж.'],
      wide: ['студзень', 'люты', 'сакавік', 'красавік', 'май', 'чэрвень', 'ліпень', 'жнівень', 'верасень', 'кастрычнік', 'лістапад', 'снежань']
    };
    var formattingMonthValues$i = {
      narrow: ['С', 'Л', 'С', 'К', 'М', 'Ч', 'Л', 'Ж', 'В', 'К', 'Л', 'С'],
      abbreviated: ['студз.', 'лют.', 'сак.', 'крас.', 'мая', 'чэрв.', 'ліп.', 'жн.', 'вер.', 'кастр.', 'ліст.', 'снеж.'],
      wide: ['студзеня', 'лютага', 'сакавіка', 'красавіка', 'мая', 'чэрвеня', 'ліпеня', 'жніўня', 'верасня', 'кастрычніка', 'лістапада', 'снежня']
    };
    var dayValues$19 = {
      narrow: ['Н', 'П', 'А', 'С', 'Ч', 'П', 'С'],
      short: ['нд', 'пн', 'аў', 'ср', 'чц', 'пт', 'сб'],
      abbreviated: ['нядз', 'пан', 'аўт', 'сер', 'чац', 'пят', 'суб'],
      wide: ['нядзеля', 'панядзелак', 'аўторак', 'серада', 'чацвер', 'пятніца', 'субота']
    };
    var dayPeriodValues$19 = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дзень',
        evening: 'веч.',
        night: 'ноч'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дзень',
        evening: 'веч.',
        night: 'ноч'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўнач',
        noon: 'поўдзень',
        morning: 'раніца',
        afternoon: 'дзень',
        evening: 'вечар',
        night: 'ноч'
      }
    };
    var formattingDayPeriodValues$W = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночы'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночы'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўнач',
        noon: 'поўдзень',
        morning: 'раніцы',
        afternoon: 'дня',
        evening: 'вечара',
        night: 'ночы'
      }
    };
    var ordinalNumber$19 = function (dirtyNumber, options) {
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      var number = Number(dirtyNumber);
      var suffix;
      if (unit === 'date') {
        suffix = '-га';
      } else if (unit === 'hour' || unit === 'minute' || unit === 'second') {
        suffix = '-я';
      } else {
        suffix = (number % 10 === 2 || number % 10 === 3) && number % 100 !== 12 && number % 100 !== 13 ? '-і' : '-ы';
      }
      return number + suffix;
    };
    var localize$19 = {
      ordinalNumber: ordinalNumber$19,
      era: buildLocalizeFn({
        values: eraValues$19,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$19,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$19,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$i,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$19,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$19,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$W,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$18 = /^(\d+)(-?(е|я|га|і|ы|ае|ая|яя|шы|гі|ці|ты|мы))?/i;
    var parseOrdinalNumberPattern$18 = /\d+/i;
    var matchEraPatterns$18 = {
      narrow: /^((да )?н\.?\s?э\.?)/i,
      abbreviated: /^((да )?н\.?\s?э\.?)/i,
      wide: /^(да нашай эры|нашай эры|наша эра)/i
    };
    var parseEraPatterns$18 = {
      any: [/^д/i, /^н/i]
    };
    var matchQuarterPatterns$18 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[ыі]?)? кв.?/i,
      wide: /^[1234](-?[ыі]?)? квартал/i
    };
    var parseQuarterPatterns$18 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$18 = {
      narrow: /^[слкмчжв]/i,
      abbreviated: /^(студз|лют|сак|крас|ма[йя]|чэрв|ліп|жн|вер|кастр|ліст|снеж)\.?/i,
      wide: /^(студзен[ья]|лют(ы|ага)|сакавіка?|красавіка?|ма[йя]|чэрвен[ья]|ліпен[ья]|жні(вень|ўня)|верас(ень|ня)|кастрычніка?|лістапада?|снеж(ань|ня))/i
    };
    var parseMonthPatterns$18 = {
      narrow: [/^с/i, /^л/i, /^с/i, /^к/i, /^м/i, /^ч/i, /^л/i, /^ж/i, /^в/i, /^к/i, /^л/i, /^с/i],
      any: [/^ст/i, /^лю/i, /^са/i, /^кр/i, /^ма/i, /^ч/i, /^ліп/i, /^ж/i, /^в/i, /^ка/i, /^ліс/i, /^сн/i]
    };
    var matchDayPatterns$18 = {
      narrow: /^[нпасч]/i,
      short: /^(нд|ня|пн|па|аў|ат|ср|се|чц|ча|пт|пя|сб|су)\.?/i,
      abbreviated: /^(нядз?|ндз|пнд|пан|аўт|срд|сер|чцв|чац|птн|пят|суб).?/i,
      wide: /^(нядзел[яі]|панядзел(ак|ка)|аўтор(ак|ка)|серад[аы]|чацв(ер|ярга)|пятніц[аы]|субот[аы])/i
    };
    var parseDayPatterns$18 = {
      narrow: [/^н/i, /^п/i, /^а/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^н/i, /^п[ан]/i, /^а/i, /^с[ер]/i, /^ч/i, /^п[ят]/i, /^с[уб]/i]
    };
    var matchDayPeriodPatterns$18 = {
      narrow: /^([дп]п|поўн\.?|поўд\.?|ран\.?|дзень|дня|веч\.?|ночы?)/i,
      abbreviated: /^([дп]п|поўн\.?|поўд\.?|ран\.?|дзень|дня|веч\.?|ночы?)/i,
      wide: /^([дп]п|поўнач|поўдзень|раніц[аы]|дзень|дня|вечара?|ночы?)/i
    };
    var parseDayPeriodPatterns$18 = {
      any: {
        am: /^дп/i,
        pm: /^пп/i,
        midnight: /^поўн/i,
        noon: /^поўд/i,
        morning: /^р/i,
        afternoon: /^д[зн]/i,
        evening: /^в/i,
        night: /^н/i
      }
    };
    var match$18 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$18,
        parsePattern: parseOrdinalNumberPattern$18,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$18,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$18,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$18,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$18,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$18,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$18,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$18,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$18,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$18,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$18,
        defaultParseWidth: 'any'
      })
    };

    var locale$1j = {
      code: 'be',
      formatDistance: formatDistance$19,
      formatLong: formatLong$1h,
      formatRelative: formatRelative$19,
      localize: localize$19,
      match: match$18,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    function declension$5(scheme, count) {
      if (scheme.one !== undefined && count === 1) {
        return scheme.one;
      }
      var rem10 = count % 10;
      var rem100 = count % 100;
      if (rem10 === 1 && rem100 !== 11) {
        return scheme.singularNominative.replace('{{count}}', String(count));
      } else if (rem10 >= 2 && rem10 <= 4 && (rem100 < 10 || rem100 > 20)) {
        return scheme.singularGenitive.replace('{{count}}', String(count));
      } else {
        return scheme.pluralGenitive.replace('{{count}}', String(count));
      }
    }
    function buildLocalizeTokenFn$3(scheme) {
      return function (count, options) {
        if (options && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            if (scheme.future) {
              return declension$5(scheme.future, count);
            } else {
              return 'праз ' + declension$5(scheme.regular, count);
            }
          } else {
            if (scheme.past) {
              return declension$5(scheme.past, count);
            } else {
              return declension$5(scheme.regular, count) + ' таму';
            }
          }
        } else {
          return declension$5(scheme.regular, count);
        }
      };
    }
    var halfAMinute = function (_, options) {
      if (options && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'праз паўхвіліны';
        } else {
          return 'паўхвіліны таму';
        }
      }
      return 'паўхвіліны';
    };
    var formatDistanceLocale$17 = {
      lessThanXSeconds: buildLocalizeTokenFn$3({
        regular: {
          one: 'менш за секунду',
          singularNominative: 'менш за {{count}} секунду',
          singularGenitive: 'менш за {{count}} секунды',
          pluralGenitive: 'менш за {{count}} секунд'
        },
        future: {
          one: 'менш, чым праз секунду',
          singularNominative: 'менш, чым праз {{count}} секунду',
          singularGenitive: 'менш, чым праз {{count}} секунды',
          pluralGenitive: 'менш, чым праз {{count}} секунд'
        }
      }),
      xSeconds: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: '{{count}} секунда',
          singularGenitive: '{{count}} секунды',
          pluralGenitive: '{{count}} секунд'
        },
        past: {
          singularNominative: '{{count}} секунду таму',
          singularGenitive: '{{count}} секунды таму',
          pluralGenitive: '{{count}} секунд таму'
        },
        future: {
          singularNominative: 'праз {{count}} секунду',
          singularGenitive: 'праз {{count}} секунды',
          pluralGenitive: 'праз {{count}} секунд'
        }
      }),
      halfAMinute: halfAMinute,
      lessThanXMinutes: buildLocalizeTokenFn$3({
        regular: {
          one: 'менш за хвіліну',
          singularNominative: 'менш за {{count}} хвіліну',
          singularGenitive: 'менш за {{count}} хвіліны',
          pluralGenitive: 'менш за {{count}} хвілін'
        },
        future: {
          one: 'менш, чым праз хвіліну',
          singularNominative: 'менш, чым праз {{count}} хвіліну',
          singularGenitive: 'менш, чым праз {{count}} хвіліны',
          pluralGenitive: 'менш, чым праз {{count}} хвілін'
        }
      }),
      xMinutes: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: '{{count}} хвіліна',
          singularGenitive: '{{count}} хвіліны',
          pluralGenitive: '{{count}} хвілін'
        },
        past: {
          singularNominative: '{{count}} хвіліну таму',
          singularGenitive: '{{count}} хвіліны таму',
          pluralGenitive: '{{count}} хвілін таму'
        },
        future: {
          singularNominative: 'праз {{count}} хвіліну',
          singularGenitive: 'праз {{count}} хвіліны',
          pluralGenitive: 'праз {{count}} хвілін'
        }
      }),
      aboutXHours: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: 'каля {{count}} гадзіны',
          singularGenitive: 'каля {{count}} гадзін',
          pluralGenitive: 'каля {{count}} гадзін'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} гадзіну',
          singularGenitive: 'прыблізна праз {{count}} гадзіны',
          pluralGenitive: 'прыблізна праз {{count}} гадзін'
        }
      }),
      xHours: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: '{{count}} гадзіна',
          singularGenitive: '{{count}} гадзіны',
          pluralGenitive: '{{count}} гадзін'
        },
        past: {
          singularNominative: '{{count}} гадзіну таму',
          singularGenitive: '{{count}} гадзіны таму',
          pluralGenitive: '{{count}} гадзін таму'
        },
        future: {
          singularNominative: 'праз {{count}} гадзіну',
          singularGenitive: 'праз {{count}} гадзіны',
          pluralGenitive: 'праз {{count}} гадзін'
        }
      }),
      xDays: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: '{{count}} дзень',
          singularGenitive: '{{count}} дні',
          pluralGenitive: '{{count}} дзён'
        }
      }),
      aboutXWeeks: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: 'каля {{count}} месяца',
          singularGenitive: 'каля {{count}} месяцаў',
          pluralGenitive: 'каля {{count}} месяцаў'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} месяц',
          singularGenitive: 'прыблізна праз {{count}} месяцы',
          pluralGenitive: 'прыблізна праз {{count}} месяцаў'
        }
      }),
      xWeeks: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: '{{count}} месяц',
          singularGenitive: '{{count}} месяцы',
          pluralGenitive: '{{count}} месяцаў'
        }
      }),
      aboutXMonths: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: 'каля {{count}} месяца',
          singularGenitive: 'каля {{count}} месяцаў',
          pluralGenitive: 'каля {{count}} месяцаў'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} месяц',
          singularGenitive: 'прыблізна праз {{count}} месяцы',
          pluralGenitive: 'прыблізна праз {{count}} месяцаў'
        }
      }),
      xMonths: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: '{{count}} месяц',
          singularGenitive: '{{count}} месяцы',
          pluralGenitive: '{{count}} месяцаў'
        }
      }),
      aboutXYears: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: 'каля {{count}} года',
          singularGenitive: 'каля {{count}} гадоў',
          pluralGenitive: 'каля {{count}} гадоў'
        },
        future: {
          singularNominative: 'прыблізна праз {{count}} год',
          singularGenitive: 'прыблізна праз {{count}} гады',
          pluralGenitive: 'прыблізна праз {{count}} гадоў'
        }
      }),
      xYears: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: '{{count}} год',
          singularGenitive: '{{count}} гады',
          pluralGenitive: '{{count}} гадоў'
        }
      }),
      overXYears: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: 'больш за {{count}} год',
          singularGenitive: 'больш за {{count}} гады',
          pluralGenitive: 'больш за {{count}} гадоў'
        },
        future: {
          singularNominative: 'больш, чым праз {{count}} год',
          singularGenitive: 'больш, чым праз {{count}} гады',
          pluralGenitive: 'больш, чым праз {{count}} гадоў'
        }
      }),
      almostXYears: buildLocalizeTokenFn$3({
        regular: {
          singularNominative: 'амаль {{count}} год',
          singularGenitive: 'амаль {{count}} гады',
          pluralGenitive: 'амаль {{count}} гадоў'
        },
        future: {
          singularNominative: 'амаль праз {{count}} год',
          singularGenitive: 'амаль праз {{count}} гады',
          pluralGenitive: 'амаль праз {{count}} гадоў'
        }
      })
    };
    var formatDistance$18 = function (token, count, options) {
      options = options || {};
      return formatDistanceLocale$17[token](count, options);
    };

    var dateFormats$1g = {
      full: "EEEE, d MMMM y 'г.'",
      long: "d MMMM y 'г.'",
      medium: "d MMM y 'г.'",
      short: 'dd.MM.y'
    };
    var timeFormats$1g = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$1g = {
      any: '{{date}}, {{time}}'
    };
    var formatLong$1g = {
      date: buildFormatLongFn({
        formats: dateFormats$1g,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1g,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1g,
        defaultWidth: 'any'
      })
    };

    var accusativeWeekdays$6 = ['нядзелю', 'панядзелак', 'аўторак', 'сераду', 'чацьвер', 'пятніцу', 'суботу'];
    function lastWeek$7(day) {
      var weekday = accusativeWeekdays$6[day];
      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у мінулую " + weekday + " а' p";
        case 1:
        case 2:
        case 4:
          return "'у мінулы " + weekday + " а' p";
      }
    }
    function thisWeek$7(day) {
      var weekday = accusativeWeekdays$6[day];
      return "'у " + weekday + " а' p";
    }
    function nextWeek$7(day) {
      var weekday = accusativeWeekdays$6[day];
      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у наступную " + weekday + " а' p";
        case 1:
        case 2:
        case 4:
          return "'у наступны " + weekday + " а' p";
      }
    }
    var lastWeekFormat$1 = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$7(day);
      } else {
        return lastWeek$7(day);
      }
    };
    var nextWeekFormat$1 = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$7(day);
      } else {
        return nextWeek$7(day);
      }
    };
    var formatRelativeLocale$18 = {
      lastWeek: lastWeekFormat$1,
      yesterday: "'учора а' p",
      today: "'сёньня а' p",
      tomorrow: "'заўтра а' p",
      nextWeek: nextWeekFormat$1,
      other: 'P'
    };
    var formatRelative$18 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$18[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$18 = {
      narrow: ['да н.э.', 'н.э.'],
      abbreviated: ['да н. э.', 'н. э.'],
      wide: ['да нашай эры', 'нашай эры']
    };
    var quarterValues$18 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-ы кв.', '2-і кв.', '3-і кв.', '4-ы кв.'],
      wide: ['1-ы квартал', '2-і квартал', '3-і квартал', '4-ы квартал']
    };
    var monthValues$18 = {
      narrow: ['С', 'Л', 'С', 'К', 'Т', 'Ч', 'Л', 'Ж', 'В', 'К', 'Л', 'С'],
      abbreviated: ['студз.', 'лют.', 'сак.', 'крас.', 'трав.', 'чэрв.', 'ліп.', 'жн.', 'вер.', 'кастр.', 'ліст.', 'сьнеж.'],
      wide: ['студзень', 'люты', 'сакавік', 'красавік', 'травень', 'чэрвень', 'ліпень', 'жнівень', 'верасень', 'кастрычнік', 'лістапад', 'сьнежань']
    };
    var formattingMonthValues$h = {
      narrow: ['С', 'Л', 'С', 'К', 'Т', 'Ч', 'Л', 'Ж', 'В', 'К', 'Л', 'С'],
      abbreviated: ['студз.', 'лют.', 'сак.', 'крас.', 'трав.', 'чэрв.', 'ліп.', 'жн.', 'вер.', 'кастр.', 'ліст.', 'сьнеж.'],
      wide: ['студзеня', 'лютага', 'сакавіка', 'красавіка', 'траўня', 'чэрвеня', 'ліпеня', 'жніўня', 'верасня', 'кастрычніка', 'лістапада', 'сьнежня']
    };
    var dayValues$18 = {
      narrow: ['Н', 'П', 'А', 'С', 'Ч', 'П', 'С'],
      short: ['нд', 'пн', 'аў', 'ср', 'чц', 'пт', 'сб'],
      abbreviated: ['нядз', 'пан', 'аўт', 'сер', 'чаць', 'пят', 'суб'],
      wide: ['нядзеля', 'панядзелак', 'аўторак', 'серада', 'чацьвер', 'пятніца', 'субота']
    };
    var dayPeriodValues$18 = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дзень',
        evening: 'веч.',
        night: 'ноч'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дзень',
        evening: 'веч.',
        night: 'ноч'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўнач',
        noon: 'поўдзень',
        morning: 'раніца',
        afternoon: 'дзень',
        evening: 'вечар',
        night: 'ноч'
      }
    };
    var formattingDayPeriodValues$V = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночы'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўн.',
        noon: 'поўд.',
        morning: 'ран.',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночы'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'поўнач',
        noon: 'поўдзень',
        morning: 'раніцы',
        afternoon: 'дня',
        evening: 'вечара',
        night: 'ночы'
      }
    };
    var ordinalNumber$18 = function (dirtyNumber, options) {
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      var number = Number(dirtyNumber);
      var suffix;
      if (unit === 'date') {
        suffix = '-га';
      } else if (unit === 'hour' || unit === 'minute' || unit === 'second') {
        suffix = '-я';
      } else {
        suffix = (number % 10 === 2 || number % 10 === 3) && number % 100 !== 12 && number % 100 !== 13 ? '-і' : '-ы';
      }
      return number + suffix;
    };
    var localize$18 = {
      ordinalNumber: ordinalNumber$18,
      era: buildLocalizeFn({
        values: eraValues$18,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$18,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$18,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$h,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$18,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$18,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$V,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$17 = /^(\d+)(-?(е|я|га|і|ы|ае|ая|яя|шы|гі|ці|ты|мы))?/i;
    var parseOrdinalNumberPattern$17 = /\d+/i;
    var matchEraPatterns$17 = {
      narrow: /^((да )?н\.?\s?э\.?)/i,
      abbreviated: /^((да )?н\.?\s?э\.?)/i,
      wide: /^(да нашай эры|нашай эры|наша эра)/i
    };
    var parseEraPatterns$17 = {
      any: [/^д/i, /^н/i]
    };
    var matchQuarterPatterns$17 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[ыі]?)? кв.?/i,
      wide: /^[1234](-?[ыі]?)? квартал/i
    };
    var parseQuarterPatterns$17 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$17 = {
      narrow: /^[слкмчжв]/i,
      abbreviated: /^(студз|лют|сак|крас|тр(ав)?|чэрв|ліп|жн|вер|кастр|ліст|сьнеж)\.?/i,
      wide: /^(студзен[ья]|лют(ы|ага)|сакавіка?|красавіка?|тра(вень|ўня)|чэрвен[ья]|ліпен[ья]|жні(вень|ўня)|верас(ень|ня)|кастрычніка?|лістапада?|сьнеж(ань|ня))/i
    };
    var parseMonthPatterns$17 = {
      narrow: [/^с/i, /^л/i, /^с/i, /^к/i, /^т/i, /^ч/i, /^л/i, /^ж/i, /^в/i, /^к/i, /^л/i, /^с/i],
      any: [/^ст/i, /^лю/i, /^са/i, /^кр/i, /^тр/i, /^ч/i, /^ліп/i, /^ж/i, /^в/i, /^ка/i, /^ліс/i, /^сн/i]
    };
    var matchDayPatterns$17 = {
      narrow: /^[нпасч]/i,
      short: /^(нд|ня|пн|па|аў|ат|ср|се|чц|ча|пт|пя|сб|су)\.?/i,
      abbreviated: /^(нядз?|ндз|пнд|пан|аўт|срд|сер|чцьв|чаць|птн|пят|суб).?/i,
      wide: /^(нядзел[яі]|панядзел(ак|ка)|аўтор(ак|ка)|серад[аы]|чацьв(ер|ярга)|пятніц[аы]|субот[аы])/i
    };
    var parseDayPatterns$17 = {
      narrow: [/^н/i, /^п/i, /^а/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^н/i, /^п[ан]/i, /^а/i, /^с[ер]/i, /^ч/i, /^п[ят]/i, /^с[уб]/i]
    };
    var matchDayPeriodPatterns$17 = {
      narrow: /^([дп]п|поўн\.?|поўд\.?|ран\.?|дзень|дня|веч\.?|ночы?)/i,
      abbreviated: /^([дп]п|поўн\.?|поўд\.?|ран\.?|дзень|дня|веч\.?|ночы?)/i,
      wide: /^([дп]п|поўнач|поўдзень|раніц[аы]|дзень|дня|вечара?|ночы?)/i
    };
    var parseDayPeriodPatterns$17 = {
      any: {
        am: /^дп/i,
        pm: /^пп/i,
        midnight: /^поўн/i,
        noon: /^поўд/i,
        morning: /^р/i,
        afternoon: /^д[зн]/i,
        evening: /^в/i,
        night: /^н/i
      }
    };
    var match$17 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$17,
        parsePattern: parseOrdinalNumberPattern$17,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$17,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$17,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$17,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$17,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$17,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$17,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$17,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$17,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$17,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$17,
        defaultParseWidth: 'any'
      })
    };

    var locale$1i = {
      code: 'be-tarask',
      formatDistance: formatDistance$18,
      formatLong: formatLong$1g,
      formatRelative: formatRelative$18,
      localize: localize$18,
      match: match$17,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$16 = {
      lessThanXSeconds: {
        one: 'по-малко от секунда',
        other: 'по-малко от {{count}} секунди'
      },
      xSeconds: {
        one: '1 секунда',
        other: '{{count}} секунди'
      },
      halfAMinute: 'половин минута',
      lessThanXMinutes: {
        one: 'по-малко от минута',
        other: 'по-малко от {{count}} минути'
      },
      xMinutes: {
        one: '1 минута',
        other: '{{count}} минути'
      },
      aboutXHours: {
        one: 'около час',
        other: 'около {{count}} часа'
      },
      xHours: {
        one: '1 час',
        other: '{{count}} часа'
      },
      xDays: {
        one: '1 ден',
        other: '{{count}} дни'
      },
      aboutXWeeks: {
        one: 'около седмица',
        other: 'около {{count}} седмици'
      },
      xWeeks: {
        one: '1 седмица',
        other: '{{count}} седмици'
      },
      aboutXMonths: {
        one: 'около месец',
        other: 'около {{count}} месеца'
      },
      xMonths: {
        one: '1 месец',
        other: '{{count}} месеца'
      },
      aboutXYears: {
        one: 'около година',
        other: 'около {{count}} години'
      },
      xYears: {
        one: '1 година',
        other: '{{count}} години'
      },
      overXYears: {
        one: 'над година',
        other: 'над {{count}} години'
      },
      almostXYears: {
        one: 'почти година',
        other: 'почти {{count}} години'
      }
    };
    var formatDistance$17 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$16[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'след ' + result;
        } else {
          return 'преди ' + result;
        }
      }
      return result;
    };

    var dateFormats$1f = {
      full: 'EEEE, dd MMMM yyyy',
      long: 'dd MMMM yyyy',
      medium: 'dd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$1f = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$1f = {
      any: '{{date}} {{time}}'
    };
    var formatLong$1f = {
      date: buildFormatLongFn({
        formats: dateFormats$1f,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1f,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1f,
        defaultWidth: 'any'
      })
    };

    var weekdays$3 = ['неделя', 'понеделник', 'вторник', 'сряда', 'четвъртък', 'петък', 'събота'];
    function lastWeek$6(day) {
      var weekday = weekdays$3[day];
      switch (day) {
        case 0:
        case 3:
        case 6:
          return "'миналата " + weekday + " в' p";
        case 1:
        case 2:
        case 4:
        case 5:
          return "'миналия " + weekday + " в' p";
      }
    }
    function thisWeek$6(day) {
      var weekday = weekdays$3[day];
      if (day === 2
      ) {
          return "'във " + weekday + " в' p";
        } else {
        return "'в " + weekday + " в' p";
      }
    }
    function nextWeek$6(day) {
      var weekday = weekdays$3[day];
      switch (day) {
        case 0:
        case 3:
        case 6:
          return "'следващата " + weekday + " в' p";
        case 1:
        case 2:
        case 4:
        case 5:
          return "'следващия " + weekday + " в' p";
      }
    }
    var lastWeekFormatToken = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$6(day);
      } else {
        return lastWeek$6(day);
      }
    };
    var nextWeekFormatToken = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$6(day);
      } else {
        return nextWeek$6(day);
      }
    };
    var formatRelativeLocale$17 = {
      lastWeek: lastWeekFormatToken,
      yesterday: "'вчера в' p",
      today: "'днес в' p",
      tomorrow: "'утре в' p",
      nextWeek: nextWeekFormatToken,
      other: 'P'
    };
    var formatRelative$17 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$17[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$17 = {
      narrow: ['пр.н.е.', 'н.е.'],
      abbreviated: ['преди н. е.', 'н. е.'],
      wide: ['преди новата ера', 'новата ера']
    };
    var quarterValues$17 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-во тримес.', '2-ро тримес.', '3-то тримес.', '4-то тримес.'],
      wide: ['1-во тримесечие', '2-ро тримесечие', '3-то тримесечие', '4-то тримесечие']
    };
    var monthValues$17 = {
      abbreviated: ['яну', 'фев', 'мар', 'апр', 'май', 'юни', 'юли', 'авг', 'сеп', 'окт', 'ное', 'дек'],
      wide: ['януари', 'февруари', 'март', 'април', 'май', 'юни', 'юли', 'август', 'септември', 'октомври', 'ноември', 'декември']
    };
    var dayValues$17 = {
      narrow: ['Н', 'П', 'В', 'С', 'Ч', 'П', 'С'],
      short: ['нд', 'пн', 'вт', 'ср', 'чт', 'пт', 'сб'],
      abbreviated: ['нед', 'пон', 'вто', 'сря', 'чет', 'пет', 'съб'],
      wide: ['неделя', 'понеделник', 'вторник', 'сряда', 'четвъртък', 'петък', 'събота']
    };
    var dayPeriodValues$17 = {
      wide: {
        am: 'преди обяд',
        pm: 'след обяд',
        midnight: 'в полунощ',
        noon: 'на обяд',
        morning: 'сутринта',
        afternoon: 'следобед',
        evening: 'вечерта',
        night: 'през нощта'
      }
    };
    function isFeminine(unit) {
      return unit === 'year' || unit === 'week' || unit === 'minute' || unit === 'second';
    }
    function isNeuter(unit) {
      return unit === 'quarter';
    }
    function numberWithSuffix(number, unit, masculine, feminine, neuter) {
      var suffix = isNeuter(unit) ? neuter : isFeminine(unit) ? feminine : masculine;
      return number + '-' + suffix;
    }
    var ordinalNumber$17 = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      if (number === 0) {
        return numberWithSuffix(0, unit, 'ев', 'ева', 'ево');
      } else if (number % 1000 === 0) {
        return numberWithSuffix(number, unit, 'ен', 'на', 'но');
      } else if (number % 100 === 0) {
        return numberWithSuffix(number, unit, 'тен', 'тна', 'тно');
      }
      var rem100 = number % 100;
      if (rem100 > 20 || rem100 < 10) {
        switch (rem100 % 10) {
          case 1:
            return numberWithSuffix(number, unit, 'ви', 'ва', 'во');
          case 2:
            return numberWithSuffix(number, unit, 'ри', 'ра', 'ро');
          case 7:
          case 8:
            return numberWithSuffix(number, unit, 'ми', 'ма', 'мо');
        }
      }
      return numberWithSuffix(number, unit, 'ти', 'та', 'то');
    };
    var localize$17 = {
      ordinalNumber: ordinalNumber$17,
      era: buildLocalizeFn({
        values: eraValues$17,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$17,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$17,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$17,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$17,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$16 = /^(\d+)(-?[врмт][аи]|-?т?(ен|на)|-?(ев|ева))?/i;
    var parseOrdinalNumberPattern$16 = /\d+/i;
    var matchEraPatterns$16 = {
      narrow: /^((пр)?н\.?\s?е\.?)/i,
      abbreviated: /^((пр)?н\.?\s?е\.?)/i,
      wide: /^(преди новата ера|новата ера|нова ера)/i
    };
    var parseEraPatterns$16 = {
      any: [/^п/i, /^н/i]
    };
    var matchQuarterPatterns$16 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[врт]?o?)? тримес.?/i,
      wide: /^[1234](-?[врт]?о?)? тримесечие/i
    };
    var parseQuarterPatterns$16 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchDayPatterns$16 = {
      narrow: /^[нпвсч]/i,
      short: /^(нд|пн|вт|ср|чт|пт|сб)/i,
      abbreviated: /^(нед|пон|вто|сря|чет|пет|съб)/i,
      wide: /^(неделя|понеделник|вторник|сряда|четвъртък|петък|събота)/i
    };
    var parseDayPatterns$16 = {
      narrow: [/^н/i, /^п/i, /^в/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^н[ед]/i, /^п[он]/i, /^вт/i, /^ср/i, /^ч[ет]/i, /^п[ет]/i, /^с[ъб]/i]
    };
    var matchMonthPatterns$16 = {
      abbreviated: /^(яну|фев|мар|апр|май|юни|юли|авг|сеп|окт|ное|дек)/i,
      wide: /^(януари|февруари|март|април|май|юни|юли|август|септември|октомври|ноември|декември)/i
    };
    var parseMonthPatterns$16 = {
      any: [/^я/i, /^ф/i, /^мар/i, /^ап/i, /^май/i, /^юн/i, /^юл/i, /^ав/i, /^се/i, /^окт/i, /^но/i, /^де/i]
    };
    var matchDayPeriodPatterns$16 = {
      any: /^(преди о|след о|в по|на о|през|веч|сут|следо)/i
    };
    var parseDayPeriodPatterns$16 = {
      any: {
        am: /^преди о/i,
        pm: /^след о/i,
        midnight: /^в пол/i,
        noon: /^на об/i,
        morning: /^сут/i,
        afternoon: /^следо/i,
        evening: /^веч/i,
        night: /^през н/i
      }
    };
    var match$16 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$16,
        parsePattern: parseOrdinalNumberPattern$16,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$16,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$16,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$16,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$16,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$16,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$16,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$16,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$16,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$16,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$16,
        defaultParseWidth: 'any'
      })
    };

    var locale$1h = {
      code: 'bg',
      formatDistance: formatDistance$17,
      formatLong: formatLong$1f,
      formatRelative: formatRelative$17,
      localize: localize$17,
      match: match$16,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var numberValues$1 = {
      locale: {
        '1': '১',
        '2': '২',
        '3': '৩',
        '4': '৪',
        '5': '৫',
        '6': '৬',
        '7': '৭',
        '8': '৮',
        '9': '৯',
        '0': '০'
      },
      number: {
        '১': '1',
        '২': '2',
        '৩': '3',
        '৪': '4',
        '৫': '5',
        '৬': '6',
        '৭': '7',
        '৮': '8',
        '৯': '9',
        '০': '0'
      }
    };
    var eraValues$16 = {
      narrow: ['খ্রিঃপূঃ', 'খ্রিঃ'],
      abbreviated: ['খ্রিঃপূর্ব', 'খ্রিঃ'],
      wide: ['খ্রিস্টপূর্ব', 'খ্রিস্টাব্দ']
    };
    var quarterValues$16 = {
      narrow: ['১', '২', '৩', '৪'],
      abbreviated: ['১ত্রৈ', '২ত্রৈ', '৩ত্রৈ', '৪ত্রৈ'],
      wide: ['১ম ত্রৈমাসিক', '২য় ত্রৈমাসিক', '৩য় ত্রৈমাসিক', '৪র্থ ত্রৈমাসিক']
    };
    var monthValues$16 = {
      narrow: ['জানু', 'ফেব্রু', 'মার্চ', 'এপ্রিল', 'মে', 'জুন', 'জুলাই', 'আগস্ট', 'সেপ্ট', 'অক্টো', 'নভে', 'ডিসে'],
      abbreviated: ['জানু', 'ফেব্রু', 'মার্চ', 'এপ্রিল', 'মে', 'জুন', 'জুলাই', 'আগস্ট', 'সেপ্ট', 'অক্টো', 'নভে', 'ডিসে'],
      wide: ['জানুয়ারি', 'ফেব্রুয়ারি', 'মার্চ', 'এপ্রিল', 'মে', 'জুন', 'জুলাই', 'আগস্ট', 'সেপ্টেম্বর', 'অক্টোবর', 'নভেম্বর', 'ডিসেম্বর']
    };
    var dayValues$16 = {
      narrow: ['র', 'সো', 'ম', 'বু', 'বৃ', 'শু', 'শ'],
      short: ['রবি', 'সোম', 'মঙ্গল', 'বুধ', 'বৃহ', 'শুক্র', 'শনি'],
      abbreviated: ['রবি', 'সোম', 'মঙ্গল', 'বুধ', 'বৃহ', 'শুক্র', 'শনি'],
      wide: ['রবিবার', 'সোমবার', 'মঙ্গলবার', 'বুধবার', 'বৃহস্পতিবার ', 'শুক্রবার', 'শনিবার']
    };
    var dayPeriodValues$16 = {
      narrow: {
        am: 'পূ',
        pm: 'অপ',
        midnight: 'মধ্যরাত',
        noon: 'মধ্যাহ্ন',
        morning: 'সকাল',
        afternoon: 'বিকাল',
        evening: 'সন্ধ্যা',
        night: 'রাত'
      },
      abbreviated: {
        am: 'পূর্বাহ্ন',
        pm: 'অপরাহ্ন',
        midnight: 'মধ্যরাত',
        noon: 'মধ্যাহ্ন',
        morning: 'সকাল',
        afternoon: 'বিকাল',
        evening: 'সন্ধ্যা',
        night: 'রাত'
      },
      wide: {
        am: 'পূর্বাহ্ন',
        pm: 'অপরাহ্ন',
        midnight: 'মধ্যরাত',
        noon: 'মধ্যাহ্ন',
        morning: 'সকাল',
        afternoon: 'বিকাল',
        evening: 'সন্ধ্যা',
        night: 'রাত'
      }
    };
    var formattingDayPeriodValues$U = {
      narrow: {
        am: 'পূ',
        pm: 'অপ',
        midnight: 'মধ্যরাত',
        noon: 'মধ্যাহ্ন',
        morning: 'সকাল',
        afternoon: 'বিকাল',
        evening: 'সন্ধ্যা',
        night: 'রাত'
      },
      abbreviated: {
        am: 'পূর্বাহ্ন',
        pm: 'অপরাহ্ন',
        midnight: 'মধ্যরাত',
        noon: 'মধ্যাহ্ন',
        morning: 'সকাল',
        afternoon: 'বিকাল',
        evening: 'সন্ধ্যা',
        night: 'রাত'
      },
      wide: {
        am: 'পূর্বাহ্ন',
        pm: 'অপরাহ্ন',
        midnight: 'মধ্যরাত',
        noon: 'মধ্যাহ্ন',
        morning: 'সকাল',
        afternoon: 'বিকাল',
        evening: 'সন্ধ্যা',
        night: 'রাত'
      }
    };
    function dateOrdinalNumber(number, localeNumber) {
      if (number > 18 && number <= 31) {
        return localeNumber + 'শে';
      } else {
        switch (number) {
          case 1:
            return localeNumber + 'লা';
          case 2:
          case 3:
            return localeNumber + 'রা';
          case 4:
            return localeNumber + 'ঠা';
          default:
            return localeNumber + 'ই';
        }
      }
    }
    var ordinalNumber$16 = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var localeNumber = numberToLocale$1(number);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      if (unit === 'date') {
        return dateOrdinalNumber(number, localeNumber);
      }
      if (number > 10 || number === 0) return localeNumber + 'তম';
      var rem10 = number % 10;
      switch (rem10) {
        case 2:
        case 3:
          return localeNumber + 'য়';
        case 4:
          return localeNumber + 'র্থ';
        case 6:
          return localeNumber + 'ষ্ঠ';
        default:
          return localeNumber + 'ম';
      }
    };
    function numberToLocale$1(enNumber) {
      return enNumber.toString().replace(/\d/g, function (match) {
        return numberValues$1.locale[match];
      });
    }
    var localize$16 = {
      ordinalNumber: ordinalNumber$16,
      era: buildLocalizeFn({
        values: eraValues$16,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$16,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$16,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$16,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$16,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$U,
        defaultFormattingWidth: 'wide'
      })
    };

    var formatDistanceLocale$15 = {
      lessThanXSeconds: {
        one: 'প্রায় ১ সেকেন্ড',
        other: 'প্রায় {{count}} সেকেন্ড'
      },
      xSeconds: {
        one: '১ সেকেন্ড',
        other: '{{count}} সেকেন্ড'
      },
      halfAMinute: 'আধ মিনিট',
      lessThanXMinutes: {
        one: 'প্রায় ১ মিনিট',
        other: 'প্রায় {{count}} মিনিট'
      },
      xMinutes: {
        one: '১ মিনিট',
        other: '{{count}} মিনিট'
      },
      aboutXHours: {
        one: 'প্রায় ১ ঘন্টা',
        other: 'প্রায় {{count}} ঘন্টা'
      },
      xHours: {
        one: '১ ঘন্টা',
        other: '{{count}} ঘন্টা'
      },
      xDays: {
        one: '১ দিন',
        other: '{{count}} দিন'
      },
      aboutXWeeks: {
        one: 'প্রায় ১ সপ্তাহ',
        other: 'প্রায় {{count}} সপ্তাহ'
      },
      xWeeks: {
        one: '১ সপ্তাহ',
        other: '{{count}} সপ্তাহ'
      },
      aboutXMonths: {
        one: 'প্রায় ১ মাস',
        other: 'প্রায় {{count}} মাস'
      },
      xMonths: {
        one: '১ মাস',
        other: '{{count}} মাস'
      },
      aboutXYears: {
        one: 'প্রায় ১ বছর',
        other: 'প্রায় {{count}} বছর'
      },
      xYears: {
        one: '১ বছর',
        other: '{{count}} বছর'
      },
      overXYears: {
        one: '১ বছরের বেশি',
        other: '{{count}} বছরের বেশি'
      },
      almostXYears: {
        one: 'প্রায় ১ বছর',
        other: 'প্রায় {{count}} বছর'
      }
    };
    var formatDistance$16 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$15[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', numberToLocale$1(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' এর মধ্যে';
        } else {
          return result + ' আগে';
        }
      }
      return result;
    };

    var dateFormats$1e = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$1e = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$1e = {
      full: "{{date}} {{time}} 'সময়'",
      long: "{{date}} {{time}} 'সময়'",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1e = {
      date: buildFormatLongFn({
        formats: dateFormats$1e,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1e,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1e,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$16 = {
      lastWeek: "'গত' eeee 'সময়' p",
      yesterday: "'গতকাল' 'সময়' p",
      today: "'আজ' 'সময়' p",
      tomorrow: "'আগামীকাল' 'সময়' p",
      nextWeek: "eeee 'সময়' p",
      other: 'P'
    };
    var formatRelative$16 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$16[token];
    };

    var matchOrdinalNumberPattern$15 = /^(\d+)(ম|য়|র্থ|ষ্ঠ|শে|ই|তম)?/i;
    var parseOrdinalNumberPattern$15 = /\d+/i;
    var matchEraPatterns$15 = {
      narrow: /^(খ্রিঃপূঃ|খ্রিঃ)/i,
      abbreviated: /^(খ্রিঃপূর্ব|খ্রিঃ)/i,
      wide: /^(খ্রিস্টপূর্ব|খ্রিস্টাব্দ)/i
    };
    var parseEraPatterns$15 = {
      narrow: [/^খ্রিঃপূঃ/i, /^খ্রিঃ/i],
      abbreviated: [/^খ্রিঃপূর্ব/i, /^খ্রিঃ/i],
      wide: [/^খ্রিস্টপূর্ব/i, /^খ্রিস্টাব্দ/i]
    };
    var matchQuarterPatterns$15 = {
      narrow: /^[১২৩৪]/i,
      abbreviated: /^[১২৩৪]ত্রৈ/i,
      wide: /^[১২৩৪](ম|য়|র্থ)? ত্রৈমাসিক/i
    };
    var parseQuarterPatterns$15 = {
      any: [/১/i, /২/i, /৩/i, /৪/i]
    };
    var matchMonthPatterns$15 = {
      narrow: /^(জানু|ফেব্রু|মার্চ|এপ্রিল|মে|জুন|জুলাই|আগস্ট|সেপ্ট|অক্টো|নভে|ডিসে)/i,
      abbreviated: /^(জানু|ফেব্রু|মার্চ|এপ্রিল|মে|জুন|জুলাই|আগস্ট|সেপ্ট|অক্টো|নভে|ডিসে)/i,
      wide: /^(জানুয়ারি|ফেব্রুয়ারি|মার্চ|এপ্রিল|মে|জুন|জুলাই|আগস্ট|সেপ্টেম্বর|অক্টোবর|নভেম্বর|ডিসেম্বর)/i
    };
    var parseMonthPatterns$15 = {
      any: [/^জানু/i, /^ফেব্রু/i, /^মার্চ/i, /^এপ্রিল/i, /^মে/i, /^জুন/i, /^জুলাই/i, /^আগস্ট/i, /^সেপ্ট/i, /^অক্টো/i, /^নভে/i, /^ডিসে/i]
    };
    var matchDayPatterns$15 = {
      narrow: /^(র|সো|ম|বু|বৃ|শু|শ)+/i,
      short: /^(রবি|সোম|মঙ্গল|বুধ|বৃহ|শুক্র|শনি)+/i,
      abbreviated: /^(রবি|সোম|মঙ্গল|বুধ|বৃহ|শুক্র|শনি)+/i,
      wide: /^(রবিবার|সোমবার|মঙ্গলবার|বুধবার|বৃহস্পতিবার |শুক্রবার|শনিবার)+/i
    };
    var parseDayPatterns$15 = {
      narrow: [/^র/i, /^সো/i, /^ম/i, /^বু/i, /^বৃ/i, /^শু/i, /^শ/i],
      short: [/^রবি/i, /^সোম/i, /^মঙ্গল/i, /^বুধ/i, /^বৃহ/i, /^শুক্র/i, /^শনি/i],
      abbreviated: [/^রবি/i, /^সোম/i, /^মঙ্গল/i, /^বুধ/i, /^বৃহ/i, /^শুক্র/i, /^শনি/i],
      wide: [/^রবিবার/i, /^সোমবার/i, /^মঙ্গলবার/i, /^বুধবার/i, /^বৃহস্পতিবার /i, /^শুক্রবার/i, /^শনিবার/i]
    };
    var matchDayPeriodPatterns$15 = {
      narrow: /^(পূ|অপ|মধ্যরাত|মধ্যাহ্ন|সকাল|বিকাল|সন্ধ্যা|রাত)/i,
      abbreviated: /^(পূর্বাহ্ন|অপরাহ্ন|মধ্যরাত|মধ্যাহ্ন|সকাল|বিকাল|সন্ধ্যা|রাত)/i,
      wide: /^(পূর্বাহ্ন|অপরাহ্ন|মধ্যরাত|মধ্যাহ্ন|সকাল|বিকাল|সন্ধ্যা|রাত)/i
    };
    var parseDayPeriodPatterns$15 = {
      any: {
        am: /^পূ/i,
        pm: /^অপ/i,
        midnight: /^মধ্যরাত/i,
        noon: /^মধ্যাহ্ন/i,
        morning: /সকাল/i,
        afternoon: /বিকাল/i,
        evening: /সন্ধ্যা/i,
        night: /রাত/i
      }
    };
    var match$15 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$15,
        parsePattern: parseOrdinalNumberPattern$15,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$15,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$15,
        defaultParseWidth: 'wide'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$15,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$15,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$15,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$15,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$15,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$15,
        defaultParseWidth: 'wide'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$15,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$15,
        defaultParseWidth: 'any'
      })
    };

    var locale$1g = {
      code: 'bn',
      formatDistance: formatDistance$16,
      formatLong: formatLong$1e,
      formatRelative: formatRelative$16,
      localize: localize$16,
      match: match$15,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$14 = {
      lessThanXSeconds: {
        one: {
          standalone: 'manje od 1 sekunde',
          withPrepositionAgo: 'manje od 1 sekunde',
          withPrepositionIn: 'manje od 1 sekundu'
        },
        dual: 'manje od {{count}} sekunde',
        other: 'manje od {{count}} sekundi'
      },
      xSeconds: {
        one: {
          standalone: '1 sekunda',
          withPrepositionAgo: '1 sekunde',
          withPrepositionIn: '1 sekundu'
        },
        dual: '{{count}} sekunde',
        other: '{{count}} sekundi'
      },
      halfAMinute: 'pola minute',
      lessThanXMinutes: {
        one: {
          standalone: 'manje od 1 minute',
          withPrepositionAgo: 'manje od 1 minute',
          withPrepositionIn: 'manje od 1 minutu'
        },
        dual: 'manje od {{count}} minute',
        other: 'manje od {{count}} minuta'
      },
      xMinutes: {
        one: {
          standalone: '1 minuta',
          withPrepositionAgo: '1 minute',
          withPrepositionIn: '1 minutu'
        },
        dual: '{{count}} minute',
        other: '{{count}} minuta'
      },
      aboutXHours: {
        one: {
          standalone: 'oko 1 sat',
          withPrepositionAgo: 'oko 1 sat',
          withPrepositionIn: 'oko 1 sat'
        },
        dual: 'oko {{count}} sata',
        other: 'oko {{count}} sati'
      },
      xHours: {
        one: {
          standalone: '1 sat',
          withPrepositionAgo: '1 sat',
          withPrepositionIn: '1 sat'
        },
        dual: '{{count}} sata',
        other: '{{count}} sati'
      },
      xDays: {
        one: {
          standalone: '1 dan',
          withPrepositionAgo: '1 dan',
          withPrepositionIn: '1 dan'
        },
        dual: '{{count}} dana',
        other: '{{count}} dana'
      },
      aboutXWeeks: {
        one: {
          standalone: 'oko 1 sedmicu',
          withPrepositionAgo: 'oko 1 sedmicu',
          withPrepositionIn: 'oko 1 sedmicu'
        },
        dual: 'oko {{count}} sedmice',
        other: 'oko {{count}} sedmice'
      },
      xWeeks: {
        one: {
          standalone: '1 sedmicu',
          withPrepositionAgo: '1 sedmicu',
          withPrepositionIn: '1 sedmicu'
        },
        dual: '{{count}} sedmice',
        other: '{{count}} sedmice'
      },
      aboutXMonths: {
        one: {
          standalone: 'oko 1 mjesec',
          withPrepositionAgo: 'oko 1 mjesec',
          withPrepositionIn: 'oko 1 mjesec'
        },
        dual: 'oko {{count}} mjeseca',
        other: 'oko {{count}} mjeseci'
      },
      xMonths: {
        one: {
          standalone: '1 mjesec',
          withPrepositionAgo: '1 mjesec',
          withPrepositionIn: '1 mjesec'
        },
        dual: '{{count}} mjeseca',
        other: '{{count}} mjeseci'
      },
      aboutXYears: {
        one: {
          standalone: 'oko 1 godinu',
          withPrepositionAgo: 'oko 1 godinu',
          withPrepositionIn: 'oko 1 godinu'
        },
        dual: 'oko {{count}} godine',
        other: 'oko {{count}} godina'
      },
      xYears: {
        one: {
          standalone: '1 godina',
          withPrepositionAgo: '1 godine',
          withPrepositionIn: '1 godinu'
        },
        dual: '{{count}} godine',
        other: '{{count}} godina'
      },
      overXYears: {
        one: {
          standalone: 'preko 1 godinu',
          withPrepositionAgo: 'preko 1 godinu',
          withPrepositionIn: 'preko 1 godinu'
        },
        dual: 'preko {{count}} godine',
        other: 'preko {{count}} godina'
      },
      almostXYears: {
        one: {
          standalone: 'gotovo 1 godinu',
          withPrepositionAgo: 'gotovo 1 godinu',
          withPrepositionIn: 'gotovo 1 godinu'
        },
        dual: 'gotovo {{count}} godine',
        other: 'gotovo {{count}} godina'
      }
    };
    var formatDistance$15 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$14[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            result = tokenValue.one.withPrepositionIn;
          } else {
            result = tokenValue.one.withPrepositionAgo;
          }
        } else {
          result = tokenValue.one.standalone;
        }
      } else if (count % 10 > 1 && count % 10 < 5 &&
      String(count).substr(-2, 1) !== '1'
      ) {
          result = tokenValue.dual.replace('{{count}}', String(count));
        } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'za ' + result;
        } else {
          return 'prije ' + result;
        }
      }
      return result;
    };

    var dateFormats$1d = {
      full: 'EEEE, d. MMMM yyyy.',
      long: 'd. MMMM yyyy.',
      medium: 'd. MMM yy.',
      short: 'dd. MM. yy.'
    };
    var timeFormats$1d = {
      full: 'HH:mm:ss (zzzz)',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$1d = {
      full: "{{date}} 'u' {{time}}",
      long: "{{date}} 'u' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$1d = {
      date: buildFormatLongFn({
        formats: dateFormats$1d,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1d,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1d,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$15 = {
      lastWeek: function (date) {
        switch (date.getUTCDay()) {
          case 0:
            return "'prošle nedjelje u' p";
          case 3:
            return "'prošle srijede u' p";
          case 6:
            return "'prošle subote u' p";
          default:
            return "'prošli' EEEE 'u' p";
        }
      },
      yesterday: "'juče u' p",
      today: "'danas u' p",
      tomorrow: "'sutra u' p",
      nextWeek: function (date) {
        switch (date.getUTCDay()) {
          case 0:
            return "'sljedeće nedjelje u' p";
          case 3:
            return "'sljedeću srijedu u' p";
          case 6:
            return "'sljedeću subotu u' p";
          default:
            return "'sljedeći' EEEE 'u' p";
        }
      },
      other: 'P'
    };
    var formatRelative$15 = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$15[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$15 = {
      narrow: ['pr.n.e.', 'AD'],
      abbreviated: ['pr. Hr.', 'po. Hr.'],
      wide: ['Prije Hrista', 'Poslije Hrista']
    };
    var quarterValues$15 = {
      narrow: ['1.', '2.', '3.', '4.'],
      abbreviated: ['1. kv.', '2. kv.', '3. kv.', '4. kv.'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$15 = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'avg', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januar', 'februar', 'mart', 'april', 'maj', 'juni', 'juli', 'avgust', 'septembar', 'oktobar', 'novembar', 'decembar']
    };
    var formattingMonthValues$g = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'avg', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januar', 'februar', 'mart', 'april', 'maj', 'juni', 'juli', 'avgust', 'septembar', 'oktobar', 'novembar', 'decembar']
    };
    var dayValues$15 = {
      narrow: ['N', 'P', 'U', 'S', 'Č', 'P', 'S'],
      short: ['ned', 'pon', 'uto', 'sre', 'čet', 'pet', 'sub'],
      abbreviated: ['ned', 'pon', 'uto', 'sre', 'čet', 'pet', 'sub'],
      wide: ['nedjelja', 'ponedjeljak', 'utorak', 'srijeda', 'četvrtak', 'petak', 'subota']
    };
    var dayPeriodValues$15 = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'poslije podne',
        evening: 'uveče',
        night: 'noću'
      }
    };
    var formattingDayPeriodValues$T = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'poslije podne',
        evening: 'uveče',
        night: 'noću'
      }
    };
    var ordinalNumber$15 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return String(number) + '.';
    };
    var localize$15 = {
      ordinalNumber: ordinalNumber$15,
      era: buildLocalizeFn({
        values: eraValues$15,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$15,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$15,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$g,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$15,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$15,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$T,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$14 = /^(\d+)\./i;
    var parseOrdinalNumberPattern$14 = /\d+/i;
    var matchEraPatterns$14 = {
      narrow: /^(pr\.n\.e\.|AD)/i,
      abbreviated: /^(pr\.\s?Hr\.|po\.\s?Hr\.)/i,
      wide: /^(Prije Hrista|prije nove ere|Poslije Hrista|nova era)/i
    };
    var parseEraPatterns$14 = {
      any: [/^pr/i, /^(po|nova)/i]
    };
    var matchQuarterPatterns$14 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]\.\s?kv\.?/i,
      wide: /^[1234]\. kvartal/i
    };
    var parseQuarterPatterns$14 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$14 = {
      narrow: /^(10|11|12|[123456789])\./i,
      abbreviated: /^(jan|feb|mar|apr|maj|jun|jul|avg|sep|okt|nov|dec)/i,
      wide: /^((januar|januara)|(februar|februara)|(mart|marta)|(april|aprila)|(maj|maja)|(juni|juna)|(juli|jula)|(avgust|avgusta)|(septembar|septembra)|(oktobar|oktobra)|(novembar|novembra)|(decembar|decembra))/i
    };
    var parseMonthPatterns$14 = {
      narrow: [/^1/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^7/i, /^8/i, /^9/i, /^10/i, /^11/i, /^12/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^avg/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$14 = {
      narrow: /^[npusčc]/i,
      short: /^(ned|pon|uto|sre|(čet|cet)|pet|sub)/i,
      abbreviated: /^(ned|pon|uto|sre|(čet|cet)|pet|sub)/i,
      wide: /^(nedjelja|ponedjeljak|utorak|srijeda|(četvrtak|cetvrtak)|petak|subota)/i
    };
    var parseDayPatterns$14 = {
      narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
      any: [/^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$14 = {
      any: /^(am|pm|ponoc|ponoć|(po)?podne|uvece|uveče|noću|poslije podne|ujutru)/i
    };
    var parseDayPeriodPatterns$14 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^pono/i,
        noon: /^pod/i,
        morning: /jutro/i,
        afternoon: /(poslije\s|po)+podne/i,
        evening: /(uvece|uveče)/i,
        night: /(nocu|noću)/i
      }
    };
    var match$14 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$14,
        parsePattern: parseOrdinalNumberPattern$14,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$14,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$14,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$14,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$14,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$14,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$14,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$14,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$14,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$14,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$14,
        defaultParseWidth: 'any'
      })
    };

    var locale$1f = {
      code: 'bs',
      formatDistance: formatDistance$15,
      formatLong: formatLong$1d,
      formatRelative: formatRelative$15,
      localize: localize$15,
      match: match$14,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$13 = {
      lessThanXSeconds: {
        one: "menys d'un segon",
        eleven: "menys d'onze segons",
        other: 'menys de {{count}} segons'
      },
      xSeconds: {
        one: '1 segon',
        other: '{{count}} segons'
      },
      halfAMinute: 'mig minut',
      lessThanXMinutes: {
        one: "menys d'un minut",
        eleven: "menys d'onze minuts",
        other: 'menys de {{count}} minuts'
      },
      xMinutes: {
        one: '1 minut',
        other: '{{count}} minuts'
      },
      aboutXHours: {
        one: 'aproximadament una hora',
        other: 'aproximadament {{count}} hores'
      },
      xHours: {
        one: '1 hora',
        other: '{{count}} hores'
      },
      xDays: {
        one: '1 dia',
        other: '{{count}} dies'
      },
      aboutXWeeks: {
        one: 'aproximadament una setmana',
        other: 'aproximadament {{count}} setmanes'
      },
      xWeeks: {
        one: '1 setmana',
        other: '{{count}} setmanes'
      },
      aboutXMonths: {
        one: 'aproximadament un mes',
        other: 'aproximadament {{count}} mesos'
      },
      xMonths: {
        one: '1 mes',
        other: '{{count}} mesos'
      },
      aboutXYears: {
        one: 'aproximadament un any',
        other: 'aproximadament {{count}} anys'
      },
      xYears: {
        one: '1 any',
        other: '{{count}} anys'
      },
      overXYears: {
        one: "més d'un any",
        eleven: "més d'onze anys",
        other: 'més de {{count}} anys'
      },
      almostXYears: {
        one: 'gairebé un any',
        other: 'gairebé {{count}} anys'
      }
    };
    var formatDistance$14 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$13[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else if (count === 11 && tokenValue.eleven) {
        result = tokenValue.eleven;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'en ' + result;
        } else {
          return 'fa ' + result;
        }
      }
      return result;
    };

    var dateFormats$1c = {
      full: "EEEE, d 'de' MMMM y",
      long: "d 'de' MMMM y",
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$1c = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$1c = {
      full: "{{date}} 'a les' {{time}}",
      long: "{{date}} 'a les' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1c = {
      date: buildFormatLongFn({
        formats: dateFormats$1c,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1c,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1c,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$14 = {
      lastWeek: "'el' eeee 'passat a la' LT",
      yesterday: "'ahir a la' p",
      today: "'avui a la' p",
      tomorrow: "'demà a la' p",
      nextWeek: "eeee 'a la' p",
      other: 'P'
    };
    var formatRelativeLocalePlural$3 = {
      lastWeek: "'el' eeee 'passat a les' p",
      yesterday: "'ahir a les' p",
      today: "'avui a les' p",
      tomorrow: "'demà a les' p",
      nextWeek: "eeee 'a les' p",
      other: 'P'
    };
    var formatRelative$14 = function (token, date, _baseDate, _options) {
      if (date.getUTCHours() !== 1) {
        return formatRelativeLocalePlural$3[token];
      }
      return formatRelativeLocale$14[token];
    };

    var eraValues$14 = {
      narrow: ['aC', 'dC'],
      abbreviated: ['a. de C.', 'd. de C.'],
      wide: ['abans de Crist', 'després de Crist']
    };
    var quarterValues$14 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1r trimestre', '2n trimestre', '3r trimestre', '4t trimestre']
    };
    var monthValues$14 = {
      narrow: ['GN', 'FB', 'MÇ', 'AB', 'MG', 'JN', 'JL', 'AG', 'ST', 'OC', 'NV', 'DS'],
      abbreviated: ['gen.', 'febr.', 'març', 'abr.', 'maig', 'juny', 'jul.', 'ag.', 'set.', 'oct.', 'nov.', 'des.'],
      wide: ['gener', 'febrer', 'març', 'abril', 'maig', 'juny', 'juliol', 'agost', 'setembre', 'octubre', 'novembre', 'desembre']
    };
    var dayValues$14 = {
      narrow: ['dg.', 'dl.', 'dt.', 'dm.', 'dj.', 'dv.', 'ds.'],
      short: ['dg.', 'dl.', 'dt.', 'dm.', 'dj.', 'dv.', 'ds.'],
      abbreviated: ['dg.', 'dl.', 'dt.', 'dm.', 'dj.', 'dv.', 'ds.'],
      wide: ['diumenge', 'dilluns', 'dimarts', 'dimecres', 'dijous', 'divendres', 'dissabte']
    };
    var dayPeriodValues$14 = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'mitjanit',
        noon: 'migdia',
        morning: 'matí',
        afternoon: 'tarda',
        evening: 'vespre',
        night: 'nit'
      },
      abbreviated: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'mitjanit',
        noon: 'migdia',
        morning: 'matí',
        afternoon: 'tarda',
        evening: 'vespre',
        night: 'nit'
      },
      wide: {
        am: 'ante meridiem',
        pm: 'post meridiem',
        midnight: 'mitjanit',
        noon: 'migdia',
        morning: 'matí',
        afternoon: 'tarda',
        evening: 'vespre',
        night: 'nit'
      }
    };
    var formattingDayPeriodValues$S = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'de la mitjanit',
        noon: 'del migdia',
        morning: 'del matí',
        afternoon: 'de la tarda',
        evening: 'del vespre',
        night: 'de la nit'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'de la mitjanit',
        noon: 'del migdia',
        morning: 'del matí',
        afternoon: 'de la tarda',
        evening: 'del vespre',
        night: 'de la nit'
      },
      wide: {
        am: 'ante meridiem',
        pm: 'post meridiem',
        midnight: 'de la mitjanit',
        noon: 'del migdia',
        morning: 'del matí',
        afternoon: 'de la tarda',
        evening: 'del vespre',
        night: 'de la nit'
      }
    };
    var ordinalNumber$14 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      var rem100 = number % 100;
      if (rem100 > 20 || rem100 < 10) {
        switch (rem100 % 10) {
          case 1:
            return number + 'r';
          case 2:
            return number + 'n';
          case 3:
            return number + 'r';
          case 4:
            return number + 't';
        }
      }
      return number + 'è';
    };
    var localize$14 = {
      ordinalNumber: ordinalNumber$14,
      era: buildLocalizeFn({
        values: eraValues$14,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$14,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$14,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$14,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$14,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$S,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$13 = /^(\d+)(è|r|n|r|t)?/i;
    var parseOrdinalNumberPattern$13 = /\d+/i;
    var matchEraPatterns$13 = {
      narrow: /^(aC|dC)/i,
      abbreviated: /^(a. de C.|d. de C.)/i,
      wide: /^(abans de Crist|despr[eé]s de Crist)/i
    };
    var parseEraPatterns$13 = {
      narrow: [/^aC/i, /^dC/i],
      abbreviated: [/^(a. de C.)/i, /^(d. de C.)/i],
      wide: [/^(abans de Crist)/i, /^(despr[eé]s de Crist)/i]
    };
    var matchQuarterPatterns$13 = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^[1234](è|r|n|r|t)? trimestre/i
    };
    var parseQuarterPatterns$13 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$13 = {
      narrow: /^(GN|FB|MÇ|AB|MG|JN|JL|AG|ST|OC|NV|DS)/i,
      abbreviated: /^(gen.|febr.|març|abr.|maig|juny|jul.|ag.|set.|oct.|nov.|des.)/i,
      wide: /^(gener|febrer|març|abril|maig|juny|juliol|agost|setembre|octubre|novembre|desembre)/i
    };
    var parseMonthPatterns$13 = {
      narrow: [/^GN/i, /^FB/i, /^MÇ/i, /^AB/i, /^MG/i, /^JN/i, /^JL/i, /^AG/i, /^ST/i, /^OC/i, /^NV/i, /^DS/i],
      abbreviated: [/^gen./i, /^febr./i, /^març/i, /^abr./i, /^maig/i, /^juny/i, /^jul./i, /^ag./i, /^set./i, /^oct./i, /^nov./i, /^des./i],
      wide: [/^gener/i, /^febrer/i, /^març/i, /^abril/i, /^maig/i, /^juny/i, /^juliol/i, /^agost/i, /^setembre/i, /^octubre/i, /^novembre/i, /^desembre/i]
    };
    var matchDayPatterns$13 = {
      narrow: /^(dg\.|dl\.|dt\.|dm\.|dj\.|dv\.|ds\.)/i,
      short: /^(dg\.|dl\.|dt\.|dm\.|dj\.|dv\.|ds\.)/i,
      abbreviated: /^(dg\.|dl\.|dt\.|dm\.|dj\.|dv\.|ds\.)/i,
      wide: /^(diumenge|dilluns|dimarts|dimecres|dijous|divendres|dissabte)/i
    };
    var parseDayPatterns$13 = {
      narrow: [/^dg./i, /^dl./i, /^dt./i, /^dm./i, /^dj./i, /^dv./i, /^ds./i],
      abbreviated: [/^dg./i, /^dl./i, /^dt./i, /^dm./i, /^dj./i, /^dv./i, /^ds./i],
      wide: [/^diumenge/i, /^dilluns/i, /^dimarts/i, /^dimecres/i, /^dijous/i, /^divendres/i, /^disssabte/i]
    };
    var matchDayPeriodPatterns$13 = {
      narrow: /^(a|p|mn|md|(del|de la) (matí|tarda|vespre|nit))/i,
      abbreviated: /^([ap]\.?\s?m\.?|mitjanit|migdia|(del|de la) (matí|tarda|vespre|nit))/i,
      wide: /^(ante meridiem|post meridiem|mitjanit|migdia|(del|de la) (matí|tarda|vespre|nit))/i
    };
    var parseDayPeriodPatterns$13 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mitjanit/i,
        noon: /^migdia/i,
        morning: /matí/i,
        afternoon: /tarda/i,
        evening: /vespre/i,
        night: /nit/i
      }
    };
    var match$13 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$13,
        parsePattern: parseOrdinalNumberPattern$13,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$13,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$13,
        defaultParseWidth: 'wide'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$13,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$13,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$13,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$13,
        defaultParseWidth: 'wide'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$13,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$13,
        defaultParseWidth: 'wide'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$13,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$13,
        defaultParseWidth: 'any'
      })
    };

    var locale$1e = {
      code: 'ca',
      formatDistance: formatDistance$14,
      formatLong: formatLong$1c,
      formatRelative: formatRelative$14,
      localize: localize$14,
      match: match$13,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$12 = {
      lessThanXSeconds: {
        one: {
          regular: 'méně než sekunda',
          past: 'před méně než sekundou',
          future: 'za méně než sekundu'
        },
        few: {
          regular: 'méně než {{count}} sekundy',
          past: 'před méně než {{count}} sekundami',
          future: 'za méně než {{count}} sekundy'
        },
        many: {
          regular: 'méně než {{count}} sekund',
          past: 'před méně než {{count}} sekundami',
          future: 'za méně než {{count}} sekund'
        }
      },
      xSeconds: {
        one: {
          regular: 'sekunda',
          past: 'před sekundou',
          future: 'za sekundu'
        },
        few: {
          regular: '{{count}} sekundy',
          past: 'před {{count}} sekundami',
          future: 'za {{count}} sekundy'
        },
        many: {
          regular: '{{count}} sekund',
          past: 'před {{count}} sekundami',
          future: 'za {{count}} sekund'
        }
      },
      halfAMinute: {
        type: 'other',
        other: {
          regular: 'půl minuty',
          past: 'před půl minutou',
          future: 'za půl minuty'
        }
      },
      lessThanXMinutes: {
        one: {
          regular: 'méně než minuta',
          past: 'před méně než minutou',
          future: 'za méně než minutu'
        },
        few: {
          regular: 'méně než {{count}} minuty',
          past: 'před méně než {{count}} minutami',
          future: 'za méně než {{count}} minuty'
        },
        many: {
          regular: 'méně než {{count}} minut',
          past: 'před méně než {{count}} minutami',
          future: 'za méně než {{count}} minut'
        }
      },
      xMinutes: {
        one: {
          regular: 'minuta',
          past: 'před minutou',
          future: 'za minutu'
        },
        few: {
          regular: '{{count}} minuty',
          past: 'před {{count}} minutami',
          future: 'za {{count}} minuty'
        },
        many: {
          regular: '{{count}} minut',
          past: 'před {{count}} minutami',
          future: 'za {{count}} minut'
        }
      },
      aboutXHours: {
        one: {
          regular: 'přibližně hodina',
          past: 'přibližně před hodinou',
          future: 'přibližně za hodinu'
        },
        few: {
          regular: 'přibližně {{count}} hodiny',
          past: 'přibližně před {{count}} hodinami',
          future: 'přibližně za {{count}} hodiny'
        },
        many: {
          regular: 'přibližně {{count}} hodin',
          past: 'přibližně před {{count}} hodinami',
          future: 'přibližně za {{count}} hodin'
        }
      },
      xHours: {
        one: {
          regular: 'hodina',
          past: 'před hodinou',
          future: 'za hodinu'
        },
        few: {
          regular: '{{count}} hodiny',
          past: 'před {{count}} hodinami',
          future: 'za {{count}} hodiny'
        },
        many: {
          regular: '{{count}} hodin',
          past: 'před {{count}} hodinami',
          future: 'za {{count}} hodin'
        }
      },
      xDays: {
        one: {
          regular: 'den',
          past: 'před dnem',
          future: 'za den'
        },
        few: {
          regular: '{{count}} dny',
          past: 'před {{count}} dny',
          future: 'za {{count}} dny'
        },
        many: {
          regular: '{{count}} dní',
          past: 'před {{count}} dny',
          future: 'za {{count}} dní'
        }
      },
      aboutXWeeks: {
        one: {
          regular: 'přibližně týden',
          past: 'přibližně před týdnem',
          future: 'přibližně za týden'
        },
        few: {
          regular: 'přibližně {{count}} týdny',
          past: 'přibližně před {{count}} týdny',
          future: 'přibližně za {{count}} týdny'
        },
        many: {
          regular: 'přibližně {{count}} týdnů',
          past: 'přibližně před {{count}} týdny',
          future: 'přibližně za {{count}} týdnů'
        }
      },
      xWeeks: {
        one: {
          regular: 'týden',
          past: 'před týdnem',
          future: 'za týden'
        },
        few: {
          regular: '{{count}} týdny',
          past: 'před {{count}} týdny',
          future: 'za {{count}} týdny'
        },
        many: {
          regular: '{{count}} týdnů',
          past: 'před {{count}} týdny',
          future: 'za {{count}} týdnů'
        }
      },
      aboutXMonths: {
        one: {
          regular: 'přibližně měsíc',
          past: 'přibližně před měsícem',
          future: 'přibližně za měsíc'
        },
        few: {
          regular: 'přibližně {{count}} měsíce',
          past: 'přibližně před {{count}} měsíci',
          future: 'přibližně za {{count}} měsíce'
        },
        many: {
          regular: 'přibližně {{count}} měsíců',
          past: 'přibližně před {{count}} měsíci',
          future: 'přibližně za {{count}} měsíců'
        }
      },
      xMonths: {
        one: {
          regular: 'měsíc',
          past: 'před měsícem',
          future: 'za měsíc'
        },
        few: {
          regular: '{{count}} měsíce',
          past: 'před {{count}} měsíci',
          future: 'za {{count}} měsíce'
        },
        many: {
          regular: '{{count}} měsíců',
          past: 'před {{count}} měsíci',
          future: 'za {{count}} měsíců'
        }
      },
      aboutXYears: {
        one: {
          regular: 'přibližně rok',
          past: 'přibližně před rokem',
          future: 'přibližně za rok'
        },
        few: {
          regular: 'přibližně {{count}} roky',
          past: 'přibližně před {{count}} roky',
          future: 'přibližně za {{count}} roky'
        },
        many: {
          regular: 'přibližně {{count}} roků',
          past: 'přibližně před {{count}} roky',
          future: 'přibližně za {{count}} roků'
        }
      },
      xYears: {
        one: {
          regular: 'rok',
          past: 'před rokem',
          future: 'za rok'
        },
        few: {
          regular: '{{count}} roky',
          past: 'před {{count}} roky',
          future: 'za {{count}} roky'
        },
        many: {
          regular: '{{count}} roků',
          past: 'před {{count}} roky',
          future: 'za {{count}} roků'
        }
      },
      overXYears: {
        one: {
          regular: 'více než rok',
          past: 'před více než rokem',
          future: 'za více než rok'
        },
        few: {
          regular: 'více než {{count}} roky',
          past: 'před více než {{count}} roky',
          future: 'za více než {{count}} roky'
        },
        many: {
          regular: 'více než {{count}} roků',
          past: 'před více než {{count}} roky',
          future: 'za více než {{count}} roků'
        }
      },
      almostXYears: {
        one: {
          regular: 'skoro rok',
          past: 'skoro před rokem',
          future: 'skoro za rok'
        },
        few: {
          regular: 'skoro {{count}} roky',
          past: 'skoro před {{count}} roky',
          future: 'skoro za {{count}} roky'
        },
        many: {
          regular: 'skoro {{count}} roků',
          past: 'skoro před {{count}} roky',
          future: 'skoro za {{count}} roků'
        }
      }
    };
    var formatDistance$13 = function (token, count, options) {
      var pluralResult;
      var tokenValue = formatDistanceLocale$12[token];
      if (tokenValue.type === 'other') {
        pluralResult = tokenValue.other;
      } else if (count === 1) {
        pluralResult = tokenValue.one;
      } else if (count > 1 && count < 5) {
        pluralResult = tokenValue.few;
      } else {
        pluralResult = tokenValue.many;
      }
      var suffixExist = (options === null || options === void 0 ? void 0 : options.addSuffix) === true;
      var comparison = options === null || options === void 0 ? void 0 : options.comparison;
      var timeResult;
      if (suffixExist && comparison === -1) {
        timeResult = pluralResult.past;
      } else if (suffixExist && comparison === 1) {
        timeResult = pluralResult.future;
      } else {
        timeResult = pluralResult.regular;
      }
      return timeResult.replace('{{count}}', String(count));
    };

    var dateFormats$1b = {
      full: 'EEEE, d. MMMM yyyy',
      long: 'd. MMMM yyyy',
      medium: 'd. M. yyyy',
      short: 'dd.MM.yyyy'
    };
    var timeFormats$1b = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$1b = {
      full: "{{date}} 'v' {{time}}",
      long: "{{date}} 'v' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1b = {
      date: buildFormatLongFn({
        formats: dateFormats$1b,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1b,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1b,
        defaultWidth: 'full'
      })
    };

    var accusativeWeekdays$5 = ['neděli', 'pondělí', 'úterý', 'středu', 'čtvrtek', 'pátek', 'sobotu'];
    var formatRelativeLocale$13 = {
      lastWeek: "'poslední' eeee 've' p",
      yesterday: "'včera v' p",
      today: "'dnes v' p",
      tomorrow: "'zítra v' p",
      nextWeek: function (date) {
        var day = date.getUTCDay();
        return "'v " + accusativeWeekdays$5[day] + " o' p";
      },
      other: 'P'
    };
    var formatRelative$13 = function (token, date) {
      var format = formatRelativeLocale$13[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$13 = {
      narrow: ['př. n. l.', 'n. l.'],
      abbreviated: ['př. n. l.', 'n. l.'],
      wide: ['před naším letopočtem', 'našeho letopočtu']
    };
    var quarterValues$13 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1. čtvrtletí', '2. čtvrtletí', '3. čtvrtletí', '4. čtvrtletí'],
      wide: ['1. čtvrtletí', '2. čtvrtletí', '3. čtvrtletí', '4. čtvrtletí']
    };
    var monthValues$13 = {
      narrow: ['L', 'Ú', 'B', 'D', 'K', 'Č', 'Č', 'S', 'Z', 'Ř', 'L', 'P'],
      abbreviated: ['led', 'úno', 'bře', 'dub', 'kvě', 'čvn', 'čvc', 'srp', 'zář', 'říj', 'lis', 'pro'],
      wide: ['leden', 'únor', 'březen', 'duben', 'květen', 'červen', 'červenec', 'srpen', 'září', 'říjen', 'listopad', 'prosinec']
    };
    var formattingMonthValues$f = {
      narrow: ['L', 'Ú', 'B', 'D', 'K', 'Č', 'Č', 'S', 'Z', 'Ř', 'L', 'P'],
      abbreviated: ['led', 'úno', 'bře', 'dub', 'kvě', 'čvn', 'čvc', 'srp', 'zář', 'říj', 'lis', 'pro'],
      wide: ['ledna', 'února', 'března', 'dubna', 'května', 'června', 'července', 'srpna', 'září', 'října', 'listopadu', 'prosince']
    };
    var dayValues$13 = {
      narrow: ['ne', 'po', 'út', 'st', 'čt', 'pá', 'so'],
      short: ['ne', 'po', 'út', 'st', 'čt', 'pá', 'so'],
      abbreviated: ['ned', 'pon', 'úte', 'stř', 'čtv', 'pát', 'sob'],
      wide: ['neděle', 'pondělí', 'úterý', 'středa', 'čtvrtek', 'pátek', 'sobota']
    };
    var dayPeriodValues$13 = {
      narrow: {
        am: 'dop.',
        pm: 'odp.',
        midnight: 'půlnoc',
        noon: 'poledne',
        morning: 'ráno',
        afternoon: 'odpoledne',
        evening: 'večer',
        night: 'noc'
      },
      abbreviated: {
        am: 'dop.',
        pm: 'odp.',
        midnight: 'půlnoc',
        noon: 'poledne',
        morning: 'ráno',
        afternoon: 'odpoledne',
        evening: 'večer',
        night: 'noc'
      },
      wide: {
        am: 'dopoledne',
        pm: 'odpoledne',
        midnight: 'půlnoc',
        noon: 'poledne',
        morning: 'ráno',
        afternoon: 'odpoledne',
        evening: 'večer',
        night: 'noc'
      }
    };
    var formattingDayPeriodValues$R = {
      narrow: {
        am: 'dop.',
        pm: 'odp.',
        midnight: 'půlnoc',
        noon: 'poledne',
        morning: 'ráno',
        afternoon: 'odpoledne',
        evening: 'večer',
        night: 'noc'
      },
      abbreviated: {
        am: 'dop.',
        pm: 'odp.',
        midnight: 'půlnoc',
        noon: 'poledne',
        morning: 'ráno',
        afternoon: 'odpoledne',
        evening: 'večer',
        night: 'noc'
      },
      wide: {
        am: 'dopoledne',
        pm: 'odpoledne',
        midnight: 'půlnoc',
        noon: 'poledne',
        morning: 'ráno',
        afternoon: 'odpoledne',
        evening: 'večer',
        night: 'noc'
      }
    };
    var ordinalNumber$13 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$13 = {
      ordinalNumber: ordinalNumber$13,
      era: buildLocalizeFn({
        values: eraValues$13,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$13,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$13,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$f,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$13,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$13,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$R,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$12 = /^(\d+)\.?/i;
    var parseOrdinalNumberPattern$12 = /\d+/i;
    var matchEraPatterns$12 = {
      narrow: /^(p[řr](\.|ed) Kr\.|p[řr](\.|ed) n\. l\.|po Kr\.|n\. l\.)/i,
      abbreviated: /^(p[řr](\.|ed) Kr\.|p[řr](\.|ed) n\. l\.|po Kr\.|n\. l\.)/i,
      wide: /^(p[řr](\.|ed) Kristem|p[řr](\.|ed) na[šs][íi]m letopo[čc]tem|po Kristu|na[šs]eho letopo[čc]tu)/i
    };
    var parseEraPatterns$12 = {
      any: [/^p[řr]/i, /^(po|n)/i]
    };
    var matchQuarterPatterns$12 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]\. [čc]tvrtlet[íi]/i,
      wide: /^[1234]\. [čc]tvrtlet[íi]/i
    };
    var parseQuarterPatterns$12 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$12 = {
      narrow: /^[lúubdkčcszřrlp]/i,
      abbreviated: /^(led|[úu]no|b[řr]e|dub|kv[ěe]|[čc]vn|[čc]vc|srp|z[áa][řr]|[řr][íi]j|lis|pro)/i,
      wide: /^(leden|ledna|[úu]nora?|b[řr]ezen|b[řr]ezna|duben|dubna|kv[ěe]ten|kv[ěe]tna|[čc]erven(ec|ce)?|[čc]ervna|srpen|srpna|z[áa][řr][íi]|[řr][íi]jen|[řr][íi]jna|listopad(a|u)?|prosinec|prosince)/i
    };
    var parseMonthPatterns$12 = {
      narrow: [/^l/i, /^[úu]/i, /^b/i, /^d/i, /^k/i, /^[čc]/i, /^[čc]/i, /^s/i, /^z/i, /^[řr]/i, /^l/i, /^p/i],
      any: [/^led/i, /^[úu]n/i, /^b[řr]e/i, /^dub/i, /^kv[ěe]/i, /^[čc]vn|[čc]erven(?!\w)|[čc]ervna/i, /^[čc]vc|[čc]erven(ec|ce)/i, /^srp/i, /^z[áa][řr]/i, /^[řr][íi]j/i, /^lis/i, /^pro/i]
    };
    var matchDayPatterns$12 = {
      narrow: /^[npuúsčps]/i,
      short: /^(ne|po|[úu]t|st|[čc]t|p[áa]|so)/i,
      abbreviated: /^(ned|pon|[úu]te|st[rř]|[čc]tv|p[áa]t|sob)/i,
      wide: /^(ned[ěe]le|pond[ěe]l[íi]|[úu]ter[ýy]|st[řr]eda|[čc]tvrtek|p[áa]tek|sobota)/i
    };
    var parseDayPatterns$12 = {
      narrow: [/^n/i, /^p/i, /^[úu]/i, /^s/i, /^[čc]/i, /^p/i, /^s/i],
      any: [/^ne/i, /^po/i, /^[úu]t/i, /^st/i, /^[čc]t/i, /^p[áa]/i, /^so/i]
    };
    var matchDayPeriodPatterns$12 = {
      any: /^dopoledne|dop\.?|odpoledne|odp\.?|p[ůu]lnoc|poledne|r[áa]no|odpoledne|ve[čc]er|(v )?noci?/i
    };
    var parseDayPeriodPatterns$12 = {
      any: {
        am: /^dop/i,
        pm: /^odp/i,
        midnight: /^p[ůu]lnoc/i,
        noon: /^poledne/i,
        morning: /r[áa]no/i,
        afternoon: /odpoledne/i,
        evening: /ve[čc]er/i,
        night: /noc/i
      }
    };
    var match$12 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$12,
        parsePattern: parseOrdinalNumberPattern$12,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$12,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$12,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$12,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$12,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$12,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$12,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$12,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$12,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$12,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$12,
        defaultParseWidth: 'any'
      })
    };

    var locale$1d = {
      code: 'cs',
      formatDistance: formatDistance$13,
      formatLong: formatLong$1b,
      formatRelative: formatRelative$13,
      localize: localize$13,
      match: match$12,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$11 = {
      lessThanXSeconds: {
        one: 'llai na eiliad',
        other: 'llai na {{count}} eiliad'
      },
      xSeconds: {
        one: '1 eiliad',
        other: '{{count}} eiliad'
      },
      halfAMinute: 'hanner munud',
      lessThanXMinutes: {
        one: 'llai na munud',
        two: 'llai na 2 funud',
        other: 'llai na {{count}} munud'
      },
      xMinutes: {
        one: '1 munud',
        two: '2 funud',
        other: '{{count}} munud'
      },
      aboutXHours: {
        one: 'tua 1 awr',
        other: 'tua {{count}} awr'
      },
      xHours: {
        one: '1 awr',
        other: '{{count}} awr'
      },
      xDays: {
        one: '1 diwrnod',
        two: '2 ddiwrnod',
        other: '{{count}} diwrnod'
      },
      aboutXWeeks: {
        one: 'tua 1 wythnos',
        two: 'tua pythefnos',
        other: 'tua {{count}} wythnos'
      },
      xWeeks: {
        one: '1 wythnos',
        two: 'pythefnos',
        other: '{{count}} wythnos'
      },
      aboutXMonths: {
        one: 'tua 1 mis',
        two: 'tua 2 fis',
        other: 'tua {{count}} mis'
      },
      xMonths: {
        one: '1 mis',
        two: '2 fis',
        other: '{{count}} mis'
      },
      aboutXYears: {
        one: 'tua 1 flwyddyn',
        two: 'tua 2 flynedd',
        other: 'tua {{count}} mlynedd'
      },
      xYears: {
        one: '1 flwyddyn',
        two: '2 flynedd',
        other: '{{count}} mlynedd'
      },
      overXYears: {
        one: 'dros 1 flwyddyn',
        two: 'dros 2 flynedd',
        other: 'dros {{count}} mlynedd'
      },
      almostXYears: {
        one: 'bron 1 flwyddyn',
        two: 'bron 2 flynedd',
        other: 'bron {{count}} mlynedd'
      }
    };
    var formatDistance$12 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$11[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else if (count === 2 && !!tokenValue.two) {
        result = tokenValue.two;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'mewn ' + result;
        } else {
          return result + ' yn ôl';
        }
      }
      return result;
    };

    var dateFormats$1a = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$1a = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$1a = {
      full: "{{date}} 'am' {{time}}",
      long: "{{date}} 'am' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$1a = {
      date: buildFormatLongFn({
        formats: dateFormats$1a,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1a,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1a,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$12 = {
      lastWeek: "eeee 'diwethaf am' p",
      yesterday: "'ddoe am' p",
      today: "'heddiw am' p",
      tomorrow: "'yfory am' p",
      nextWeek: "eeee 'am' p",
      other: 'P'
    };
    var formatRelative$12 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$12[token];
    };

    var eraValues$12 = {
      narrow: ['C', 'O'],
      abbreviated: ['CC', 'OC'],
      wide: ['Cyn Crist', 'Ar ôl Crist']
    };
    var quarterValues$12 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Ch1', 'Ch2', 'Ch3', 'Ch4'],
      wide: ['Chwarter 1af', '2ail chwarter', '3ydd chwarter', '4ydd chwarter']
    };
    var monthValues$12 = {
      narrow: ['I', 'Ch', 'Ma', 'E', 'Mi', 'Me', 'G', 'A', 'Md', 'H', 'T', 'Rh'],
      abbreviated: ['Ion', 'Chwe', 'Maw', 'Ebr', 'Mai', 'Meh', 'Gor', 'Aws', 'Med', 'Hyd', 'Tach', 'Rhag'],
      wide: ['Ionawr', 'Chwefror', 'Mawrth', 'Ebrill', 'Mai', 'Mehefin', 'Gorffennaf', 'Awst', 'Medi', 'Hydref', 'Tachwedd', 'Rhagfyr']
    };
    var dayValues$12 = {
      narrow: ['S', 'Ll', 'M', 'M', 'I', 'G', 'S'],
      short: ['Su', 'Ll', 'Ma', 'Me', 'Ia', 'Gw', 'Sa'],
      abbreviated: ['Sul', 'Llun', 'Maw', 'Mer', 'Iau', 'Gwe', 'Sad'],
      wide: ['dydd Sul', 'dydd Llun', 'dydd Mawrth', 'dydd Mercher', 'dydd Iau', 'dydd Gwener', 'dydd Sadwrn']
    };
    var dayPeriodValues$12 = {
      narrow: {
        am: 'b',
        pm: 'h',
        midnight: 'hn',
        noon: 'hd',
        morning: 'bore',
        afternoon: 'prynhawn',
        evening: "gyda'r nos",
        night: 'nos'
      },
      abbreviated: {
        am: 'yb',
        pm: 'yh',
        midnight: 'hanner nos',
        noon: 'hanner dydd',
        morning: 'bore',
        afternoon: 'prynhawn',
        evening: "gyda'r nos",
        night: 'nos'
      },
      wide: {
        am: 'y.b.',
        pm: 'y.h.',
        midnight: 'hanner nos',
        noon: 'hanner dydd',
        morning: 'bore',
        afternoon: 'prynhawn',
        evening: "gyda'r nos",
        night: 'nos'
      }
    };
    var formattingDayPeriodValues$Q = {
      narrow: {
        am: 'b',
        pm: 'h',
        midnight: 'hn',
        noon: 'hd',
        morning: 'yn y bore',
        afternoon: 'yn y prynhawn',
        evening: "gyda'r nos",
        night: 'yn y nos'
      },
      abbreviated: {
        am: 'yb',
        pm: 'yh',
        midnight: 'hanner nos',
        noon: 'hanner dydd',
        morning: 'yn y bore',
        afternoon: 'yn y prynhawn',
        evening: "gyda'r nos",
        night: 'yn y nos'
      },
      wide: {
        am: 'y.b.',
        pm: 'y.h.',
        midnight: 'hanner nos',
        noon: 'hanner dydd',
        morning: 'yn y bore',
        afternoon: 'yn y prynhawn',
        evening: "gyda'r nos",
        night: 'yn y nos'
      }
    };
    var ordinalNumber$12 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      if (number < 20) {
        switch (number) {
          case 0:
            return number + 'fed';
          case 1:
            return number + 'af';
          case 2:
            return number + 'ail';
          case 3:
          case 4:
            return number + 'ydd';
          case 5:
          case 6:
            return number + 'ed';
          case 7:
          case 8:
          case 9:
          case 10:
          case 12:
          case 15:
          case 18:
            return number + 'fed';
          case 11:
          case 13:
          case 14:
          case 16:
          case 17:
          case 19:
            return number + 'eg';
        }
      } else if (number >= 50 && number <= 60 || number === 80 || number >= 100) {
        return number + 'fed';
      }
      return number + 'ain';
    };
    var localize$12 = {
      ordinalNumber: ordinalNumber$12,
      era: buildLocalizeFn({
        values: eraValues$12,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$12,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$12,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$12,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$12,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$Q,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$11 = /^(\d+)(af|ail|ydd|ed|fed|eg|ain)?/i;
    var parseOrdinalNumberPattern$11 = /\d+/i;
    var matchEraPatterns$11 = {
      narrow: /^(c|o)/i,
      abbreviated: /^(c\.?\s?c\.?|o\.?\s?c\.?)/i,
      wide: /^(cyn christ|ar ôl crist|ar ol crist)/i
    };
    var parseEraPatterns$11 = {
      wide: [/^c/i, /^(ar ôl crist|ar ol crist)/i],
      any: [/^c/i, /^o/i]
    };
    var matchQuarterPatterns$11 = {
      narrow: /^[1234]/i,
      abbreviated: /^ch[1234]/i,
      wide: /^(chwarter 1af)|([234](ail|ydd)? chwarter)/i
    };
    var parseQuarterPatterns$11 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$11 = {
      narrow: /^(i|ch|m|e|g|a|h|t|rh)/i,
      abbreviated: /^(ion|chwe|maw|ebr|mai|meh|gor|aws|med|hyd|tach|rhag)/i,
      wide: /^(ionawr|chwefror|mawrth|ebrill|mai|mehefin|gorffennaf|awst|medi|hydref|tachwedd|rhagfyr)/i
    };
    var parseMonthPatterns$11 = {
      narrow: [/^i/i, /^ch/i, /^m/i, /^e/i, /^m/i, /^m/i, /^g/i, /^a/i, /^m/i, /^h/i, /^t/i, /^rh/i],
      any: [/^io/i, /^ch/i, /^maw/i, /^e/i, /^mai/i, /^meh/i, /^g/i, /^a/i, /^med/i, /^h/i, /^t/i, /^rh/i]
    };
    var matchDayPatterns$11 = {
      narrow: /^(s|ll|m|i|g)/i,
      short: /^(su|ll|ma|me|ia|gw|sa)/i,
      abbreviated: /^(sul|llun|maw|mer|iau|gwe|sad)/i,
      wide: /^dydd (sul|llun|mawrth|mercher|iau|gwener|sadwrn)/i
    };
    var parseDayPatterns$11 = {
      narrow: [/^s/i, /^ll/i, /^m/i, /^m/i, /^i/i, /^g/i, /^s/i],
      wide: [/^dydd su/i, /^dydd ll/i, /^dydd ma/i, /^dydd me/i, /^dydd i/i, /^dydd g/i, /^dydd sa/i],
      any: [/^su/i, /^ll/i, /^ma/i, /^me/i, /^i/i, /^g/i, /^sa/i]
    };
    var matchDayPeriodPatterns$11 = {
      narrow: /^(b|h|hn|hd|(yn y|y|yr|gyda'r) (bore|prynhawn|nos|hwyr))/i,
      any: /^(y\.?\s?[bh]\.?|hanner nos|hanner dydd|(yn y|y|yr|gyda'r) (bore|prynhawn|nos|hwyr))/i
    };
    var parseDayPeriodPatterns$11 = {
      any: {
        am: /^b|(y\.?\s?b\.?)/i,
        pm: /^h|(y\.?\s?h\.?)|(yr hwyr)/i,
        midnight: /^hn|hanner nos/i,
        noon: /^hd|hanner dydd/i,
        morning: /bore/i,
        afternoon: /prynhawn/i,
        evening: /^gyda'r nos$/i,
        night: /blah/i
      }
    };
    var match$11 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$11,
        parsePattern: parseOrdinalNumberPattern$11,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$11,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$11,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$11,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$11,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$11,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$11,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$11,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$11,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$11,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$11,
        defaultParseWidth: 'any'
      })
    };

    var locale$1c = {
      code: 'cy',
      formatDistance: formatDistance$12,
      formatLong: formatLong$1a,
      formatRelative: formatRelative$12,
      localize: localize$12,
      match: match$11,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$10 = {
      lessThanXSeconds: {
        one: 'mindre end ét sekund',
        other: 'mindre end {{count}} sekunder'
      },
      xSeconds: {
        one: '1 sekund',
        other: '{{count}} sekunder'
      },
      halfAMinute: 'ét halvt minut',
      lessThanXMinutes: {
        one: 'mindre end ét minut',
        other: 'mindre end {{count}} minutter'
      },
      xMinutes: {
        one: '1 minut',
        other: '{{count}} minutter'
      },
      aboutXHours: {
        one: 'cirka 1 time',
        other: 'cirka {{count}} timer'
      },
      xHours: {
        one: '1 time',
        other: '{{count}} timer'
      },
      xDays: {
        one: '1 dag',
        other: '{{count}} dage'
      },
      aboutXWeeks: {
        one: 'cirka 1 uge',
        other: 'cirka {{count}} uger'
      },
      xWeeks: {
        one: '1 uge',
        other: '{{count}} uger'
      },
      aboutXMonths: {
        one: 'cirka 1 måned',
        other: 'cirka {{count}} måneder'
      },
      xMonths: {
        one: '1 måned',
        other: '{{count}} måneder'
      },
      aboutXYears: {
        one: 'cirka 1 år',
        other: 'cirka {{count}} år'
      },
      xYears: {
        one: '1 år',
        other: '{{count}} år'
      },
      overXYears: {
        one: 'over 1 år',
        other: 'over {{count}} år'
      },
      almostXYears: {
        one: 'næsten 1 år',
        other: 'næsten {{count}} år'
      }
    };
    var formatDistance$11 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$10[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'om ' + result;
        } else {
          return result + ' siden';
        }
      }
      return result;
    };

    var dateFormats$19 = {
      full: "EEEE 'den' d. MMMM y",
      long: 'd. MMMM y',
      medium: 'd. MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$19 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$19 = {
      full: "{{date}} 'kl'. {{time}}",
      long: "{{date}} 'kl'. {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$19 = {
      date: buildFormatLongFn({
        formats: dateFormats$19,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$19,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$19,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$11 = {
      lastWeek: "'sidste' eeee 'kl.' p",
      yesterday: "'i går kl.' p",
      today: "'i dag kl.' p",
      tomorrow: "'i morgen kl.' p",
      nextWeek: "'på' eeee 'kl.' p",
      other: 'P'
    };
    var formatRelative$11 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$11[token];
    };

    var eraValues$11 = {
      narrow: ['fvt', 'vt'],
      abbreviated: ['f.v.t.', 'v.t.'],
      wide: ['før vesterlandsk tidsregning', 'vesterlandsk tidsregning']
    };
    var quarterValues$11 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1. kvt.', '2. kvt.', '3. kvt.', '4. kvt.'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$11 = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mar.', 'apr.', 'maj', 'jun.', 'jul.', 'aug.', 'sep.', 'okt.', 'nov.', 'dec.'],
      wide: ['januar', 'februar', 'marts', 'april', 'maj', 'juni', 'juli', 'august', 'september', 'oktober', 'november', 'december']
    };
    var dayValues$11 = {
      narrow: ['S', 'M', 'T', 'O', 'T', 'F', 'L'],
      short: ['sø', 'ma', 'ti', 'on', 'to', 'fr', 'lø'],
      abbreviated: ['søn.', 'man.', 'tir.', 'ons.', 'tor.', 'fre.', 'lør.'],
      wide: ['søndag', 'mandag', 'tirsdag', 'onsdag', 'torsdag', 'fredag', 'lørdag']
    };
    var dayPeriodValues$11 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'midnat',
        noon: 'middag',
        morning: 'morgen',
        afternoon: 'eftermiddag',
        evening: 'aften',
        night: 'nat'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'midnat',
        noon: 'middag',
        morning: 'morgen',
        afternoon: 'eftermiddag',
        evening: 'aften',
        night: 'nat'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnat',
        noon: 'middag',
        morning: 'morgen',
        afternoon: 'eftermiddag',
        evening: 'aften',
        night: 'nat'
      }
    };
    var formattingDayPeriodValues$P = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'midnat',
        noon: 'middag',
        morning: 'om morgenen',
        afternoon: 'om eftermiddagen',
        evening: 'om aftenen',
        night: 'om natten'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'midnat',
        noon: 'middag',
        morning: 'om morgenen',
        afternoon: 'om eftermiddagen',
        evening: 'om aftenen',
        night: 'om natten'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnat',
        noon: 'middag',
        morning: 'om morgenen',
        afternoon: 'om eftermiddagen',
        evening: 'om aftenen',
        night: 'om natten'
      }
    };
    var ordinalNumber$11 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$11 = {
      ordinalNumber: ordinalNumber$11,
      era: buildLocalizeFn({
        values: eraValues$11,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$11,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$11,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$11,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$11,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$P,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$10 = /^(\d+)(\.)?/i;
    var parseOrdinalNumberPattern$10 = /\d+/i;
    var matchEraPatterns$10 = {
      narrow: /^(fKr|fvt|eKr|vt)/i,
      abbreviated: /^(f\.Kr\.?|f\.v\.t\.?|e\.Kr\.?|v\.t\.)/i,
      wide: /^(f.Kr.|før vesterlandsk tidsregning|e.Kr.|vesterlandsk tidsregning)/i
    };
    var parseEraPatterns$10 = {
      any: [/^f/i, /^(v|e)/i]
    };
    var matchQuarterPatterns$10 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]. kvt\./i,
      wide: /^[1234]\.? kvartal/i
    };
    var parseQuarterPatterns$10 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$10 = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan.|feb.|mar.|apr.|maj|jun.|jul.|aug.|sep.|okt.|nov.|dec.)/i,
      wide: /^(januar|februar|marts|april|maj|juni|juli|august|september|oktober|november|december)/i
    };
    var parseMonthPatterns$10 = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$10 = {
      narrow: /^[smtofl]/i,
      short: /^(søn.|man.|tir.|ons.|tor.|fre.|lør.)/i,
      abbreviated: /^(søn|man|tir|ons|tor|fre|lør)/i,
      wide: /^(søndag|mandag|tirsdag|onsdag|torsdag|fredag|lørdag)/i
    };
    var parseDayPatterns$10 = {
      narrow: [/^s/i, /^m/i, /^t/i, /^o/i, /^t/i, /^f/i, /^l/i],
      any: [/^s/i, /^m/i, /^ti/i, /^o/i, /^to/i, /^f/i, /^l/i]
    };
    var matchDayPeriodPatterns$10 = {
      narrow: /^(a|p|midnat|middag|(om) (morgenen|eftermiddagen|aftenen|natten))/i,
      any: /^([ap]\.?\s?m\.?|midnat|middag|(om) (morgenen|eftermiddagen|aftenen|natten))/i
    };
    var parseDayPeriodPatterns$10 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /midnat/i,
        noon: /middag/i,
        morning: /morgen/i,
        afternoon: /eftermiddag/i,
        evening: /aften/i,
        night: /nat/i
      }
    };
    var match$10 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$10,
        parsePattern: parseOrdinalNumberPattern$10,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$10,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$10,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$10,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$10,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$10,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$10,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$10,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$10,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$10,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$10,
        defaultParseWidth: 'any'
      })
    };

    var locale$1b = {
      code: 'da',
      formatDistance: formatDistance$11,
      formatLong: formatLong$19,
      formatRelative: formatRelative$11,
      localize: localize$11,
      match: match$10,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$$ = {
      lessThanXSeconds: {
        standalone: {
          one: 'weniger als 1 Sekunde',
          other: 'weniger als {{count}} Sekunden'
        },
        withPreposition: {
          one: 'weniger als 1 Sekunde',
          other: 'weniger als {{count}} Sekunden'
        }
      },
      xSeconds: {
        standalone: {
          one: '1 Sekunde',
          other: '{{count}} Sekunden'
        },
        withPreposition: {
          one: '1 Sekunde',
          other: '{{count}} Sekunden'
        }
      },
      halfAMinute: {
        standalone: 'halbe Minute',
        withPreposition: 'halben Minute'
      },
      lessThanXMinutes: {
        standalone: {
          one: 'weniger als 1 Minute',
          other: 'weniger als {{count}} Minuten'
        },
        withPreposition: {
          one: 'weniger als 1 Minute',
          other: 'weniger als {{count}} Minuten'
        }
      },
      xMinutes: {
        standalone: {
          one: '1 Minute',
          other: '{{count}} Minuten'
        },
        withPreposition: {
          one: '1 Minute',
          other: '{{count}} Minuten'
        }
      },
      aboutXHours: {
        standalone: {
          one: 'etwa 1 Stunde',
          other: 'etwa {{count}} Stunden'
        },
        withPreposition: {
          one: 'etwa 1 Stunde',
          other: 'etwa {{count}} Stunden'
        }
      },
      xHours: {
        standalone: {
          one: '1 Stunde',
          other: '{{count}} Stunden'
        },
        withPreposition: {
          one: '1 Stunde',
          other: '{{count}} Stunden'
        }
      },
      xDays: {
        standalone: {
          one: '1 Tag',
          other: '{{count}} Tage'
        },
        withPreposition: {
          one: '1 Tag',
          other: '{{count}} Tagen'
        }
      },
      aboutXWeeks: {
        standalone: {
          one: 'etwa 1 Woche',
          other: 'etwa {{count}} Wochen'
        },
        withPreposition: {
          one: 'etwa 1 Woche',
          other: 'etwa {{count}} Wochen'
        }
      },
      xWeeks: {
        standalone: {
          one: '1 Woche',
          other: '{{count}} Wochen'
        },
        withPreposition: {
          one: '1 Woche',
          other: '{{count}} Wochen'
        }
      },
      aboutXMonths: {
        standalone: {
          one: 'etwa 1 Monat',
          other: 'etwa {{count}} Monate'
        },
        withPreposition: {
          one: 'etwa 1 Monat',
          other: 'etwa {{count}} Monaten'
        }
      },
      xMonths: {
        standalone: {
          one: '1 Monat',
          other: '{{count}} Monate'
        },
        withPreposition: {
          one: '1 Monat',
          other: '{{count}} Monaten'
        }
      },
      aboutXYears: {
        standalone: {
          one: 'etwa 1 Jahr',
          other: 'etwa {{count}} Jahre'
        },
        withPreposition: {
          one: 'etwa 1 Jahr',
          other: 'etwa {{count}} Jahren'
        }
      },
      xYears: {
        standalone: {
          one: '1 Jahr',
          other: '{{count}} Jahre'
        },
        withPreposition: {
          one: '1 Jahr',
          other: '{{count}} Jahren'
        }
      },
      overXYears: {
        standalone: {
          one: 'mehr als 1 Jahr',
          other: 'mehr als {{count}} Jahre'
        },
        withPreposition: {
          one: 'mehr als 1 Jahr',
          other: 'mehr als {{count}} Jahren'
        }
      },
      almostXYears: {
        standalone: {
          one: 'fast 1 Jahr',
          other: 'fast {{count}} Jahre'
        },
        withPreposition: {
          one: 'fast 1 Jahr',
          other: 'fast {{count}} Jahren'
        }
      }
    };
    var formatDistance$10 = function (token, count, options) {
      var result;
      var tokenValue = options !== null && options !== void 0 && options.addSuffix ? formatDistanceLocale$$[token].withPreposition : formatDistanceLocale$$[token].standalone;
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'in ' + result;
        } else {
          return 'vor ' + result;
        }
      }
      return result;
    };

    var dateFormats$18 = {
      full: 'EEEE, do MMMM y',
      long: 'do MMMM y',
      medium: 'do MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$18 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$18 = {
      full: "{{date}} 'um' {{time}}",
      long: "{{date}} 'um' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$18 = {
      date: buildFormatLongFn({
        formats: dateFormats$18,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$18,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$18,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$10 = {
      lastWeek: "'letzten' eeee 'um' p",
      yesterday: "'gestern um' p",
      today: "'heute um' p",
      tomorrow: "'morgen um' p",
      nextWeek: "eeee 'um' p",
      other: 'P'
    };
    var formatRelative$10 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$10[token];
    };

    var eraValues$10 = {
      narrow: ['v.Chr.', 'n.Chr.'],
      abbreviated: ['v.Chr.', 'n.Chr.'],
      wide: ['vor Christus', 'nach Christus']
    };
    var quarterValues$10 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal']
    };
    var monthValues$10 = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      wide: ['Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember']
    };
    var formattingMonthValues$e = {
      narrow: monthValues$10.narrow,
      abbreviated: ['Jan.', 'Feb.', 'März', 'Apr.', 'Mai', 'Juni', 'Juli', 'Aug.', 'Sep.', 'Okt.', 'Nov.', 'Dez.'],
      wide: monthValues$10.wide
    };
    var dayValues$10 = {
      narrow: ['S', 'M', 'D', 'M', 'D', 'F', 'S'],
      short: ['So', 'Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa'],
      abbreviated: ['So.', 'Mo.', 'Di.', 'Mi.', 'Do.', 'Fr.', 'Sa.'],
      wide: ['Sonntag', 'Montag', 'Dienstag', 'Mittwoch', 'Donnerstag', 'Freitag', 'Samstag']
    };
    var dayPeriodValues$10 = {
      narrow: {
        am: 'vm.',
        pm: 'nm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachm.',
        evening: 'Abend',
        night: 'Nacht'
      },
      abbreviated: {
        am: 'vorm.',
        pm: 'nachm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachmittag',
        evening: 'Abend',
        night: 'Nacht'
      },
      wide: {
        am: 'vormittags',
        pm: 'nachmittags',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachmittag',
        evening: 'Abend',
        night: 'Nacht'
      }
    };
    var formattingDayPeriodValues$O = {
      narrow: {
        am: 'vm.',
        pm: 'nm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachm.',
        evening: 'abends',
        night: 'nachts'
      },
      abbreviated: {
        am: 'vorm.',
        pm: 'nachm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachmittags',
        evening: 'abends',
        night: 'nachts'
      },
      wide: {
        am: 'vormittags',
        pm: 'nachmittags',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachmittags',
        evening: 'abends',
        night: 'nachts'
      }
    };
    var ordinalNumber$10 = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$10 = {
      ordinalNumber: ordinalNumber$10,
      era: buildLocalizeFn({
        values: eraValues$10,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$10,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$10,
        formattingValues: formattingMonthValues$e,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$10,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$10,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$O,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$$ = /^(\d+)(\.)?/i;
    var parseOrdinalNumberPattern$$ = /\d+/i;
    var matchEraPatterns$$ = {
      narrow: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
      abbreviated: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
      wide: /^(vor Christus|vor unserer Zeitrechnung|nach Christus|unserer Zeitrechnung)/i
    };
    var parseEraPatterns$$ = {
      any: [/^v/i, /^n/i]
    };
    var matchQuarterPatterns$$ = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](\.)? Quartal/i
    };
    var parseQuarterPatterns$$ = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$$ = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(j[aä]n|feb|mär[z]?|apr|mai|jun[i]?|jul[i]?|aug|sep|okt|nov|dez)\.?/i,
      wide: /^(januar|februar|märz|april|mai|juni|juli|august|september|oktober|november|dezember)/i
    };
    var parseMonthPatterns$$ = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^j[aä]/i, /^f/i, /^mär/i, /^ap/i, /^mai/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$$ = {
      narrow: /^[smdmf]/i,
      short: /^(so|mo|di|mi|do|fr|sa)/i,
      abbreviated: /^(son?|mon?|die?|mit?|don?|fre?|sam?)\.?/i,
      wide: /^(sonntag|montag|dienstag|mittwoch|donnerstag|freitag|samstag)/i
    };
    var parseDayPatterns$$ = {
      any: [/^so/i, /^mo/i, /^di/i, /^mi/i, /^do/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$$ = {
      narrow: /^(vm\.?|nm\.?|Mitternacht|Mittag|morgens|nachm\.?|abends|nachts)/i,
      abbreviated: /^(vorm\.?|nachm\.?|Mitternacht|Mittag|morgens|nachm\.?|abends|nachts)/i,
      wide: /^(vormittags|nachmittags|Mitternacht|Mittag|morgens|nachmittags|abends|nachts)/i
    };
    var parseDayPeriodPatterns$$ = {
      any: {
        am: /^v/i,
        pm: /^n/i,
        midnight: /^Mitte/i,
        noon: /^Mitta/i,
        morning: /morgens/i,
        afternoon: /nachmittags/i,
        evening: /abends/i,
        night: /nachts/i
      }
    };
    var match$$ = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$$,
        parsePattern: parseOrdinalNumberPattern$$,
        valueCallback: function (value) {
          return parseInt(value);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$$,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$$,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$$,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$$,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$$,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$$,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$$,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$$,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$$,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$$,
        defaultParseWidth: 'any'
      })
    };

    var locale$1a = {
      code: 'de',
      formatDistance: formatDistance$10,
      formatLong: formatLong$18,
      formatRelative: formatRelative$10,
      localize: localize$10,
      match: match$$,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var eraValues$$ = {
      narrow: ['v.Chr.', 'n.Chr.'],
      abbreviated: ['v.Chr.', 'n.Chr.'],
      wide: ['vor Christus', 'nach Christus']
    };
    var quarterValues$$ = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal']
    };
    var monthValues$$ = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jän', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      wide: ['Jänner', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember']
    };
    var formattingMonthValues$d = {
      narrow: monthValues$$.narrow,
      abbreviated: ['Jän.', 'Feb.', 'März', 'Apr.', 'Mai', 'Juni', 'Juli', 'Aug.', 'Sep.', 'Okt.', 'Nov.', 'Dez.'],
      wide: monthValues$$.wide
    };
    var dayValues$$ = {
      narrow: ['S', 'M', 'D', 'M', 'D', 'F', 'S'],
      short: ['So', 'Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa'],
      abbreviated: ['So.', 'Mo.', 'Di.', 'Mi.', 'Do.', 'Fr.', 'Sa.'],
      wide: ['Sonntag', 'Montag', 'Dienstag', 'Mittwoch', 'Donnerstag', 'Freitag', 'Samstag']
    };
    var dayPeriodValues$$ = {
      narrow: {
        am: 'vm.',
        pm: 'nm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachm.',
        evening: 'Abend',
        night: 'Nacht'
      },
      abbreviated: {
        am: 'vorm.',
        pm: 'nachm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachmittag',
        evening: 'Abend',
        night: 'Nacht'
      },
      wide: {
        am: 'vormittags',
        pm: 'nachmittags',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachmittag',
        evening: 'Abend',
        night: 'Nacht'
      }
    };
    var formattingDayPeriodValues$N = {
      narrow: {
        am: 'vm.',
        pm: 'nm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachm.',
        evening: 'abends',
        night: 'nachts'
      },
      abbreviated: {
        am: 'vorm.',
        pm: 'nachm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachmittags',
        evening: 'abends',
        night: 'nachts'
      },
      wide: {
        am: 'vormittags',
        pm: 'nachmittags',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachmittags',
        evening: 'abends',
        night: 'nachts'
      }
    };
    var ordinalNumber$$ = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$$ = {
      ordinalNumber: ordinalNumber$$,
      era: buildLocalizeFn({
        values: eraValues$$,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$$,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$$,
        formattingValues: formattingMonthValues$d,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$$,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$$,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$N,
        defaultFormattingWidth: 'wide'
      })
    };

    var locale$19 = {
      code: 'de-AT',
      formatDistance: formatDistance$10,
      formatLong: formatLong$18,
      formatRelative: formatRelative$10,
      localize: localize$$,
      match: match$$,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$_ = {
      lessThanXSeconds: {
        one: 'λιγότερο από ένα δευτερόλεπτο',
        other: 'λιγότερο από {{count}} δευτερόλεπτα'
      },
      xSeconds: {
        one: '1 δευτερόλεπτο',
        other: '{{count}} δευτερόλεπτα'
      },
      halfAMinute: 'μισό λεπτό',
      lessThanXMinutes: {
        one: 'λιγότερο από ένα λεπτό',
        other: 'λιγότερο από {{count}} λεπτά'
      },
      xMinutes: {
        one: '1 λεπτό',
        other: '{{count}} λεπτά'
      },
      aboutXHours: {
        one: 'περίπου 1 ώρα',
        other: 'περίπου {{count}} ώρες'
      },
      xHours: {
        one: '1 ώρα',
        other: '{{count}} ώρες'
      },
      xDays: {
        one: '1 ημέρα',
        other: '{{count}} ημέρες'
      },
      aboutXWeeks: {
        one: 'περίπου 1 εβδομάδα',
        other: 'περίπου {{count}} εβδομάδες'
      },
      xWeeks: {
        one: '1 εβδομάδα',
        other: '{{count}} εβδομάδες'
      },
      aboutXMonths: {
        one: 'περίπου 1 μήνας',
        other: 'περίπου {{count}} μήνες'
      },
      xMonths: {
        one: '1 μήνας',
        other: '{{count}} μήνες'
      },
      aboutXYears: {
        one: 'περίπου 1 χρόνο',
        other: 'περίπου {{count}} χρόνια'
      },
      xYears: {
        one: '1 χρόνο',
        other: '{{count}} χρόνια'
      },
      overXYears: {
        one: 'πάνω από 1 χρόνο',
        other: 'πάνω από {{count}} χρόνια'
      },
      almostXYears: {
        one: 'περίπου 1 χρόνο',
        other: 'περίπου {{count}} χρόνια'
      }
    };
    var formatDistance$$ = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$_[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'σε ' + result;
        } else {
          return result + ' πριν';
        }
      }
      return result;
    };

    var dateFormats$17 = {
      full: 'EEEE, d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'd/M/yy'
    };
    var timeFormats$17 = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$17 = {
      full: '{{date}} - {{time}}',
      long: '{{date}} - {{time}}',
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$17 = {
      date: buildFormatLongFn({
        formats: dateFormats$17,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$17,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$17,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$$ = {
      lastWeek: function (date) {
        switch (date.getUTCDay()) {
          case 6:
            return "'το προηγούμενο' eeee 'στις' p";
          default:
            return "'την προηγούμενη' eeee 'στις' p";
        }
      },
      yesterday: "'χθες στις' p",
      today: "'σήμερα στις' p",
      tomorrow: "'αύριο στις' p",
      nextWeek: "eeee 'στις' p",
      other: 'P'
    };
    var formatRelative$$ = function (token, date) {
      var format = formatRelativeLocale$$[token];
      if (typeof format === 'function') return format(date);
      return format;
    };

    var eraValues$_ = {
      narrow: ['πΧ', 'μΧ'],
      abbreviated: ['π.Χ.', 'μ.Χ.'],
      wide: ['προ Χριστού', 'μετά Χριστόν']
    };
    var quarterValues$_ = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Τ1', 'Τ2', 'Τ3', 'Τ4'],
      wide: ['1ο τρίμηνο', '2ο τρίμηνο', '3ο τρίμηνο', '4ο τρίμηνο']
    };
    var monthValues$_ = {
      narrow: ['Ι', 'Φ', 'Μ', 'Α', 'Μ', 'Ι', 'Ι', 'Α', 'Σ', 'Ο', 'Ν', 'Δ'],
      abbreviated: ['Ιαν', 'Φεβ', 'Μάρ', 'Απρ', 'Μάι', 'Ιούν', 'Ιούλ', 'Αύγ', 'Σεπ', 'Οκτ', 'Νοέ', 'Δεκ'],
      wide: ['Ιανουάριος', 'Φεβρουάριος', 'Μάρτιος', 'Απρίλιος', 'Μάιος', 'Ιούνιος', 'Ιούλιος', 'Αύγουστος', 'Σεπτέμβριος', 'Οκτώβριος', 'Νοέμβριος', 'Δεκέμβριος']
    };
    var formattingMonthValues$c = {
      narrow: ['Ι', 'Φ', 'Μ', 'Α', 'Μ', 'Ι', 'Ι', 'Α', 'Σ', 'Ο', 'Ν', 'Δ'],
      abbreviated: ['Ιαν', 'Φεβ', 'Μαρ', 'Απρ', 'Μαΐ', 'Ιουν', 'Ιουλ', 'Αυγ', 'Σεπ', 'Οκτ', 'Νοε', 'Δεκ'],
      wide: ['Ιανουαρίου', 'Φεβρουαρίου', 'Μαρτίου', 'Απριλίου', 'Μαΐου', 'Ιουνίου', 'Ιουλίου', 'Αυγούστου', 'Σεπτεμβρίου', 'Οκτωβρίου', 'Νοεμβρίου', 'Δεκεμβρίου']
    };
    var dayValues$_ = {
      narrow: ['Κ', 'Δ', 'T', 'Τ', 'Π', 'Π', 'Σ'],
      short: ['Κυ', 'Δε', 'Τρ', 'Τε', 'Πέ', 'Πα', 'Σά'],
      abbreviated: ['Κυρ', 'Δευ', 'Τρί', 'Τετ', 'Πέμ', 'Παρ', 'Σάβ'],
      wide: ['Κυριακή', 'Δευτέρα', 'Τρίτη', 'Τετάρτη', 'Πέμπτη', 'Παρασκευή', 'Σάββατο']
    };
    var dayPeriodValues$_ = {
      narrow: {
        am: 'πμ',
        pm: 'μμ',
        midnight: 'μεσάνυχτα',
        noon: 'μεσημέρι',
        morning: 'πρωί',
        afternoon: 'απόγευμα',
        evening: 'βράδυ',
        night: 'νύχτα'
      },
      abbreviated: {
        am: 'π.μ.',
        pm: 'μ.μ.',
        midnight: 'μεσάνυχτα',
        noon: 'μεσημέρι',
        morning: 'πρωί',
        afternoon: 'απόγευμα',
        evening: 'βράδυ',
        night: 'νύχτα'
      },
      wide: {
        am: 'π.μ.',
        pm: 'μ.μ.',
        midnight: 'μεσάνυχτα',
        noon: 'μεσημέρι',
        morning: 'πρωί',
        afternoon: 'απόγευμα',
        evening: 'βράδυ',
        night: 'νύχτα'
      }
    };
    var ordinalNumber$_ = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      var suffix;
      if (unit === 'year' || unit === 'month') {
        suffix = 'ος';
      } else if (unit === 'week' || unit === 'dayOfYear' || unit === 'day' || unit === 'hour' || unit === 'date') {
        suffix = 'η';
      } else {
        suffix = 'ο';
      }
      return number + suffix;
    };
    var localize$_ = {
      ordinalNumber: ordinalNumber$_,
      era: buildLocalizeFn({
        values: eraValues$_,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$_,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$_,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$c,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$_,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$_,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$_ = /^(\d+)(ος|η|ο)?/i;
    var parseOrdinalNumberPattern$_ = /\d+/i;
    var matchEraPatterns$_ = {
      narrow: /^(πΧ|μΧ)/i,
      abbreviated: /^(π\.?\s?χ\.?|π\.?\s?κ\.?\s?χ\.?|μ\.?\s?χ\.?|κ\.?\s?χ\.?)/i,
      wide: /^(προ Χριστο(ύ|υ)|πριν απ(ό|ο) την Κοιν(ή|η) Χρονολογ(ί|ι)α|μετ(ά|α) Χριστ(ό|ο)ν|Κοιν(ή|η) Χρονολογ(ί|ι)α)/i
    };
    var parseEraPatterns$_ = {
      any: [/^π/i, /^(μ|κ)/i]
    };
    var matchQuarterPatterns$_ = {
      narrow: /^[1234]/i,
      abbreviated: /^τ[1234]/i,
      wide: /^[1234]ο? τρ(ί|ι)μηνο/i
    };
    var parseQuarterPatterns$_ = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$_ = {
      narrow: /^[ιφμαμιιασονδ]/i,
      abbreviated: /^(ιαν|φεβ|μ[άα]ρ|απρ|μ[άα][ιΐ]|ιο[ύυ]ν|ιο[ύυ]λ|α[ύυ]γ|σεπ|οκτ|νο[έε]|δεκ)/i,
      wide: /^(μ[άα][ιΐ]|α[ύυ]γο[υύ]στ)(ος|ου)|(ιανου[άα]ρ|φεβρου[άα]ρ|μ[άα]ρτ|απρ[ίι]λ|ιο[ύυ]ν|ιο[ύυ]λ|σεπτ[έε]μβρ|οκτ[ώω]βρ|νο[έε]μβρ|δεκ[έε]μβρ)(ιος|ίου)/i
    };
    var parseMonthPatterns$_ = {
      narrow: [/^ι/i, /^φ/i, /^μ/i, /^α/i, /^μ/i, /^ι/i, /^ι/i, /^α/i, /^σ/i, /^ο/i, /^ν/i, /^δ/i],
      any: [/^ια/i, /^φ/i, /^μ[άα]ρ/i, /^απ/i, /^μ[άα][ιΐ]/i, /^ιο[ύυ]ν/i, /^ιο[ύυ]λ/i, /^α[ύυ]/i, /^σ/i, /^ο/i, /^ν/i, /^δ/i]
    };
    var matchDayPatterns$_ = {
      narrow: /^[κδτπσ]/i,
      short: /^(κυ|δε|τρ|τε|π[εέ]|π[αά]|σ[αά])/i,
      abbreviated: /^(κυρ|δευ|τρι|τετ|πεμ|παρ|σαβ)/i,
      wide: /^(κυριακ(ή|η)|δευτ(έ|ε)ρα|τρ(ί|ι)τη|τετ(ά|α)ρτη|π(έ|ε)μπτη|παρασκευ(ή|η)|σ(ά|α)ββατο)/i
    };
    var parseDayPatterns$_ = {
      narrow: [/^κ/i, /^δ/i, /^τ/i, /^τ/i, /^π/i, /^π/i, /^σ/i],
      any: [/^κ/i, /^δ/i, /^τρ/i, /^τε/i, /^π[εέ]/i, /^π[αά]/i, /^σ/i]
    };
    var matchDayPeriodPatterns$_ = {
      narrow: /^(πμ|μμ|μεσ(ά|α)νυχτα|μεσημ(έ|ε)ρι|πρω(ί|ι)|απ(ό|ο)γευμα|βρ(ά|α)δυ|ν(ύ|υ)χτα)/i,
      any: /^([πμ]\.?\s?μ\.?|μεσ(ά|α)νυχτα|μεσημ(έ|ε)ρι|πρω(ί|ι)|απ(ό|ο)γευμα|βρ(ά|α)δυ|ν(ύ|υ)χτα)/i
    };
    var parseDayPeriodPatterns$_ = {
      any: {
        am: /^πμ|π\.\s?μ\./i,
        pm: /^μμ|μ\.\s?μ\./i,
        midnight: /^μεσάν/i,
        noon: /^μεσημ(έ|ε)/i,
        morning: /πρω(ί|ι)/i,
        afternoon: /απ(ό|ο)γευμα/i,
        evening: /βρ(ά|α)δυ/i,
        night: /ν(ύ|υ)χτα/i
      }
    };
    var match$_ = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$_,
        parsePattern: parseOrdinalNumberPattern$_,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$_,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$_,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$_,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$_,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$_,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$_,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$_,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$_,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$_,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$_,
        defaultParseWidth: 'any'
      })
    };

    var locale$18 = {
      code: 'el',
      formatDistance: formatDistance$$,
      formatLong: formatLong$17,
      formatRelative: formatRelative$$,
      localize: localize$_,
      match: match$_,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var dateFormats$16 = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$16 = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$16 = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$16 = {
      date: buildFormatLongFn({
        formats: dateFormats$16,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$16,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$16,
        defaultWidth: 'full'
      })
    };

    var locale$17 = {
      code: 'en-AU',
      formatDistance: formatDistance$1j,
      formatLong: formatLong$16,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$Z = {
      lessThanXSeconds: {
        one: 'less than a second',
        other: 'less than {{count}} seconds'
      },
      xSeconds: {
        one: 'a second',
        other: '{{count}} seconds'
      },
      halfAMinute: 'half a minute',
      lessThanXMinutes: {
        one: 'less than a minute',
        other: 'less than {{count}} minutes'
      },
      xMinutes: {
        one: 'a minute',
        other: '{{count}} minutes'
      },
      aboutXHours: {
        one: 'about an hour',
        other: 'about {{count}} hours'
      },
      xHours: {
        one: 'an hour',
        other: '{{count}} hours'
      },
      xDays: {
        one: 'a day',
        other: '{{count}} days'
      },
      aboutXWeeks: {
        one: 'about a week',
        other: 'about {{count}} weeks'
      },
      xWeeks: {
        one: 'a week',
        other: '{{count}} weeks'
      },
      aboutXMonths: {
        one: 'about a month',
        other: 'about {{count}} months'
      },
      xMonths: {
        one: 'a month',
        other: '{{count}} months'
      },
      aboutXYears: {
        one: 'about a year',
        other: 'about {{count}} years'
      },
      xYears: {
        one: 'a year',
        other: '{{count}} years'
      },
      overXYears: {
        one: 'over a year',
        other: 'over {{count}} years'
      },
      almostXYears: {
        one: 'almost a year',
        other: 'almost {{count}} years'
      }
    };
    var formatDistance$_ = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$Z[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'in ' + result;
        } else {
          return result + ' ago';
        }
      }
      return result;
    };

    var dateFormats$15 = {
      full: 'EEEE, MMMM do, yyyy',
      long: 'MMMM do, yyyy',
      medium: 'MMM d, yyyy',
      short: 'yyyy-MM-dd'
    };
    var timeFormats$15 = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$15 = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$15 = {
      date: buildFormatLongFn({
        formats: dateFormats$15,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$15,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$15,
        defaultWidth: 'full'
      })
    };

    var locale$16 = {
      code: 'en-CA',
      formatDistance: formatDistance$_,
      formatLong: formatLong$15,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var dateFormats$14 = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$14 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$14 = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$14 = {
      date: buildFormatLongFn({
        formats: dateFormats$14,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$14,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$14,
        defaultWidth: 'full'
      })
    };

    var locale$15 = {
      code: 'en-GB',
      formatDistance: formatDistance$1j,
      formatLong: formatLong$14,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var locale$14 = {
      code: 'en-IE',
      formatDistance: formatDistance$1j,
      formatLong: formatLong$14,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var dateFormats$13 = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM, yyyy',
      medium: 'd MMM, yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$13 = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$13 = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$13 = {
      date: buildFormatLongFn({
        formats: dateFormats$13,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$13,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$13,
        defaultWidth: 'full'
      })
    };

    var locale$13 = {
      code: 'en-IN',
      formatDistance: formatDistance$1j,
      formatLong: formatLong$13,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 1,
        firstWeekContainsDate: 4
      }
    };

    var dateFormats$12 = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$12 = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$12 = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$12 = {
      date: buildFormatLongFn({
        formats: dateFormats$12,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$12,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$12,
        defaultWidth: 'full'
      })
    };

    var locale$12 = {
      code: 'en-NZ',
      formatDistance: formatDistance$1j,
      formatLong: formatLong$12,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var dateFormats$11 = {
      full: 'EEEE, dd MMMM yyyy',
      long: 'dd MMMM yyyy',
      medium: 'dd MMM yyyy',
      short: 'yyyy/MM/dd'
    };
    var timeFormats$11 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$11 = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$11 = {
      date: buildFormatLongFn({
        formats: dateFormats$11,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$11,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$11,
        defaultWidth: 'full'
      })
    };

    var locale$11 = {
      code: 'en-ZA',
      formatDistance: formatDistance$1j,
      formatLong: formatLong$11,
      formatRelative: formatRelative$1i,
      localize: localize$1i,
      match: match$1h,
      options: {
        weekStartsOn: 0,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$Y = {
      lessThanXSeconds: {
        one: 'malpli ol sekundo',
        other: 'malpli ol {{count}} sekundoj'
      },
      xSeconds: {
        one: '1 sekundo',
        other: '{{count}} sekundoj'
      },
      halfAMinute: 'duonminuto',
      lessThanXMinutes: {
        one: 'malpli ol minuto',
        other: 'malpli ol {{count}} minutoj'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutoj'
      },
      aboutXHours: {
        one: 'proksimume 1 horo',
        other: 'proksimume {{count}} horoj'
      },
      xHours: {
        one: '1 horo',
        other: '{{count}} horoj'
      },
      xDays: {
        one: '1 tago',
        other: '{{count}} tagoj'
      },
      aboutXMonths: {
        one: 'proksimume 1 monato',
        other: 'proksimume {{count}} monatoj'
      },
      xWeeks: {
        one: '1 semajno',
        other: '{{count}} semajnoj'
      },
      aboutXWeeks: {
        one: 'proksimume 1 semajno',
        other: 'proksimume {{count}} semajnoj'
      },
      xMonths: {
        one: '1 monato',
        other: '{{count}} monatoj'
      },
      aboutXYears: {
        one: 'proksimume 1 jaro',
        other: 'proksimume {{count}} jaroj'
      },
      xYears: {
        one: '1 jaro',
        other: '{{count}} jaroj'
      },
      overXYears: {
        one: 'pli ol 1 jaro',
        other: 'pli ol {{count}} jaroj'
      },
      almostXYears: {
        one: 'preskaŭ 1 jaro',
        other: 'preskaŭ {{count}} jaroj'
      }
    };
    var formatDistance$Z = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$Y[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options !== null && options !== void 0 && options.comparison && options.comparison > 0) {
          return 'post ' + result;
        } else {
          return 'antaŭ ' + result;
        }
      }
      return result;
    };

    var dateFormats$10 = {
      full: "EEEE, do 'de' MMMM y",
      long: 'y-MMMM-dd',
      medium: 'y-MMM-dd',
      short: 'yyyy-MM-dd'
    };
    var timeFormats$10 = {
      full: "Ho 'horo kaj' m:ss zzzz",
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$10 = {
      any: '{{date}} {{time}}'
    };
    var formatLong$10 = {
      date: buildFormatLongFn({
        formats: dateFormats$10,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$10,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$10,
        defaultWidth: 'any'
      })
    };

    var formatRelativeLocale$_ = {
      lastWeek: "'pasinta' eeee 'je' p",
      yesterday: "'hieraŭ je' p",
      today: "'hodiaŭ je' p",
      tomorrow: "'morgaŭ je' p",
      nextWeek: "eeee 'je' p",
      other: 'P'
    };
    var formatRelative$_ = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$_[token];
    };

    var eraValues$Z = {
      narrow: ['aK', 'pK'],
      abbreviated: ['a.K.E.', 'p.K.E.'],
      wide: ['antaŭ Komuna Erao', 'Komuna Erao']
    };
    var quarterValues$Z = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1-a kvaronjaro', '2-a kvaronjaro', '3-a kvaronjaro', '4-a kvaronjaro']
    };
    var monthValues$Z = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aŭg', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januaro', 'februaro', 'marto', 'aprilo', 'majo', 'junio', 'julio', 'aŭgusto', 'septembro', 'oktobro', 'novembro', 'decembro']
    };
    var dayValues$Z = {
      narrow: ['D', 'L', 'M', 'M', 'Ĵ', 'V', 'S'],
      short: ['di', 'lu', 'ma', 'me', 'ĵa', 've', 'sa'],
      abbreviated: ['dim', 'lun', 'mar', 'mer', 'ĵaŭ', 'ven', 'sab'],
      wide: ['dimanĉo', 'lundo', 'mardo', 'merkredo', 'ĵaŭdo', 'vendredo', 'sabato']
    };
    var dayPeriodValues$Z = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'noktomezo',
        noon: 'tagmezo',
        morning: 'matene',
        afternoon: 'posttagmeze',
        evening: 'vespere',
        night: 'nokte'
      },
      abbreviated: {
        am: 'a.t.m.',
        pm: 'p.t.m.',
        midnight: 'noktomezo',
        noon: 'tagmezo',
        morning: 'matene',
        afternoon: 'posttagmeze',
        evening: 'vespere',
        night: 'nokte'
      },
      wide: {
        am: 'antaŭtagmeze',
        pm: 'posttagmeze',
        midnight: 'noktomezo',
        noon: 'tagmezo',
        morning: 'matene',
        afternoon: 'posttagmeze',
        evening: 'vespere',
        night: 'nokte'
      }
    };
    var ordinalNumber$Z = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      return number + '-a';
    };
    var localize$Z = {
      ordinalNumber: ordinalNumber$Z,
      era: buildLocalizeFn({
        values: eraValues$Z,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$Z,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$Z,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$Z,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$Z,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$Z = /^(\d+)(-?a)?/i;
    var parseOrdinalNumberPattern$Z = /\d+/i;
    var matchEraPatterns$Z = {
      narrow: /^([ap]k)/i,
      abbreviated: /^([ap]\.?\s?k\.?\s?e\.?)/i,
      wide: /^((antaǔ |post )?komuna erao)/i
    };
    var parseEraPatterns$Z = {
      any: [/^a/i, /^[kp]/i]
    };
    var matchQuarterPatterns$Z = {
      narrow: /^[1234]/i,
      abbreviated: /^k[1234]/i,
      wide: /^[1234](-?a)? kvaronjaro/i
    };
    var parseQuarterPatterns$Z = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$Z = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|maj|jun|jul|a(ŭ|ux|uh|u)g|sep|okt|nov|dec)/i,
      wide: /^(januaro|februaro|marto|aprilo|majo|junio|julio|a(ŭ|ux|uh|u)gusto|septembro|oktobro|novembro|decembro)/i
    };
    var parseMonthPatterns$Z = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^a(u|ŭ)/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$Z = {
      narrow: /^[dlmĵjvs]/i,
      short: /^(di|lu|ma|me|(ĵ|jx|jh|j)a|ve|sa)/i,
      abbreviated: /^(dim|lun|mar|mer|(ĵ|jx|jh|j)a(ŭ|ux|uh|u)|ven|sab)/i,
      wide: /^(diman(ĉ|cx|ch|c)o|lundo|mardo|merkredo|(ĵ|jx|jh|j)a(ŭ|ux|uh|u)do|vendredo|sabato)/i
    };
    var parseDayPatterns$Z = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^(j|ĵ)/i, /^v/i, /^s/i],
      any: [/^d/i, /^l/i, /^ma/i, /^me/i, /^(j|ĵ)/i, /^v/i, /^s/i]
    };
    var matchDayPeriodPatterns$Z = {
      narrow: /^([ap]|(posttagmez|noktomez|tagmez|maten|vesper|nokt)[eo])/i,
      abbreviated: /^([ap][.\s]?t[.\s]?m[.\s]?|(posttagmez|noktomez|tagmez|maten|vesper|nokt)[eo])/i,
      wide: /^(anta(ŭ|ux)tagmez|posttagmez|noktomez|tagmez|maten|vesper|nokt)[eo]/i
    };
    var parseDayPeriodPatterns$Z = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^noktom/i,
        noon: /^t/i,
        morning: /^m/i,
        afternoon: /^posttagmeze/i,
        evening: /^v/i,
        night: /^n/i
      }
    };
    var match$Z = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$Z,
        parsePattern: parseOrdinalNumberPattern$Z,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$Z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$Z,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$Z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$Z,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$Z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$Z,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$Z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$Z,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$Z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$Z,
        defaultParseWidth: 'any'
      })
    };

    var locale$10 = {
      code: 'eo',
      formatDistance: formatDistance$Z,
      formatLong: formatLong$10,
      formatRelative: formatRelative$_,
      localize: localize$Z,
      match: match$Z,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$X = {
      lessThanXSeconds: {
        one: 'menos de un segundo',
        other: 'menos de {{count}} segundos'
      },
      xSeconds: {
        one: '1 segundo',
        other: '{{count}} segundos'
      },
      halfAMinute: 'medio minuto',
      lessThanXMinutes: {
        one: 'menos de un minuto',
        other: 'menos de {{count}} minutos'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutos'
      },
      aboutXHours: {
        one: 'alrededor de 1 hora',
        other: 'alrededor de {{count}} horas'
      },
      xHours: {
        one: '1 hora',
        other: '{{count}} horas'
      },
      xDays: {
        one: '1 día',
        other: '{{count}} días'
      },
      aboutXWeeks: {
        one: 'alrededor de 1 semana',
        other: 'alrededor de {{count}} semanas'
      },
      xWeeks: {
        one: '1 semana',
        other: '{{count}} semanas'
      },
      aboutXMonths: {
        one: 'alrededor de 1 mes',
        other: 'alrededor de {{count}} meses'
      },
      xMonths: {
        one: '1 mes',
        other: '{{count}} meses'
      },
      aboutXYears: {
        one: 'alrededor de 1 año',
        other: 'alrededor de {{count}} años'
      },
      xYears: {
        one: '1 año',
        other: '{{count}} años'
      },
      overXYears: {
        one: 'más de 1 año',
        other: 'más de {{count}} años'
      },
      almostXYears: {
        one: 'casi 1 año',
        other: 'casi {{count}} años'
      }
    };
    var formatDistance$Y = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$X[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'en ' + result;
        } else {
          return 'hace ' + result;
        }
      }
      return result;
    };

    var dateFormats$$ = {
      full: "EEEE, d 'de' MMMM 'de' y",
      long: "d 'de' MMMM 'de' y",
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$$ = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$$ = {
      full: "{{date}} 'a las' {{time}}",
      long: "{{date}} 'a las' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$$ = {
      date: buildFormatLongFn({
        formats: dateFormats$$,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$$,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$$,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$Z = {
      lastWeek: "'el' eeee 'pasado a la' p",
      yesterday: "'ayer a la' p",
      today: "'hoy a la' p",
      tomorrow: "'mañana a la' p",
      nextWeek: "eeee 'a la' p",
      other: 'P'
    };
    var formatRelativeLocalePlural$2 = {
      lastWeek: "'el' eeee 'pasado a las' p",
      yesterday: "'ayer a las' p",
      today: "'hoy a las' p",
      tomorrow: "'mañana a las' p",
      nextWeek: "eeee 'a las' p",
      other: 'P'
    };
    var formatRelative$Z = function (token, date, _baseDate, _options) {
      if (date.getUTCHours() !== 1) {
        return formatRelativeLocalePlural$2[token];
      } else {
        return formatRelativeLocale$Z[token];
      }
    };

    var eraValues$Y = {
      narrow: ['AC', 'DC'],
      abbreviated: ['AC', 'DC'],
      wide: ['antes de cristo', 'después de cristo']
    };
    var quarterValues$Y = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$Y = {
      narrow: ['e', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['ene', 'feb', 'mar', 'abr', 'may', 'jun', 'jul', 'ago', 'sep', 'oct', 'nov', 'dic'],
      wide: ['enero', 'febrero', 'marzo', 'abril', 'mayo', 'junio', 'julio', 'agosto', 'septiembre', 'octubre', 'noviembre', 'diciembre']
    };
    var dayValues$Y = {
      narrow: ['d', 'l', 'm', 'm', 'j', 'v', 's'],
      short: ['do', 'lu', 'ma', 'mi', 'ju', 'vi', 'sá'],
      abbreviated: ['dom', 'lun', 'mar', 'mié', 'jue', 'vie', 'sáb'],
      wide: ['domingo', 'lunes', 'martes', 'miércoles', 'jueves', 'viernes', 'sábado']
    };
    var dayPeriodValues$Y = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'mañana',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noche'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'mañana',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noche'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'mañana',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noche'
      }
    };
    var formattingDayPeriodValues$M = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'de la mañana',
        afternoon: 'de la tarde',
        evening: 'de la tarde',
        night: 'de la noche'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'de la mañana',
        afternoon: 'de la tarde',
        evening: 'de la tarde',
        night: 'de la noche'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'de la mañana',
        afternoon: 'de la tarde',
        evening: 'de la tarde',
        night: 'de la noche'
      }
    };
    var ordinalNumber$Y = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'º';
    };
    var localize$Y = {
      ordinalNumber: ordinalNumber$Y,
      era: buildLocalizeFn({
        values: eraValues$Y,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$Y,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$Y,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$Y,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$Y,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$M,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$Y = /^(\d+)(º)?/i;
    var parseOrdinalNumberPattern$Y = /\d+/i;
    var matchEraPatterns$Y = {
      narrow: /^(ac|dc|a|d)/i,
      abbreviated: /^(a\.?\s?c\.?|a\.?\s?e\.?\s?c\.?|d\.?\s?c\.?|e\.?\s?c\.?)/i,
      wide: /^(antes de cristo|antes de la era com[uú]n|despu[eé]s de cristo|era com[uú]n)/i
    };
    var parseEraPatterns$Y = {
      any: [/^ac/i, /^dc/i],
      wide: [/^(antes de cristo|antes de la era com[uú]n)/i, /^(despu[eé]s de cristo|era com[uú]n)/i]
    };
    var matchQuarterPatterns$Y = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^[1234](º)? trimestre/i
    };
    var parseQuarterPatterns$Y = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$Y = {
      narrow: /^[efmajsond]/i,
      abbreviated: /^(ene|feb|mar|abr|may|jun|jul|ago|sep|oct|nov|dic)/i,
      wide: /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i
    };
    var parseMonthPatterns$Y = {
      narrow: [/^e/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^en/i, /^feb/i, /^mar/i, /^abr/i, /^may/i, /^jun/i, /^jul/i, /^ago/i, /^sep/i, /^oct/i, /^nov/i, /^dic/i]
    };
    var matchDayPatterns$Y = {
      narrow: /^[dlmjvs]/i,
      short: /^(do|lu|ma|mi|ju|vi|s[áa])/i,
      abbreviated: /^(dom|lun|mar|mi[ée]|jue|vie|s[áa]b)/i,
      wide: /^(domingo|lunes|martes|mi[ée]rcoles|jueves|viernes|s[áa]bado)/i
    };
    var parseDayPatterns$Y = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i],
      any: [/^do/i, /^lu/i, /^ma/i, /^mi/i, /^ju/i, /^vi/i, /^sa/i]
    };
    var matchDayPeriodPatterns$Y = {
      narrow: /^(a|p|mn|md|(de la|a las) (mañana|tarde|noche))/i,
      any: /^([ap]\.?\s?m\.?|medianoche|mediodia|(de la|a las) (mañana|tarde|noche))/i
    };
    var parseDayPeriodPatterns$Y = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mn/i,
        noon: /^md/i,
        morning: /mañana/i,
        afternoon: /tarde/i,
        evening: /tarde/i,
        night: /noche/i
      }
    };
    var match$Y = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$Y,
        parsePattern: parseOrdinalNumberPattern$Y,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$Y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$Y,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$Y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$Y,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$Y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$Y,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$Y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$Y,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$Y,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$Y,
        defaultParseWidth: 'any'
      })
    };

    var locale$$ = {
      code: 'es',
      formatDistance: formatDistance$Y,
      formatLong: formatLong$$,
      formatRelative: formatRelative$Z,
      localize: localize$Y,
      match: match$Y,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$W = {
      lessThanXSeconds: {
        standalone: {
          one: 'vähem kui üks sekund',
          other: 'vähem kui {{count}} sekundit'
        },
        withPreposition: {
          one: 'vähem kui ühe sekundi',
          other: 'vähem kui {{count}} sekundi'
        }
      },
      xSeconds: {
        standalone: {
          one: 'üks sekund',
          other: '{{count}} sekundit'
        },
        withPreposition: {
          one: 'ühe sekundi',
          other: '{{count}} sekundi'
        }
      },
      halfAMinute: {
        standalone: 'pool minutit',
        withPreposition: 'poole minuti'
      },
      lessThanXMinutes: {
        standalone: {
          one: 'vähem kui üks minut',
          other: 'vähem kui {{count}} minutit'
        },
        withPreposition: {
          one: 'vähem kui ühe minuti',
          other: 'vähem kui {{count}} minuti'
        }
      },
      xMinutes: {
        standalone: {
          one: 'üks minut',
          other: '{{count}} minutit'
        },
        withPreposition: {
          one: 'ühe minuti',
          other: '{{count}} minuti'
        }
      },
      aboutXHours: {
        standalone: {
          one: 'umbes üks tund',
          other: 'umbes {{count}} tundi'
        },
        withPreposition: {
          one: 'umbes ühe tunni',
          other: 'umbes {{count}} tunni'
        }
      },
      xHours: {
        standalone: {
          one: 'üks tund',
          other: '{{count}} tundi'
        },
        withPreposition: {
          one: 'ühe tunni',
          other: '{{count}} tunni'
        }
      },
      xDays: {
        standalone: {
          one: 'üks päev',
          other: '{{count}} päeva'
        },
        withPreposition: {
          one: 'ühe päeva',
          other: '{{count}} päeva'
        }
      },
      aboutXWeeks: {
        standalone: {
          one: 'umbes üks nädal',
          other: 'umbes {{count}} nädalat'
        },
        withPreposition: {
          one: 'umbes ühe nädala',
          other: 'umbes {{count}} nädala'
        }
      },
      xWeeks: {
        standalone: {
          one: 'üks nädal',
          other: '{{count}} nädalat'
        },
        withPreposition: {
          one: 'ühe nädala',
          other: '{{count}} nädala'
        }
      },
      aboutXMonths: {
        standalone: {
          one: 'umbes üks kuu',
          other: 'umbes {{count}} kuud'
        },
        withPreposition: {
          one: 'umbes ühe kuu',
          other: 'umbes {{count}} kuu'
        }
      },
      xMonths: {
        standalone: {
          one: 'üks kuu',
          other: '{{count}} kuud'
        },
        withPreposition: {
          one: 'ühe kuu',
          other: '{{count}} kuu'
        }
      },
      aboutXYears: {
        standalone: {
          one: 'umbes üks aasta',
          other: 'umbes {{count}} aastat'
        },
        withPreposition: {
          one: 'umbes ühe aasta',
          other: 'umbes {{count}} aasta'
        }
      },
      xYears: {
        standalone: {
          one: 'üks aasta',
          other: '{{count}} aastat'
        },
        withPreposition: {
          one: 'ühe aasta',
          other: '{{count}} aasta'
        }
      },
      overXYears: {
        standalone: {
          one: 'rohkem kui üks aasta',
          other: 'rohkem kui {{count}} aastat'
        },
        withPreposition: {
          one: 'rohkem kui ühe aasta',
          other: 'rohkem kui {{count}} aasta'
        }
      },
      almostXYears: {
        standalone: {
          one: 'peaaegu üks aasta',
          other: 'peaaegu {{count}} aastat'
        },
        withPreposition: {
          one: 'peaaegu ühe aasta',
          other: 'peaaegu {{count}} aasta'
        }
      }
    };
    var formatDistance$X = function (token, count, options) {
      var usageGroup = options !== null && options !== void 0 && options.addSuffix ? formatDistanceLocale$W[token].withPreposition : formatDistanceLocale$W[token].standalone;
      var result;
      if (typeof usageGroup === 'string') {
        result = usageGroup;
      } else if (count === 1) {
        result = usageGroup.one;
      } else {
        result = usageGroup.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' pärast';
        } else {
          return result + ' eest';
        }
      }
      return result;
    };

    var dateFormats$_ = {
      full: 'EEEE, d. MMMM y',
      long: 'd. MMMM y',
      medium: 'd. MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$_ = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$_ = {
      full: "{{date}} 'kell' {{time}}",
      long: "{{date}} 'kell' {{time}}",
      medium: '{{date}}. {{time}}',
      short: '{{date}}. {{time}}'
    };
    var formatLong$_ = {
      date: buildFormatLongFn({
        formats: dateFormats$_,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$_,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$_,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$Y = {
      lastWeek: "'eelmine' eeee 'kell' p",
      yesterday: "'eile kell' p",
      today: "'täna kell' p",
      tomorrow: "'homme kell' p",
      nextWeek: "'järgmine' eeee 'kell' p",
      other: 'P'
    };
    var formatRelative$Y = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$Y[token];
    };

    var eraValues$X = {
      narrow: ['e.m.a', 'm.a.j'],
      abbreviated: ['e.m.a', 'm.a.j'],
      wide: ['enne meie ajaarvamist', 'meie ajaarvamise järgi']
    };
    var quarterValues$X = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$X = {
      narrow: ['J', 'V', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jaan', 'veebr', 'märts', 'apr', 'mai', 'juuni', 'juuli', 'aug', 'sept', 'okt', 'nov', 'dets'],
      wide: ['jaanuar', 'veebruar', 'märts', 'aprill', 'mai', 'juuni', 'juuli', 'august', 'september', 'oktoober', 'november', 'detsember']
    };
    var dayValues$X = {
      narrow: ['P', 'E', 'T', 'K', 'N', 'R', 'L'],
      short: ['P', 'E', 'T', 'K', 'N', 'R', 'L'],
      abbreviated: ['pühap.', 'esmasp.', 'teisip.', 'kolmap.', 'neljap.', 'reede.', 'laup.'],
      wide: ['pühapäev', 'esmaspäev', 'teisipäev', 'kolmapäev', 'neljapäev', 'reede', 'laupäev']
    };
    var dayPeriodValues$X = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'kesköö',
        noon: 'keskpäev',
        morning: 'hommik',
        afternoon: 'pärastlõuna',
        evening: 'õhtu',
        night: 'öö'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'kesköö',
        noon: 'keskpäev',
        morning: 'hommik',
        afternoon: 'pärastlõuna',
        evening: 'õhtu',
        night: 'öö'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'kesköö',
        noon: 'keskpäev',
        morning: 'hommik',
        afternoon: 'pärastlõuna',
        evening: 'õhtu',
        night: 'öö'
      }
    };
    var formattingDayPeriodValues$L = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'keskööl',
        noon: 'keskpäeval',
        morning: 'hommikul',
        afternoon: 'pärastlõunal',
        evening: 'õhtul',
        night: 'öösel'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'keskööl',
        noon: 'keskpäeval',
        morning: 'hommikul',
        afternoon: 'pärastlõunal',
        evening: 'õhtul',
        night: 'öösel'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'keskööl',
        noon: 'keskpäeval',
        morning: 'hommikul',
        afternoon: 'pärastlõunal',
        evening: 'õhtul',
        night: 'öösel'
      }
    };
    var ordinalNumber$X = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$X = {
      ordinalNumber: ordinalNumber$X,
      era: buildLocalizeFn({
        values: eraValues$X,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$X,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$X,
        defaultWidth: 'wide',
        formattingValues: monthValues$X,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$X,
        defaultWidth: 'wide',
        formattingValues: dayValues$X,
        defaultFormattingWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$X,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$L,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$X = /^\d+\./i;
    var parseOrdinalNumberPattern$X = /\d+/i;
    var matchEraPatterns$X = {
      narrow: /^(e\.m\.a|m\.a\.j|eKr|pKr)/i,
      abbreviated: /^(e\.m\.a|m\.a\.j|eKr|pKr)/i,
      wide: /^(enne meie ajaarvamist|meie ajaarvamise järgi|enne Kristust|pärast Kristust)/i
    };
    var parseEraPatterns$X = {
      any: [/^e/i, /^(m|p)/i]
    };
    var matchQuarterPatterns$X = {
      narrow: /^[1234]/i,
      abbreviated: /^K[1234]/i,
      wide: /^[1234](\.)? kvartal/i
    };
    var parseQuarterPatterns$X = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$X = {
      narrow: /^[jvmasond]/i,
      abbreviated: /^(jaan|veebr|märts|apr|mai|juuni|juuli|aug|sept|okt|nov|dets)/i,
      wide: /^(jaanuar|veebruar|märts|aprill|mai|juuni|juuli|august|september|oktoober|november|detsember)/i
    };
    var parseMonthPatterns$X = {
      narrow: [/^j/i, /^v/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^v/i, /^mär/i, /^ap/i, /^mai/i, /^juun/i, /^juul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$X = {
      narrow: /^[petknrl]/i,
      short: /^[petknrl]/i,
      abbreviated: /^(püh?|esm?|tei?|kolm?|nel?|ree?|laup?)\.?/i,
      wide: /^(pühapäev|esmaspäev|teisipäev|kolmapäev|neljapäev|reede|laupäev)/i
    };
    var parseDayPatterns$X = {
      any: [/^p/i, /^e/i, /^t/i, /^k/i, /^n/i, /^r/i, /^l/i]
    };
    var matchDayPeriodPatterns$X = {
      any: /^(am|pm|keskööl?|keskpäev(al)?|hommik(ul)?|pärastlõunal?|õhtul?|öö(sel)?)/i
    };
    var parseDayPeriodPatterns$X = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^keskö/i,
        noon: /^keskp/i,
        morning: /hommik/i,
        afternoon: /pärastlõuna/i,
        evening: /õhtu/i,
        night: /öö/i
      }
    };
    var match$X = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$X,
        parsePattern: parseOrdinalNumberPattern$X,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$X,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$X,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$X,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$X,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$X,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$X,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$X,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$X,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$X,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$X,
        defaultParseWidth: 'any'
      })
    };

    var locale$_ = {
      code: 'et',
      formatDistance: formatDistance$X,
      formatLong: formatLong$_,
      formatRelative: formatRelative$Y,
      localize: localize$X,
      match: match$X,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$V = {
      lessThanXSeconds: {
        one: 'segundo bat baino gutxiago',
        other: '{{count}} segundo baino gutxiago'
      },
      xSeconds: {
        one: '1 segundo',
        other: '{{count}} segundo'
      },
      halfAMinute: 'minutu erdi',
      lessThanXMinutes: {
        one: 'minutu bat baino gutxiago',
        other: '{{count}} minutu baino gutxiago'
      },
      xMinutes: {
        one: '1 minutu',
        other: '{{count}} minutu'
      },
      aboutXHours: {
        one: '1 ordu gutxi gorabehera',
        other: '{{count}} ordu gutxi gorabehera'
      },
      xHours: {
        one: '1 ordu',
        other: '{{count}} ordu'
      },
      xDays: {
        one: '1 egun',
        other: '{{count}} egun'
      },
      aboutXWeeks: {
        one: 'aste 1 inguru',
        other: '{{count}} aste inguru'
      },
      xWeeks: {
        one: '1 aste',
        other: '{{count}} astean'
      },
      aboutXMonths: {
        one: '1 hilabete gutxi gorabehera',
        other: '{{count}} hilabete gutxi gorabehera'
      },
      xMonths: {
        one: '1 hilabete',
        other: '{{count}} hilabete'
      },
      aboutXYears: {
        one: '1 urte gutxi gorabehera',
        other: '{{count}} urte gutxi gorabehera'
      },
      xYears: {
        one: '1 urte',
        other: '{{count}} urte'
      },
      overXYears: {
        one: '1 urte baino gehiago',
        other: '{{count}} urte baino gehiago'
      },
      almostXYears: {
        one: 'ia 1 urte',
        other: 'ia {{count}} urte'
      }
    };
    var formatDistance$W = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$V[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'en ' + result;
        } else {
          return 'duela ' + result;
        }
      }
      return result;
    };

    var dateFormats$Z = {
      full: "EEEE, y'ko' MMMM'ren' d'a' y'ren'",
      long: "y'ko' MMMM'ren' d'a'",
      medium: 'y MMM d',
      short: 'yy/MM/dd'
    };
    var timeFormats$Z = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$Z = {
      full: "{{date}} 'tan' {{time}}",
      long: "{{date}} 'tan' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$Z = {
      date: buildFormatLongFn({
        formats: dateFormats$Z,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$Z,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$Z,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$X = {
      lastWeek: "'joan den' eeee, LT",
      yesterday: "'atzo,' p",
      today: "'gaur,' p",
      tomorrow: "'bihar,' p",
      nextWeek: 'eeee, p',
      other: 'P'
    };
    var formatRelativeLocalePlural$1 = {
      lastWeek: "'joan den' eeee, p",
      yesterday: "'atzo,' p",
      today: "'gaur,' p",
      tomorrow: "'bihar,' p",
      nextWeek: 'eeee, p',
      other: 'P'
    };
    var formatRelative$X = function (token, date) {
      if (date.getUTCHours() !== 1) {
        return formatRelativeLocalePlural$1[token];
      }
      return formatRelativeLocale$X[token];
    };

    var eraValues$W = {
      narrow: ['k.a.', 'k.o.'],
      abbreviated: ['k.a.', 'k.o.'],
      wide: ['kristo aurretik', 'kristo ondoren']
    };
    var quarterValues$W = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1H', '2H', '3H', '4H'],
      wide: ['1. hiruhilekoa', '2. hiruhilekoa', '3. hiruhilekoa', '4. hiruhilekoa']
    };
    var monthValues$W = {
      narrow: ['u', 'o', 'm', 'a', 'm', 'e', 'u', 'a', 'i', 'u', 'a', 'a'],
      abbreviated: ['urt', 'ots', 'mar', 'api', 'mai', 'eka', 'uzt', 'abu', 'ira', 'urr', 'aza', 'abe'],
      wide: ['urtarrila', 'otsaila', 'martxoa', 'apirila', 'maiatza', 'ekaina', 'uztaila', 'abuztua', 'iraila', 'urria', 'azaroa', 'abendua']
    };
    var dayValues$W = {
      narrow: ['i', 'a', 'a', 'a', 'o', 'o', 'l'],
      short: ['ig', 'al', 'as', 'az', 'og', 'or', 'lr'],
      abbreviated: ['iga', 'ast', 'ast', 'ast', 'ost', 'ost', 'lar'],
      wide: ['igandea', 'astelehena', 'asteartea', 'asteazkena', 'osteguna', 'ostirala', 'larunbata']
    };
    var dayPeriodValues$W = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'ge',
        noon: 'eg',
        morning: 'goiza',
        afternoon: 'arratsaldea',
        evening: 'arratsaldea',
        night: 'gaua'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'gauerdia',
        noon: 'eguerdia',
        morning: 'goiza',
        afternoon: 'arratsaldea',
        evening: 'arratsaldea',
        night: 'gaua'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'gauerdia',
        noon: 'eguerdia',
        morning: 'goiza',
        afternoon: 'arratsaldea',
        evening: 'arratsaldea',
        night: 'gaua'
      }
    };
    var formattingDayPeriodValues$K = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'ge',
        noon: 'eg',
        morning: 'goizean',
        afternoon: 'arratsaldean',
        evening: 'arratsaldean',
        night: 'gauean'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'gauerdia',
        noon: 'eguerdia',
        morning: 'goizean',
        afternoon: 'arratsaldean',
        evening: 'arratsaldean',
        night: 'gauean'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'gauerdia',
        noon: 'eguerdia',
        morning: 'goizean',
        afternoon: 'arratsaldean',
        evening: 'arratsaldean',
        night: 'gauean'
      }
    };
    var ordinalNumber$W = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$W = {
      ordinalNumber: ordinalNumber$W,
      era: buildLocalizeFn({
        values: eraValues$W,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$W,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$W,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$W,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$W,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$K,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$W = /^(\d+)(.)?/i;
    var parseOrdinalNumberPattern$W = /\d+/i;
    var matchEraPatterns$W = {
      narrow: /^(k.a.|k.o.)/i,
      abbreviated: /^(k.a.|k.o.)/i,
      wide: /^(kristo aurretik|kristo ondoren)/i
    };
    var parseEraPatterns$W = {
      narrow: [/^k.a./i, /^k.o./i],
      abbreviated: [/^(k.a.)/i, /^(k.o.)/i],
      wide: [/^(kristo aurretik)/i, /^(kristo ondoren)/i]
    };
    var matchQuarterPatterns$W = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]H/i,
      wide: /^[1234](.)? hiruhilekoa/i
    };
    var parseQuarterPatterns$W = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$W = {
      narrow: /^[uomaei]/i,
      abbreviated: /^(urt|ots|mar|api|mai|eka|uzt|abu|ira|urr|aza|abe)/i,
      wide: /^(urtarrila|otsaila|martxoa|apirila|maiatza|ekaina|uztaila|abuztua|iraila|urria|azaroa|abendua)/i
    };
    var parseMonthPatterns$W = {
      narrow: [/^u/i, /^o/i, /^m/i, /^a/i, /^m/i, /^e/i, /^u/i, /^a/i, /^i/i, /^u/i, /^a/i, /^a/i],
      any: [/^urt/i, /^ots/i, /^mar/i, /^api/i, /^mai/i, /^eka/i, /^uzt/i, /^abu/i, /^ira/i, /^urr/i, /^aza/i, /^abe/i]
    };
    var matchDayPatterns$W = {
      narrow: /^[iaol]/i,
      short: /^(ig|al|as|az|og|or|lr)/i,
      abbreviated: /^(iga|ast|ast|ast|ost|ost|lar)/i,
      wide: /^(igandea|astelehena|asteartea|asteazkena|osteguna|ostirala|larunbata)/i
    };
    var parseDayPatterns$W = {
      narrow: [/^i/i, /^a/i, /^a/i, /^a/i, /^o/i, /^o/i, /^l/i],
      short: [/^ig/i, /^al/i, /^as/i, /^az/i, /^og/i, /^or/i, /^lr/i],
      abbreviated: [/^iga/i, /^ast/i, /^ast/i, /^ast/i, /^ost/i, /^ost/i, /^lar/i],
      wide: [/^igandea/i, /^astelehena/i, /^asteartea/i, /^asteazkena/i, /^osteguna/i, /^ostirala/i, /^larunbata/i]
    };
    var matchDayPeriodPatterns$W = {
      narrow: /^(a|p|ge|eg|((goiza|goizean)|arratsaldea|(gaua|gauean)))/i,
      any: /^([ap]\.?\s?m\.?|gauerdia|eguerdia|((goiza|goizean)|arratsaldea|(gaua|gauean)))/i
    };
    var parseDayPeriodPatterns$W = {
      narrow: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^ge/i,
        noon: /^eg/i,
        morning: /goiz/i,
        afternoon: /arratsaldea/i,
        evening: /arratsaldea/i,
        night: /gau/i
      },
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^gauerdia/i,
        noon: /^eguerdia/i,
        morning: /goiz/i,
        afternoon: /arratsaldea/i,
        evening: /arratsaldea/i,
        night: /gau/i
      }
    };
    var match$W = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$W,
        parsePattern: parseOrdinalNumberPattern$W,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$W,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$W,
        defaultParseWidth: 'wide'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$W,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$W,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$W,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$W,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$W,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$W,
        defaultParseWidth: 'wide'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$W,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$W,
        defaultParseWidth: 'any'
      })
    };

    var locale$Z = {
      code: 'eu',
      formatDistance: formatDistance$W,
      formatLong: formatLong$Z,
      formatRelative: formatRelative$X,
      localize: localize$W,
      match: match$W,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$U = {
      lessThanXSeconds: {
        one: 'کمتر از یک ثانیه',
        other: 'کمتر از {{count}} ثانیه'
      },
      xSeconds: {
        one: '1 ثانیه',
        other: '{{count}} ثانیه'
      },
      halfAMinute: 'نیم دقیقه',
      lessThanXMinutes: {
        one: 'کمتر از یک دقیقه',
        other: 'کمتر از {{count}} دقیقه'
      },
      xMinutes: {
        one: '1 دقیقه',
        other: '{{count}} دقیقه'
      },
      aboutXHours: {
        one: 'حدود 1 ساعت',
        other: 'حدود {{count}} ساعت'
      },
      xHours: {
        one: '1 ساعت',
        other: '{{count}} ساعت'
      },
      xDays: {
        one: '1 روز',
        other: '{{count}} روز'
      },
      aboutXWeeks: {
        one: 'حدود 1 هفته',
        other: 'حدود {{count}} هفته'
      },
      xWeeks: {
        one: '1 هفته',
        other: '{{count}} هفته'
      },
      aboutXMonths: {
        one: 'حدود 1 ماه',
        other: 'حدود {{count}} ماه'
      },
      xMonths: {
        one: '1 ماه',
        other: '{{count}} ماه'
      },
      aboutXYears: {
        one: 'حدود 1 سال',
        other: 'حدود {{count}} سال'
      },
      xYears: {
        one: '1 سال',
        other: '{{count}} سال'
      },
      overXYears: {
        one: 'بیشتر از 1 سال',
        other: 'بیشتر از {{count}} سال'
      },
      almostXYears: {
        one: 'نزدیک 1 سال',
        other: 'نزدیک {{count}} سال'
      }
    };
    var formatDistance$V = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$U[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'در ' + result;
        } else {
          return result + ' قبل';
        }
      }
      return result;
    };

    var dateFormats$Y = {
      full: 'EEEE do MMMM y',
      long: 'do MMMM y',
      medium: 'd MMM y',
      short: 'yyyy/MM/dd'
    };
    var timeFormats$Y = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$Y = {
      full: "{{date}} 'در' {{time}}",
      long: "{{date}} 'در' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$Y = {
      date: buildFormatLongFn({
        formats: dateFormats$Y,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$Y,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$Y,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$W = {
      lastWeek: "eeee 'گذشته در' p",
      yesterday: "'دیروز در' p",
      today: "'امروز در' p",
      tomorrow: "'فردا در' p",
      nextWeek: "eeee 'در' p",
      other: 'P'
    };
    var formatRelative$W = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$W[token];
    };

    var eraValues$V = {
      narrow: ['ق', 'ب'],
      abbreviated: ['ق.م.', 'ب.م.'],
      wide: ['قبل از میلاد', 'بعد از میلاد']
    };
    var quarterValues$V = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['س‌م1', 'س‌م2', 'س‌م3', 'س‌م4'],
      wide: ['سه‌ماهه 1', 'سه‌ماهه 2', 'سه‌ماهه 3', 'سه‌ماهه 4']
    };
    var monthValues$V = {
      narrow: ['ژ', 'ف', 'م', 'آ', 'م', 'ج', 'ج', 'آ', 'س', 'ا', 'ن', 'د'],
      abbreviated: ['ژانـ', 'فور', 'مارس', 'آپر', 'می', 'جون', 'جولـ', 'آگو', 'سپتـ', 'اکتـ', 'نوامـ', 'دسامـ'],
      wide: ['ژانویه', 'فوریه', 'مارس', 'آپریل', 'می', 'جون', 'جولای', 'آگوست', 'سپتامبر', 'اکتبر', 'نوامبر', 'دسامبر']
    };
    var dayValues$V = {
      narrow: ['ی', 'د', 'س', 'چ', 'پ', 'ج', 'ش'],
      short: ['1ش', '2ش', '3ش', '4ش', '5ش', 'ج', 'ش'],
      abbreviated: ['یکشنبه', 'دوشنبه', 'سه‌شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه'],
      wide: ['یکشنبه', 'دوشنبه', 'سه‌شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه']
    };
    var dayPeriodValues$V = {
      narrow: {
        am: 'ق',
        pm: 'ب',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'ص',
        afternoon: 'ب.ظ.',
        evening: 'ع',
        night: 'ش'
      },
      abbreviated: {
        am: 'ق.ظ.',
        pm: 'ب.ظ.',
        midnight: 'نیمه‌شب',
        noon: 'ظهر',
        morning: 'صبح',
        afternoon: 'بعدازظهر',
        evening: 'عصر',
        night: 'شب'
      },
      wide: {
        am: 'قبل‌ازظهر',
        pm: 'بعدازظهر',
        midnight: 'نیمه‌شب',
        noon: 'ظهر',
        morning: 'صبح',
        afternoon: 'بعدازظهر',
        evening: 'عصر',
        night: 'شب'
      }
    };
    var formattingDayPeriodValues$J = {
      narrow: {
        am: 'ق',
        pm: 'ب',
        midnight: 'ن',
        noon: 'ظ',
        morning: 'ص',
        afternoon: 'ب.ظ.',
        evening: 'ع',
        night: 'ش'
      },
      abbreviated: {
        am: 'ق.ظ.',
        pm: 'ب.ظ.',
        midnight: 'نیمه‌شب',
        noon: 'ظهر',
        morning: 'صبح',
        afternoon: 'بعدازظهر',
        evening: 'عصر',
        night: 'شب'
      },
      wide: {
        am: 'قبل‌ازظهر',
        pm: 'بعدازظهر',
        midnight: 'نیمه‌شب',
        noon: 'ظهر',
        morning: 'صبح',
        afternoon: 'بعدازظهر',
        evening: 'عصر',
        night: 'شب'
      }
    };
    var ordinalNumber$V = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$V = {
      ordinalNumber: ordinalNumber$V,
      era: buildLocalizeFn({
        values: eraValues$V,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$V,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$V,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$V,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$V,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$J,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$V = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$V = /\d+/i;
    var matchEraPatterns$V = {
      narrow: /^(ق|ب)/i,
      abbreviated: /^(ق\.?\s?م\.?|ق\.?\s?د\.?\s?م\.?|م\.?\s?|د\.?\s?م\.?)/i,
      wide: /^(قبل از میلاد|قبل از دوران مشترک|میلادی|دوران مشترک|بعد از میلاد)/i
    };
    var parseEraPatterns$V = {
      any: [/^قبل/i, /^بعد/i]
    };
    var matchQuarterPatterns$V = {
      narrow: /^[1234]/i,
      abbreviated: /^س‌م[1234]/i,
      wide: /^سه‌ماهه [1234]/i
    };
    var parseQuarterPatterns$V = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$V = {
      narrow: /^[جژفمآاماسند]/i,
      abbreviated: /^(جنو|ژانـ|ژانویه|فوریه|فور|مارس|آوریل|آپر|مه|می|ژوئن|جون|جول|جولـ|ژوئیه|اوت|آگو|سپتمبر|سپتامبر|اکتبر|اکتوبر|نوامبر|نوامـ|دسامبر|دسامـ|دسم)/i,
      wide: /^(ژانویه|جنوری|فبروری|فوریه|مارچ|مارس|آپریل|اپریل|ایپریل|آوریل|مه|می|ژوئن|جون|جولای|ژوئیه|آگست|اگست|آگوست|اوت|سپتمبر|سپتامبر|اکتبر|اکتوبر|نوامبر|نومبر|دسامبر|دسمبر)/i
    };
    var parseMonthPatterns$V = {
      narrow: [/^(ژ|ج)/i, /^ف/i, /^م/i, /^(آ|ا)/i, /^م/i, /^(ژ|ج)/i, /^(ج|ژ)/i, /^(آ|ا)/i, /^س/i, /^ا/i, /^ن/i, /^د/i],
      any: [/^ژا/i, /^ف/i, /^ما/i, /^آپ/i, /^(می|مه)/i, /^(ژوئن|جون)/i, /^(ژوئی|جول)/i, /^(اوت|آگ)/i, /^س/i, /^(اوک|اک)/i, /^ن/i, /^د/i]
    };
    var matchDayPatterns$V = {
      narrow: /^[شیدسچپج]/i,
      short: /^(ش|ج|1ش|2ش|3ش|4ش|5ش)/i,
      abbreviated: /^(یکشنبه|دوشنبه|سه‌شنبه|چهارشنبه|پنج‌شنبه|جمعه|شنبه)/i,
      wide: /^(یکشنبه|دوشنبه|سه‌شنبه|چهارشنبه|پنج‌شنبه|جمعه|شنبه)/i
    };
    var parseDayPatterns$V = {
      narrow: [/^ی/i, /^دو/i, /^س/i, /^چ/i, /^پ/i, /^ج/i, /^ش/i],
      any: [/^(ی|1ش|یکشنبه)/i, /^(د|2ش|دوشنبه)/i, /^(س|3ش|سه‌شنبه)/i, /^(چ|4ش|چهارشنبه)/i, /^(پ|5ش|پنجشنبه)/i, /^(ج|جمعه)/i, /^(ش|شنبه)/i]
    };
    var matchDayPeriodPatterns$V = {
      narrow: /^(ب|ق|ن|ظ|ص|ب.ظ.|ع|ش)/i,
      abbreviated: /^(ق.ظ.|ب.ظ.|نیمه‌شب|ظهر|صبح|بعدازظهر|عصر|شب)/i,
      wide: /^(قبل‌ازظهر|نیمه‌شب|ظهر|صبح|بعدازظهر|عصر|شب)/i
    };
    var parseDayPeriodPatterns$V = {
      any: {
        am: /^(ق|ق.ظ.|قبل‌ازظهر)/i,
        pm: /^(ب|ب.ظ.|بعدازظهر)/i,
        midnight: /^(‌نیمه‌شب|ن)/i,
        noon: /^(ظ|ظهر)/i,
        morning: /(ص|صبح)/i,
        afternoon: /(ب|ب.ظ.|بعدازظهر)/i,
        evening: /(ع|عصر)/i,
        night: /(ش|شب)/i
      }
    };
    var match$V = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$V,
        parsePattern: parseOrdinalNumberPattern$V,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$V,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$V,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$V,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$V,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$V,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$V,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$V,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$V,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$V,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$V,
        defaultParseWidth: 'any'
      })
    };

    var locale$Y = {
      code: 'fa-IR',
      formatDistance: formatDistance$V,
      formatLong: formatLong$Y,
      formatRelative: formatRelative$W,
      localize: localize$V,
      match: match$V,
      options: {
        weekStartsOn: 6
        ,
        firstWeekContainsDate: 1
      }
    };

    function futureSeconds(text) {
      return text.replace(/sekuntia?/, 'sekunnin');
    }
    function futureMinutes(text) {
      return text.replace(/minuuttia?/, 'minuutin');
    }
    function futureHours(text) {
      return text.replace(/tuntia?/, 'tunnin');
    }
    function futureDays(text) {
      return text.replace(/päivää?/, 'päivän');
    }
    function futureWeeks(text) {
      return text.replace(/(viikko|viikkoa)/, 'viikon');
    }
    function futureMonths(text) {
      return text.replace(/(kuukausi|kuukautta)/, 'kuukauden');
    }
    function futureYears(text) {
      return text.replace(/(vuosi|vuotta)/, 'vuoden');
    }
    var formatDistanceLocale$T = {
      lessThanXSeconds: {
        one: 'alle sekunti',
        other: 'alle {{count}} sekuntia',
        futureTense: futureSeconds
      },
      xSeconds: {
        one: 'sekunti',
        other: '{{count}} sekuntia',
        futureTense: futureSeconds
      },
      halfAMinute: {
        one: 'puoli minuuttia',
        other: 'puoli minuuttia',
        futureTense: function (_text) {
          return 'puolen minuutin';
        }
      },
      lessThanXMinutes: {
        one: 'alle minuutti',
        other: 'alle {{count}} minuuttia',
        futureTense: futureMinutes
      },
      xMinutes: {
        one: 'minuutti',
        other: '{{count}} minuuttia',
        futureTense: futureMinutes
      },
      aboutXHours: {
        one: 'noin tunti',
        other: 'noin {{count}} tuntia',
        futureTense: futureHours
      },
      xHours: {
        one: 'tunti',
        other: '{{count}} tuntia',
        futureTense: futureHours
      },
      xDays: {
        one: 'päivä',
        other: '{{count}} päivää',
        futureTense: futureDays
      },
      aboutXWeeks: {
        one: 'noin viikko',
        other: 'noin {{count}} viikkoa',
        futureTense: futureWeeks
      },
      xWeeks: {
        one: 'viikko',
        other: '{{count}} viikkoa',
        futureTense: futureWeeks
      },
      aboutXMonths: {
        one: 'noin kuukausi',
        other: 'noin {{count}} kuukautta',
        futureTense: futureMonths
      },
      xMonths: {
        one: 'kuukausi',
        other: '{{count}} kuukautta',
        futureTense: futureMonths
      },
      aboutXYears: {
        one: 'noin vuosi',
        other: 'noin {{count}} vuotta',
        futureTense: futureYears
      },
      xYears: {
        one: 'vuosi',
        other: '{{count}} vuotta',
        futureTense: futureYears
      },
      overXYears: {
        one: 'yli vuosi',
        other: 'yli {{count}} vuotta',
        futureTense: futureYears
      },
      almostXYears: {
        one: 'lähes vuosi',
        other: 'lähes {{count}} vuotta',
        futureTense: futureYears
      }
    };
    var formatDistance$U = function (token, count, options) {
      var tokenValue = formatDistanceLocale$T[token];
      var result = count === 1 ? tokenValue.one : tokenValue.other.replace('{{count}}', String(count));
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return tokenValue.futureTense(result) + ' kuluttua';
        } else {
          return result + ' sitten';
        }
      }
      return result;
    };

    var dateFormats$X = {
      full: 'eeee d. MMMM y',
      long: 'd. MMMM y',
      medium: 'd. MMM y',
      short: 'd.M.y'
    };
    var timeFormats$X = {
      full: 'HH.mm.ss zzzz',
      long: 'HH.mm.ss z',
      medium: 'HH.mm.ss',
      short: 'HH.mm'
    };
    var dateTimeFormats$X = {
      full: "{{date}} 'klo' {{time}}",
      long: "{{date}} 'klo' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$X = {
      date: buildFormatLongFn({
        formats: dateFormats$X,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$X,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$X,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$V = {
      lastWeek: "'viime' eeee 'klo' p",
      yesterday: "'eilen klo' p",
      today: "'tänään klo' p",
      tomorrow: "'huomenna klo' p",
      nextWeek: "'ensi' eeee 'klo' p",
      other: 'P'
    };
    var formatRelative$V = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$V[token];
    };

    var eraValues$U = {
      narrow: ['eaa.', 'jaa.'],
      abbreviated: ['eaa.', 'jaa.'],
      wide: ['ennen ajanlaskun alkua', 'jälkeen ajanlaskun alun']
    };
    var quarterValues$U = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. kvartaali', '2. kvartaali', '3. kvartaali', '4. kvartaali']
    };
    var monthValues$U = {
      narrow: ['T', 'H', 'M', 'H', 'T', 'K', 'H', 'E', 'S', 'L', 'M', 'J'],
      abbreviated: ['tammi', 'helmi', 'maalis', 'huhti', 'touko', 'kesä', 'heinä', 'elo', 'syys', 'loka', 'marras', 'joulu'],
      wide: ['tammikuu', 'helmikuu', 'maaliskuu', 'huhtikuu', 'toukokuu', 'kesäkuu', 'heinäkuu', 'elokuu', 'syyskuu', 'lokakuu', 'marraskuu', 'joulukuu']
    };
    var formattingMonthValues$b = {
      narrow: monthValues$U.narrow,
      abbreviated: monthValues$U.abbreviated,
      wide: ['tammikuuta', 'helmikuuta', 'maaliskuuta', 'huhtikuuta', 'toukokuuta', 'kesäkuuta', 'heinäkuuta', 'elokuuta', 'syyskuuta', 'lokakuuta', 'marraskuuta', 'joulukuuta']
    };
    var dayValues$U = {
      narrow: ['S', 'M', 'T', 'K', 'T', 'P', 'L'],
      short: ['su', 'ma', 'ti', 'ke', 'to', 'pe', 'la'],
      abbreviated: ['sunn.', 'maan.', 'tiis.', 'kesk.', 'torst.', 'perj.', 'la'],
      wide: ['sunnuntai', 'maanantai', 'tiistai', 'keskiviikko', 'torstai', 'perjantai', 'lauantai']
    };
    var formattingDayValues$3 = {
      narrow: dayValues$U.narrow,
      short: dayValues$U.short,
      abbreviated: dayValues$U.abbreviated,
      wide: ['sunnuntaina', 'maanantaina', 'tiistaina', 'keskiviikkona', 'torstaina', 'perjantaina', 'lauantaina']
    };
    var dayPeriodValues$U = {
      narrow: {
        am: 'ap',
        pm: 'ip',
        midnight: 'keskiyö',
        noon: 'keskipäivä',
        morning: 'ap',
        afternoon: 'ip',
        evening: 'illalla',
        night: 'yöllä'
      },
      abbreviated: {
        am: 'ap',
        pm: 'ip',
        midnight: 'keskiyö',
        noon: 'keskipäivä',
        morning: 'ap',
        afternoon: 'ip',
        evening: 'illalla',
        night: 'yöllä'
      },
      wide: {
        am: 'ap',
        pm: 'ip',
        midnight: 'keskiyöllä',
        noon: 'keskipäivällä',
        morning: 'aamupäivällä',
        afternoon: 'iltapäivällä',
        evening: 'illalla',
        night: 'yöllä'
      }
    };
    var ordinalNumber$U = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$U = {
      ordinalNumber: ordinalNumber$U,
      era: buildLocalizeFn({
        values: eraValues$U,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$U,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$U,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$b,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$U,
        defaultWidth: 'wide',
        formattingValues: formattingDayValues$3,
        defaultFormattingWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$U,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$U = /^(\d+)(\.)/i;
    var parseOrdinalNumberPattern$U = /\d+/i;
    var matchEraPatterns$U = {
      narrow: /^(e|j)/i,
      abbreviated: /^(eaa.|jaa.)/i,
      wide: /^(ennen ajanlaskun alkua|jälkeen ajanlaskun alun)/i
    };
    var parseEraPatterns$U = {
      any: [/^e/i, /^j/i]
    };
    var matchQuarterPatterns$U = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234]\.? kvartaali/i
    };
    var parseQuarterPatterns$U = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$U = {
      narrow: /^[thmkeslj]/i,
      abbreviated: /^(tammi|helmi|maalis|huhti|touko|kesä|heinä|elo|syys|loka|marras|joulu)/i,
      wide: /^(tammikuu|helmikuu|maaliskuu|huhtikuu|toukokuu|kesäkuu|heinäkuu|elokuu|syyskuu|lokakuu|marraskuu|joulukuu)(ta)?/i
    };
    var parseMonthPatterns$U = {
      narrow: [/^t/i, /^h/i, /^m/i, /^h/i, /^t/i, /^k/i, /^h/i, /^e/i, /^s/i, /^l/i, /^m/i, /^j/i],
      any: [/^ta/i, /^hel/i, /^maa/i, /^hu/i, /^to/i, /^k/i, /^hei/i, /^e/i, /^s/i, /^l/i, /^mar/i, /^j/i]
    };
    var matchDayPatterns$U = {
      narrow: /^[smtkpl]/i,
      short: /^(su|ma|ti|ke|to|pe|la)/i,
      abbreviated: /^(sunn.|maan.|tiis.|kesk.|torst.|perj.|la)/i,
      wide: /^(sunnuntai|maanantai|tiistai|keskiviikko|torstai|perjantai|lauantai)(na)?/i
    };
    var parseDayPatterns$U = {
      narrow: [/^s/i, /^m/i, /^t/i, /^k/i, /^t/i, /^p/i, /^l/i],
      any: [/^s/i, /^m/i, /^ti/i, /^k/i, /^to/i, /^p/i, /^l/i]
    };
    var matchDayPeriodPatterns$U = {
      narrow: /^(ap|ip|keskiyö|keskipäivä|aamupäivällä|iltapäivällä|illalla|yöllä)/i,
      any: /^(ap|ip|keskiyöllä|keskipäivällä|aamupäivällä|iltapäivällä|illalla|yöllä)/i
    };
    var parseDayPeriodPatterns$U = {
      any: {
        am: /^ap/i,
        pm: /^ip/i,
        midnight: /^keskiyö/i,
        noon: /^keskipäivä/i,
        morning: /aamupäivällä/i,
        afternoon: /iltapäivällä/i,
        evening: /illalla/i,
        night: /yöllä/i
      }
    };
    var match$U = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$U,
        parsePattern: parseOrdinalNumberPattern$U,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$U,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$U,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$U,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$U,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$U,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$U,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$U,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$U,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$U,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$U,
        defaultParseWidth: 'any'
      })
    };

    var locale$X = {
      code: 'fi',
      formatDistance: formatDistance$U,
      formatLong: formatLong$X,
      formatRelative: formatRelative$V,
      localize: localize$U,
      match: match$U,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$S = {
      lessThanXSeconds: {
        one: 'moins d’une seconde',
        other: 'moins de {{count}} secondes'
      },
      xSeconds: {
        one: '1 seconde',
        other: '{{count}} secondes'
      },
      halfAMinute: '30 secondes',
      lessThanXMinutes: {
        one: 'moins d’une minute',
        other: 'moins de {{count}} minutes'
      },
      xMinutes: {
        one: '1 minute',
        other: '{{count}} minutes'
      },
      aboutXHours: {
        one: 'environ 1 heure',
        other: 'environ {{count}} heures'
      },
      xHours: {
        one: '1 heure',
        other: '{{count}} heures'
      },
      xDays: {
        one: '1 jour',
        other: '{{count}} jours'
      },
      aboutXWeeks: {
        one: 'environ 1 semaine',
        other: 'environ {{count}} semaines'
      },
      xWeeks: {
        one: '1 semaine',
        other: '{{count}} semaines'
      },
      aboutXMonths: {
        one: 'environ 1 mois',
        other: 'environ {{count}} mois'
      },
      xMonths: {
        one: '1 mois',
        other: '{{count}} mois'
      },
      aboutXYears: {
        one: 'environ 1 an',
        other: 'environ {{count}} ans'
      },
      xYears: {
        one: '1 an',
        other: '{{count}} ans'
      },
      overXYears: {
        one: 'plus d’un an',
        other: 'plus de {{count}} ans'
      },
      almostXYears: {
        one: 'presqu’un an',
        other: 'presque {{count}} ans'
      }
    };
    var formatDistance$T = function (token, count, options) {
      var result;
      var form = formatDistanceLocale$S[token];
      if (typeof form === 'string') {
        result = form;
      } else if (count === 1) {
        result = form.one;
      } else {
        result = form.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'dans ' + result;
        } else {
          return 'il y a ' + result;
        }
      }
      return result;
    };

    var dateFormats$W = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$W = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$W = {
      full: "{{date}} 'à' {{time}}",
      long: "{{date}} 'à' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$W = {
      date: buildFormatLongFn({
        formats: dateFormats$W,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$W,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$W,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$U = {
      lastWeek: "eeee 'dernier à' p",
      yesterday: "'hier à' p",
      today: "'aujourd’hui à' p",
      tomorrow: "'demain à' p'",
      nextWeek: "eeee 'prochain à' p",
      other: 'P'
    };
    var formatRelative$U = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$U[token];
    };

    var eraValues$T = {
      narrow: ['av. J.-C', 'ap. J.-C'],
      abbreviated: ['av. J.-C', 'ap. J.-C'],
      wide: ['avant Jésus-Christ', 'après Jésus-Christ']
    };
    var quarterValues$T = {
      narrow: ['T1', 'T2', 'T3', 'T4'],
      abbreviated: ['1er trim.', '2ème trim.', '3ème trim.', '4ème trim.'],
      wide: ['1er trimestre', '2ème trimestre', '3ème trimestre', '4ème trimestre']
    };
    var monthValues$T = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['janv.', 'févr.', 'mars', 'avr.', 'mai', 'juin', 'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
      wide: ['janvier', 'février', 'mars', 'avril', 'mai', 'juin', 'juillet', 'août', 'septembre', 'octobre', 'novembre', 'décembre']
    };
    var dayValues$T = {
      narrow: ['D', 'L', 'M', 'M', 'J', 'V', 'S'],
      short: ['di', 'lu', 'ma', 'me', 'je', 've', 'sa'],
      abbreviated: ['dim.', 'lun.', 'mar.', 'mer.', 'jeu.', 'ven.', 'sam.'],
      wide: ['dimanche', 'lundi', 'mardi', 'mercredi', 'jeudi', 'vendredi', 'samedi']
    };
    var dayPeriodValues$T = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minuit',
        noon: 'midi',
        morning: 'mat.',
        afternoon: 'ap.m.',
        evening: 'soir',
        night: 'mat.'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minuit',
        noon: 'midi',
        morning: 'matin',
        afternoon: 'après-midi',
        evening: 'soir',
        night: 'matin'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minuit',
        noon: 'midi',
        morning: 'du matin',
        afternoon: 'de l’après-midi',
        evening: 'du soir',
        night: 'du matin'
      }
    };
    var ordinalNumber$T = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      if (number === 0) return '0';
      var feminineUnits = ['year', 'week', 'hour', 'minute', 'second'];
      var suffix;
      if (number === 1) {
        suffix = unit && feminineUnits.includes(unit) ? 'ère' : 'er';
      } else {
        suffix = 'ème';
      }
      return number + suffix;
    };
    var localize$T = {
      ordinalNumber: ordinalNumber$T,
      era: buildLocalizeFn({
        values: eraValues$T,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$T,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$T,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$T,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$T,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$T = /^(\d+)(ième|ère|ème|er|e)?/i;
    var parseOrdinalNumberPattern$T = /\d+/i;
    var matchEraPatterns$T = {
      narrow: /^(av\.J\.C|ap\.J\.C|ap\.J\.-C)/i,
      abbreviated: /^(av\.J\.-C|av\.J-C|apr\.J\.-C|apr\.J-C|ap\.J-C)/i,
      wide: /^(avant Jésus-Christ|après Jésus-Christ)/i
    };
    var parseEraPatterns$T = {
      any: [/^av/i, /^ap/i]
    };
    var matchQuarterPatterns$T = {
      narrow: /^T?[1234]/i,
      abbreviated: /^[1234](er|ème|e)? trim\.?/i,
      wide: /^[1234](er|ème|e)? trimestre/i
    };
    var parseQuarterPatterns$T = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$T = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(janv|févr|mars|avr|mai|juin|juill|juil|août|sept|oct|nov|déc)\.?/i,
      wide: /^(janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i
    };
    var parseMonthPatterns$T = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^av/i, /^ma/i, /^juin/i, /^juil/i, /^ao/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$T = {
      narrow: /^[lmjvsd]/i,
      short: /^(di|lu|ma|me|je|ve|sa)/i,
      abbreviated: /^(dim|lun|mar|mer|jeu|ven|sam)\.?/i,
      wide: /^(dimanche|lundi|mardi|mercredi|jeudi|vendredi|samedi)/i
    };
    var parseDayPatterns$T = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i],
      any: [/^di/i, /^lu/i, /^ma/i, /^me/i, /^je/i, /^ve/i, /^sa/i]
    };
    var matchDayPeriodPatterns$T = {
      narrow: /^(a|p|minuit|midi|mat\.?|ap\.?m\.?|soir|nuit)/i,
      any: /^([ap]\.?\s?m\.?|du matin|de l'après[-\s]midi|du soir|de la nuit)/i
    };
    var parseDayPeriodPatterns$T = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^min/i,
        noon: /^mid/i,
        morning: /mat/i,
        afternoon: /ap/i,
        evening: /soir/i,
        night: /nuit/i
      }
    };
    var match$T = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$T,
        parsePattern: parseOrdinalNumberPattern$T,
        valueCallback: function (value) {
          return parseInt(value);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$T,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$T,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$T,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$T,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$T,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$T,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$T,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$T,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$T,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$T,
        defaultParseWidth: 'any'
      })
    };

    var locale$W = {
      code: 'fr',
      formatDistance: formatDistance$T,
      formatLong: formatLong$W,
      formatRelative: formatRelative$U,
      localize: localize$T,
      match: match$T,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var dateFormats$V = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'yy-MM-dd'
    };
    var timeFormats$V = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$V = {
      full: "{{date}} 'à' {{time}}",
      long: "{{date}} 'à' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$V = {
      date: buildFormatLongFn({
        formats: dateFormats$V,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$V,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$V,
        defaultWidth: 'full'
      })
    };

    var locale$V = {
      code: 'fr-CA',
      formatDistance: formatDistance$T,
      formatLong: formatLong$V,
      formatRelative: formatRelative$U,
      localize: localize$T,
      match: match$T,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var dateFormats$U = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$U = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$U = {
      full: "{{date}} 'à' {{time}}",
      long: "{{date}} 'à' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$U = {
      date: buildFormatLongFn({
        formats: dateFormats$U,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$U,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$U,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$T = {
      lastWeek: "eeee 'la semaine dernière à' p",
      yesterday: "'hier à' p",
      today: "'aujourd’hui à' p",
      tomorrow: "'demain à' p'",
      nextWeek: "eeee 'la semaine prochaine à' p",
      other: 'P'
    };
    var formatRelative$T = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$T[token];
    };

    var locale$U = {
      code: 'fr-CH',
      formatDistance: formatDistance$T,
      formatLong: formatLong$U,
      formatRelative: formatRelative$T,
      localize: localize$T,
      match: match$T,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$R = {
      lessThanXSeconds: {
        one: 'minder as 1 sekonde',
        other: 'minder as {{count}} sekonden'
      },
      xSeconds: {
        one: '1 sekonde',
        other: '{{count}} sekonden'
      },
      halfAMinute: 'oardel minút',
      lessThanXMinutes: {
        one: 'minder as 1 minút',
        other: 'minder as {{count}} minuten'
      },
      xMinutes: {
        one: '1 minút',
        other: '{{count}} minuten'
      },
      aboutXHours: {
        one: 'sawat 1 oere',
        other: 'sawat {{count}} oere'
      },
      xHours: {
        one: '1 oere',
        other: '{{count}} oere'
      },
      xDays: {
        one: '1 dei',
        other: '{{count}} dagen'
      },
      aboutXWeeks: {
        one: 'sawat 1 wike',
        other: 'sawat {{count}} wiken'
      },
      xWeeks: {
        one: '1 wike',
        other: '{{count}} wiken'
      },
      aboutXMonths: {
        one: 'sawat 1 moanne',
        other: 'sawat {{count}} moannen'
      },
      xMonths: {
        one: '1 moanne',
        other: '{{count}} moannen'
      },
      aboutXYears: {
        one: 'sawat 1 jier',
        other: 'sawat {{count}} jier'
      },
      xYears: {
        one: '1 jier',
        other: '{{count}} jier'
      },
      overXYears: {
        one: 'mear as 1 jier',
        other: 'mear as {{count}}s jier'
      },
      almostXYears: {
        one: 'hast 1 jier',
        other: 'hast {{count}} jier'
      }
    };
    var formatDistance$S = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$R[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'oer ' + result;
        } else {
          return result + ' lyn';
        }
      }
      return result;
    };

    var dateFormats$T = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd-MM-y'
    };
    var timeFormats$T = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$T = {
      full: "{{date}} 'om' {{time}}",
      long: "{{date}} 'om' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$T = {
      date: buildFormatLongFn({
        formats: dateFormats$T,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$T,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$T,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$S = {
      lastWeek: "'ôfrûne' eeee 'om' p",
      yesterday: "'juster om' p",
      today: "'hjoed om' p",
      tomorrow: "'moarn om' p",
      nextWeek: "eeee 'om' p",
      other: 'P'
    };
    var formatRelative$S = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$S[token];
    };

    var eraValues$S = {
      narrow: ['f.K.', 'n.K.'],
      abbreviated: ['f.Kr.', 'n.Kr.'],
      wide: ['foar Kristus', 'nei Kristus']
    };
    var quarterValues$S = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1e fearnsjier', '2e fearnsjier', '3e fearnsjier', '4e fearnsjier']
    };
    var monthValues$S = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan.', 'feb.', 'mrt.', 'apr.', 'mai.', 'jun.', 'jul.', 'aug.', 'sep.', 'okt.', 'nov.', 'des.'],
      wide: ['jannewaris', 'febrewaris', 'maart', 'april', 'maaie', 'juny', 'july', 'augustus', 'septimber', 'oktober', 'novimber', 'desimber']
    };
    var dayValues$S = {
      narrow: ['s', 'm', 't', 'w', 't', 'f', 's'],
      short: ['si', 'mo', 'ti', 'wo', 'to', 'fr', 'so'],
      abbreviated: ['snein', 'moa', 'tii', 'woa', 'ton', 'fre', 'sneon'],
      wide: ['snein', 'moandei', 'tiisdei', 'woansdei', 'tongersdei', 'freed', 'sneon']
    };
    var dayPeriodValues$S = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'middei',
        morning: 'moarns',
        afternoon: 'middeis',
        evening: 'jûns',
        night: 'nachts'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'middei',
        morning: 'moarns',
        afternoon: 'middeis',
        evening: 'jûns',
        night: 'nachts'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'middei',
        morning: 'moarns',
        afternoon: 'middeis',
        evening: 'jûns',
        night: 'nachts'
      }
    };
    var ordinalNumber$S = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'e';
    };
    var localize$S = {
      ordinalNumber: ordinalNumber$S,
      era: buildLocalizeFn({
        values: eraValues$S,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$S,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$S,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$S,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$S,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$S = /^(\d+)e?/i;
    var parseOrdinalNumberPattern$S = /\d+/i;
    var matchEraPatterns$S = {
      narrow: /^([fn]\.? ?K\.?)/,
      abbreviated: /^([fn]\. ?Kr\.?)/,
      wide: /^((foar|nei) Kristus)/
    };
    var parseEraPatterns$S = {
      any: [/^f/, /^n/]
    };
    var matchQuarterPatterns$S = {
      narrow: /^[1234]/i,
      abbreviated: /^K[1234]/i,
      wide: /^[1234]e fearnsjier/i
    };
    var parseQuarterPatterns$S = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$S = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan.|feb.|mrt.|apr.|mai.|jun.|jul.|aug.|sep.|okt.|nov.|des.)/i,
      wide: /^(jannewaris|febrewaris|maart|april|maaie|juny|july|augustus|septimber|oktober|novimber|desimber)/i
    };
    var parseMonthPatterns$S = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^jan/i, /^feb/i, /^m(r|a)/i, /^apr/i, /^mai/i, /^jun/i, /^jul/i, /^aug/i, /^sep/i, /^okt/i, /^nov/i, /^des/i]
    };
    var matchDayPatterns$S = {
      narrow: /^[smtwf]/i,
      short: /^(si|mo|ti|wo|to|fr|so)/i,
      abbreviated: /^(snein|moa|tii|woa|ton|fre|sneon)/i,
      wide: /^(snein|moandei|tiisdei|woansdei|tongersdei|freed|sneon)/i
    };
    var parseDayPatterns$S = {
      narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
      any: [/^sn/i, /^mo/i, /^ti/i, /^wo/i, /^to/i, /^fr/i, /^sn/i]
    };
    var matchDayPeriodPatterns$S = {
      any: /^(am|pm|middernacht|middeis|moarns|middei|jûns|nachts)/i
    };
    var parseDayPeriodPatterns$S = {
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /^middernacht/i,
        noon: /^middei/i,
        morning: /moarns/i,
        afternoon: /^middeis/i,
        evening: /jûns/i,
        night: /nachts/i
      }
    };
    var match$S = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$S,
        parsePattern: parseOrdinalNumberPattern$S,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$S,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$S,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$S,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$S,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$S,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$S,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$S,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$S,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$S,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$S,
        defaultParseWidth: 'any'
      })
    };

    var locale$T = {
      code: 'fy',
      formatDistance: formatDistance$S,
      formatLong: formatLong$T,
      formatRelative: formatRelative$S,
      localize: localize$S,
      match: match$S,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$Q = {
      lessThanXSeconds: {
        one: 'nas lugha na diog',
        other: 'nas lugha na {{count}} diogan'
      },
      xSeconds: {
        one: '1 diog',
        two: '2 dhiog',
        twenty: '20 diog',
        other: '{{count}} diogan'
      },
      halfAMinute: 'leth mhionaid',
      lessThanXMinutes: {
        one: 'nas lugha na mionaid',
        other: 'nas lugha na {{count}} mionaidean'
      },
      xMinutes: {
        one: '1 mionaid',
        two: '2 mhionaid',
        twenty: '20 mionaid',
        other: '{{count}} mionaidean'
      },
      aboutXHours: {
        one: 'mu uair de thìde',
        other: 'mu {{count}} uairean de thìde'
      },
      xHours: {
        one: '1 uair de thìde',
        two: '2 uair de thìde',
        twenty: '20 uair de thìde',
        other: '{{count}} uairean de thìde'
      },
      xDays: {
        one: '1 là',
        other: '{{count}} là'
      },
      aboutXWeeks: {
        one: 'mu 1 seachdain',
        other: 'mu {{count}} seachdainean'
      },
      xWeeks: {
        one: '1 seachdain',
        other: '{{count}} seachdainean'
      },
      aboutXMonths: {
        one: 'mu mhìos',
        other: 'mu {{count}} mìosan'
      },
      xMonths: {
        one: '1 mìos',
        other: '{{count}} mìosan'
      },
      aboutXYears: {
        one: 'mu bhliadhna',
        other: 'mu {{count}} bliadhnaichean'
      },
      xYears: {
        one: '1 bhliadhna',
        other: '{{count}} bliadhna'
      },
      overXYears: {
        one: 'còrr is bliadhna',
        other: 'còrr is {{count}} bliadhnaichean'
      },
      almostXYears: {
        one: 'cha mhòr bliadhna',
        other: 'cha mhòr {{count}} bliadhnaichean'
      }
    };
    var formatDistance$R = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$Q[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else if (count === 2 && !!tokenValue.two) {
        result = tokenValue.two;
      } else if (count === 20 && !!tokenValue.twenty) {
        result = tokenValue.twenty;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'ann an ' + result;
        } else {
          return 'o chionn ' + result;
        }
      }
      return result;
    };

    var dateFormats$S = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$S = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$S = {
      full: "{{date}} 'aig' {{time}}",
      long: "{{date}} 'aig' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$S = {
      date: buildFormatLongFn({
        formats: dateFormats$S,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$S,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$S,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$R = {
      lastWeek: "'mu dheireadh' eeee 'aig' p",
      yesterday: "'an-dè aig' p",
      today: "'an-diugh aig' p",
      tomorrow: "'a-màireach aig' p",
      nextWeek: "eeee 'aig' p",
      other: 'P'
    };
    var formatRelative$R = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$R[token];
    };

    var eraValues$R = {
      narrow: ['R', 'A'],
      abbreviated: ['RC', 'AD'],
      wide: ['ro Chrìosta', 'anno domini']
    };
    var quarterValues$R = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['C1', 'C2', 'C3', 'C4'],
      wide: ["a' chiad chairteal", 'an dàrna cairteal', 'an treas cairteal', 'an ceathramh cairteal']
    };
    var monthValues$R = {
      narrow: ['F', 'G', 'M', 'G', 'C', 'Ò', 'I', 'L', 'S', 'D', 'S', 'D'],
      abbreviated: ['Faoi', 'Gear', 'Màrt', 'Gibl', 'Cèit', 'Ògmh', 'Iuch', 'Lùn', 'Sult', 'Dàmh', 'Samh', 'Dùbh'],
      wide: ['Am Faoilleach', 'An Gearran', 'Am Màrt', 'An Giblean', 'An Cèitean', 'An t-Ògmhios', 'An t-Iuchar', 'An Lùnastal', 'An t-Sultain', 'An Dàmhair', 'An t-Samhain', 'An Dùbhlachd']
    };
    var dayValues$R = {
      narrow: ['D', 'L', 'M', 'C', 'A', 'H', 'S'],
      short: ['Dò', 'Lu', 'Mà', 'Ci', 'Ar', 'Ha', 'Sa'],
      abbreviated: ['Did', 'Dil', 'Dim', 'Dic', 'Dia', 'Dih', 'Dis'],
      wide: ['Didòmhnaich', 'Diluain', 'Dimàirt', 'Diciadain', 'Diardaoin', 'Dihaoine', 'Disathairne']
    };
    var dayPeriodValues$R = {
      narrow: {
        am: 'm',
        pm: 'f',
        midnight: 'm.o.',
        noon: 'm.l.',
        morning: 'madainn',
        afternoon: 'feasgar',
        evening: 'feasgar',
        night: 'oidhche'
      },
      abbreviated: {
        am: 'M.',
        pm: 'F.',
        midnight: 'meadhan oidhche',
        noon: 'meadhan là',
        morning: 'madainn',
        afternoon: 'feasgar',
        evening: 'feasgar',
        night: 'oidhche'
      },
      wide: {
        am: 'm.',
        pm: 'f.',
        midnight: 'meadhan oidhche',
        noon: 'meadhan là',
        morning: 'madainn',
        afternoon: 'feasgar',
        evening: 'feasgar',
        night: 'oidhche'
      }
    };
    var formattingDayPeriodValues$I = {
      narrow: {
        am: 'm',
        pm: 'f',
        midnight: 'm.o.',
        noon: 'm.l.',
        morning: 'sa mhadainn',
        afternoon: 'feasgar',
        evening: 'feasgar',
        night: 'air an oidhche'
      },
      abbreviated: {
        am: 'M.',
        pm: 'F.',
        midnight: 'meadhan oidhche',
        noon: 'meadhan là',
        morning: 'sa mhadainn',
        afternoon: 'feasgar',
        evening: 'feasgar',
        night: 'air an oidhche'
      },
      wide: {
        am: 'm.',
        pm: 'f.',
        midnight: 'meadhan oidhche',
        noon: 'meadhan là',
        morning: 'sa mhadainn',
        afternoon: 'feasgar',
        evening: 'feasgar',
        night: 'air an oidhche'
      }
    };
    var ordinalNumber$R = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      var rem100 = number % 100;
      if (rem100 > 20 || rem100 < 10) {
        switch (rem100 % 10) {
          case 1:
            return number + 'd';
          case 2:
            return number + 'na';
        }
      }
      if (rem100 === 12) {
        return number + 'na';
      }
      return number + 'mh';
    };
    var localize$R = {
      ordinalNumber: ordinalNumber$R,
      era: buildLocalizeFn({
        values: eraValues$R,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$R,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$R,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$R,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$R,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$I,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$R = /^(\d+)(d|na|tr|mh)?/i;
    var parseOrdinalNumberPattern$R = /\d+/i;
    var matchEraPatterns$R = {
      narrow: /^(r|a)/i,
      abbreviated: /^(r\.?\s?c\.?|r\.?\s?a\.?\s?c\.?|a\.?\s?d\.?|a\.?\s?c\.?)/i,
      wide: /^(ro Chrìosta|ron aois choitchinn|anno domini|aois choitcheann)/i
    };
    var parseEraPatterns$R = {
      any: [/^b/i, /^(a|c)/i]
    };
    var matchQuarterPatterns$R = {
      narrow: /^[1234]/i,
      abbreviated: /^c[1234]/i,
      wide: /^[1234](cd|na|tr|mh)? cairteal/i
    };
    var parseQuarterPatterns$R = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$R = {
      narrow: /^[fgmcòilsd]/i,
      abbreviated: /^(faoi|gear|màrt|gibl|cèit|ògmh|iuch|lùn|sult|dàmh|samh|dùbh)/i,
      wide: /^(am faoilleach|an gearran|am màrt|an giblean|an cèitean|an t-Ògmhios|an t-Iuchar|an lùnastal|an t-Sultain|an dàmhair|an t-Samhain|an dùbhlachd)/i
    };
    var parseMonthPatterns$R = {
      narrow: [/^f/i, /^g/i, /^m/i, /^g/i, /^c/i, /^ò/i, /^i/i, /^l/i, /^s/i, /^d/i, /^s/i, /^d/i],
      any: [/^fa/i, /^ge/i, /^mà/i, /^gi/i, /^c/i, /^ò/i, /^i/i, /^l/i, /^su/i, /^d/i, /^sa/i, /^d/i]
    };
    var matchDayPatterns$R = {
      narrow: /^[dlmcahs]/i,
      short: /^(dò|lu|mà|ci|ar|ha|sa)/i,
      abbreviated: /^(did|dil|dim|dic|dia|dih|dis)/i,
      wide: /^(didòmhnaich|diluain|dimàirt|diciadain|diardaoin|dihaoine|disathairne)/i
    };
    var parseDayPatterns$R = {
      narrow: [/^d/i, /^l/i, /^m/i, /^c/i, /^a/i, /^h/i, /^s/i],
      any: [/^d/i, /^l/i, /^m/i, /^c/i, /^a/i, /^h/i, /^s/i]
    };
    var matchDayPeriodPatterns$R = {
      narrow: /^(a|p|mi|n|(san|aig) (madainn|feasgar|feasgar|oidhche))/i,
      any: /^([ap]\.?\s?m\.?|meadhan oidhche|meadhan là|(san|aig) (madainn|feasgar|feasgar|oidhche))/i
    };
    var parseDayPeriodPatterns$R = {
      any: {
        am: /^m/i,
        pm: /^f/i,
        midnight: /^meadhan oidhche/i,
        noon: /^meadhan là/i,
        morning: /sa mhadainn/i,
        afternoon: /feasgar/i,
        evening: /feasgar/i,
        night: /air an oidhche/i
      }
    };
    var match$R = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$R,
        parsePattern: parseOrdinalNumberPattern$R,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$R,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$R,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$R,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$R,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$R,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$R,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$R,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$R,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$R,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$R,
        defaultParseWidth: 'any'
      })
    };

    var locale$S = {
      code: 'gd',
      formatDistance: formatDistance$R,
      formatLong: formatLong$S,
      formatRelative: formatRelative$R,
      localize: localize$R,
      match: match$R,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$P = {
      lessThanXSeconds: {
        one: 'menos dun segundo',
        other: 'menos de {{count}} segundos'
      },
      xSeconds: {
        one: '1 segundo',
        other: '{{count}} segundos'
      },
      halfAMinute: 'medio minuto',
      lessThanXMinutes: {
        one: 'menos dun minuto',
        other: 'menos de {{count}} minutos'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutos'
      },
      aboutXHours: {
        one: 'arredor dunha hora',
        other: 'arredor de {{count}} horas'
      },
      xHours: {
        one: '1 hora',
        other: '{{count}} horas'
      },
      xDays: {
        one: '1 día',
        other: '{{count}} días'
      },
      aboutXWeeks: {
        one: 'arredor dunha semana',
        other: 'arredor de {{count}} semanas'
      },
      xWeeks: {
        one: '1 semana',
        other: '{{count}} semanas'
      },
      aboutXMonths: {
        one: 'arredor de 1 mes',
        other: 'arredor de {{count}} meses'
      },
      xMonths: {
        one: '1 mes',
        other: '{{count}} meses'
      },
      aboutXYears: {
        one: 'arredor dun ano',
        other: 'arredor de {{count}} anos'
      },
      xYears: {
        one: '1 ano',
        other: '{{count}} anos'
      },
      overXYears: {
        one: 'máis dun ano',
        other: 'máis de {{count}} anos'
      },
      almostXYears: {
        one: 'case un ano',
        other: 'case {{count}} anos'
      }
    };
    var formatDistance$Q = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$P[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'en ' + result;
        } else {
          return 'hai ' + result;
        }
      }
      return result;
    };

    var dateFormats$R = {
      full: "EEEE, d 'de' MMMM y",
      long: "d 'de' MMMM y",
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$R = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$R = {
      full: "{{date}} 'ás' {{time}}",
      long: "{{date}} 'ás' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$R = {
      date: buildFormatLongFn({
        formats: dateFormats$R,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$R,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$R,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$Q = {
      lastWeek: "'o' eeee 'pasado á' LT",
      yesterday: "'onte á' p",
      today: "'hoxe á' p",
      tomorrow: "'mañá á' p",
      nextWeek: "eeee 'á' p",
      other: 'P'
    };
    var formatRelativeLocalePlural = {
      lastWeek: "'o' eeee 'pasado ás' p",
      yesterday: "'onte ás' p",
      today: "'hoxe ás' p",
      tomorrow: "'mañá ás' p",
      nextWeek: "eeee 'ás' p",
      other: 'P'
    };
    var formatRelative$Q = function (token, date, _baseDate, _options) {
      if (date.getUTCHours() !== 1) {
        return formatRelativeLocalePlural[token];
      }
      return formatRelativeLocale$Q[token];
    };

    var eraValues$Q = {
      narrow: ['AC', 'DC'],
      abbreviated: ['AC', 'DC'],
      wide: ['antes de cristo', 'despois de cristo']
    };
    var quarterValues$Q = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$Q = {
      narrow: ['e', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['xan', 'feb', 'mar', 'abr', 'mai', 'xun', 'xul', 'ago', 'set', 'out', 'nov', 'dec'],
      wide: ['xaneiro', 'febreiro', 'marzo', 'abril', 'maio', 'xuño', 'xullo', 'agosto', 'setembro', 'outubro', 'novembro', 'decembro']
    };
    var dayValues$Q = {
      narrow: ['d', 'l', 'm', 'm', 'j', 'v', 's'],
      short: ['do', 'lu', 'ma', 'me', 'xo', 've', 'sa'],
      abbreviated: ['dom', 'lun', 'mar', 'mer', 'xov', 'ven', 'sab'],
      wide: ['domingo', 'luns', 'martes', 'mércores', 'xoves', 'venres', 'sábado']
    };
    var dayPeriodValues$Q = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'mañá',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noite'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'medianoite',
        noon: 'mediodía',
        morning: 'mañá',
        afternoon: 'tarde',
        evening: 'tardiña',
        night: 'noite'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'medianoite',
        noon: 'mediodía',
        morning: 'mañá',
        afternoon: 'tarde',
        evening: 'tardiña',
        night: 'noite'
      }
    };
    var formattingDayPeriodValues$H = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'da mañá',
        afternoon: 'da tarde',
        evening: 'da tardiña',
        night: 'da noite'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'medianoite',
        noon: 'mediodía',
        morning: 'da mañá',
        afternoon: 'da tarde',
        evening: 'da tardiña',
        night: 'da noite'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'medianoite',
        noon: 'mediodía',
        morning: 'da mañá',
        afternoon: 'da tarde',
        evening: 'da tardiña',
        night: 'da noite'
      }
    };
    var ordinalNumber$Q = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'º';
    };
    var localize$Q = {
      ordinalNumber: ordinalNumber$Q,
      era: buildLocalizeFn({
        values: eraValues$Q,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$Q,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$Q,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$Q,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$Q,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$H,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$Q = /^(\d+)(º)?/i;
    var parseOrdinalNumberPattern$Q = /\d+/i;
    var matchEraPatterns$Q = {
      narrow: /^(ac|dc|a|d)/i,
      abbreviated: /^(a\.?\s?c\.?|a\.?\s?e\.?\s?c\.?|d\.?\s?c\.?|e\.?\s?c\.?)/i,
      wide: /^(antes de cristo|antes da era com[uú]n|despois de cristo|era com[uú]n)/i
    };
    var parseEraPatterns$Q = {
      any: [/^ac/i, /^dc/i],
      wide: [/^(antes de cristo|antes da era com[uú]n)/i, /^(despois de cristo|era com[uú]n)/i]
    };
    var matchQuarterPatterns$Q = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^[1234](º)? trimestre/i
    };
    var parseQuarterPatterns$Q = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$Q = {
      narrow: /^[xfmasond]/i,
      abbreviated: /^(xan|feb|mar|abr|mai|xun|xul|ago|set|out|nov|dec)/i,
      wide: /^(xaneiro|febreiro|marzo|abril|maio|xuño|xullo|agosto|setembro|outubro|novembro|decembro)/i
    };
    var parseMonthPatterns$Q = {
      narrow: [/^x/i, /^f/i, /^m/i, /^a/i, /^m/i, /^x/i, /^x/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^xan/i, /^feb/i, /^mar/i, /^abr/i, /^mai/i, /^xun/i, /^xul/i, /^ago/i, /^set/i, /^out/i, /^nov/i, /^dec/i]
    };
    var matchDayPatterns$Q = {
      narrow: /^[dlmxvs]/i,
      short: /^(do|lu|ma|me|xo|ve|sa)/i,
      abbreviated: /^(dom|lun|mar|mer|xov|ven|sab)/i,
      wide: /^(domingo|luns|martes|m[eé]rcores|xoves|venres|s[áa]bado)/i
    };
    var parseDayPatterns$Q = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^x/i, /^v/i, /^s/i],
      any: [/^do/i, /^lu/i, /^ma/i, /^me/i, /^xo/i, /^ve/i, /^sa/i]
    };
    var matchDayPeriodPatterns$Q = {
      narrow: /^(a|p|mn|md|(da|[aá]s) (mañ[aá]|tarde|noite))/i,
      any: /^([ap]\.?\s?m\.?|medianoite|mediod[ií]a|(da|[aá]s) (mañ[aá]|tarde|noite))/i
    };
    var parseDayPeriodPatterns$Q = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mn/i,
        noon: /^md/i,
        morning: /mañ[aá]/i,
        afternoon: /tarde/i,
        evening: /tardiña/i,
        night: /noite/i
      }
    };
    var match$Q = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$Q,
        parsePattern: parseOrdinalNumberPattern$Q,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$Q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$Q,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$Q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$Q,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$Q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$Q,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$Q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$Q,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$Q,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$Q,
        defaultParseWidth: 'any'
      })
    };

    var locale$R = {
      code: 'gl',
      formatDistance: formatDistance$Q,
      formatLong: formatLong$R,
      formatRelative: formatRelative$Q,
      localize: localize$Q,
      match: match$Q,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$O = {
      lessThanXSeconds: {
        one: 'હમણાં',
        other: '​આશરે {{count}} સેકંડ'
      },
      xSeconds: {
        one: '1 સેકંડ',
        other: '{{count}} સેકંડ'
      },
      halfAMinute: 'અડધી મિનિટ',
      lessThanXMinutes: {
        one: 'આ મિનિટ',
        other: '​આશરે {{count}} મિનિટ'
      },
      xMinutes: {
        one: '1 મિનિટ',
        other: '{{count}} મિનિટ'
      },
      aboutXHours: {
        one: '​આશરે 1 કલાક',
        other: '​આશરે {{count}} કલાક'
      },
      xHours: {
        one: '1 કલાક',
        other: '{{count}} કલાક'
      },
      xDays: {
        one: '1 દિવસ',
        other: '{{count}} દિવસ'
      },
      aboutXWeeks: {
        one: 'આશરે 1 અઠવાડિયું',
        other: 'આશરે {{count}} અઠવાડિયા'
      },
      xWeeks: {
        one: '1 અઠવાડિયું',
        other: '{{count}} અઠવાડિયા'
      },
      aboutXMonths: {
        one: 'આશરે 1 મહિનો',
        other: 'આશરે {{count}} મહિના'
      },
      xMonths: {
        one: '1 મહિનો',
        other: '{{count}} મહિના'
      },
      aboutXYears: {
        one: 'આશરે 1 વર્ષ',
        other: 'આશરે {{count}} વર્ષ'
      },
      xYears: {
        one: '1 વર્ષ',
        other: '{{count}} વર્ષ'
      },
      overXYears: {
        one: '1 વર્ષથી વધુ',
        other: '{{count}} વર્ષથી વધુ'
      },
      almostXYears: {
        one: 'લગભગ 1 વર્ષ',
        other: 'લગભગ {{count}} વર્ષ'
      }
    };
    var formatDistance$P = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$O[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + 'માં';
        } else {
          return result + ' પહેલાં';
        }
      }
      return result;
    };

    var dateFormats$Q = {
      full: 'EEEE, d MMMM, y',
      long: 'd MMMM, y',
      medium: 'd MMM, y',
      short: 'd/M/yy'
    };
    var timeFormats$Q = {
      full: 'hh:mm:ss a zzzz',
      long: 'hh:mm:ss a z',
      medium: 'hh:mm:ss a',
      short: 'hh:mm a'
    };
    var dateTimeFormats$Q = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$Q = {
      date: buildFormatLongFn({
        formats: dateFormats$Q,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$Q,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$Q,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$P = {
      lastWeek: "'પાછલા' eeee p",
      yesterday: "'ગઈકાલે' p",
      today: "'આજે' p",
      tomorrow: "'આવતીકાલે' p",
      nextWeek: 'eeee p',
      other: 'P'
    };
    var formatRelative$P = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$P[token];
    };

    var eraValues$P = {
      narrow: ['ઈસપૂ', 'ઈસ'],
      abbreviated: ['ઈ.સ.પૂર્વે', 'ઈ.સ.'],
      wide: ['ઈસવીસન પૂર્વે', 'ઈસવીસન']
    };
    var quarterValues$P = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1લો ત્રિમાસ', '2જો ત્રિમાસ', '3જો ત્રિમાસ', '4થો ત્રિમાસ']
    };
    var monthValues$P = {
      narrow: ['જા', 'ફે', 'મા', 'એ', 'મે', 'જૂ', 'જુ', 'ઓ', 'સ', 'ઓ', 'ન', 'ડિ'],
      abbreviated: ['જાન્યુ', 'ફેબ્રુ', 'માર્ચ', 'એપ્રિલ', 'મે', 'જૂન', 'જુલાઈ', 'ઑગસ્ટ', 'સપ્ટે', 'ઓક્ટો', 'નવે', 'ડિસે'],
      wide: ['જાન્યુઆરી', 'ફેબ્રુઆરી', 'માર્ચ', 'એપ્રિલ', 'મે', 'જૂન', 'જુલાઇ', 'ઓગસ્ટ', 'સપ્ટેમ્બર', 'ઓક્ટોબર', 'નવેમ્બર', 'ડિસેમ્બર']
    };
    var dayValues$P = {
      narrow: ['ર', 'સો', 'મં', 'બુ', 'ગુ', 'શુ', 'શ'],
      short: ['ર', 'સો', 'મં', 'બુ', 'ગુ', 'શુ', 'શ'],
      abbreviated: ['રવિ', 'સોમ', 'મંગળ', 'બુધ', 'ગુરુ', 'શુક્ર', 'શનિ'],
      wide: ['રવિવાર'
      , 'સોમવાર'
      , 'મંગળવાર'
      , 'બુધવાર'
      , 'ગુરુવાર'
      , 'શુક્રવાર'
      , 'શનિવાર'
      ]
    };
    var dayPeriodValues$P = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'મ.રાત્રિ',
        noon: 'બ.',
        morning: 'સવારે',
        afternoon: 'બપોરે',
        evening: 'સાંજે',
        night: 'રાત્રે'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: '​મધ્યરાત્રિ',
        noon: 'બપોરે',
        morning: 'સવારે',
        afternoon: 'બપોરે',
        evening: 'સાંજે',
        night: 'રાત્રે'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: '​મધ્યરાત્રિ',
        noon: 'બપોરે',
        morning: 'સવારે',
        afternoon: 'બપોરે',
        evening: 'સાંજે',
        night: 'રાત્રે'
      }
    };
    var formattingDayPeriodValues$G = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'મ.રાત્રિ',
        noon: 'બપોરે',
        morning: 'સવારે',
        afternoon: 'બપોરે',
        evening: 'સાંજે',
        night: 'રાત્રે'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'મધ્યરાત્રિ',
        noon: 'બપોરે',
        morning: 'સવારે',
        afternoon: 'બપોરે',
        evening: 'સાંજે',
        night: 'રાત્રે'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: '​મધ્યરાત્રિ',
        noon: 'બપોરે',
        morning: 'સવારે',
        afternoon: 'બપોરે',
        evening: 'સાંજે',
        night: 'રાત્રે'
      }
    };
    var ordinalNumber$P = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$P = {
      ordinalNumber: ordinalNumber$P,
      era: buildLocalizeFn({
        values: eraValues$P,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$P,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$P,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$P,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$P,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$G,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$P = /^(\d+)(લ|જ|થ|ઠ્ઠ|મ)?/i;
    var parseOrdinalNumberPattern$P = /\d+/i;
    var matchEraPatterns$P = {
      narrow: /^(ઈસપૂ|ઈસ)/i,
      abbreviated: /^(ઈ\.સ\.પૂર્વે|ઈ\.સ\.)/i,
      wide: /^(ઈસવીસન\sપૂર્વે|ઈસવીસન)/i
    };
    var parseEraPatterns$P = {
      any: [/^ઈસપૂ/i, /^ઈસ/i]
    };
    var matchQuarterPatterns$P = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](લો|જો|થો)? ત્રિમાસ/i
    };
    var parseQuarterPatterns$P = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$P = {
      narrow: /^[જાફેમાએમેજૂજુઓસઓનડિ]/i,
      abbreviated: /^(જાન્યુ|ફેબ્રુ|માર્ચ|એપ્રિલ|મે|જૂન|જુલાઈ|ઑગસ્ટ|સપ્ટે|ઓક્ટો|નવે|ડિસે)/i,
      wide: /^(જાન્યુઆરી|ફેબ્રુઆરી|માર્ચ|એપ્રિલ|મે|જૂન|જુલાઇ|ઓગસ્ટ|સપ્ટેમ્બર|ઓક્ટોબર|નવેમ્બર|ડિસેમ્બર)/i
    };
    var parseMonthPatterns$P = {
      narrow: [/^જા/i, /^ફે/i, /^મા/i, /^એ/i, /^મે/i, /^જૂ/i, /^જુ/i, /^ઑગ/i, /^સ/i, /^ઓક્ટો/i, /^ન/i, /^ડિ/i],
      any: [/^જા/i, /^ફે/i, /^મા/i, /^એ/i, /^મે/i, /^જૂ/i, /^જુ/i, /^ઑગ/i, /^સ/i, /^ઓક્ટો/i, /^ન/i, /^ડિ/i]
    };
    var matchDayPatterns$P = {
      narrow: /^(ર|સો|મં|બુ|ગુ|શુ|શ)/i,
      short: /^(ર|સો|મં|બુ|ગુ|શુ|શ)/i,
      abbreviated: /^(રવિ|સોમ|મંગળ|બુધ|ગુરુ|શુક્ર|શનિ)/i,
      wide: /^(રવિવાર|સોમવાર|મંગળવાર|બુધવાર|ગુરુવાર|શુક્રવાર|શનિવાર)/i
    };
    var parseDayPatterns$P = {
      narrow: [/^ર/i, /^સો/i, /^મં/i, /^બુ/i, /^ગુ/i, /^શુ/i, /^શ/i],
      any: [/^ર/i, /^સો/i, /^મં/i, /^બુ/i, /^ગુ/i, /^શુ/i, /^શ/i]
    };
    var matchDayPeriodPatterns$P = {
      narrow: /^(a|p|મ\.?|સ|બ|સાં|રા)/i,
      any: /^(a|p|મ\.?|સ|બ|સાં|રા)/i
    };
    var parseDayPeriodPatterns$P = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^મ\.?/i,
        noon: /^બ/i,
        morning: /સ/i,
        afternoon: /બ/i,
        evening: /સાં/i,
        night: /રા/i
      }
    };
    var match$P = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$P,
        parsePattern: parseOrdinalNumberPattern$P,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$P,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$P,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$P,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$P,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$P,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$P,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$P,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$P,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$P,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$P,
        defaultParseWidth: 'any'
      })
    };

    var locale$Q = {
      code: 'gu',
      formatDistance: formatDistance$P,
      formatLong: formatLong$Q,
      formatRelative: formatRelative$P,
      localize: localize$P,
      match: match$P,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$N = {
      lessThanXSeconds: {
        one: 'פחות משנייה',
        two: 'פחות משתי שניות',
        other: 'פחות מ־{{count}} שניות'
      },
      xSeconds: {
        one: 'שנייה',
        two: 'שתי שניות',
        other: '{{count}} שניות'
      },
      halfAMinute: 'חצי דקה',
      lessThanXMinutes: {
        one: 'פחות מדקה',
        two: 'פחות משתי דקות',
        other: 'פחות מ־{{count}} דקות'
      },
      xMinutes: {
        one: 'דקה',
        two: 'שתי דקות',
        other: '{{count}} דקות'
      },
      aboutXHours: {
        one: 'כשעה',
        two: 'כשעתיים',
        other: 'כ־{{count}} שעות'
      },
      xHours: {
        one: 'שעה',
        two: 'שעתיים',
        other: '{{count}} שעות'
      },
      xDays: {
        one: 'יום',
        two: 'יומיים',
        other: '{{count}} ימים'
      },
      aboutXWeeks: {
        one: 'כשבוע',
        two: 'כשבועיים',
        other: 'כ־{{count}} שבועות'
      },
      xWeeks: {
        one: 'שבוע',
        two: 'שבועיים',
        other: '{{count}} שבועות'
      },
      aboutXMonths: {
        one: 'כחודש',
        two: 'כחודשיים',
        other: 'כ־{{count}} חודשים'
      },
      xMonths: {
        one: 'חודש',
        two: 'חודשיים',
        other: '{{count}} חודשים'
      },
      aboutXYears: {
        one: 'כשנה',
        two: 'כשנתיים',
        other: 'כ־{{count}} שנים'
      },
      xYears: {
        one: 'שנה',
        two: 'שנתיים',
        other: '{{count}} שנים'
      },
      overXYears: {
        one: 'יותר משנה',
        two: 'יותר משנתיים',
        other: 'יותר מ־{{count}} שנים'
      },
      almostXYears: {
        one: 'כמעט שנה',
        two: 'כמעט שנתיים',
        other: 'כמעט {{count}} שנים'
      }
    };
    var formatDistance$O = function (token, count, options) {
      if (token === 'xDays' && options !== null && options !== void 0 && options.addSuffix && count <= 2) {
        if (options.comparison && options.comparison > 0) {
          return count === 1 ? 'מחר' : 'מחרתיים';
        }
        return count === 1 ? 'אתמול' : 'שלשום';
      }
      var result;
      var tokenValue = formatDistanceLocale$N[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else if (count === 2) {
        result = tokenValue.two;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'בעוד ' + result;
        } else {
          return 'לפני ' + result;
        }
      }
      return result;
    };

    var dateFormats$P = {
      full: 'EEEE, d בMMMM y',
      long: 'd בMMMM y',
      medium: 'd בMMM y',
      short: 'd.M.y'
    };
    var timeFormats$P = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$P = {
      full: "{{date}} 'בשעה' {{time}}",
      long: "{{date}} 'בשעה' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$P = {
      date: buildFormatLongFn({
        formats: dateFormats$P,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$P,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$P,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$O = {
      lastWeek: "eeee 'שעבר בשעה' p",
      yesterday: "'אתמול בשעה' p",
      today: "'היום בשעה' p",
      tomorrow: "'מחר בשעה' p",
      nextWeek: "eeee 'בשעה' p",
      other: 'P'
    };
    var formatRelative$O = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$O[token];
    };

    var eraValues$O = {
      narrow: ['לפנה״ס', 'לספירה'],
      abbreviated: ['לפנה״ס', 'לספירה'],
      wide: ['לפני הספירה', 'לספירה']
    };
    var quarterValues$O = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['רבעון 1', 'רבעון 2', 'רבעון 3', 'רבעון 4']
    };
    var monthValues$O = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['ינו׳', 'פבר׳', 'מרץ', 'אפר׳', 'מאי', 'יוני', 'יולי', 'אוג׳', 'ספט׳', 'אוק׳', 'נוב׳', 'דצמ׳'],
      wide: ['ינואר', 'פברואר', 'מרץ', 'אפריל', 'מאי', 'יוני', 'יולי', 'אוגוסט', 'ספטמבר', 'אוקטובר', 'נובמבר', 'דצמבר']
    };
    var dayValues$O = {
      narrow: ['א׳', 'ב׳', 'ג׳', 'ד׳', 'ה׳', 'ו׳', 'ש׳'],
      short: ['א׳', 'ב׳', 'ג׳', 'ד׳', 'ה׳', 'ו׳', 'ש׳'],
      abbreviated: ['יום א׳', 'יום ב׳', 'יום ג׳', 'יום ד׳', 'יום ה׳', 'יום ו׳', 'שבת'],
      wide: ['יום ראשון', 'יום שני', 'יום שלישי', 'יום רביעי', 'יום חמישי', 'יום שישי', 'יום שבת']
    };
    var dayPeriodValues$O = {
      narrow: {
        am: 'לפנה״צ',
        pm: 'אחה״צ',
        midnight: 'חצות',
        noon: 'צהריים',
        morning: 'בוקר',
        afternoon: 'אחר הצהריים',
        evening: 'ערב',
        night: 'לילה'
      },
      abbreviated: {
        am: 'לפנה״צ',
        pm: 'אחה״צ',
        midnight: 'חצות',
        noon: 'צהריים',
        morning: 'בוקר',
        afternoon: 'אחר הצהריים',
        evening: 'ערב',
        night: 'לילה'
      },
      wide: {
        am: 'לפנה״צ',
        pm: 'אחה״צ',
        midnight: 'חצות',
        noon: 'צהריים',
        morning: 'בוקר',
        afternoon: 'אחר הצהריים',
        evening: 'ערב',
        night: 'לילה'
      }
    };
    var formattingDayPeriodValues$F = {
      narrow: {
        am: 'לפנה״צ',
        pm: 'אחה״צ',
        midnight: 'חצות',
        noon: 'צהריים',
        morning: 'בבוקר',
        afternoon: 'בצהריים',
        evening: 'בערב',
        night: 'בלילה'
      },
      abbreviated: {
        am: 'לפנה״צ',
        pm: 'אחה״צ',
        midnight: 'חצות',
        noon: 'צהריים',
        morning: 'בבוקר',
        afternoon: 'אחר הצהריים',
        evening: 'בערב',
        night: 'בלילה'
      },
      wide: {
        am: 'לפנה״צ',
        pm: 'אחה״צ',
        midnight: 'חצות',
        noon: 'צהריים',
        morning: 'בבוקר',
        afternoon: 'אחר הצהריים',
        evening: 'בערב',
        night: 'בלילה'
      }
    };
    var ordinalNumber$O = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      if (number <= 0 || number > 10) return String(number);
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      var isFemale = ['year', 'hour', 'minute', 'second'].indexOf(unit) >= 0;
      var male = ['ראשון', 'שני', 'שלישי', 'רביעי', 'חמישי', 'שישי', 'שביעי', 'שמיני', 'תשיעי', 'עשירי'];
      var female = ['ראשונה', 'שנייה', 'שלישית', 'רביעית', 'חמישית', 'שישית', 'שביעית', 'שמינית', 'תשיעית', 'עשירית'];
      var index = number - 1;
      return isFemale ? female[index] : male[index];
    };
    var localize$O = {
      ordinalNumber: ordinalNumber$O,
      era: buildLocalizeFn({
        values: eraValues$O,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$O,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$O,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$O,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$O,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$F,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$O = /^(\d+|(ראשון|שני|שלישי|רביעי|חמישי|שישי|שביעי|שמיני|תשיעי|עשירי|ראשונה|שנייה|שלישית|רביעית|חמישית|שישית|שביעית|שמינית|תשיעית|עשירית))/i;
    var parseOrdinalNumberPattern$O = /^(\d+|רא|שנ|של|רב|ח|שי|שב|שמ|ת|ע)/i;
    var matchEraPatterns$O = {
      narrow: /^ל(ספירה|פנה״ס)/i,
      abbreviated: /^ל(ספירה|פנה״ס)/i,
      wide: /^ל(פני ה)?ספירה/i
    };
    var parseEraPatterns$O = {
      any: [/^לפ/i, /^לס/i]
    };
    var matchQuarterPatterns$O = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^רבעון [1234]/i
    };
    var parseQuarterPatterns$O = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$O = {
      narrow: /^\d+/i,
      abbreviated: /^(ינו|פבר|מרץ|אפר|מאי|יוני|יולי|אוג|ספט|אוק|נוב|דצמ)׳?/i,
      wide: /^(ינואר|פברואר|מרץ|אפריל|מאי|יוני|יולי|אוגוסט|ספטמבר|אוקטובר|נובמבר|דצמבר)/i
    };
    var parseMonthPatterns$O = {
      narrow: [/^1$/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^7/i, /^8/i, /^9/i, /^10/i, /^11/i, /^12/i],
      any: [/^ינ/i, /^פ/i, /^מר/i, /^אפ/i, /^מא/i, /^יונ/i, /^יול/i, /^אוג/i, /^ס/i, /^אוק/i, /^נ/i, /^ד/i]
    };
    var matchDayPatterns$O = {
      narrow: /^[אבגדהוש]׳/i,
      short: /^[אבגדהוש]׳/i,
      abbreviated: /^(שבת|יום (א|ב|ג|ד|ה|ו)׳)/i,
      wide: /^יום (ראשון|שני|שלישי|רביעי|חמישי|שישי|שבת)/i
    };
    var parseDayPatterns$O = {
      abbreviated: [/א׳$/i, /ב׳$/i, /ג׳$/i, /ד׳$/i, /ה׳$/i, /ו׳$/i, /^ש/i],
      wide: [/ן$/i, /ני$/i, /לישי$/i, /עי$/i, /מישי$/i, /שישי$/i, /ת$/i],
      any: [/^א/i, /^ב/i, /^ג/i, /^ד/i, /^ה/i, /^ו/i, /^ש/i]
    };
    var matchDayPeriodPatterns$O = {
      any: /^(אחר ה|ב)?(חצות|צהריים|בוקר|ערב|לילה|אחה״צ|לפנה״צ)/i
    };
    var parseDayPeriodPatterns$O = {
      any: {
        am: /^לפ/i,
        pm: /^אחה/i,
        midnight: /^ח/i,
        noon: /^צ/i,
        morning: /בוקר/i,
        afternoon: /בצ|אחר/i,
        evening: /ערב/i,
        night: /לילה/i
      }
    };
    var ordinalName = ['רא', 'שנ', 'של', 'רב', 'ח', 'שי', 'שב', 'שמ', 'ת', 'ע'];
    var match$O = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$O,
        parsePattern: parseOrdinalNumberPattern$O,
        valueCallback: function (value) {
          var number = parseInt(value, 10);
          return isNaN(number) ? ordinalName.indexOf(value) + 1 : number;
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$O,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$O,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$O,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$O,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$O,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$O,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$O,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$O,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$O,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$O,
        defaultParseWidth: 'any'
      })
    };

    var locale$P = {
      code: 'he',
      formatDistance: formatDistance$O,
      formatLong: formatLong$P,
      formatRelative: formatRelative$O,
      localize: localize$O,
      match: match$O,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var numberValues = {
      locale: {
        '1': '१',
        '2': '२',
        '3': '३',
        '4': '४',
        '5': '५',
        '6': '६',
        '7': '७',
        '8': '८',
        '9': '९',
        '0': '०'
      },
      number: {
        '१': '1',
        '२': '2',
        '३': '3',
        '४': '4',
        '५': '5',
        '६': '6',
        '७': '7',
        '८': '8',
        '९': '9',
        '०': '0'
      }
    };
    var eraValues$N = {
      narrow: ['ईसा-पूर्व', 'ईस्वी'],
      abbreviated: ['ईसा-पूर्व', 'ईस्वी'],
      wide: ['ईसा-पूर्व', 'ईसवी सन']
    };
    var quarterValues$N = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ति1', 'ति2', 'ति3', 'ति4'],
      wide: ['पहली तिमाही', 'दूसरी तिमाही', 'तीसरी तिमाही', 'चौथी तिमाही']
    };
    var monthValues$N = {
      narrow: ['ज', 'फ़', 'मा', 'अ', 'मई', 'जू', 'जु', 'अग', 'सि', 'अक्टू', 'न', 'दि'],
      abbreviated: ['जन', 'फ़र', 'मार्च', 'अप्रैल', 'मई', 'जून', 'जुल', 'अग', 'सित', 'अक्टू', 'नव', 'दिस'],
      wide: ['जनवरी', 'फ़रवरी', 'मार्च', 'अप्रैल', 'मई', 'जून', 'जुलाई', 'अगस्त', 'सितंबर', 'अक्टूबर', 'नवंबर', 'दिसंबर']
    };
    var dayValues$N = {
      narrow: ['र', 'सो', 'मं', 'बु', 'गु', 'शु', 'श'],
      short: ['र', 'सो', 'मं', 'बु', 'गु', 'शु', 'श'],
      abbreviated: ['रवि', 'सोम', 'मंगल', 'बुध', 'गुरु', 'शुक्र', 'शनि'],
      wide: ['रविवार', 'सोमवार', 'मंगलवार', 'बुधवार', 'गुरुवार', 'शुक्रवार', 'शनिवार']
    };
    var dayPeriodValues$N = {
      narrow: {
        am: 'पूर्वाह्न',
        pm: 'अपराह्न',
        midnight: 'मध्यरात्रि',
        noon: 'दोपहर',
        morning: 'सुबह',
        afternoon: 'दोपहर',
        evening: 'शाम',
        night: 'रात'
      },
      abbreviated: {
        am: 'पूर्वाह्न',
        pm: 'अपराह्न',
        midnight: 'मध्यरात्रि',
        noon: 'दोपहर',
        morning: 'सुबह',
        afternoon: 'दोपहर',
        evening: 'शाम',
        night: 'रात'
      },
      wide: {
        am: 'पूर्वाह्न',
        pm: 'अपराह्न',
        midnight: 'मध्यरात्रि',
        noon: 'दोपहर',
        morning: 'सुबह',
        afternoon: 'दोपहर',
        evening: 'शाम',
        night: 'रात'
      }
    };
    var formattingDayPeriodValues$E = {
      narrow: {
        am: 'पूर्वाह्न',
        pm: 'अपराह्न',
        midnight: 'मध्यरात्रि',
        noon: 'दोपहर',
        morning: 'सुबह',
        afternoon: 'दोपहर',
        evening: 'शाम',
        night: 'रात'
      },
      abbreviated: {
        am: 'पूर्वाह्न',
        pm: 'अपराह्न',
        midnight: 'मध्यरात्रि',
        noon: 'दोपहर',
        morning: 'सुबह',
        afternoon: 'दोपहर',
        evening: 'शाम',
        night: 'रात'
      },
      wide: {
        am: 'पूर्वाह्न',
        pm: 'अपराह्न',
        midnight: 'मध्यरात्रि',
        noon: 'दोपहर',
        morning: 'सुबह',
        afternoon: 'दोपहर',
        evening: 'शाम',
        night: 'रात'
      }
    };
    var ordinalNumber$N = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return numberToLocale(number);
    };
    function localeToNumber(locale) {
      var enNumber = locale.toString().replace(/[१२३४५६७८९०]/g, function (match) {
        return numberValues.number[match];
      });
      return Number(enNumber);
    }
    function numberToLocale(enNumber) {
      return enNumber.toString().replace(/\d/g, function (match) {
        return numberValues.locale[match];
      });
    }
    var localize$N = {
      ordinalNumber: ordinalNumber$N,
      era: buildLocalizeFn({
        values: eraValues$N,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$N,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$N,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$N,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$N,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$E,
        defaultFormattingWidth: 'wide'
      })
    };

    var formatDistanceLocale$M = {
      lessThanXSeconds: {
        one: '१ सेकंड से कम',
        other: '{{count}} सेकंड से कम'
      },
      xSeconds: {
        one: '१ सेकंड',
        other: '{{count}} सेकंड'
      },
      halfAMinute: 'आधा मिनट',
      lessThanXMinutes: {
        one: '१ मिनट से कम',
        other: '{{count}} मिनट से कम'
      },
      xMinutes: {
        one: '१ मिनट',
        other: '{{count}} मिनट'
      },
      aboutXHours: {
        one: 'लगभग १ घंटा',
        other: 'लगभग {{count}} घंटे'
      },
      xHours: {
        one: '१ घंटा',
        other: '{{count}} घंटे'
      },
      xDays: {
        one: '१ दिन',
        other: '{{count}} दिन'
      },
      aboutXWeeks: {
        one: 'लगभग १ सप्ताह',
        other: 'लगभग {{count}} सप्ताह'
      },
      xWeeks: {
        one: '१ सप्ताह',
        other: '{{count}} सप्ताह'
      },
      aboutXMonths: {
        one: 'लगभग १ महीना',
        other: 'लगभग {{count}} महीने'
      },
      xMonths: {
        one: '१ महीना',
        other: '{{count}} महीने'
      },
      aboutXYears: {
        one: 'लगभग १ वर्ष',
        other: 'लगभग {{count}} वर्ष'
      },
      xYears: {
        one: '१ वर्ष',
        other: '{{count}} वर्ष'
      },
      overXYears: {
        one: '१ वर्ष से अधिक',
        other: '{{count}} वर्ष से अधिक'
      },
      almostXYears: {
        one: 'लगभग १ वर्ष',
        other: 'लगभग {{count}} वर्ष'
      }
    };
    var formatDistance$N = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$M[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', numberToLocale(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + 'मे ';
        } else {
          return result + ' पहले';
        }
      }
      return result;
    };

    var dateFormats$O = {
      full: 'EEEE, do MMMM, y',
      long: 'do MMMM, y',
      medium: 'd MMM, y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$O = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$O = {
      full: "{{date}} 'को' {{time}}",
      long: "{{date}} 'को' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$O = {
      date: buildFormatLongFn({
        formats: dateFormats$O,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$O,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$O,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$N = {
      lastWeek: "'पिछले' eeee p",
      yesterday: "'कल' p",
      today: "'आज' p",
      tomorrow: "'कल' p",
      nextWeek: "eeee 'को' p",
      other: 'P'
    };
    var formatRelative$N = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$N[token];
    };

    var matchOrdinalNumberPattern$N = /^[०१२३४५६७८९]+/i;
    var parseOrdinalNumberPattern$N = /^[०१२३४५६७८९]+/i;
    var matchEraPatterns$N = {
      narrow: /^(ईसा-पूर्व|ईस्वी)/i,
      abbreviated: /^(ईसा\.?\s?पूर्व\.?|ईसा\.?)/i,
      wide: /^(ईसा-पूर्व|ईसवी पूर्व|ईसवी सन|ईसवी)/i
    };
    var parseEraPatterns$N = {
      any: [/^b/i, /^(a|c)/i]
    };
    var matchQuarterPatterns$N = {
      narrow: /^[1234]/i,
      abbreviated: /^ति[1234]/i,
      wide: /^[1234](पहली|दूसरी|तीसरी|चौथी)? तिमाही/i
    };
    var parseQuarterPatterns$N = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$N = {
      narrow: /^[जफ़माअप्मईजूनजुअगसिअक्तनदि]/i,
      abbreviated: /^(जन|फ़र|मार्च|अप्|मई|जून|जुल|अग|सित|अक्तू|नव|दिस)/i,
      wide: /^(जनवरी|फ़रवरी|मार्च|अप्रैल|मई|जून|जुलाई|अगस्त|सितंबर|अक्तूबर|नवंबर|दिसंबर)/i
    };
    var parseMonthPatterns$N = {
      narrow: [/^ज/i, /^फ़/i, /^मा/i, /^अप्/i, /^मई/i, /^जू/i, /^जु/i, /^अग/i, /^सि/i, /^अक्तू/i, /^न/i, /^दि/i],
      any: [/^जन/i, /^फ़/i, /^मा/i, /^अप्/i, /^मई/i, /^जू/i, /^जु/i, /^अग/i, /^सि/i, /^अक्तू/i, /^नव/i, /^दिस/i]
    };
    var matchDayPatterns$N = {
      narrow: /^[रविसोममंगलबुधगुरुशुक्रशनि]/i,
      short: /^(रवि|सोम|मंगल|बुध|गुरु|शुक्र|शनि)/i,
      abbreviated: /^(रवि|सोम|मंगल|बुध|गुरु|शुक्र|शनि)/i,
      wide: /^(रविवार|सोमवार|मंगलवार|बुधवार|गुरुवार|शुक्रवार|शनिवार)/i
    };
    var parseDayPatterns$N = {
      narrow: [/^रवि/i, /^सोम/i, /^मंगल/i, /^बुध/i, /^गुरु/i, /^शुक्र/i, /^शनि/i],
      any: [/^रवि/i, /^सोम/i, /^मंगल/i, /^बुध/i, /^गुरु/i, /^शुक्र/i, /^शनि/i]
    };
    var matchDayPeriodPatterns$N = {
      narrow: /^(पू|अ|म|द.\?|सु|दो|शा|रा)/i,
      any: /^(पूर्वाह्न|अपराह्न|म|द.\?|सु|दो|शा|रा)/i
    };
    var parseDayPeriodPatterns$N = {
      any: {
        am: /^पूर्वाह्न/i,
        pm: /^अपराह्न/i,
        midnight: /^मध्य/i,
        noon: /^दो/i,
        morning: /सु/i,
        afternoon: /दो/i,
        evening: /शा/i,
        night: /रा/i
      }
    };
    var match$N = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$N,
        parsePattern: parseOrdinalNumberPattern$N,
        valueCallback: localeToNumber
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$N,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$N,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$N,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$N,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$N,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$N,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$N,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$N,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$N,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$N,
        defaultParseWidth: 'any'
      })
    };

    var locale$O = {
      code: 'hi',
      formatDistance: formatDistance$N,
      formatLong: formatLong$O,
      formatRelative: formatRelative$N,
      localize: localize$N,
      match: match$N,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$L = {
      lessThanXSeconds: {
        one: {
          standalone: 'manje od 1 sekunde',
          withPrepositionAgo: 'manje od 1 sekunde',
          withPrepositionIn: 'manje od 1 sekundu'
        },
        dual: 'manje od {{count}} sekunde',
        other: 'manje od {{count}} sekundi'
      },
      xSeconds: {
        one: {
          standalone: '1 sekunda',
          withPrepositionAgo: '1 sekunde',
          withPrepositionIn: '1 sekundu'
        },
        dual: '{{count}} sekunde',
        other: '{{count}} sekundi'
      },
      halfAMinute: 'pola minute',
      lessThanXMinutes: {
        one: {
          standalone: 'manje od 1 minute',
          withPrepositionAgo: 'manje od 1 minute',
          withPrepositionIn: 'manje od 1 minutu'
        },
        dual: 'manje od {{count}} minute',
        other: 'manje od {{count}} minuta'
      },
      xMinutes: {
        one: {
          standalone: '1 minuta',
          withPrepositionAgo: '1 minute',
          withPrepositionIn: '1 minutu'
        },
        dual: '{{count}} minute',
        other: '{{count}} minuta'
      },
      aboutXHours: {
        one: {
          standalone: 'oko 1 sat',
          withPrepositionAgo: 'oko 1 sat',
          withPrepositionIn: 'oko 1 sat'
        },
        dual: 'oko {{count}} sata',
        other: 'oko {{count}} sati'
      },
      xHours: {
        one: {
          standalone: '1 sat',
          withPrepositionAgo: '1 sat',
          withPrepositionIn: '1 sat'
        },
        dual: '{{count}} sata',
        other: '{{count}} sati'
      },
      xDays: {
        one: {
          standalone: '1 dan',
          withPrepositionAgo: '1 dan',
          withPrepositionIn: '1 dan'
        },
        dual: '{{count}} dana',
        other: '{{count}} dana'
      },
      aboutXWeeks: {
        one: {
          standalone: 'oko 1 tjedan',
          withPrepositionAgo: 'oko 1 tjedan',
          withPrepositionIn: 'oko 1 tjedan'
        },
        dual: 'oko {{count}} tjedna',
        other: 'oko {{count}} tjedana'
      },
      xWeeks: {
        one: {
          standalone: '1 tjedan',
          withPrepositionAgo: '1 tjedan',
          withPrepositionIn: '1 tjedan'
        },
        dual: '{{count}} tjedna',
        other: '{{count}} tjedana'
      },
      aboutXMonths: {
        one: {
          standalone: 'oko 1 mjesec',
          withPrepositionAgo: 'oko 1 mjesec',
          withPrepositionIn: 'oko 1 mjesec'
        },
        dual: 'oko {{count}} mjeseca',
        other: 'oko {{count}} mjeseci'
      },
      xMonths: {
        one: {
          standalone: '1 mjesec',
          withPrepositionAgo: '1 mjesec',
          withPrepositionIn: '1 mjesec'
        },
        dual: '{{count}} mjeseca',
        other: '{{count}} mjeseci'
      },
      aboutXYears: {
        one: {
          standalone: 'oko 1 godinu',
          withPrepositionAgo: 'oko 1 godinu',
          withPrepositionIn: 'oko 1 godinu'
        },
        dual: 'oko {{count}} godine',
        other: 'oko {{count}} godina'
      },
      xYears: {
        one: {
          standalone: '1 godina',
          withPrepositionAgo: '1 godine',
          withPrepositionIn: '1 godinu'
        },
        dual: '{{count}} godine',
        other: '{{count}} godina'
      },
      overXYears: {
        one: {
          standalone: 'preko 1 godinu',
          withPrepositionAgo: 'preko 1 godinu',
          withPrepositionIn: 'preko 1 godinu'
        },
        dual: 'preko {{count}} godine',
        other: 'preko {{count}} godina'
      },
      almostXYears: {
        one: {
          standalone: 'gotovo 1 godinu',
          withPrepositionAgo: 'gotovo 1 godinu',
          withPrepositionIn: 'gotovo 1 godinu'
        },
        dual: 'gotovo {{count}} godine',
        other: 'gotovo {{count}} godina'
      }
    };
    var formatDistance$M = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$L[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            result = tokenValue.one.withPrepositionIn;
          } else {
            result = tokenValue.one.withPrepositionAgo;
          }
        } else {
          result = tokenValue.one.standalone;
        }
      } else if (count % 10 > 1 && count % 10 < 5 &&
      String(count).substr(-2, 1) !== '1'
      ) {
          result = tokenValue.dual.replace('{{count}}', String(count));
        } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'za ' + result;
        } else {
          return 'prije ' + result;
        }
      }
      return result;
    };

    var dateFormats$N = {
      full: 'EEEE, d. MMMM y.',
      long: 'd. MMMM y.',
      medium: 'd. MMM y.',
      short: 'dd. MM. y.'
    };
    var timeFormats$N = {
      full: 'HH:mm:ss (zzzz)',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$N = {
      full: "{{date}} 'u' {{time}}",
      long: "{{date}} 'u' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$N = {
      date: buildFormatLongFn({
        formats: dateFormats$N,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$N,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$N,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$M = {
      lastWeek: function (date) {
        switch (date.getUTCDay()) {
          case 0:
            return "'prošlu nedjelju u' p";
          case 3:
            return "'prošlu srijedu u' p";
          case 6:
            return "'prošlu subotu u' p";
          default:
            return "'prošli' EEEE 'u' p";
        }
      },
      yesterday: "'jučer u' p",
      today: "'danas u' p",
      tomorrow: "'sutra u' p",
      nextWeek: function (date) {
        switch (date.getUTCDay()) {
          case 0:
            return "'iduću nedjelju u' p";
          case 3:
            return "'iduću srijedu u' p";
          case 6:
            return "'iduću subotu u' p";
          default:
            return "'prošli' EEEE 'u' p";
        }
      },
      other: 'P'
    };
    var formatRelative$M = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$M[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$M = {
      narrow: ['pr.n.e.', 'AD'],
      abbreviated: ['pr. Kr.', 'po. Kr.'],
      wide: ['Prije Krista', 'Poslije Krista']
    };
    var quarterValues$M = {
      narrow: ['1.', '2.', '3.', '4.'],
      abbreviated: ['1. kv.', '2. kv.', '3. kv.', '4. kv.'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$M = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['sij', 'velj', 'ožu', 'tra', 'svi', 'lip', 'srp', 'kol', 'ruj', 'lis', 'stu', 'pro'],
      wide: ['siječanj', 'veljača', 'ožujak', 'travanj', 'svibanj', 'lipanj', 'srpanj', 'kolovoz', 'rujan', 'listopad', 'studeni', 'prosinac']
    };
    var formattingMonthValues$a = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['sij', 'velj', 'ožu', 'tra', 'svi', 'lip', 'srp', 'kol', 'ruj', 'lis', 'stu', 'pro'],
      wide: ['siječnja', 'veljače', 'ožujka', 'travnja', 'svibnja', 'lipnja', 'srpnja', 'kolovoza', 'rujna', 'listopada', 'studenog', 'prosinca']
    };
    var dayValues$M = {
      narrow: ['N', 'P', 'U', 'S', 'Č', 'P', 'S'],
      short: ['ned', 'pon', 'uto', 'sri', 'čet', 'pet', 'sub'],
      abbreviated: ['ned', 'pon', 'uto', 'sri', 'čet', 'pet', 'sub'],
      wide: ['nedjelja', 'ponedjeljak', 'utorak', 'srijeda', 'četvrtak', 'petak', 'subota']
    };
    var formattingDayPeriodValues$D = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutro',
        afternoon: 'popodne',
        evening: 'navečer',
        night: 'noću'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutro',
        afternoon: 'popodne',
        evening: 'navečer',
        night: 'noću'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutro',
        afternoon: 'poslije podne',
        evening: 'navečer',
        night: 'noću'
      }
    };
    var dayPeriodValues$M = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutro',
        afternoon: 'popodne',
        evening: 'navečer',
        night: 'noću'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutro',
        afternoon: 'popodne',
        evening: 'navečer',
        night: 'noću'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutro',
        afternoon: 'poslije podne',
        evening: 'navečer',
        night: 'noću'
      }
    };
    var ordinalNumber$M = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$M = {
      ordinalNumber: ordinalNumber$M,
      era: buildLocalizeFn({
        values: eraValues$M,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$M,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$M,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$a,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$M,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$M,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$D,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$M = /^(\d+)\./i;
    var parseOrdinalNumberPattern$M = /\d+/i;
    var matchEraPatterns$M = {
      narrow: /^(pr\.n\.e\.|AD)/i,
      abbreviated: /^(pr\.\s?Kr\.|po\.\s?Kr\.)/i,
      wide: /^(Prije Krista|prije nove ere|Poslije Krista|nova era)/i
    };
    var parseEraPatterns$M = {
      any: [/^pr/i, /^(po|nova)/i]
    };
    var matchQuarterPatterns$M = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]\.\s?kv\.?/i,
      wide: /^[1234]\. kvartal/i
    };
    var parseQuarterPatterns$M = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$M = {
      narrow: /^(10|11|12|[123456789])\./i,
      abbreviated: /^(sij|velj|(ožu|ozu)|tra|svi|lip|srp|kol|ruj|lis|stu|pro)/i,
      wide: /^((siječanj|siječnja|sijecanj|sijecnja)|(veljača|veljače|veljaca|veljace)|(ožujak|ožujka|ozujak|ozujka)|(travanj|travnja)|(svibanj|svibnja)|(lipanj|lipnja)|(srpanj|srpnja)|(kolovoz|kolovoza)|(rujan|rujna)|(listopad|listopada)|(studeni|studenog)|(prosinac|prosinca))/i
    };
    var parseMonthPatterns$M = {
      narrow: [/1/i, /2/i, /3/i, /4/i, /5/i, /6/i, /7/i, /8/i, /9/i, /10/i, /11/i, /12/i],
      abbreviated: [/^sij/i, /^velj/i, /^(ožu|ozu)/i, /^tra/i, /^svi/i, /^lip/i, /^srp/i, /^kol/i, /^ruj/i, /^lis/i, /^stu/i, /^pro/i],
      wide: [/^sij/i, /^velj/i, /^(ožu|ozu)/i, /^tra/i, /^svi/i, /^lip/i, /^srp/i, /^kol/i, /^ruj/i, /^lis/i, /^stu/i, /^pro/i]
    };
    var matchDayPatterns$M = {
      narrow: /^[npusčc]/i,
      short: /^(ned|pon|uto|sri|(čet|cet)|pet|sub)/i,
      abbreviated: /^(ned|pon|uto|sri|(čet|cet)|pet|sub)/i,
      wide: /^(nedjelja|ponedjeljak|utorak|srijeda|(četvrtak|cetvrtak)|petak|subota)/i
    };
    var parseDayPatterns$M = {
      narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
      any: [/^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$M = {
      any: /^(am|pm|ponoc|ponoć|(po)?podne|navecer|navečer|noću|poslije podne|ujutro)/i
    };
    var parseDayPeriodPatterns$M = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^pono/i,
        noon: /^pod/i,
        morning: /jutro/i,
        afternoon: /(poslije\s|po)+podne/i,
        evening: /(navece|naveče)/i,
        night: /(nocu|noću)/i
      }
    };
    var match$M = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$M,
        parsePattern: parseOrdinalNumberPattern$M,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$M,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$M,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$M,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$M,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$M,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$M,
        defaultParseWidth: 'wide'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$M,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$M,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$M,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$M,
        defaultParseWidth: 'any'
      })
    };

    var locale$N = {
      code: 'hr',
      formatDistance: formatDistance$M,
      formatLong: formatLong$N,
      formatRelative: formatRelative$M,
      localize: localize$M,
      match: match$M,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$K = {
      lessThanXSeconds: {
        one: 'mwens pase yon segond',
        other: 'mwens pase {{count}} segond'
      },
      xSeconds: {
        one: '1 segond',
        other: '{{count}} segond'
      },
      halfAMinute: '30 segond',
      lessThanXMinutes: {
        one: 'mwens pase yon minit',
        other: 'mwens pase {{count}} minit'
      },
      xMinutes: {
        one: '1 minit',
        other: '{{count}} minit'
      },
      aboutXHours: {
        one: 'anviwon inè',
        other: 'anviwon {{count}} è'
      },
      xHours: {
        one: '1 lè',
        other: '{{count}} lè'
      },
      xDays: {
        one: '1 jou',
        other: '{{count}} jou'
      },
      aboutXWeeks: {
        one: 'anviwon 1 semèn',
        other: 'anviwon {{count}} semèn'
      },
      xWeeks: {
        one: '1 semèn',
        other: '{{count}} semèn'
      },
      aboutXMonths: {
        one: 'anviwon 1 mwa',
        other: 'anviwon {{count}} mwa'
      },
      xMonths: {
        one: '1 mwa',
        other: '{{count}} mwa'
      },
      aboutXYears: {
        one: 'anviwon 1 an',
        other: 'anviwon {{count}} an'
      },
      xYears: {
        one: '1 an',
        other: '{{count}} an'
      },
      overXYears: {
        one: 'plis pase 1 an',
        other: 'plis pase {{count}} an'
      },
      almostXYears: {
        one: 'prèske 1 an',
        other: 'prèske {{count}} an'
      }
    };
    var formatDistance$L = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$K[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'nan ' + result;
        } else {
          return 'sa fè ' + result;
        }
      }
      return result;
    };

    var dateFormats$M = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$M = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$M = {
      full: "{{date}} 'nan lè' {{time}}",
      long: "{{date}} 'nan lè' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$M = {
      date: buildFormatLongFn({
        formats: dateFormats$M,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$M,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$M,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$L = {
      lastWeek: "eeee 'pase nan lè' p",
      yesterday: "'yè nan lè' p",
      today: "'jodi a' p",
      tomorrow: "'demen nan lè' p'",
      nextWeek: "eeee 'pwochen nan lè' p",
      other: 'P'
    };
    var formatRelative$L = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$L[token];
    };

    var eraValues$L = {
      narrow: ['av. J.-K', 'ap. J.-K'],
      abbreviated: ['av. J.-K', 'ap. J.-K'],
      wide: ['anvan Jezi Kris', 'apre Jezi Kris']
    };
    var quarterValues$L = {
      narrow: ['T1', 'T2', 'T3', 'T4'],
      abbreviated: ['1ye trim.', '2yèm trim.', '3yèm trim.', '4yèm trim.'],
      wide: ['1ye trimès', '2yèm trimès', '3yèm trimès', '4yèm trimès']
    };
    var monthValues$L = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'O', 'S', 'O', 'N', 'D'],
      abbreviated: ['janv.', 'fevr.', 'mas', 'avr.', 'me', 'jen', 'jiyè', 'out', 'sept.', 'okt.', 'nov.', 'des.'],
      wide: ['janvye', 'fevrye', 'mas', 'avril', 'me', 'jen', 'jiyè', 'out', 'septanm', 'oktòb', 'novanm', 'desanm']
    };
    var dayValues$L = {
      narrow: ['D', 'L', 'M', 'M', 'J', 'V', 'S'],
      short: ['di', 'le', 'ma', 'mè', 'je', 'va', 'sa'],
      abbreviated: ['dim.', 'len.', 'mad.', 'mèk.', 'jed.', 'van.', 'sam.'],
      wide: ['dimanch', 'lendi', 'madi', 'mèkredi', 'jedi', 'vandredi', 'samdi']
    };
    var dayPeriodValues$L = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minwit',
        noon: 'midi',
        morning: 'mat.',
        afternoon: 'ap.m.',
        evening: 'swa',
        night: 'mat.'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minwit',
        noon: 'midi',
        morning: 'maten',
        afternoon: 'aprèmidi',
        evening: 'swa',
        night: 'maten'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minwit',
        noon: 'midi',
        morning: 'nan maten',
        afternoon: 'nan aprèmidi',
        evening: 'nan aswè',
        night: 'nan maten'
      }
    };
    var ordinalNumber$L = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      if (number === 0) return String(number);
      var suffix = number === 1 ? 'ye' : 'yèm';
      return number + suffix;
    };
    var localize$L = {
      ordinalNumber: ordinalNumber$L,
      era: buildLocalizeFn({
        values: eraValues$L,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$L,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$L,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$L,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$L,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$L = /^(\d+)(ye|yèm)?/i;
    var parseOrdinalNumberPattern$L = /\d+/i;
    var matchEraPatterns$L = {
      narrow: /^(av\.J\.K|ap\.J\.K|ap\.J\.-K)/i,
      abbreviated: /^(av\.J\.-K|av\.J-K|apr\.J\.-K|apr\.J-K|ap\.J-K)/i,
      wide: /^(avan Jezi Kris|apre Jezi Kris)/i
    };
    var parseEraPatterns$L = {
      any: [/^av/i, /^ap/i]
    };
    var matchQuarterPatterns$L = {
      narrow: /^[1234]/i,
      abbreviated: /^t[1234]/i,
      wide: /^[1234](ye|yèm)? trimès/i
    };
    var parseQuarterPatterns$L = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$L = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(janv|fevr|mas|avr|me|jen|jiyè|out|sept|okt|nov|des)\.?/i,
      wide: /^(janvye|fevrye|mas|avril|me|jen|jiyè|out|septanm|oktòb|novanm|desanm)/i
    };
    var parseMonthPatterns$L = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^o/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^ma/i, /^av/i, /^me/i, /^je/i, /^ji/i, /^ou/i, /^s/i, /^ok/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$L = {
      narrow: /^[lmjvsd]/i,
      short: /^(di|le|ma|me|je|va|sa)/i,
      abbreviated: /^(dim|len|mad|mèk|jed|van|sam)\.?/i,
      wide: /^(dimanch|lendi|madi|mèkredi|jedi|vandredi|samdi)/i
    };
    var parseDayPatterns$L = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i],
      any: [/^di/i, /^le/i, /^ma/i, /^mè/i, /^je/i, /^va/i, /^sa/i]
    };
    var matchDayPeriodPatterns$L = {
      narrow: /^(a|p|minwit|midi|mat\.?|ap\.?m\.?|swa)/i,
      any: /^([ap]\.?\s?m\.?|nan maten|nan aprèmidi|nan aswè)/i
    };
    var parseDayPeriodPatterns$L = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^min/i,
        noon: /^mid/i,
        morning: /mat/i,
        afternoon: /ap/i,
        evening: /sw/i,
        night: /nwit/i
      }
    };
    var match$L = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$L,
        parsePattern: parseOrdinalNumberPattern$L,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$L,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$L,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$L,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$L,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$L,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$L,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$L,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$L,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$L,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$L,
        defaultParseWidth: 'any'
      })
    };

    var locale$M = {
      code: 'ht',
      formatDistance: formatDistance$L,
      formatLong: formatLong$M,
      formatRelative: formatRelative$L,
      localize: localize$L,
      match: match$L,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var translations$1 = {
      about: 'körülbelül',
      over: 'több mint',
      almost: 'majdnem',
      lessthan: 'kevesebb mint'
    };
    var withoutSuffixes = {
      xseconds: ' másodperc',
      halfaminute: 'fél perc',
      xminutes: ' perc',
      xhours: ' óra',
      xdays: ' nap',
      xweeks: ' hét',
      xmonths: ' hónap',
      xyears: ' év'
    };
    var withSuffixes = {
      xseconds: {
        '-1': ' másodperccel ezelőtt',
        '1': ' másodperc múlva',
        '0': ' másodperce'
      },
      halfaminute: {
        '-1': 'fél perccel ezelőtt',
        '1': 'fél perc múlva',
        '0': 'fél perce'
      },
      xminutes: {
        '-1': ' perccel ezelőtt',
        '1': ' perc múlva',
        '0': ' perce'
      },
      xhours: {
        '-1': ' órával ezelőtt',
        '1': ' óra múlva',
        '0': ' órája'
      },
      xdays: {
        '-1': ' nappal ezelőtt',
        '1': ' nap múlva',
        '0': ' napja'
      },
      xweeks: {
        '-1': ' héttel ezelőtt',
        '1': ' hét múlva',
        '0': ' hete'
      },
      xmonths: {
        '-1': ' hónappal ezelőtt',
        '1': ' hónap múlva',
        '0': ' hónapja'
      },
      xyears: {
        '-1': ' évvel ezelőtt',
        '1': ' év múlva',
        '0': ' éve'
      }
    };
    var formatDistance$K = function (token, count, options) {
      var adverb = token.match(/about|over|almost|lessthan/i);
      var unit = adverb ? token.replace(adverb[0], '') : token;
      var addSuffix = (options === null || options === void 0 ? void 0 : options.addSuffix) === true;
      var key = unit.toLowerCase();
      var comparison = (options === null || options === void 0 ? void 0 : options.comparison) || 0;
      var translated = addSuffix ? withSuffixes[key][comparison] : withoutSuffixes[key];
      var result = key === 'halfaminute' ? translated : count + translated;
      if (adverb) {
        var adv = adverb[0].toLowerCase();
        result = translations$1[adv] + ' ' + result;
      }
      return result;
    };

    var dateFormats$L = {
      full: 'y. MMMM d., EEEE',
      long: 'y. MMMM d.',
      medium: 'y. MMM d.',
      short: 'y. MM. dd.'
    };
    var timeFormats$L = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$L = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$L = {
      date: buildFormatLongFn({
        formats: dateFormats$L,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$L,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$L,
        defaultWidth: 'full'
      })
    };

    var accusativeWeekdays$4 = ['vasárnap', 'hétfőn', 'kedden', 'szerdán', 'csütörtökön', 'pénteken', 'szombaton'];
    function week(isFuture) {
      return function (date) {
        var weekday = accusativeWeekdays$4[date.getUTCDay()];
        var prefix = isFuture ? '' : "'múlt' ";
        return "".concat(prefix, "'").concat(weekday, "' p'-kor'");
      };
    }
    var formatRelativeLocale$K = {
      lastWeek: week(false),
      yesterday: "'tegnap' p'-kor'",
      today: "'ma' p'-kor'",
      tomorrow: "'holnap' p'-kor'",
      nextWeek: week(true),
      other: 'P'
    };
    var formatRelative$K = function (token, date) {
      var format = formatRelativeLocale$K[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$K = {
      narrow: ['ie.', 'isz.'],
      abbreviated: ['i. e.', 'i. sz.'],
      wide: ['Krisztus előtt', 'időszámításunk szerint']
    };
    var quarterValues$K = {
      narrow: ['1.', '2.', '3.', '4.'],
      abbreviated: ['1. n.év', '2. n.év', '3. n.év', '4. n.év'],
      wide: ['1. negyedév', '2. negyedév', '3. negyedév', '4. negyedév']
    };
    var formattingQuarterValues$3 = {
      narrow: ['I.', 'II.', 'III.', 'IV.'],
      abbreviated: ['I. n.év', 'II. n.év', 'III. n.év', 'IV. n.év'],
      wide: ['I. negyedév', 'II. negyedév', 'III. negyedév', 'IV. negyedév']
    };
    var monthValues$K = {
      narrow: ['J', 'F', 'M', 'Á', 'M', 'J', 'J', 'A', 'Sz', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'febr.', 'márc.', 'ápr.', 'máj.', 'jún.', 'júl.', 'aug.', 'szept.', 'okt.', 'nov.', 'dec.'],
      wide: ['január', 'február', 'március', 'április', 'május', 'június', 'július', 'augusztus', 'szeptember', 'október', 'november', 'december']
    };
    var dayValues$K = {
      narrow: ['V', 'H', 'K', 'Sz', 'Cs', 'P', 'Sz'],
      short: ['V', 'H', 'K', 'Sze', 'Cs', 'P', 'Szo'],
      abbreviated: ['V', 'H', 'K', 'Sze', 'Cs', 'P', 'Szo'],
      wide: ['vasárnap', 'hétfő', 'kedd', 'szerda', 'csütörtök', 'péntek', 'szombat']
    };
    var dayPeriodValues$K = {
      narrow: {
        am: 'de.',
        pm: 'du.',
        midnight: 'éjfél',
        noon: 'dél',
        morning: 'reggel',
        afternoon: 'du.',
        evening: 'este',
        night: 'éjjel'
      },
      abbreviated: {
        am: 'de.',
        pm: 'du.',
        midnight: 'éjfél',
        noon: 'dél',
        morning: 'reggel',
        afternoon: 'du.',
        evening: 'este',
        night: 'éjjel'
      },
      wide: {
        am: 'de.',
        pm: 'du.',
        midnight: 'éjfél',
        noon: 'dél',
        morning: 'reggel',
        afternoon: 'délután',
        evening: 'este',
        night: 'éjjel'
      }
    };
    var ordinalNumber$K = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$K = {
      ordinalNumber: ordinalNumber$K,
      era: buildLocalizeFn({
        values: eraValues$K,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$K,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        },
        formattingValues: formattingQuarterValues$3,
        defaultFormattingWidth: 'wide'
      }),
      month: buildLocalizeFn({
        values: monthValues$K,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$K,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$K,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$K = /^(\d+)\.?/i;
    var parseOrdinalNumberPattern$K = /\d+/i;
    var matchEraPatterns$K = {
      narrow: /^(ie\.|isz\.)/i,
      abbreviated: /^(i\.\s?e\.?|b?\s?c\s?e|i\.\s?sz\.?)/i,
      wide: /^(Krisztus előtt|időszámításunk előtt|időszámításunk szerint|i\. sz\.)/i
    };
    var parseEraPatterns$K = {
      narrow: [/ie/i, /isz/i],
      abbreviated: [/^(i\.?\s?e\.?|b\s?ce)/i, /^(i\.?\s?sz\.?|c\s?e)/i],
      any: [/előtt/i, /(szerint|i. sz.)/i]
    };
    var matchQuarterPatterns$K = {
      narrow: /^[1234]\.?/i,
      abbreviated: /^[1234]?\.?\s?n\.év/i,
      wide: /^([1234]|I|II|III|IV)?\.?\s?negyedév/i
    };
    var parseQuarterPatterns$K = {
      any: [/1|I$/i, /2|II$/i, /3|III/i, /4|IV/i]
    };
    var matchMonthPatterns$K = {
      narrow: /^[jfmaásond]|sz/i,
      abbreviated: /^(jan\.?|febr\.?|márc\.?|ápr\.?|máj\.?|jún\.?|júl\.?|aug\.?|szept\.?|okt\.?|nov\.?|dec\.?)/i,
      wide: /^(január|február|március|április|május|június|július|augusztus|szeptember|október|november|december)/i
    };
    var parseMonthPatterns$K = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a|á/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s|sz/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^már/i, /^áp/i, /^máj/i, /^jún/i, /^júl/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$K = {
      narrow: /^([vhkpc]|sz|cs|sz)/i,
      short: /^([vhkp]|sze|cs|szo)/i,
      abbreviated: /^([vhkp]|sze|cs|szo)/i,
      wide: /^(vasárnap|hétfő|kedd|szerda|csütörtök|péntek|szombat)/i
    };
    var parseDayPatterns$K = {
      narrow: [/^v/i, /^h/i, /^k/i, /^sz/i, /^c/i, /^p/i, /^sz/i],
      any: [/^v/i, /^h/i, /^k/i, /^sze/i, /^c/i, /^p/i, /^szo/i]
    };
    var matchDayPeriodPatterns$K = {
      any: /^((de|du)\.?|éjfél|délután|dél|reggel|este|éjjel)/i
    };
    var parseDayPeriodPatterns$K = {
      any: {
        am: /^de\.?/i,
        pm: /^du\.?/i,
        midnight: /^éjf/i,
        noon: /^dé/i,
        morning: /reg/i,
        afternoon: /^délu\.?/i,
        evening: /es/i,
        night: /éjj/i
      }
    };
    var match$K = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$K,
        parsePattern: parseOrdinalNumberPattern$K,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$K,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$K,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$K,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$K,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$K,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$K,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$K,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$K,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$K,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$K,
        defaultParseWidth: 'any'
      })
    };

    var locale$L = {
      code: 'hu',
      formatDistance: formatDistance$K,
      formatLong: formatLong$L,
      formatRelative: formatRelative$K,
      localize: localize$K,
      match: match$K,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$J = {
      lessThanXSeconds: {
        one: 'ավելի քիչ քան 1 վայրկյան',
        other: 'ավելի քիչ քան {{count}} վայրկյան'
      },
      xSeconds: {
        one: '1 վայրկյան',
        other: '{{count}} վայրկյան'
      },
      halfAMinute: 'կես րոպե',
      lessThanXMinutes: {
        one: 'ավելի քիչ քան 1 րոպե',
        other: 'ավելի քիչ քան {{count}} րոպե'
      },
      xMinutes: {
        one: '1 րոպե',
        other: '{{count}} րոպե'
      },
      aboutXHours: {
        one: 'մոտ 1 ժամ',
        other: 'մոտ {{count}} ժամ'
      },
      xHours: {
        one: '1 ժամ',
        other: '{{count}} ժամ'
      },
      xDays: {
        one: '1 օր',
        other: '{{count}} օր'
      },
      aboutXWeeks: {
        one: 'մոտ 1 շաբաթ',
        other: 'մոտ {{count}} շաբաթ'
      },
      xWeeks: {
        one: '1 շաբաթ',
        other: '{{count}} շաբաթ'
      },
      aboutXMonths: {
        one: 'մոտ 1 ամիս',
        other: 'մոտ {{count}} ամիս'
      },
      xMonths: {
        one: '1 ամիս',
        other: '{{count}} ամիս'
      },
      aboutXYears: {
        one: 'մոտ 1 տարի',
        other: 'մոտ {{count}} տարի'
      },
      xYears: {
        one: '1 տարի',
        other: '{{count}} տարի'
      },
      overXYears: {
        one: 'ավելի քան 1 տարի',
        other: 'ավելի քան {{count}} տարի'
      },
      almostXYears: {
        one: 'համարյա 1 տարի',
        other: 'համարյա {{count}} տարի'
      }
    };
    var formatDistance$J = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$J[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' հետո';
        } else {
          return result + ' առաջ';
        }
      }
      return result;
    };

    var dateFormats$K = {
      full: 'd MMMM, y, EEEE',
      long: 'd MMMM, y',
      medium: 'd MMM, y',
      short: 'dd.MM.yyyy'
    };
    var timeFormats$K = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$K = {
      full: "{{date}} 'ժ․'{{time}}",
      long: "{{date}} 'ժ․'{{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$K = {
      date: buildFormatLongFn({
        formats: dateFormats$K,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$K,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$K,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$J = {
      lastWeek: "'նախորդ' eeee p'֊ին'",
      yesterday: "'երեկ' p'֊ին'",
      today: "'այսօր' p'֊ին'",
      tomorrow: "'վաղը' p'֊ին'",
      nextWeek: "'հաջորդ' eeee p'֊ին'",
      other: 'P'
    };
    var formatRelative$J = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$J[token];
    };

    var eraValues$J = {
      narrow: ['Ք', 'Մ'],
      abbreviated: ['ՔԱ', 'ՄԹ'],
      wide: ['Քրիստոսից առաջ', 'Մեր թվարկության']
    };
    var quarterValues$J = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Ք1', 'Ք2', 'Ք3', 'Ք4'],
      wide: ['1֊ին քառորդ', '2֊րդ քառորդ', '3֊րդ քառորդ', '4֊րդ քառորդ']
    };
    var monthValues$J = {
      narrow: ['Հ', 'Փ', 'Մ', 'Ա', 'Մ', 'Հ', 'Հ', 'Օ', 'Ս', 'Հ', 'Ն', 'Դ'],
      abbreviated: ['հուն', 'փետ', 'մար', 'ապր', 'մայ', 'հուն', 'հուլ', 'օգս', 'սեպ', 'հոկ', 'նոյ', 'դեկ'],
      wide: ['հունվար', 'փետրվար', 'մարտ', 'ապրիլ', 'մայիս', 'հունիս', 'հուլիս', 'օգոստոս', 'սեպտեմբեր', 'հոկտեմբեր', 'նոյեմբեր', 'դեկտեմբեր']
    };
    var dayValues$J = {
      narrow: ['Կ', 'Ե', 'Ե', 'Չ', 'Հ', 'Ո', 'Շ'],
      short: ['կր', 'եր', 'եք', 'չք', 'հգ', 'ուր', 'շբ'],
      abbreviated: ['կիր', 'երկ', 'երք', 'չոր', 'հնգ', 'ուրբ', 'շաբ'],
      wide: ['կիրակի', 'երկուշաբթի', 'երեքշաբթի', 'չորեքշաբթի', 'հինգշաբթի', 'ուրբաթ', 'շաբաթ']
    };
    var dayPeriodValues$J = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'կեսգշ',
        noon: 'կեսօր',
        morning: 'առավոտ',
        afternoon: 'ցերեկ',
        evening: 'երեկո',
        night: 'գիշեր'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'կեսգիշեր',
        noon: 'կեսօր',
        morning: 'առավոտ',
        afternoon: 'ցերեկ',
        evening: 'երեկո',
        night: 'գիշեր'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'կեսգիշեր',
        noon: 'կեսօր',
        morning: 'առավոտ',
        afternoon: 'ցերեկ',
        evening: 'երեկո',
        night: 'գիշեր'
      }
    };
    var formattingDayPeriodValues$C = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'կեսգշ',
        noon: 'կեսօր',
        morning: 'առավոտը',
        afternoon: 'ցերեկը',
        evening: 'երեկոյան',
        night: 'գիշերը'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'կեսգիշերին',
        noon: 'կեսօրին',
        morning: 'առավոտը',
        afternoon: 'ցերեկը',
        evening: 'երեկոյան',
        night: 'գիշերը'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'կեսգիշերին',
        noon: 'կեսօրին',
        morning: 'առավոտը',
        afternoon: 'ցերեկը',
        evening: 'երեկոյան',
        night: 'գիշերը'
      }
    };
    var ordinalNumber$J = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      var rem100 = number % 100;
      if (rem100 < 10) {
        if (rem100 % 10 === 1) {
          return number + '֊ին';
        }
      }
      return number + '֊րդ';
    };
    var localize$J = {
      ordinalNumber: ordinalNumber$J,
      era: buildLocalizeFn({
        values: eraValues$J,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$J,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$J,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$J,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$J,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$C,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$J = /^(\d+)((-|֊)?(ին|րդ))?/i;
    var parseOrdinalNumberPattern$J = /\d+/i;
    var matchEraPatterns$J = {
      narrow: /^(Ք|Մ)/i,
      abbreviated: /^(Ք\.?\s?Ա\.?|Մ\.?\s?Թ\.?\s?Ա\.?|Մ\.?\s?Թ\.?|Ք\.?\s?Հ\.?)/i,
      wide: /^(քրիստոսից առաջ|մեր թվարկությունից առաջ|մեր թվարկության|քրիստոսից հետո)/i
    };
    var parseEraPatterns$J = {
      any: [/^ք/i, /^մ/i]
    };
    var matchQuarterPatterns$J = {
      narrow: /^[1234]/i,
      abbreviated: /^ք[1234]/i,
      wide: /^[1234]((-|֊)?(ին|րդ)) քառորդ/i
    };
    var parseQuarterPatterns$J = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$J = {
      narrow: /^[հփմաօսնդ]/i,
      abbreviated: /^(հուն|փետ|մար|ապր|մայ|հուն|հուլ|օգս|սեպ|հոկ|նոյ|դեկ)/i,
      wide: /^(հունվար|փետրվար|մարտ|ապրիլ|մայիս|հունիս|հուլիս|օգոստոս|սեպտեմբեր|հոկտեմբեր|նոյեմբեր|դեկտեմբեր)/i
    };
    var parseMonthPatterns$J = {
      narrow: [/^հ/i, /^փ/i, /^մ/i, /^ա/i, /^մ/i, /^հ/i, /^հ/i, /^օ/i, /^ս/i, /^հ/i, /^ն/i, /^դ/i],
      any: [/^հու/i, /^փ/i, /^մար/i, /^ա/i, /^մայ/i, /^հուն/i, /^հուլ/i, /^օ/i, /^ս/i, /^հոկ/i, /^ն/i, /^դ/i]
    };
    var matchDayPatterns$J = {
      narrow: /^[եչհոշկ]/i,
      short: /^(կր|եր|եք|չք|հգ|ուր|շբ)/i,
      abbreviated: /^(կիր|երկ|երք|չոր|հնգ|ուրբ|շաբ)/i,
      wide: /^(կիրակի|երկուշաբթի|երեքշաբթի|չորեքշաբթի|հինգշաբթի|ուրբաթ|շաբաթ)/i
    };
    var parseDayPatterns$J = {
      narrow: [/^կ/i, /^ե/i, /^ե/i, /^չ/i, /^հ/i, /^(ո|Ո)/, /^շ/i],
      short: [/^կ/i, /^եր/i, /^եք/i, /^չ/i, /^հ/i, /^(ո|Ո)/, /^շ/i],
      abbreviated: [/^կ/i, /^երկ/i, /^երք/i, /^չ/i, /^հ/i, /^(ո|Ո)/, /^շ/i],
      wide: [/^կ/i, /^երկ/i, /^երե/i, /^չ/i, /^հ/i, /^(ո|Ո)/, /^շ/i]
    };
    var matchDayPeriodPatterns$J = {
      narrow: /^([ap]|կեսգշ|կեսօր|(առավոտը?|ցերեկը?|երեկո(յան)?|գիշերը?))/i,
      any: /^([ap]\.?\s?m\.?|կեսգիշեր(ին)?|կեսօր(ին)?|(առավոտը?|ցերեկը?|երեկո(յան)?|գիշերը?))/i
    };
    var parseDayPeriodPatterns$J = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /կեսգիշեր/i,
        noon: /կեսօր/i,
        morning: /առավոտ/i,
        afternoon: /ցերեկ/i,
        evening: /երեկո/i,
        night: /գիշեր/i
      }
    };
    var match$J = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$J,
        parsePattern: parseOrdinalNumberPattern$J,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$J,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$J,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$J,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$J,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$J,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$J,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$J,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$J,
        defaultParseWidth: 'wide'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$J,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$J,
        defaultParseWidth: 'any'
      })
    };

    var locale$K = {
      code: 'hy',
      formatDistance: formatDistance$J,
      formatLong: formatLong$K,
      formatRelative: formatRelative$J,
      localize: localize$J,
      match: match$J,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$I = {
      lessThanXSeconds: {
        one: 'kurang dari 1 detik',
        other: 'kurang dari {{count}} detik'
      },
      xSeconds: {
        one: '1 detik',
        other: '{{count}} detik'
      },
      halfAMinute: 'setengah menit',
      lessThanXMinutes: {
        one: 'kurang dari 1 menit',
        other: 'kurang dari {{count}} menit'
      },
      xMinutes: {
        one: '1 menit',
        other: '{{count}} menit'
      },
      aboutXHours: {
        one: 'sekitar 1 jam',
        other: 'sekitar {{count}} jam'
      },
      xHours: {
        one: '1 jam',
        other: '{{count}} jam'
      },
      xDays: {
        one: '1 hari',
        other: '{{count}} hari'
      },
      aboutXWeeks: {
        one: 'sekitar 1 minggu',
        other: 'sekitar {{count}} minggu'
      },
      xWeeks: {
        one: '1 minggu',
        other: '{{count}} minggu'
      },
      aboutXMonths: {
        one: 'sekitar 1 bulan',
        other: 'sekitar {{count}} bulan'
      },
      xMonths: {
        one: '1 bulan',
        other: '{{count}} bulan'
      },
      aboutXYears: {
        one: 'sekitar 1 tahun',
        other: 'sekitar {{count}} tahun'
      },
      xYears: {
        one: '1 tahun',
        other: '{{count}} tahun'
      },
      overXYears: {
        one: 'lebih dari 1 tahun',
        other: 'lebih dari {{count}} tahun'
      },
      almostXYears: {
        one: 'hampir 1 tahun',
        other: 'hampir {{count}} tahun'
      }
    };
    var formatDistance$I = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$I[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'dalam waktu ' + result;
        } else {
          return result + ' yang lalu';
        }
      }
      return result;
    };

    var dateFormats$J = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'd/M/yyyy'
    };
    var timeFormats$J = {
      full: 'HH.mm.ss',
      long: 'HH.mm.ss',
      medium: 'HH.mm',
      short: 'HH.mm'
    };
    var dateTimeFormats$J = {
      full: "{{date}} 'pukul' {{time}}",
      long: "{{date}} 'pukul' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$J = {
      date: buildFormatLongFn({
        formats: dateFormats$J,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$J,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$J,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$I = {
      lastWeek: "eeee 'lalu pukul' p",
      yesterday: "'Kemarin pukul' p",
      today: "'Hari ini pukul' p",
      tomorrow: "'Besok pukul' p",
      nextWeek: "eeee 'pukul' p",
      other: 'P'
    };
    var formatRelative$I = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$I[token];
    };

    var eraValues$I = {
      narrow: ['SM', 'M'],
      abbreviated: ['SM', 'M'],
      wide: ['Sebelum Masehi', 'Masehi']
    };
    var quarterValues$I = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['Kuartal ke-1', 'Kuartal ke-2', 'Kuartal ke-3', 'Kuartal ke-4']
    };
    var monthValues$I = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun', 'Jul', 'Agt', 'Sep', 'Okt', 'Nov', 'Des'],
      wide: ['Januari', 'Februari', 'Maret', 'April', 'Mei', 'Juni', 'Juli', 'Agustus', 'September', 'Oktober', 'November', 'Desember']
    };
    var dayValues$I = {
      narrow: ['M', 'S', 'S', 'R', 'K', 'J', 'S'],
      short: ['Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum', 'Sab'],
      abbreviated: ['Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum', 'Sab'],
      wide: ['Minggu', 'Senin', 'Selasa', 'Rabu', 'Kamis', 'Jumat', 'Sabtu']
    };
    var dayPeriodValues$I = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      }
    };
    var formattingDayPeriodValues$B = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      }
    };
    var ordinalNumber$I = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return 'ke-' + number;
    };
    var localize$I = {
      ordinalNumber: ordinalNumber$I,
      era: buildLocalizeFn({
        values: eraValues$I,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$I,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$I,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$I,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$I,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$B,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$I = /^ke-(\d+)?/i;
    var parseOrdinalNumberPattern$I = /\d+/i;
    var matchEraPatterns$I = {
      narrow: /^(sm|m)/i,
      abbreviated: /^(s\.?\s?m\.?|s\.?\s?e\.?\s?u\.?|m\.?|e\.?\s?u\.?)/i,
      wide: /^(sebelum masehi|sebelum era umum|masehi|era umum)/i
    };
    var parseEraPatterns$I = {
      any: [/^s/i, /^(m|e)/i]
    };
    var matchQuarterPatterns$I = {
      narrow: /^[1234]/i,
      abbreviated: /^K-?\s[1234]/i,
      wide: /^Kuartal ke-?\s?[1234]/i
    };
    var parseQuarterPatterns$I = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$I = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|mei|jun|jul|agt|sep|okt|nov|des)/i,
      wide: /^(januari|februari|maret|april|mei|juni|juli|agustus|september|oktober|november|desember)/i
    };
    var parseMonthPatterns$I = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^ma/i, /^ap/i, /^me/i, /^jun/i, /^jul/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$I = {
      narrow: /^[srkjm]/i,
      short: /^(min|sen|sel|rab|kam|jum|sab)/i,
      abbreviated: /^(min|sen|sel|rab|kam|jum|sab)/i,
      wide: /^(minggu|senin|selasa|rabu|kamis|jumat|sabtu)/i
    };
    var parseDayPatterns$I = {
      narrow: [/^m/i, /^s/i, /^s/i, /^r/i, /^k/i, /^j/i, /^s/i],
      any: [/^m/i, /^sen/i, /^sel/i, /^r/i, /^k/i, /^j/i, /^sa/i]
    };
    var matchDayPeriodPatterns$I = {
      narrow: /^(a|p|tengah m|tengah h|(di(\swaktu)?) (pagi|siang|sore|malam))/i,
      any: /^([ap]\.?\s?m\.?|tengah malam|tengah hari|(di(\swaktu)?) (pagi|siang|sore|malam))/i
    };
    var parseDayPeriodPatterns$I = {
      any: {
        am: /^a/i,
        pm: /^pm/i,
        midnight: /^tengah m/i,
        noon: /^tengah h/i,
        morning: /pagi/i,
        afternoon: /siang/i,
        evening: /sore/i,
        night: /malam/i
      }
    };
    var match$I = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$I,
        parsePattern: parseOrdinalNumberPattern$I,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$I,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$I,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$I,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$I,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$I,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$I,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$I,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$I,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$I,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$I,
        defaultParseWidth: 'any'
      })
    };

    var locale$J = {
      code: 'id',
      formatDistance: formatDistance$I,
      formatLong: formatLong$J,
      formatRelative: formatRelative$I,
      localize: localize$I,
      match: match$I,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$H = {
      lessThanXSeconds: {
        one: 'minna en 1 sekúnda',
        other: 'minna en {{count}} sekúndur'
      },
      xSeconds: {
        one: '1 sekúnda',
        other: '{{count}} sekúndur'
      },
      halfAMinute: 'hálf mínúta',
      lessThanXMinutes: {
        one: 'minna en 1 mínúta',
        other: 'minna en {{count}} mínútur'
      },
      xMinutes: {
        one: '1 mínúta',
        other: '{{count}} mínútur'
      },
      aboutXHours: {
        one: 'u.þ.b. 1 klukkustund',
        other: 'u.þ.b. {{count}} klukkustundir'
      },
      xHours: {
        one: '1 klukkustund',
        other: '{{count}} klukkustundir'
      },
      xDays: {
        one: '1 dagur',
        other: '{{count}} dagar'
      },
      aboutXWeeks: {
        one: 'um viku',
        other: 'um {{count}} vikur'
      },
      xWeeks: {
        one: '1 viku',
        other: '{{count}} vikur'
      },
      aboutXMonths: {
        one: 'u.þ.b. 1 mánuður',
        other: 'u.þ.b. {{count}} mánuðir'
      },
      xMonths: {
        one: '1 mánuður',
        other: '{{count}} mánuðir'
      },
      aboutXYears: {
        one: 'u.þ.b. 1 ár',
        other: 'u.þ.b. {{count}} ár'
      },
      xYears: {
        one: '1 ár',
        other: '{{count}} ár'
      },
      overXYears: {
        one: 'meira en 1 ár',
        other: 'meira en {{count}} ár'
      },
      almostXYears: {
        one: 'næstum 1 ár',
        other: 'næstum {{count}} ár'
      }
    };
    var formatDistance$H = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$H[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'í ' + result;
        } else {
          return result + ' síðan';
        }
      }
      return result;
    };

    var dateFormats$I = {
      full: 'EEEE, do MMMM y',
      long: 'do MMMM y',
      medium: 'do MMM y',
      short: 'd.MM.y'
    };
    var timeFormats$I = {
      full: "'kl'. HH:mm:ss zzzz",
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$I = {
      full: "{{date}} 'kl.' {{time}}",
      long: "{{date}} 'kl.' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$I = {
      date: buildFormatLongFn({
        formats: dateFormats$I,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$I,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$I,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$H = {
      lastWeek: "'síðasta' dddd 'kl.' p",
      yesterday: "'í gær kl.' p",
      today: "'í dag kl.' p",
      tomorrow: "'á morgun kl.' p",
      nextWeek: "dddd 'kl.' p",
      other: 'P'
    };
    var formatRelative$H = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$H[token];
    };

    var eraValues$H = {
      narrow: ['f.Kr.', 'e.Kr.'],
      abbreviated: ['f.Kr.', 'e.Kr.'],
      wide: ['fyrir Krist', 'eftir Krist']
    };
    var quarterValues$H = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1F', '2F', '3F', '4F'],
      wide: ['1. fjórðungur', '2. fjórðungur', '3. fjórðungur', '4. fjórðungur']
    };
    var monthValues$H = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'Á', 'S', 'Ó', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mars', 'apríl', 'maí', 'júní', 'júlí', 'ágúst', 'sept.', 'okt.', 'nóv.', 'des.'],
      wide: ['janúar', 'febrúar', 'mars', 'apríl', 'maí', 'júní', 'júlí', 'ágúst', 'september', 'október', 'nóvember', 'desember']
    };
    var dayValues$H = {
      narrow: ['S', 'M', 'Þ', 'M', 'F', 'F', 'L'],
      short: ['Su', 'Má', 'Þr', 'Mi', 'Fi', 'Fö', 'La'],
      abbreviated: ['sun.', 'mán.', 'þri.', 'mið.', 'fim.', 'fös.', 'lau.'],
      wide: ['sunnudagur', 'mánudagur', 'þriðjudagur', 'miðvikudagur', 'fimmtudagur', 'föstudagur', 'laugardagur']
    };
    var dayPeriodValues$H = {
      narrow: {
        am: 'f',
        pm: 'e',
        midnight: 'miðnætti',
        noon: 'hádegi',
        morning: 'morgunn',
        afternoon: 'síðdegi',
        evening: 'kvöld',
        night: 'nótt'
      },
      abbreviated: {
        am: 'f.h.',
        pm: 'e.h.',
        midnight: 'miðnætti',
        noon: 'hádegi',
        morning: 'morgunn',
        afternoon: 'síðdegi',
        evening: 'kvöld',
        night: 'nótt'
      },
      wide: {
        am: 'fyrir hádegi',
        pm: 'eftir hádegi',
        midnight: 'miðnætti',
        noon: 'hádegi',
        morning: 'morgunn',
        afternoon: 'síðdegi',
        evening: 'kvöld',
        night: 'nótt'
      }
    };
    var formattingDayPeriodValues$A = {
      narrow: {
        am: 'f',
        pm: 'e',
        midnight: 'á miðnætti',
        noon: 'á hádegi',
        morning: 'að morgni',
        afternoon: 'síðdegis',
        evening: 'um kvöld',
        night: 'um nótt'
      },
      abbreviated: {
        am: 'f.h.',
        pm: 'e.h.',
        midnight: 'á miðnætti',
        noon: 'á hádegi',
        morning: 'að morgni',
        afternoon: 'síðdegis',
        evening: 'um kvöld',
        night: 'um nótt'
      },
      wide: {
        am: 'fyrir hádegi',
        pm: 'eftir hádegi',
        midnight: 'á miðnætti',
        noon: 'á hádegi',
        morning: 'að morgni',
        afternoon: 'síðdegis',
        evening: 'um kvöld',
        night: 'um nótt'
      }
    };
    var ordinalNumber$H = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$H = {
      ordinalNumber: ordinalNumber$H,
      era: buildLocalizeFn({
        values: eraValues$H,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$H,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$H,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$H,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$H,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$A,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$H = /^(\d+)(\.)?/i;
    var parseOrdinalNumberPattern$H = /\d+(\.)?/i;
    var matchEraPatterns$H = {
      narrow: /^(f\.Kr\.|e\.Kr\.)/i,
      abbreviated: /^(f\.Kr\.|e\.Kr\.)/i,
      wide: /^(fyrir Krist|eftir Krist)/i
    };
    var parseEraPatterns$H = {
      any: [/^(f\.Kr\.)/i, /^(e\.Kr\.)/i]
    };
    var matchQuarterPatterns$H = {
      narrow: /^[1234]\.?/i,
      abbreviated: /^q[1234]\.?/i,
      wide: /^[1234]\.? fjórðungur/i
    };
    var parseQuarterPatterns$H = {
      any: [/1\.?/i, /2\.?/i, /3\.?/i, /4\.?/i]
    };
    var matchMonthPatterns$H = {
      narrow: /^[jfmásónd]/i,
      abbreviated: /^(jan\.|feb\.|mars\.|apríl\.|maí|júní|júlí|águst|sep\.|oct\.|nov\.|dec\.)/i,
      wide: /^(januar|febrúar|mars|apríl|maí|júní|júlí|águst|september|október|nóvember|desember)/i
    };
    var parseMonthPatterns$H = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^á/i, /^s/i, /^ó/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^maí/i, /^jún/i, /^júl/i, /^áu/i, /^s/i, /^ó/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$H = {
      narrow: /^[smtwf]/i,
      short: /^(su|má|þr|mi|fi|fö|la)/i,
      abbreviated: /^(sun|mán|þri|mið|fim|fös|lau)\.?/i,
      wide: /^(sunnudagur|mánudagur|þriðjudagur|miðvikudagur|fimmtudagur|föstudagur|laugardagur)/i
    };
    var parseDayPatterns$H = {
      narrow: [/^s/i, /^m/i, /^þ/i, /^m/i, /^f/i, /^f/i, /^l/i],
      any: [/^su/i, /^má/i, /^þr/i, /^mi/i, /^fi/i, /^fö/i, /^la/i]
    };
    var matchDayPeriodPatterns$H = {
      narrow: /^(f|e|síðdegis|(á|að|um) (morgni|kvöld|nótt|miðnætti))/i,
      any: /^(fyrir hádegi|eftir hádegi|[ef]\.?h\.?|síðdegis|morgunn|(á|að|um) (morgni|kvöld|nótt|miðnætti))/i
    };
    var parseDayPeriodPatterns$H = {
      any: {
        am: /^f/i,
        pm: /^e/i,
        midnight: /^mi/i,
        noon: /^há/i,
        morning: /morgunn/i,
        afternoon: /síðdegi/i,
        evening: /kvöld/i,
        night: /nótt/i
      }
    };
    var match$H = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$H,
        parsePattern: parseOrdinalNumberPattern$H,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$H,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$H,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$H,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$H,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$H,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$H,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$H,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$H,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$H,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$H,
        defaultParseWidth: 'any'
      })
    };

    var locale$I = {
      code: 'is',
      formatDistance: formatDistance$H,
      formatLong: formatLong$I,
      formatRelative: formatRelative$H,
      localize: localize$H,
      match: match$H,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$G = {
      lessThanXSeconds: {
        one: 'meno di un secondo',
        other: 'meno di {{count}} secondi'
      },
      xSeconds: {
        one: 'un secondo',
        other: '{{count}} secondi'
      },
      halfAMinute: 'alcuni secondi',
      lessThanXMinutes: {
        one: 'meno di un minuto',
        other: 'meno di {{count}} minuti'
      },
      xMinutes: {
        one: 'un minuto',
        other: '{{count}} minuti'
      },
      aboutXHours: {
        one: "circa un'ora",
        other: 'circa {{count}} ore'
      },
      xHours: {
        one: "un'ora",
        other: '{{count}} ore'
      },
      xDays: {
        one: 'un giorno',
        other: '{{count}} giorni'
      },
      aboutXWeeks: {
        one: 'circa una settimana',
        other: 'circa {{count}} settimane'
      },
      xWeeks: {
        one: 'una settimana',
        other: '{{count}} settimane'
      },
      aboutXMonths: {
        one: 'circa un mese',
        other: 'circa {{count}} mesi'
      },
      xMonths: {
        one: 'un mese',
        other: '{{count}} mesi'
      },
      aboutXYears: {
        one: 'circa un anno',
        other: 'circa {{count}} anni'
      },
      xYears: {
        one: 'un anno',
        other: '{{count}} anni'
      },
      overXYears: {
        one: 'più di un anno',
        other: 'più di {{count}} anni'
      },
      almostXYears: {
        one: 'quasi un anno',
        other: 'quasi {{count}} anni'
      }
    };
    var formatDistance$G = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$G[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'tra ' + result;
        } else {
          return result + ' fa';
        }
      }
      return result;
    };

    var dateFormats$H = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$H = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$H = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$H = {
      date: buildFormatLongFn({
        formats: dateFormats$H,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$H,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$H,
        defaultWidth: 'full'
      })
    };

    var weekdays$2 = ['domenica', 'lunedì', 'martedì', 'mercoledì', 'giovedì', 'venerdì', 'sabato'];
    function lastWeek$5(day) {
      switch (day) {
        case 0:
          return "'domenica scorsa alle' p";
        default:
          return "'" + weekdays$2[day] + " scorso alle' p";
      }
    }
    function thisWeek$5(day) {
      return "'" + weekdays$2[day] + " alle' p";
    }
    function nextWeek$5(day) {
      switch (day) {
        case 0:
          return "'domenica prossima alle' p";
        default:
          return "'" + weekdays$2[day] + " prossimo alle' p";
      }
    }
    var formatRelativeLocale$G = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$5(day);
        } else {
          return lastWeek$5(day);
        }
      },
      yesterday: "'ieri alle' p",
      today: "'oggi alle' p",
      tomorrow: "'domani alle' p",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$5(day);
        } else {
          return nextWeek$5(day);
        }
      },
      other: 'P'
    };
    var formatRelative$G = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$G[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$G = {
      narrow: ['aC', 'dC'],
      abbreviated: ['a.C.', 'd.C.'],
      wide: ['avanti Cristo', 'dopo Cristo']
    };
    var quarterValues$G = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$G = {
      narrow: ['G', 'F', 'M', 'A', 'M', 'G', 'L', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['gen', 'feb', 'mar', 'apr', 'mag', 'giu', 'lug', 'ago', 'set', 'ott', 'nov', 'dic'],
      wide: ['gennaio', 'febbraio', 'marzo', 'aprile', 'maggio', 'giugno', 'luglio', 'agosto', 'settembre', 'ottobre', 'novembre', 'dicembre']
    };
    var dayValues$G = {
      narrow: ['D', 'L', 'M', 'M', 'G', 'V', 'S'],
      short: ['dom', 'lun', 'mar', 'mer', 'gio', 'ven', 'sab'],
      abbreviated: ['dom', 'lun', 'mar', 'mer', 'gio', 'ven', 'sab'],
      wide: ['domenica', 'lunedì', 'martedì', 'mercoledì', 'giovedì', 'venerdì', 'sabato']
    };
    var dayPeriodValues$G = {
      narrow: {
        am: 'm.',
        pm: 'p.',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'mattina',
        afternoon: 'pomeriggio',
        evening: 'sera',
        night: 'notte'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'mattina',
        afternoon: 'pomeriggio',
        evening: 'sera',
        night: 'notte'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'mattina',
        afternoon: 'pomeriggio',
        evening: 'sera',
        night: 'notte'
      }
    };
    var formattingDayPeriodValues$z = {
      narrow: {
        am: 'm.',
        pm: 'p.',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'di mattina',
        afternoon: 'del pomeriggio',
        evening: 'di sera',
        night: 'di notte'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'di mattina',
        afternoon: 'del pomeriggio',
        evening: 'di sera',
        night: 'di notte'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'di mattina',
        afternoon: 'del pomeriggio',
        evening: 'di sera',
        night: 'di notte'
      }
    };
    var ordinalNumber$G = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return String(number);
    };
    var localize$G = {
      ordinalNumber: ordinalNumber$G,
      era: buildLocalizeFn({
        values: eraValues$G,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$G,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$G,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$G,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$G,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$z,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$G = /^(\d+)(º)?/i;
    var parseOrdinalNumberPattern$G = /\d+/i;
    var matchEraPatterns$G = {
      narrow: /^(aC|dC)/i,
      abbreviated: /^(a\.?\s?C\.?|a\.?\s?e\.?\s?v\.?|d\.?\s?C\.?|e\.?\s?v\.?)/i,
      wide: /^(avanti Cristo|avanti Era Volgare|dopo Cristo|Era Volgare)/i
    };
    var parseEraPatterns$G = {
      any: [/^a/i, /^(d|e)/i]
    };
    var matchQuarterPatterns$G = {
      narrow: /^[1234]/i,
      abbreviated: /^t[1234]/i,
      wide: /^[1234](º)? trimestre/i
    };
    var parseQuarterPatterns$G = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$G = {
      narrow: /^[gfmalsond]/i,
      abbreviated: /^(gen|feb|mar|apr|mag|giu|lug|ago|set|ott|nov|dic)/i,
      wide: /^(gennaio|febbraio|marzo|aprile|maggio|giugno|luglio|agosto|settembre|ottobre|novembre|dicembre)/i
    };
    var parseMonthPatterns$G = {
      narrow: [/^g/i, /^f/i, /^m/i, /^a/i, /^m/i, /^g/i, /^l/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ge/i, /^f/i, /^mar/i, /^ap/i, /^mag/i, /^gi/i, /^l/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$G = {
      narrow: /^[dlmgvs]/i,
      short: /^(do|lu|ma|me|gi|ve|sa)/i,
      abbreviated: /^(dom|lun|mar|mer|gio|ven|sab)/i,
      wide: /^(domenica|luned[i|ì]|marted[i|ì]|mercoled[i|ì]|gioved[i|ì]|venerd[i|ì]|sabato)/i
    };
    var parseDayPatterns$G = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^g/i, /^v/i, /^s/i],
      any: [/^d/i, /^l/i, /^ma/i, /^me/i, /^g/i, /^v/i, /^s/i]
    };
    var matchDayPeriodPatterns$G = {
      narrow: /^(a|m\.|p|mezzanotte|mezzogiorno|(di|del) (mattina|pomeriggio|sera|notte))/i,
      any: /^([ap]\.?\s?m\.?|mezzanotte|mezzogiorno|(di|del) (mattina|pomeriggio|sera|notte))/i
    };
    var parseDayPeriodPatterns$G = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mezza/i,
        noon: /^mezzo/i,
        morning: /mattina/i,
        afternoon: /pomeriggio/i,
        evening: /sera/i,
        night: /notte/i
      }
    };
    var match$G = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$G,
        parsePattern: parseOrdinalNumberPattern$G,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$G,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$G,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$G,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$G,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$G,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$G,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$G,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$G,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$G,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$G,
        defaultParseWidth: 'any'
      })
    };

    var locale$H = {
      code: 'it',
      formatDistance: formatDistance$G,
      formatLong: formatLong$H,
      formatRelative: formatRelative$G,
      localize: localize$G,
      match: match$G,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var dateFormats$G = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$G = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$G = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$G = {
      date: buildFormatLongFn({
        formats: dateFormats$G,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$G,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$G,
        defaultWidth: 'full'
      })
    };

    var locale$G = {
      code: 'it-CH',
      formatDistance: formatDistance$G,
      formatLong: formatLong$G,
      formatRelative: formatRelative$G,
      localize: localize$G,
      match: match$G,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$F = {
      lessThanXSeconds: {
        one: '1秒未満',
        other: '{{count}}秒未満',
        oneWithSuffix: '約1秒',
        otherWithSuffix: '約{{count}}秒'
      },
      xSeconds: {
        one: '1秒',
        other: '{{count}}秒'
      },
      halfAMinute: '30秒',
      lessThanXMinutes: {
        one: '1分未満',
        other: '{{count}}分未満',
        oneWithSuffix: '約1分',
        otherWithSuffix: '約{{count}}分'
      },
      xMinutes: {
        one: '1分',
        other: '{{count}}分'
      },
      aboutXHours: {
        one: '約1時間',
        other: '約{{count}}時間'
      },
      xHours: {
        one: '1時間',
        other: '{{count}}時間'
      },
      xDays: {
        one: '1日',
        other: '{{count}}日'
      },
      aboutXWeeks: {
        one: '約1週間',
        other: '約{{count}}週間'
      },
      xWeeks: {
        one: '1週間',
        other: '{{count}}週間'
      },
      aboutXMonths: {
        one: '約1か月',
        other: '約{{count}}か月'
      },
      xMonths: {
        one: '1か月',
        other: '{{count}}か月'
      },
      aboutXYears: {
        one: '約1年',
        other: '約{{count}}年'
      },
      xYears: {
        one: '1年',
        other: '{{count}}年'
      },
      overXYears: {
        one: '1年以上',
        other: '{{count}}年以上'
      },
      almostXYears: {
        one: '1年近く',
        other: '{{count}}年近く'
      }
    };
    var formatDistance$F = function (token, count, options) {
      options = options || {};
      var result;
      var tokenValue = formatDistanceLocale$F[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        if (options.addSuffix && tokenValue.oneWithSuffix) {
          result = tokenValue.oneWithSuffix;
        } else {
          result = tokenValue.one;
        }
      } else {
        if (options.addSuffix && tokenValue.otherWithSuffix) {
          result = tokenValue.otherWithSuffix.replace('{{count}}', String(count));
        } else {
          result = tokenValue.other.replace('{{count}}', String(count));
        }
      }
      if (options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + '後';
        } else {
          return result + '前';
        }
      }
      return result;
    };

    var dateFormats$F = {
      full: 'y年M月d日EEEE',
      long: 'y年M月d日',
      medium: 'y/MM/dd',
      short: 'y/MM/dd'
    };
    var timeFormats$F = {
      full: 'H時mm分ss秒 zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$F = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$F = {
      date: buildFormatLongFn({
        formats: dateFormats$F,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$F,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$F,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$F = {
      lastWeek: '先週のeeeeのp',
      yesterday: '昨日のp',
      today: '今日のp',
      tomorrow: '明日のp',
      nextWeek: '翌週のeeeeのp',
      other: 'P'
    };
    var formatRelative$F = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$F[token];
    };

    var eraValues$F = {
      narrow: ['BC', 'AC'],
      abbreviated: ['紀元前', '西暦'],
      wide: ['紀元前', '西暦']
    };
    var quarterValues$F = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['第1四半期', '第2四半期', '第3四半期', '第4四半期']
    };
    var monthValues$F = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      wide: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
    };
    var dayValues$F = {
      narrow: ['日', '月', '火', '水', '木', '金', '土'],
      short: ['日', '月', '火', '水', '木', '金', '土'],
      abbreviated: ['日', '月', '火', '水', '木', '金', '土'],
      wide: ['日曜日', '月曜日', '火曜日', '水曜日', '木曜日', '金曜日', '土曜日']
    };
    var dayPeriodValues$F = {
      narrow: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      abbreviated: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      wide: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      }
    };
    var formattingDayPeriodValues$y = {
      narrow: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      abbreviated: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      wide: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      }
    };
    var ordinalNumber$F = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      switch (unit) {
        case 'year':
          return "".concat(number, "\u5E74");
        case 'quarter':
          return "\u7B2C".concat(number, "\u56DB\u534A\u671F");
        case 'month':
          return "".concat(number, "\u6708");
        case 'week':
          return "\u7B2C".concat(number, "\u9031");
        case 'date':
          return "".concat(number, "\u65E5");
        case 'hour':
          return "".concat(number, "\u6642");
        case 'minute':
          return "".concat(number, "\u5206");
        case 'second':
          return "".concat(number, "\u79D2");
        default:
          return "".concat(number);
      }
    };
    var localize$F = {
      ordinalNumber: ordinalNumber$F,
      era: buildLocalizeFn({
        values: eraValues$F,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$F,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$F,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$F,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$F,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$y,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$F = /^第?\d+(年|四半期|月|週|日|時|分|秒)?/i;
    var parseOrdinalNumberPattern$F = /\d+/i;
    var matchEraPatterns$F = {
      narrow: /^(B\.?C\.?|A\.?D\.?)/i,
      abbreviated: /^(紀元[前後]|西暦)/i,
      wide: /^(紀元[前後]|西暦)/i
    };
    var parseEraPatterns$F = {
      narrow: [/^B/i, /^A/i],
      any: [/^(紀元前)/i, /^(西暦|紀元後)/i]
    };
    var matchQuarterPatterns$F = {
      narrow: /^[1234]/i,
      abbreviated: /^Q[1234]/i,
      wide: /^第[1234一二三四１２３４]四半期/i
    };
    var parseQuarterPatterns$F = {
      any: [/(1|一|１)/i, /(2|二|２)/i, /(3|三|３)/i, /(4|四|４)/i]
    };
    var matchMonthPatterns$F = {
      narrow: /^([123456789]|1[012])/,
      abbreviated: /^([123456789]|1[012])月/i,
      wide: /^([123456789]|1[012])月/i
    };
    var parseMonthPatterns$F = {
      any: [/^1\D/, /^2/, /^3/, /^4/, /^5/, /^6/, /^7/, /^8/, /^9/, /^10/, /^11/, /^12/]
    };
    var matchDayPatterns$F = {
      narrow: /^[日月火水木金土]/,
      short: /^[日月火水木金土]/,
      abbreviated: /^[日月火水木金土]/,
      wide: /^[日月火水木金土]曜日/
    };
    var parseDayPatterns$F = {
      any: [/^日/, /^月/, /^火/, /^水/, /^木/, /^金/, /^土/]
    };
    var matchDayPeriodPatterns$F = {
      any: /^(AM|PM|午前|午後|正午|深夜|真夜中|夜|朝)/i
    };
    var parseDayPeriodPatterns$F = {
      any: {
        am: /^(A|午前)/i,
        pm: /^(P|午後)/i,
        midnight: /^深夜|真夜中/i,
        noon: /^正午/i,
        morning: /^朝/i,
        afternoon: /^午後/i,
        evening: /^夜/i,
        night: /^深夜/i
      }
    };
    var match$F = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$F,
        parsePattern: parseOrdinalNumberPattern$F,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$F,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$F,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$F,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$F,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$F,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$F,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$F,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$F,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$F,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$F,
        defaultParseWidth: 'any'
      })
    };

    var locale$F = {
      code: 'ja',
      formatDistance: formatDistance$F,
      formatLong: formatLong$F,
      formatRelative: formatRelative$F,
      localize: localize$F,
      match: match$F,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$E = {
      lessThanXSeconds: {
        one: '1びょうみまん',
        other: '{{count}}びょうみまん',
        oneWithSuffix: 'やく1びょう',
        otherWithSuffix: 'やく{{count}}びょう'
      },
      xSeconds: {
        one: '1びょう',
        other: '{{count}}びょう'
      },
      halfAMinute: '30びょう',
      lessThanXMinutes: {
        one: '1ぷんみまん',
        other: '{{count}}ふんみまん',
        oneWithSuffix: 'やく1ぷん',
        otherWithSuffix: 'やく{{count}}ふん'
      },
      xMinutes: {
        one: '1ぷん',
        other: '{{count}}ふん'
      },
      aboutXHours: {
        one: 'やく1じかん',
        other: 'やく{{count}}じかん'
      },
      xHours: {
        one: '1じかん',
        other: '{{count}}じかん'
      },
      xDays: {
        one: '1にち',
        other: '{{count}}にち'
      },
      aboutXWeeks: {
        one: 'やく1しゅうかん',
        other: 'やく{{count}}しゅうかん'
      },
      xWeeks: {
        one: '1しゅうかん',
        other: '{{count}}しゅうかん'
      },
      aboutXMonths: {
        one: 'やく1かげつ',
        other: 'やく{{count}}かげつ'
      },
      xMonths: {
        one: '1かげつ',
        other: '{{count}}かげつ'
      },
      aboutXYears: {
        one: 'やく1ねん',
        other: 'やく{{count}}ねん'
      },
      xYears: {
        one: '1ねん',
        other: '{{count}}ねん'
      },
      overXYears: {
        one: '1ねんいじょう',
        other: '{{count}}ねんいじょう'
      },
      almostXYears: {
        one: '1ねんちかく',
        other: '{{count}}ねんちかく'
      }
    };
    var formatDistance$E = function (token, count, options) {
      options = options || {};
      var result;
      var tokenValue = formatDistanceLocale$E[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        if (options.addSuffix && tokenValue.oneWithSuffix) {
          result = tokenValue.oneWithSuffix;
        } else {
          result = tokenValue.one;
        }
      } else {
        if (options.addSuffix && tokenValue.otherWithSuffix) {
          result = tokenValue.otherWithSuffix.replace('{{count}}', String(count));
        } else {
          result = tokenValue.other.replace('{{count}}', String(count));
        }
      }
      if (options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + 'あと';
        } else {
          return result + 'まえ';
        }
      }
      return result;
    };

    var dateFormats$E = {
      full: 'yねんMがつdにちEEEE',
      long: 'yねんMがつdにち',
      medium: 'y/MM/dd',
      short: 'y/MM/dd'
    };
    var timeFormats$E = {
      full: 'Hじmmふんssびょう zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$E = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$E = {
      date: buildFormatLongFn({
        formats: dateFormats$E,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$E,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$E,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$E = {
      lastWeek: 'せんしゅうのeeeeのp',
      yesterday: 'きのうのp',
      today: 'きょうのp',
      tomorrow: 'あしたのp',
      nextWeek: 'よくしゅうのeeeeのp',
      other: 'P'
    };
    var formatRelative$E = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$E[token];
    };

    var eraValues$E = {
      narrow: ['BC', 'AC'],
      abbreviated: ['きげんぜん', 'せいれき'],
      wide: ['きげんぜん', 'せいれき']
    };
    var quarterValues$E = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['だい1しはんき', 'だい2しはんき', 'だい3しはんき', 'だい4しはんき']
    };
    var monthValues$E = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['1がつ', '2がつ', '3がつ', '4がつ', '5がつ', '6がつ', '7がつ', '8がつ', '9がつ', '10がつ', '11がつ', '12がつ'],
      wide: ['1がつ', '2がつ', '3がつ', '4がつ', '5がつ', '6がつ', '7がつ', '8がつ', '9がつ', '10がつ', '11がつ', '12がつ']
    };
    var dayValues$E = {
      narrow: ['にち', 'げつ', 'か', 'すい', 'もく', 'きん', 'ど'],
      short: ['にち', 'げつ', 'か', 'すい', 'もく', 'きん', 'ど'],
      abbreviated: ['にち', 'げつ', 'か', 'すい', 'もく', 'きん', 'ど'],
      wide: ['にちようび', 'げつようび', 'かようび', 'すいようび', 'もくようび', 'きんようび', 'どようび']
    };
    var dayPeriodValues$E = {
      narrow: {
        am: 'ごぜん',
        pm: 'ごご',
        midnight: 'しんや',
        noon: 'しょうご',
        morning: 'あさ',
        afternoon: 'ごご',
        evening: 'よる',
        night: 'しんや'
      },
      abbreviated: {
        am: 'ごぜん',
        pm: 'ごご',
        midnight: 'しんや',
        noon: 'しょうご',
        morning: 'あさ',
        afternoon: 'ごご',
        evening: 'よる',
        night: 'しんや'
      },
      wide: {
        am: 'ごぜん',
        pm: 'ごご',
        midnight: 'しんや',
        noon: 'しょうご',
        morning: 'あさ',
        afternoon: 'ごご',
        evening: 'よる',
        night: 'しんや'
      }
    };
    var formattingDayPeriodValues$x = {
      narrow: {
        am: 'ごぜん',
        pm: 'ごご',
        midnight: 'しんや',
        noon: 'しょうご',
        morning: 'あさ',
        afternoon: 'ごご',
        evening: 'よる',
        night: 'しんや'
      },
      abbreviated: {
        am: 'ごぜん',
        pm: 'ごご',
        midnight: 'しんや',
        noon: 'しょうご',
        morning: 'あさ',
        afternoon: 'ごご',
        evening: 'よる',
        night: 'しんや'
      },
      wide: {
        am: 'ごぜん',
        pm: 'ごご',
        midnight: 'しんや',
        noon: 'しょうご',
        morning: 'あさ',
        afternoon: 'ごご',
        evening: 'よる',
        night: 'しんや'
      }
    };
    var ordinalNumber$E = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      switch (unit) {
        case 'year':
          return "".concat(number, "\u306D\u3093");
        case 'quarter':
          return "\u3060\u3044".concat(number, "\u3057\u306F\u3093\u304D");
        case 'month':
          return "".concat(number, "\u304C\u3064");
        case 'week':
          return "\u3060\u3044".concat(number, "\u3057\u3085\u3046");
        case 'date':
          return "".concat(number, "\u306B\u3061");
        case 'hour':
          return "".concat(number, "\u3058");
        case 'minute':
          return "".concat(number, "\u3075\u3093");
        case 'second':
          return "".concat(number, "\u3073\u3087\u3046");
        default:
          return "".concat(number);
      }
    };
    var localize$E = {
      ordinalNumber: ordinalNumber$E,
      era: buildLocalizeFn({
        values: eraValues$E,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$E,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$E,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$E,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$E,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$x,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$E = /^だ?い?\d+(ねん|しはんき|がつ|しゅう|にち|じ|ふん|びょう)?/i;
    var parseOrdinalNumberPattern$E = /\d+/i;
    var matchEraPatterns$E = {
      narrow: /^(B\.?C\.?|A\.?D\.?)/i,
      abbreviated: /^(きげん[前後]|せいれき)/i,
      wide: /^(きげん[前後]|せいれき)/i
    };
    var parseEraPatterns$E = {
      narrow: [/^B/i, /^A/i],
      any: [/^(きげんぜん)/i, /^(せいれき|きげんご)/i]
    };
    var matchQuarterPatterns$E = {
      narrow: /^[1234]/i,
      abbreviated: /^Q[1234]/i,
      wide: /^だい[1234一二三四１２３４]しはんき/i
    };
    var parseQuarterPatterns$E = {
      any: [/(1|一|１)/i, /(2|二|２)/i, /(3|三|３)/i, /(4|四|４)/i]
    };
    var matchMonthPatterns$E = {
      narrow: /^([123456789]|1[012])/,
      abbreviated: /^([123456789]|1[012])がつ/i,
      wide: /^([123456789]|1[012])がつ/i
    };
    var parseMonthPatterns$E = {
      any: [/^1\D/, /^2/, /^3/, /^4/, /^5/, /^6/, /^7/, /^8/, /^9/, /^10/, /^11/, /^12/]
    };
    var matchDayPatterns$E = {
      narrow: /^(にち|げつ|か|すい|もく|きん|ど)/,
      short: /^(にち|げつ|か|すい|もく|きん|ど)/,
      abbreviated: /^(にち|げつ|か|すい|もく|きん|ど)/,
      wide: /^(にち|げつ|か|すい|もく|きん|ど)ようび/
    };
    var parseDayPatterns$E = {
      any: [/^にち/, /^げつ/, /^か/, /^すい/, /^もく/, /^きん/, /^ど/]
    };
    var matchDayPeriodPatterns$E = {
      any: /^(AM|PM|ごぜん|ごご|しょうご|しんや|まよなか|よる|あさ)/i
    };
    var parseDayPeriodPatterns$E = {
      any: {
        am: /^(A|ごぜん)/i,
        pm: /^(P|ごご)/i,
        midnight: /^しんや|まよなか/i,
        noon: /^しょうご/i,
        morning: /^あさ/i,
        afternoon: /^ごご/i,
        evening: /^よる/i,
        night: /^しんや/i
      }
    };
    var match$E = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$E,
        parsePattern: parseOrdinalNumberPattern$E,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$E,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$E,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$E,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$E,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$E,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$E,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$E,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$E,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$E,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$E,
        defaultParseWidth: 'any'
      })
    };

    var locale$E = {
      code: 'ja-Hira',
      formatDistance: formatDistance$E,
      formatLong: formatLong$E,
      formatRelative: formatRelative$E,
      localize: localize$E,
      match: match$E,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$D = {
      lessThanXSeconds: {
        past: '{{count}} წამზე ნაკლები ხნის წინ',
        present: '{{count}} წამზე ნაკლები',
        future: '{{count}} წამზე ნაკლებში'
      },
      xSeconds: {
        past: '{{count}} წამის წინ',
        present: '{{count}} წამი',
        future: '{{count}} წამში'
      },
      halfAMinute: {
        past: 'ნახევარი წუთის წინ',
        present: 'ნახევარი წუთი',
        future: 'ნახევარი წუთში'
      },
      lessThanXMinutes: {
        past: '{{count}} წუთზე ნაკლები ხნის წინ',
        present: '{{count}} წუთზე ნაკლები',
        future: '{{count}} წუთზე ნაკლებში'
      },
      xMinutes: {
        past: '{{count}} წუთის წინ',
        present: '{{count}} წუთი',
        future: '{{count}} წუთში'
      },
      aboutXHours: {
        past: 'დაახლოებით {{count}} საათის წინ',
        present: 'დაახლოებით {{count}} საათი',
        future: 'დაახლოებით {{count}} საათში'
      },
      xHours: {
        past: '{{count}} საათის წინ',
        present: '{{count}} საათი',
        future: '{{count}} საათში'
      },
      xDays: {
        past: '{{count}} დღის წინ',
        present: '{{count}} დღე',
        future: '{{count}} დღეში'
      },
      aboutXWeeks: {
        past: 'დაახლოებით {{count}} კვირას წინ',
        present: 'დაახლოებით {{count}} კვირა',
        future: 'დაახლოებით {{count}} კვირაში'
      },
      xWeeks: {
        past: '{{count}} კვირას კვირა',
        present: '{{count}} კვირა',
        future: '{{count}} კვირაში'
      },
      aboutXMonths: {
        past: 'დაახლოებით {{count}} თვის წინ',
        present: 'დაახლოებით {{count}} თვე',
        future: 'დაახლოებით {{count}} თვეში'
      },
      xMonths: {
        past: '{{count}} თვის წინ',
        present: '{{count}} თვე',
        future: '{{count}} თვეში'
      },
      aboutXYears: {
        past: 'დაახლოებით {{count}} წლის წინ',
        present: 'დაახლოებით {{count}} წელი',
        future: 'დაახლოებით {{count}} წელში'
      },
      xYears: {
        past: '{{count}} წლის წინ',
        present: '{{count}} წელი',
        future: '{{count}} წელში'
      },
      overXYears: {
        past: '{{count}} წელზე მეტი ხნის წინ',
        present: '{{count}} წელზე მეტი',
        future: '{{count}} წელზე მეტი ხნის შემდეგ'
      },
      almostXYears: {
        past: 'თითქმის {{count}} წლის წინ',
        present: 'თითქმის {{count}} წელი',
        future: 'თითქმის {{count}} წელში'
      }
    };
    var formatDistance$D = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$D[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (options !== null && options !== void 0 && options.addSuffix && options.comparison && options.comparison > 0) {
        result = tokenValue.future.replace('{{count}}', String(count));
      } else if (options !== null && options !== void 0 && options.addSuffix) {
        result = tokenValue.past.replace('{{count}}', String(count));
      } else {
        result = tokenValue.present.replace('{{count}}', String(count));
      }
      return result;
    };

    var dateFormats$D = {
      full: 'EEEE, do MMMM, y',
      long: 'do, MMMM, y',
      medium: 'd, MMM, y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$D = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$D = {
      full: "{{date}} {{time}}'-ზე'",
      long: "{{date}} {{time}}'-ზე'",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$D = {
      date: buildFormatLongFn({
        formats: dateFormats$D,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$D,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$D,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$D = {
      lastWeek: "'წინა' eeee p'-ზე'",
      yesterday: "'გუშინ' p'-ზე'",
      today: "'დღეს' p'-ზე'",
      tomorrow: "'ხვალ' p'-ზე'",
      nextWeek: "'შემდეგი' eeee p'-ზე'",
      other: 'P'
    };
    var formatRelative$D = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$D[token];
    };

    var eraValues$D = {
      narrow: ['ჩ.წ-მდე', 'ჩ.წ'],
      abbreviated: ['ჩვ.წ-მდე', 'ჩვ.წ'],
      wide: ['ჩვენს წელთაღრიცხვამდე', 'ჩვენი წელთაღრიცხვით']
    };
    var quarterValues$D = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-ლი კვ', '2-ე კვ', '3-ე კვ', '4-ე კვ'],
      wide: ['1-ლი კვარტალი', '2-ე კვარტალი', '3-ე კვარტალი', '4-ე კვარტალი']
    };
    var monthValues$D = {
      narrow: ['ია', 'თე', 'მა', 'აპ', 'მს', 'ვნ', 'ვლ', 'აგ', 'სე', 'ოქ', 'ნო', 'დე'],
      abbreviated: ['იან', 'თებ', 'მარ', 'აპრ', 'მაი', 'ივნ', 'ივლ', 'აგვ', 'სექ', 'ოქტ', 'ნოე', 'დეკ'],
      wide: ['იანვარი', 'თებერვალი', 'მარტი', 'აპრილი', 'მაისი', 'ივნისი', 'ივლისი', 'აგვისტო', 'სექტემბერი', 'ოქტომბერი', 'ნოემბერი', 'დეკემბერი']
    };
    var dayValues$D = {
      narrow: ['კვ', 'ორ', 'სა', 'ოთ', 'ხუ', 'პა', 'შა'],
      short: ['კვი', 'ორშ', 'სამ', 'ოთხ', 'ხუთ', 'პარ', 'შაბ'],
      abbreviated: ['კვი', 'ორშ', 'სამ', 'ოთხ', 'ხუთ', 'პარ', 'შაბ'],
      wide: ['კვირა', 'ორშაბათი', 'სამშაბათი', 'ოთხშაბათი', 'ხუთშაბათი', 'პარასკევი', 'შაბათი']
    };
    var dayPeriodValues$D = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'შუაღამე',
        noon: 'შუადღე',
        morning: 'დილა',
        afternoon: 'საღამო',
        evening: 'საღამო',
        night: 'ღამე'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'შუაღამე',
        noon: 'შუადღე',
        morning: 'დილა',
        afternoon: 'საღამო',
        evening: 'საღამო',
        night: 'ღამე'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'შუაღამე',
        noon: 'შუადღე',
        morning: 'დილა',
        afternoon: 'საღამო',
        evening: 'საღამო',
        night: 'ღამე'
      }
    };
    var formattingDayPeriodValues$w = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'შუაღამით',
        noon: 'შუადღისას',
        morning: 'დილით',
        afternoon: 'ნაშუადღევს',
        evening: 'საღამოს',
        night: 'ღამით'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'შუაღამით',
        noon: 'შუადღისას',
        morning: 'დილით',
        afternoon: 'ნაშუადღევს',
        evening: 'საღამოს',
        night: 'ღამით'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'შუაღამით',
        noon: 'შუადღისას',
        morning: 'დილით',
        afternoon: 'ნაშუადღევს',
        evening: 'საღამოს',
        night: 'ღამით'
      }
    };
    var ordinalNumber$D = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      if (number === 1) {
        return number + '-ლი';
      }
      return number + '-ე';
    };
    var localize$D = {
      ordinalNumber: ordinalNumber$D,
      era: buildLocalizeFn({
        values: eraValues$D,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$D,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$D,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$D,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$D,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$w,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$D = /^(\d+)(-ლი|-ე)?/i;
    var parseOrdinalNumberPattern$D = /\d+/i;
    var matchEraPatterns$D = {
      narrow: /^(ჩვ?\.წ)/i,
      abbreviated: /^(ჩვ?\.წ)/i,
      wide: /^(ჩვენს წელთაღრიცხვამდე|ქრისტეშობამდე|ჩვენი წელთაღრიცხვით|ქრისტეშობიდან)/i
    };
    var parseEraPatterns$D = {
      any: [/^(ჩვენს წელთაღრიცხვამდე|ქრისტეშობამდე)/i, /^(ჩვენი წელთაღრიცხვით|ქრისტეშობიდან)/i]
    };
    var matchQuarterPatterns$D = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]-(ლი|ე)? კვ/i,
      wide: /^[1234]-(ლი|ე)? კვარტალი/i
    };
    var parseQuarterPatterns$D = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$D = {
      any: /^(ია|თე|მა|აპ|მს|ვნ|ვლ|აგ|სე|ოქ|ნო|დე)/i
    };
    var parseMonthPatterns$D = {
      any: [/^ია/i, /^თ/i, /^მარ/i, /^აპ/i, /^მაი/i, /^ი?ვნ/i, /^ი?ვლ/i, /^აგ/i, /^ს/i, /^ო/i, /^ნ/i, /^დ/i]
    };
    var matchDayPatterns$D = {
      narrow: /^(კვ|ორ|სა|ოთ|ხუ|პა|შა)/i,
      short: /^(კვი|ორშ|სამ|ოთხ|ხუთ|პარ|შაბ)/i,
      wide: /^(კვირა|ორშაბათი|სამშაბათი|ოთხშაბათი|ხუთშაბათი|პარასკევი|შაბათი)/i
    };
    var parseDayPatterns$D = {
      any: [/^კვ/i, /^ორ/i, /^სა/i, /^ოთ/i, /^ხუ/i, /^პა/i, /^შა/i]
    };
    var matchDayPeriodPatterns$D = {
      any: /^([ap]\.?\s?m\.?|შუაღ|დილ)/i
    };
    var parseDayPeriodPatterns$D = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^შუაღ/i,
        noon: /^შუადღ/i,
        morning: /^დილ/i,
        afternoon: /ნაშუადღევს/i,
        evening: /საღამო/i,
        night: /ღამ/i
      }
    };
    var match$D = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$D,
        parsePattern: parseOrdinalNumberPattern$D,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$D,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$D,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$D,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$D,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$D,
        defaultMatchWidth: 'any',
        parsePatterns: parseMonthPatterns$D,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$D,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$D,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$D,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$D,
        defaultParseWidth: 'any'
      })
    };

    var locale$D = {
      code: 'ka',
      formatDistance: formatDistance$D,
      formatLong: formatLong$D,
      formatRelative: formatRelative$D,
      localize: localize$D,
      match: match$D,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$C = {
      lessThanXSeconds: {
        regular: {
          one: '1 секундтан аз',
          singularNominative: '{{count}} секундтан аз',
          singularGenitive: '{{count}} секундтан аз',
          pluralGenitive: '{{count}} секундтан аз'
        },
        future: {
          one: 'бір секундтан кейін',
          singularNominative: '{{count}} секундтан кейін',
          singularGenitive: '{{count}} секундтан кейін',
          pluralGenitive: '{{count}} секундтан кейін'
        }
      },
      xSeconds: {
        regular: {
          singularNominative: '{{count}} секунд',
          singularGenitive: '{{count}} секунд',
          pluralGenitive: '{{count}} секунд'
        },
        past: {
          singularNominative: '{{count}} секунд бұрын',
          singularGenitive: '{{count}} секунд бұрын',
          pluralGenitive: '{{count}} секунд бұрын'
        },
        future: {
          singularNominative: '{{count}} секундтан кейін',
          singularGenitive: '{{count}} секундтан кейін',
          pluralGenitive: '{{count}} секундтан кейін'
        }
      },
      halfAMinute: function (options) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            return 'жарты минут ішінде';
          } else {
            return 'жарты минут бұрын';
          }
        }
        return 'жарты минут';
      },
      lessThanXMinutes: {
        regular: {
          one: '1 минуттан аз',
          singularNominative: '{{count}} минуттан аз',
          singularGenitive: '{{count}} минуттан аз',
          pluralGenitive: '{{count}} минуттан аз'
        },
        future: {
          one: 'минуттан кем ',
          singularNominative: '{{count}} минуттан кем',
          singularGenitive: '{{count}} минуттан кем',
          pluralGenitive: '{{count}} минуттан кем'
        }
      },
      xMinutes: {
        regular: {
          singularNominative: '{{count}} минут',
          singularGenitive: '{{count}} минут',
          pluralGenitive: '{{count}} минут'
        },
        past: {
          singularNominative: '{{count}} минут бұрын',
          singularGenitive: '{{count}} минут бұрын',
          pluralGenitive: '{{count}} минут бұрын'
        },
        future: {
          singularNominative: '{{count}} минуттан кейін',
          singularGenitive: '{{count}} минуттан кейін',
          pluralGenitive: '{{count}} минуттан кейін'
        }
      },
      aboutXHours: {
        regular: {
          singularNominative: 'шамамен {{count}} сағат',
          singularGenitive: 'шамамен {{count}} сағат',
          pluralGenitive: 'шамамен {{count}} сағат'
        },
        future: {
          singularNominative: 'шамамен {{count}} сағаттан кейін',
          singularGenitive: 'шамамен {{count}} сағаттан кейін',
          pluralGenitive: 'шамамен {{count}} сағаттан кейін'
        }
      },
      xHours: {
        regular: {
          singularNominative: '{{count}} сағат',
          singularGenitive: '{{count}} сағат',
          pluralGenitive: '{{count}} сағат'
        }
      },
      xDays: {
        regular: {
          singularNominative: '{{count}} күн',
          singularGenitive: '{{count}} күн',
          pluralGenitive: '{{count}} күн'
        },
        future: {
          singularNominative: '{{count}} күннен кейін',
          singularGenitive: '{{count}} күннен кейін',
          pluralGenitive: '{{count}} күннен кейін'
        }
      },
      aboutXWeeks: {
        type: 'weeks',
        one: 'шамамен 1 апта',
        other: 'шамамен {{count}} апта'
      },
      xWeeks: {
        type: 'weeks',
        one: '1 апта',
        other: '{{count}} апта'
      },
      aboutXMonths: {
        regular: {
          singularNominative: 'шамамен {{count}} ай',
          singularGenitive: 'шамамен {{count}} ай',
          pluralGenitive: 'шамамен {{count}} ай'
        },
        future: {
          singularNominative: 'шамамен {{count}} айдан кейін',
          singularGenitive: 'шамамен {{count}} айдан кейін',
          pluralGenitive: 'шамамен {{count}} айдан кейін'
        }
      },
      xMonths: {
        regular: {
          singularNominative: '{{count}} ай',
          singularGenitive: '{{count}} ай',
          pluralGenitive: '{{count}} ай'
        }
      },
      aboutXYears: {
        regular: {
          singularNominative: 'шамамен {{count}} жыл',
          singularGenitive: 'шамамен {{count}} жыл',
          pluralGenitive: 'шамамен {{count}} жыл'
        },
        future: {
          singularNominative: 'шамамен {{count}} жылдан кейін',
          singularGenitive: 'шамамен {{count}} жылдан кейін',
          pluralGenitive: 'шамамен {{count}} жылдан кейін'
        }
      },
      xYears: {
        regular: {
          singularNominative: '{{count}} жыл',
          singularGenitive: '{{count}} жыл',
          pluralGenitive: '{{count}} жыл'
        },
        future: {
          singularNominative: '{{count}} жылдан кейін',
          singularGenitive: '{{count}} жылдан кейін',
          pluralGenitive: '{{count}} жылдан кейін'
        }
      },
      overXYears: {
        regular: {
          singularNominative: '{{count}} жылдан астам',
          singularGenitive: '{{count}} жылдан астам',
          pluralGenitive: '{{count}} жылдан астам'
        },
        future: {
          singularNominative: '{{count}} жылдан астам',
          singularGenitive: '{{count}} жылдан астам',
          pluralGenitive: '{{count}} жылдан астам'
        }
      },
      almostXYears: {
        regular: {
          singularNominative: '{{count}} жылға жақын',
          singularGenitive: '{{count}} жылға жақын',
          pluralGenitive: '{{count}} жылға жақын'
        },
        future: {
          singularNominative: '{{count}} жылдан кейін',
          singularGenitive: '{{count}} жылдан кейін',
          pluralGenitive: '{{count}} жылдан кейін'
        }
      }
    };
    function declension$4(scheme, count) {
      if (scheme.one && count === 1) return scheme.one;
      var rem10 = count % 10;
      var rem100 = count % 100;
      if (rem10 === 1 && rem100 !== 11) {
        return scheme.singularNominative.replace('{{count}}', String(count));
      } else if (rem10 >= 2 && rem10 <= 4 && (rem100 < 10 || rem100 > 20)) {
        return scheme.singularGenitive.replace('{{count}}', String(count));
      } else {
        return scheme.pluralGenitive.replace('{{count}}', String(count));
      }
    }
    var formatDistance$C = function (token, count, options) {
      var tokenValue = formatDistanceLocale$C[token];
      if (typeof tokenValue === 'function') return tokenValue(options);
      if (tokenValue.type === 'weeks') {
        return count === 1 ? tokenValue.one : tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          if (tokenValue.future) {
            return declension$4(tokenValue.future, count);
          } else {
            return declension$4(tokenValue.regular, count) + ' кейін';
          }
        } else {
          if (tokenValue.past) {
            return declension$4(tokenValue.past, count);
          } else {
            return declension$4(tokenValue.regular, count) + ' бұрын';
          }
        }
      } else {
        return declension$4(tokenValue.regular, count);
      }
    };

    var dateFormats$C = {
      full: "EEEE, do MMMM y 'ж.'",
      long: "do MMMM y 'ж.'",
      medium: "d MMM y 'ж.'",
      short: 'dd.MM.yyyy'
    };
    var timeFormats$C = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$C = {
      any: '{{date}}, {{time}}'
    };
    var formatLong$C = {
      date: buildFormatLongFn({
        formats: dateFormats$C,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$C,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$C,
        defaultWidth: 'any'
      })
    };

    var accusativeWeekdays$3 = ['жексенбіде', 'дүйсенбіде', 'сейсенбіде', 'сәрсенбіде', 'бейсенбіде', 'жұмада', 'сенбіде'];
    function lastWeek$4(day) {
      var weekday = accusativeWeekdays$3[day];
      return "'өткен " + weekday + " сағат' p'-де'";
    }
    function thisWeek$4(day) {
      var weekday = accusativeWeekdays$3[day];
      return "'" + weekday + " сағат' p'-де'";
    }
    function nextWeek$4(day) {
      var weekday = accusativeWeekdays$3[day];
      return "'келесі " + weekday + " сағат' p'-де'";
    }
    var formatRelativeLocale$C = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$4(day);
        } else {
          return lastWeek$4(day);
        }
      },
      yesterday: "'кеше сағат' p'-де'",
      today: "'бүгін сағат' p'-де'",
      tomorrow: "'ертең сағат' p'-де'",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$4(day);
        } else {
          return nextWeek$4(day);
        }
      },
      other: 'P'
    };
    var formatRelative$C = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$C[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$C = {
      narrow: ['б.з.д.', 'б.з.'],
      abbreviated: ['б.з.д.', 'б.з.'],
      wide: ['біздің заманымызға дейін', 'біздің заманымыз']
    };
    var quarterValues$C = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-ші тоқ.', '2-ші тоқ.', '3-ші тоқ.', '4-ші тоқ.'],
      wide: ['1-ші тоқсан', '2-ші тоқсан', '3-ші тоқсан', '4-ші тоқсан']
    };
    var monthValues$C = {
      narrow: ['Қ', 'А', 'Н', 'С', 'М', 'М', 'Ш', 'Т', 'Қ', 'Қ', 'Қ', 'Ж'],
      abbreviated: ['қаң', 'ақп', 'нау', 'сәу', 'мам', 'мау', 'шіл', 'там', 'қыр', 'қаз', 'қар', 'жел'],
      wide: ['қаңтар', 'ақпан', 'наурыз', 'сәуір', 'мамыр', 'маусым', 'шілде', 'тамыз', 'қыркүйек', 'қазан', 'қараша', 'желтоқсан']
    };
    var formattingMonthValues$9 = {
      narrow: ['Қ', 'А', 'Н', 'С', 'М', 'М', 'Ш', 'Т', 'Қ', 'Қ', 'Қ', 'Ж'],
      abbreviated: ['қаң', 'ақп', 'нау', 'сәу', 'мам', 'мау', 'шіл', 'там', 'қыр', 'қаз', 'қар', 'жел'],
      wide: ['қаңтар', 'ақпан', 'наурыз', 'сәуір', 'мамыр', 'маусым', 'шілде', 'тамыз', 'қыркүйек', 'қазан', 'қараша', 'желтоқсан']
    };
    var dayValues$C = {
      narrow: ['Ж', 'Д', 'С', 'С', 'Б', 'Ж', 'С'],
      short: ['жс', 'дс', 'сс', 'ср', 'бс', 'жм', 'сб'],
      abbreviated: ['жс', 'дс', 'сс', 'ср', 'бс', 'жм', 'сб'],
      wide: ['жексенбі', 'дүйсенбі', 'сейсенбі', 'сәрсенбі', 'бейсенбі', 'жұма', 'сенбі']
    };
    var dayPeriodValues$C = {
      narrow: {
        am: 'ТД',
        pm: 'ТК',
        midnight: 'түн ортасы',
        noon: 'түс',
        morning: 'таң',
        afternoon: 'күндіз',
        evening: 'кеш',
        night: 'түн'
      },
      wide: {
        am: 'ТД',
        pm: 'ТК',
        midnight: 'түн ортасы',
        noon: 'түс',
        morning: 'таң',
        afternoon: 'күндіз',
        evening: 'кеш',
        night: 'түн'
      }
    };
    var formattingDayPeriodValues$v = {
      narrow: {
        am: 'ТД',
        pm: 'ТК',
        midnight: 'түн ортасында',
        noon: 'түс',
        morning: 'таң',
        afternoon: 'күн',
        evening: 'кеш',
        night: 'түн'
      },
      wide: {
        am: 'ТД',
        pm: 'ТК',
        midnight: 'түн ортасында',
        noon: 'түсте',
        morning: 'таңертең',
        afternoon: 'күндіз',
        evening: 'кеште',
        night: 'түнде'
      }
    };
    var suffixes = {
      0: '-ші',
      1: '-ші',
      2: '-ші',
      3: '-ші',
      4: '-ші',
      5: '-ші',
      6: '-шы',
      7: '-ші',
      8: '-ші',
      9: '-шы',
      10: '-шы',
      20: '-шы',
      30: '-шы',
      40: '-шы',
      50: '-ші',
      60: '-шы',
      70: '-ші',
      80: '-ші',
      90: '-шы',
      100: '-ші'
    };
    var ordinalNumber$C = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      var mod10 = number % 10;
      var b = number >= 100 ? 100 : null;
      var suffix = suffixes[number] || suffixes[mod10] || b && suffixes[b] || '';
      return number + suffix;
    };
    var localize$C = {
      ordinalNumber: ordinalNumber$C,
      era: buildLocalizeFn({
        values: eraValues$C,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$C,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$C,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$9,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$C,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$C,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$v,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$C = /^(\d+)(-?(ші|шы))?/i;
    var parseOrdinalNumberPattern$C = /\d+/i;
    var matchEraPatterns$C = {
      narrow: /^((б )?з\.?\s?д\.?)/i,
      abbreviated: /^((б )?з\.?\s?д\.?)/i,
      wide: /^(біздің заманымызға дейін|біздің заманымыз|біздің заманымыздан)/i
    };
    var parseEraPatterns$C = {
      any: [/^б/i, /^з/i]
    };
    var matchQuarterPatterns$C = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?ші)? тоқ.?/i,
      wide: /^[1234](-?ші)? тоқсан/i
    };
    var parseQuarterPatterns$C = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$C = {
      narrow: /^(қ|а|н|с|м|мау|ш|т|қыр|қаз|қар|ж)/i,
      abbreviated: /^(қаң|ақп|нау|сәу|мам|мау|шіл|там|қыр|қаз|қар|жел)/i,
      wide: /^(қаңтар|ақпан|наурыз|сәуір|мамыр|маусым|шілде|тамыз|қыркүйек|қазан|қараша|желтоқсан)/i
    };
    var parseMonthPatterns$C = {
      narrow: [/^қ/i, /^а/i, /^н/i, /^с/i, /^м/i, /^м/i, /^ш/i, /^т/i, /^қ/i, /^қ/i, /^қ/i, /^ж/i],
      abbreviated: [/^қаң/i, /^ақп/i, /^нау/i, /^сәу/i, /^мам/i, /^мау/i, /^шіл/i, /^там/i, /^қыр/i, /^қаз/i, /^қар/i, /^жел/i],
      any: [/^қ/i, /^а/i, /^н/i, /^с/i, /^м/i, /^м/i, /^ш/i, /^т/i, /^қ/i, /^қ/i, /^қ/i, /^ж/i]
    };
    var matchDayPatterns$C = {
      narrow: /^(ж|д|с|с|б|ж|с)/i,
      short: /^(жс|дс|сс|ср|бс|жм|сб)/i,
      wide: /^(жексенбі|дүйсенбі|сейсенбі|сәрсенбі|бейсенбі|жұма|сенбі)/i
    };
    var parseDayPatterns$C = {
      narrow: [/^ж/i, /^д/i, /^с/i, /^с/i, /^б/i, /^ж/i, /^с/i],
      short: [/^жс/i, /^дс/i, /^сс/i, /^ср/i, /^бс/i, /^жм/i, /^сб/i],
      any: [/^ж[ек]/i, /^д[үй]/i, /^сe[й]/i, /^сә[р]/i, /^б[ей]/i, /^ж[ұм]/i, /^се[н]/i]
    };
    var matchDayPeriodPatterns$C = {
      narrow: /^Т\.?\s?[ДК]\.?|түн ортасында|((түсте|таңертең|таңда|таңертең|таңмен|таң|күндіз|күн|кеште|кеш|түнде|түн)\.?)/i,
      wide: /^Т\.?\s?[ДК]\.?|түн ортасында|((түсте|таңертең|таңда|таңертең|таңмен|таң|күндіз|күн|кеште|кеш|түнде|түн)\.?)/i,
      any: /^Т\.?\s?[ДК]\.?|түн ортасында|((түсте|таңертең|таңда|таңертең|таңмен|таң|күндіз|күн|кеште|кеш|түнде|түн)\.?)/i
    };
    var parseDayPeriodPatterns$C = {
      any: {
        am: /^ТД/i,
        pm: /^ТК/i,
        midnight: /^түн орта/i,
        noon: /^күндіз/i,
        morning: /таң/i,
        afternoon: /түс/i,
        evening: /кеш/i,
        night: /түн/i
      }
    };
    var match$C = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$C,
        parsePattern: parseOrdinalNumberPattern$C,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$C,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$C,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$C,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$C,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$C,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$C,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$C,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$C,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$C,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$C,
        defaultParseWidth: 'any'
      })
    };

    var locale$C = {
      code: 'kk',
      formatDistance: formatDistance$C,
      formatLong: formatLong$C,
      formatRelative: formatRelative$C,
      localize: localize$C,
      match: match$C,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$B = {
      lessThanXSeconds: 'តិចជាង {{count}} វិនាទី',
      xSeconds: '{{count}} វិនាទី',
      halfAMinute: 'កន្លះនាទី',
      lessThanXMinutes: 'តិចជាង {{count}} នាទី',
      xMinutes: '{{count}} នាទី',
      aboutXHours: 'ប្រហែល {{count}} ម៉ោង',
      xHours: '{{count}} ម៉ោង',
      xDays: '{{count}} ថ្ងៃ',
      aboutXWeeks: 'ប្រហែល {{count}} សប្តាហ៍',
      xWeeks: '{{count}} សប្តាហ៍',
      aboutXMonths: 'ប្រហែល {{count}} ខែ',
      xMonths: '{{count}} ខែ',
      aboutXYears: 'ប្រហែល {{count}} ឆ្នាំ',
      xYears: '{{count}} ឆ្នាំ',
      overXYears: 'ជាង {{count}} ឆ្នាំ',
      almostXYears: 'ជិត {{count}} ឆ្នាំ'
    };
    var formatDistance$B = function (token, count, options) {
      var tokenValue = formatDistanceLocale$B[token];
      var result = tokenValue;
      if (typeof count === 'number') {
        result = result.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'ក្នុងរយៈពេល ' + result;
        } else {
          return result + 'មុន';
        }
      }
      return result;
    };

    var dateFormats$B = {
      full: 'EEEE do MMMM y',
      long: 'do MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$B = {
      full: 'h:mm:ss a',
      long: 'h:mm:ss a',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$B = {
      full: "{{date}} 'ម៉ោង' {{time}}",
      long: "{{date}} 'ម៉ោង' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$B = {
      date: buildFormatLongFn({
        formats: dateFormats$B,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$B,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$B,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$B = {
      lastWeek: "'ថ្ងៃ'eeee'ស​ប្តា​ហ៍​មុនម៉ោង' p",
      yesterday: "'ម្សិលមិញនៅម៉ោង' p",
      today: "'ថ្ងៃនេះម៉ោង' p",
      tomorrow: "'ថ្ងៃស្អែកម៉ោង' p",
      nextWeek: "'ថ្ងៃ'eeee'ស​ប្តា​ហ៍​ក្រោយម៉ោង' p",
      other: 'P'
    };
    var formatRelative$B = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$B[token];
    };

    var eraValues$B = {
      narrow: ['ម.គស', 'គស'],
      abbreviated: ['មុនគ.ស', 'គ.ស'],
      wide: ['មុនគ្រិស្តសករាជ', 'នៃគ្រិស្តសករាជ']
    };
    var quarterValues$B = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['ត្រីមាសទី 1', 'ត្រីមាសទី 2', 'ត្រីមាសទី 3', 'ត្រីមាសទី 4']
    };
    var monthValues$B = {
      narrow: ['ម.ក', 'ក.ម', 'មិ', 'ម.ស', 'ឧ.ស', 'ម.ថ', 'ក.ដ', 'សី', 'កញ', 'តុ', 'វិ', 'ធ'],
      abbreviated: ['មករា', 'កុម្ភៈ', 'មីនា', 'មេសា', 'ឧសភា', 'មិថុនា', 'កក្កដា', 'សីហា', 'កញ្ញា', 'តុលា', 'វិច្ឆិកា', 'ធ្នូ'],
      wide: ['មករា', 'កុម្ភៈ', 'មីនា', 'មេសា', 'ឧសភា', 'មិថុនា', 'កក្កដា', 'សីហា', 'កញ្ញា', 'តុលា', 'វិច្ឆិកា', 'ធ្នូ']
    };
    var dayValues$B = {
      narrow: ['អា', 'ច', 'អ', 'ព', 'ព្រ', 'សុ', 'ស'],
      short: ['អា', 'ច', 'អ', 'ព', 'ព្រ', 'សុ', 'ស'],
      abbreviated: ['អា', 'ច', 'អ', 'ព', 'ព្រ', 'សុ', 'ស'],
      wide: ['អាទិត្យ', 'ចន្ទ', 'អង្គារ', 'ពុធ', 'ព្រហស្បតិ៍', 'សុក្រ', 'សៅរ៍']
    };
    var dayPeriodValues$B = {
      narrow: {
        am: 'ព្រឹក',
        pm: 'ល្ងាច',
        midnight: '​ពេលកណ្ដាលអធ្រាត្រ',
        noon: 'ពេលថ្ងៃត្រង់',
        morning: 'ពេលព្រឹក',
        afternoon: 'ពេលរសៀល',
        evening: 'ពេលល្ងាច',
        night: 'ពេលយប់'
      },
      abbreviated: {
        am: 'ព្រឹក',
        pm: 'ល្ងាច',
        midnight: '​ពេលកណ្ដាលអធ្រាត្រ',
        noon: 'ពេលថ្ងៃត្រង់',
        morning: 'ពេលព្រឹក',
        afternoon: 'ពេលរសៀល',
        evening: 'ពេលល្ងាច',
        night: 'ពេលយប់'
      },
      wide: {
        am: 'ព្រឹក',
        pm: 'ល្ងាច',
        midnight: '​ពេលកណ្ដាលអធ្រាត្រ',
        noon: 'ពេលថ្ងៃត្រង់',
        morning: 'ពេលព្រឹក',
        afternoon: 'ពេលរសៀល',
        evening: 'ពេលល្ងាច',
        night: 'ពេលយប់'
      }
    };
    var formattingDayPeriodValues$u = {
      narrow: {
        am: 'ព្រឹក',
        pm: 'ល្ងាច',
        midnight: '​ពេលកណ្ដាលអធ្រាត្រ',
        noon: 'ពេលថ្ងៃត្រង់',
        morning: 'ពេលព្រឹក',
        afternoon: 'ពេលរសៀល',
        evening: 'ពេលល្ងាច',
        night: 'ពេលយប់'
      },
      abbreviated: {
        am: 'ព្រឹក',
        pm: 'ល្ងាច',
        midnight: '​ពេលកណ្ដាលអធ្រាត្រ',
        noon: 'ពេលថ្ងៃត្រង់',
        morning: 'ពេលព្រឹក',
        afternoon: 'ពេលរសៀល',
        evening: 'ពេលល្ងាច',
        night: 'ពេលយប់'
      },
      wide: {
        am: 'ព្រឹក',
        pm: 'ល្ងាច',
        midnight: '​ពេលកណ្ដាលអធ្រាត្រ',
        noon: 'ពេលថ្ងៃត្រង់',
        morning: 'ពេលព្រឹក',
        afternoon: 'ពេលរសៀល',
        evening: 'ពេលល្ងាច',
        night: 'ពេលយប់'
      }
    };
    var ordinalNumber$B = function (dirtyNumber, _) {
      var number = Number(dirtyNumber);
      return number.toString();
    };
    var localize$B = {
      ordinalNumber: ordinalNumber$B,
      era: buildLocalizeFn({
        values: eraValues$B,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$B,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$B,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$B,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$B,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$u,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$B = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$B = /\d+/i;
    var matchEraPatterns$B = {
      narrow: /^(ម\.)?គស/i,
      abbreviated: /^(មុន)?គ\.ស/i,
      wide: /^(មុន|នៃ)គ្រិស្តសករាជ/i
    };
    var parseEraPatterns$B = {
      any: [/^(ម|មុន)គ\.?ស/i, /^(នៃ)?គ\.?ស/i]
    };
    var matchQuarterPatterns$B = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^(ត្រីមាស)(ទី)?\s?[1234]/i
    };
    var parseQuarterPatterns$B = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$B = {
      narrow: /^(ម\.ក|ក\.ម|មិ|ម\.ស|ឧ\.ស|ម\.ថ|ក\.ដ|សី|កញ|តុ|វិ|ធ)/i,
      abbreviated: /^(មករា|កុម្ភៈ|មីនា|មេសា|ឧសភា|មិថុនា|កក្កដា|សីហា|កញ្ញា|តុលា|វិច្ឆិកា|ធ្នូ)/i,
      wide: /^(មករា|កុម្ភៈ|មីនា|មេសា|ឧសភា|មិថុនា|កក្កដា|សីហា|កញ្ញា|តុលា|វិច្ឆិកា|ធ្នូ)/i
    };
    var parseMonthPatterns$B = {
      narrow: [/^ម\.ក/i, /^ក\.ម/i, /^មិ/i, /^ម\.ស/i, /^ឧ\.ស/i, /^ម\.ថ/i, /^ក\.ដ/i, /^សី/i, /^កញ/i, /^តុ/i, /^វិ/i, /^ធ/i],
      any: [/^មក/i, /^កុ/i, /^មីន/i, /^មេ/i, /^ឧស/i, /^មិថ/i, /^កក/i, /^សី/i, /^កញ/i, /^តុ/i, /^វិច/i, /^ធ/i]
    };
    var matchDayPatterns$B = {
      narrow: /^(អា|ច|អ|ព|ព្រ|សុ|ស)/i,
      short: /^(អា|ច|អ|ព|ព្រ|សុ|ស)/i,
      abbreviated: /^(អា|ច|អ|ព|ព្រ|សុ|ស)/i,
      wide: /^(អាទិត្យ|ចន្ទ|អង្គារ|ពុធ|ព្រហស្បតិ៍|សុក្រ|សៅរ៍)/i
    };
    var parseDayPatterns$B = {
      narrow: [/^អា/i, /^ច/i, /^អ/i, /^ព/i, /^ព្រ/i, /^សុ/i, /^ស/i],
      any: [/^អា/i, /^ច/i, /^អ/i, /^ព/i, /^ព្រ/i, /^សុ/i, /^សៅ/i]
    };
    var matchDayPeriodPatterns$B = {
      narrow: /^(ព្រឹក|ល្ងាច|ពេលព្រឹក|ពេលថ្ងៃត្រង់|ពេលល្ងាច|ពេលរសៀល|ពេលយប់|ពេលកណ្ដាលអធ្រាត្រ)/i,
      any: /^(ព្រឹក|ល្ងាច|ពេលព្រឹក|ពេលថ្ងៃត្រង់|ពេលល្ងាច|ពេលរសៀល|ពេលយប់|ពេលកណ្ដាលអធ្រាត្រ)/i
    };
    var parseDayPeriodPatterns$B = {
      any: {
        am: /^ព្រឹក/i,
        pm: /^ល្ងាច/i,
        midnight: /^ពេលកណ្ដាលអធ្រាត្រ/i,
        noon: /^ពេលថ្ងៃត្រង់/i,
        morning: /ពេលព្រឹក/i,
        afternoon: /ពេលរសៀល/i,
        evening: /ពេលល្ងាច/i,
        night: /ពេលយប់/i
      }
    };
    var match$B = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$B,
        parsePattern: parseOrdinalNumberPattern$B,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$B,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$B,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$B,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$B,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$B,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$B,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$B,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$B,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$B,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$B,
        defaultParseWidth: 'any'
      })
    };

    var locale$B = {
      code: 'km',
      formatDistance: formatDistance$B,
      formatLong: formatLong$B,
      formatRelative: formatRelative$B,
      localize: localize$B,
      match: match$B,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$A = {
      lessThanXSeconds: {
        one: {
          default: '1 ಸೆಕೆಂಡ್‌ಗಿಂತ ಕಡಿಮೆ',
          future: '1 ಸೆಕೆಂಡ್‌ಗಿಂತ ಕಡಿಮೆ',
          past: '1 ಸೆಕೆಂಡ್‌ಗಿಂತ ಕಡಿಮೆ'
        },
        other: {
          default: '{{count}} ಸೆಕೆಂಡ್‌ಗಿಂತ ಕಡಿಮೆ',
          future: '{{count}} ಸೆಕೆಂಡ್‌ಗಿಂತ ಕಡಿಮೆ',
          past: '{{count}} ಸೆಕೆಂಡ್‌ಗಿಂತ ಕಡಿಮೆ'
        }
      },
      xSeconds: {
        one: {
          default: '1 ಸೆಕೆಂಡ್',
          future: '1 ಸೆಕೆಂಡ್‌ನಲ್ಲಿ',
          past: '1 ಸೆಕೆಂಡ್ ಹಿಂದೆ'
        },
        other: {
          default: '{{count}} ಸೆಕೆಂಡುಗಳು',
          future: '{{count}} ಸೆಕೆಂಡ್‌ಗಳಲ್ಲಿ',
          past: '{{count}} ಸೆಕೆಂಡ್ ಹಿಂದೆ'
        }
      },
      halfAMinute: {
        other: {
          default: 'ಅರ್ಧ ನಿಮಿಷ',
          future: 'ಅರ್ಧ ನಿಮಿಷದಲ್ಲಿ',
          past: 'ಅರ್ಧ ನಿಮಿಷದ ಹಿಂದೆ'
        }
      },
      lessThanXMinutes: {
        one: {
          default: '1 ನಿಮಿಷಕ್ಕಿಂತ ಕಡಿಮೆ',
          future: '1 ನಿಮಿಷಕ್ಕಿಂತ ಕಡಿಮೆ',
          past: '1 ನಿಮಿಷಕ್ಕಿಂತ ಕಡಿಮೆ'
        },
        other: {
          default: '{{count}} ನಿಮಿಷಕ್ಕಿಂತ ಕಡಿಮೆ',
          future: '{{count}} ನಿಮಿಷಕ್ಕಿಂತ ಕಡಿಮೆ',
          past: '{{count}} ನಿಮಿಷಕ್ಕಿಂತ ಕಡಿಮೆ'
        }
      },
      xMinutes: {
        one: {
          default: '1 ನಿಮಿಷ',
          future: '1 ನಿಮಿಷದಲ್ಲಿ',
          past: '1 ನಿಮಿಷದ ಹಿಂದೆ'
        },
        other: {
          default: '{{count}} ನಿಮಿಷಗಳು',
          future: '{{count}} ನಿಮಿಷಗಳಲ್ಲಿ',
          past: '{{count}} ನಿಮಿಷಗಳ ಹಿಂದೆ'
        }
      },
      aboutXHours: {
        one: {
          default: 'ಸುಮಾರು 1 ಗಂಟೆ',
          future: 'ಸುಮಾರು 1 ಗಂಟೆಯಲ್ಲಿ',
          past: 'ಸುಮಾರು 1 ಗಂಟೆ ಹಿಂದೆ'
        },
        other: {
          default: 'ಸುಮಾರು {{count}} ಗಂಟೆಗಳು',
          future: 'ಸುಮಾರು {{count}} ಗಂಟೆಗಳಲ್ಲಿ',
          past: 'ಸುಮಾರು {{count}} ಗಂಟೆಗಳ ಹಿಂದೆ'
        }
      },
      xHours: {
        one: {
          default: '1 ಗಂಟೆ',
          future: '1 ಗಂಟೆಯಲ್ಲಿ',
          past: '1 ಗಂಟೆ ಹಿಂದೆ'
        },
        other: {
          default: '{{count}} ಗಂಟೆಗಳು',
          future: '{{count}} ಗಂಟೆಗಳಲ್ಲಿ',
          past: '{{count}} ಗಂಟೆಗಳ ಹಿಂದೆ'
        }
      },
      xDays: {
        one: {
          default: '1 ದಿನ',
          future: '1 ದಿನದಲ್ಲಿ',
          past: '1 ದಿನದ ಹಿಂದೆ'
        },
        other: {
          default: '{{count}} ದಿನಗಳು',
          future: '{{count}} ದಿನಗಳಲ್ಲಿ',
          past: '{{count}} ದಿನಗಳ ಹಿಂದೆ'
        }
      },
      aboutXMonths: {
        one: {
          default: 'ಸುಮಾರು 1 ತಿಂಗಳು',
          future: 'ಸುಮಾರು 1 ತಿಂಗಳಲ್ಲಿ',
          past: 'ಸುಮಾರು 1 ತಿಂಗಳ ಹಿಂದೆ'
        },
        other: {
          default: 'ಸುಮಾರು {{count}} ತಿಂಗಳು',
          future: 'ಸುಮಾರು {{count}} ತಿಂಗಳುಗಳಲ್ಲಿ',
          past: 'ಸುಮಾರು {{count}} ತಿಂಗಳುಗಳ ಹಿಂದೆ'
        }
      },
      xMonths: {
        one: {
          default: '1 ತಿಂಗಳು',
          future: '1 ತಿಂಗಳಲ್ಲಿ',
          past: '1 ತಿಂಗಳ ಹಿಂದೆ'
        },
        other: {
          default: '{{count}} ತಿಂಗಳು',
          future: '{{count}} ತಿಂಗಳುಗಳಲ್ಲಿ',
          past: '{{count}} ತಿಂಗಳುಗಳ ಹಿಂದೆ'
        }
      },
      aboutXYears: {
        one: {
          default: 'ಸುಮಾರು 1 ವರ್ಷ',
          future: 'ಸುಮಾರು 1 ವರ್ಷದಲ್ಲಿ',
          past: 'ಸುಮಾರು 1 ವರ್ಷದ ಹಿಂದೆ'
        },
        other: {
          default: 'ಸುಮಾರು {{count}} ವರ್ಷಗಳು',
          future: 'ಸುಮಾರು {{count}} ವರ್ಷಗಳಲ್ಲಿ',
          past: 'ಸುಮಾರು {{count}} ವರ್ಷಗಳ ಹಿಂದೆ'
        }
      },
      xYears: {
        one: {
          default: '1 ವರ್ಷ',
          future: '1 ವರ್ಷದಲ್ಲಿ',
          past: '1 ವರ್ಷದ ಹಿಂದೆ'
        },
        other: {
          default: '{{count}} ವರ್ಷಗಳು',
          future: '{{count}} ವರ್ಷಗಳಲ್ಲಿ',
          past: '{{count}} ವರ್ಷಗಳ ಹಿಂದೆ'
        }
      },
      overXYears: {
        one: {
          default: '1 ವರ್ಷದ ಮೇಲೆ',
          future: '1 ವರ್ಷದ ಮೇಲೆ',
          past: '1 ವರ್ಷದ ಮೇಲೆ'
        },
        other: {
          default: '{{count}} ವರ್ಷಗಳ ಮೇಲೆ',
          future: '{{count}} ವರ್ಷಗಳ ಮೇಲೆ',
          past: '{{count}} ವರ್ಷಗಳ ಮೇಲೆ'
        }
      },
      almostXYears: {
        one: {
          default: 'ಬಹುತೇಕ 1 ವರ್ಷದಲ್ಲಿ',
          future: 'ಬಹುತೇಕ 1 ವರ್ಷದಲ್ಲಿ',
          past: 'ಬಹುತೇಕ 1 ವರ್ಷದಲ್ಲಿ'
        },
        other: {
          default: 'ಬಹುತೇಕ {{count}} ವರ್ಷಗಳಲ್ಲಿ',
          future: 'ಬಹುತೇಕ {{count}} ವರ್ಷಗಳಲ್ಲಿ',
          past: 'ಬಹುತೇಕ {{count}} ವರ್ಷಗಳಲ್ಲಿ'
        }
      }
    };
    function getResultByTense(parentToken, options) {
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return parentToken.future;
        } else {
          return parentToken.past;
        }
      }
      return parentToken.default;
    }
    var formatDistance$A = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$A[token];
      if (tokenValue.one && count === 1) {
        result = getResultByTense(tokenValue.one, options);
      } else {
        result = getResultByTense(tokenValue.other, options);
      }
      return result.replace('{{count}}', String(count));
    };

    var dateFormats$A = {
      full: 'EEEE, MMMM d, y',
      long: 'MMMM d, y',
      medium: 'MMM d, y',
      short: 'd/M/yy'
    };
    var timeFormats$A = {
      full: 'hh:mm:ss a zzzz',
      long: 'hh:mm:ss a z',
      medium: 'hh:mm:ss a',
      short: 'hh:mm a'
    };
    var dateTimeFormats$A = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$A = {
      date: buildFormatLongFn({
        formats: dateFormats$A,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$A,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$A,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$A = {
      lastWeek: "'ಕಳೆದ' eeee p 'ಕ್ಕೆ'",
      yesterday: "'ನಿನ್ನೆ' p 'ಕ್ಕೆ'",
      today: "'ಇಂದು' p 'ಕ್ಕೆ'",
      tomorrow: "'ನಾಳೆ' p 'ಕ್ಕೆ'",
      nextWeek: "eeee p 'ಕ್ಕೆ'",
      other: 'P'
    };
    var formatRelative$A = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$A[token];
    };

    var eraValues$A = {
      narrow: ['ಕ್ರಿ.ಪೂ', 'ಕ್ರಿ.ಶ'],
      abbreviated: ['ಕ್ರಿ.ಪೂ', 'ಕ್ರಿ.ಶ'],
      wide: ['ಕ್ರಿಸ್ತ ಪೂರ್ವ', 'ಕ್ರಿಸ್ತ ಶಕ']
    };
    var quarterValues$A = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['ತ್ರೈ 1', 'ತ್ರೈ 2', 'ತ್ರೈ 3', 'ತ್ರೈ 4'],
      wide: ['1ನೇ ತ್ರೈಮಾಸಿಕ', '2ನೇ ತ್ರೈಮಾಸಿಕ', '3ನೇ ತ್ರೈಮಾಸಿಕ', '4ನೇ ತ್ರೈಮಾಸಿಕ']
    };
    var monthValues$A = {
      narrow: ['ಜ', 'ಫೆ', 'ಮಾ', 'ಏ', 'ಮೇ', 'ಜೂ', 'ಜು', 'ಆ', 'ಸೆ', 'ಅ', 'ನ', 'ಡಿ'],
      abbreviated: ['ಜನ', 'ಫೆಬ್ರ', 'ಮಾರ್ಚ್', 'ಏಪ್ರಿ', 'ಮೇ', 'ಜೂನ್', 'ಜುಲೈ', 'ಆಗ', 'ಸೆಪ್ಟೆಂ', 'ಅಕ್ಟೋ', 'ನವೆಂ', 'ಡಿಸೆಂ'],
      wide: ['ಜನವರಿ', 'ಫೆಬ್ರವರಿ', 'ಮಾರ್ಚ್', 'ಏಪ್ರಿಲ್', 'ಮೇ', 'ಜೂನ್', 'ಜುಲೈ', 'ಆಗಸ್ಟ್', 'ಸೆಪ್ಟೆಂಬರ್', 'ಅಕ್ಟೋಬರ್', 'ನವೆಂಬರ್', 'ಡಿಸೆಂಬರ್']
    };
    var dayValues$A = {
      narrow: ['ಭಾ', 'ಸೋ', 'ಮಂ', 'ಬು', 'ಗು', 'ಶು', 'ಶ'],
      short: ['ಭಾನು', 'ಸೋಮ', 'ಮಂಗಳ', 'ಬುಧ', 'ಗುರು', 'ಶುಕ್ರ', 'ಶನಿ'],
      abbreviated: ['ಭಾನು', 'ಸೋಮ', 'ಮಂಗಳ', 'ಬುಧ', 'ಗುರು', 'ಶುಕ್ರ', 'ಶನಿ'],
      wide: ['ಭಾನುವಾರ', 'ಸೋಮವಾರ', 'ಮಂಗಳವಾರ', 'ಬುಧವಾರ', 'ಗುರುವಾರ', 'ಶುಕ್ರವಾರ', 'ಶನಿವಾರ']
    };
    var dayPeriodValues$A = {
      narrow: {
        am: 'ಪೂರ್ವಾಹ್ನ',
        pm: 'ಅಪರಾಹ್ನ',
        midnight: 'ಮಧ್ಯರಾತ್ರಿ',
        noon: 'ಮಧ್ಯಾಹ್ನ',
        morning: 'ಬೆಳಗ್ಗೆ',
        afternoon: 'ಮಧ್ಯಾಹ್ನ',
        evening: 'ಸಂಜೆ',
        night: 'ರಾತ್ರಿ'
      },
      abbreviated: {
        am: 'ಪೂರ್ವಾಹ್ನ',
        pm: 'ಅಪರಾಹ್ನ',
        midnight: 'ಮಧ್ಯರಾತ್ರಿ',
        noon: 'ಮಧ್ಯಾನ್ಹ',
        morning: 'ಬೆಳಗ್ಗೆ',
        afternoon: 'ಮಧ್ಯಾನ್ಹ',
        evening: 'ಸಂಜೆ',
        night: 'ರಾತ್ರಿ'
      },
      wide: {
        am: 'ಪೂರ್ವಾಹ್ನ',
        pm: 'ಅಪರಾಹ್ನ',
        midnight: 'ಮಧ್ಯರಾತ್ರಿ',
        noon: 'ಮಧ್ಯಾನ್ಹ',
        morning: 'ಬೆಳಗ್ಗೆ',
        afternoon: 'ಮಧ್ಯಾನ್ಹ',
        evening: 'ಸಂಜೆ',
        night: 'ರಾತ್ರಿ'
      }
    };
    var formattingDayPeriodValues$t = {
      narrow: {
        am: 'ಪೂ',
        pm: 'ಅ',
        midnight: 'ಮಧ್ಯರಾತ್ರಿ',
        noon: 'ಮಧ್ಯಾನ್ಹ',
        morning: 'ಬೆಳಗ್ಗೆ',
        afternoon: 'ಮಧ್ಯಾನ್ಹ',
        evening: 'ಸಂಜೆ',
        night: 'ರಾತ್ರಿ'
      },
      abbreviated: {
        am: 'ಪೂರ್ವಾಹ್ನ',
        pm: 'ಅಪರಾಹ್ನ',
        midnight: 'ಮಧ್ಯ ರಾತ್ರಿ',
        noon: 'ಮಧ್ಯಾನ್ಹ',
        morning: 'ಬೆಳಗ್ಗೆ',
        afternoon: 'ಮಧ್ಯಾನ್ಹ',
        evening: 'ಸಂಜೆ',
        night: 'ರಾತ್ರಿ'
      },
      wide: {
        am: 'ಪೂರ್ವಾಹ್ನ',
        pm: 'ಅಪರಾಹ್ನ',
        midnight: 'ಮಧ್ಯ ರಾತ್ರಿ',
        noon: 'ಮಧ್ಯಾನ್ಹ',
        morning: 'ಬೆಳಗ್ಗೆ',
        afternoon: 'ಮಧ್ಯಾನ್ಹ',
        evening: 'ಸಂಜೆ',
        night: 'ರಾತ್ರಿ'
      }
    };
    var ordinalNumber$A = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'ನೇ';
    };
    var localize$A = {
      ordinalNumber: ordinalNumber$A,
      era: buildLocalizeFn({
        values: eraValues$A,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$A,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$A,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$A,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$A,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$t,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$A = /^(\d+)(ನೇ|ನೆ)?/i;
    var parseOrdinalNumberPattern$A = /\d+/i;
    var matchEraPatterns$A = {
      narrow: /^(ಕ್ರಿ.ಪೂ|ಕ್ರಿ.ಶ)/i,
      abbreviated: /^(ಕ್ರಿ\.?\s?ಪೂ\.?|ಕ್ರಿ\.?\s?ಶ\.?|ಪ್ರ\.?\s?ಶ\.?)/i,
      wide: /^(ಕ್ರಿಸ್ತ ಪೂರ್ವ|ಕ್ರಿಸ್ತ ಶಕ|ಪ್ರಸಕ್ತ ಶಕ)/i
    };
    var parseEraPatterns$A = {
      any: [/^ಪೂ/i, /^(ಶ|ಪ್ರ)/i]
    };
    var matchQuarterPatterns$A = {
      narrow: /^[1234]/i,
      abbreviated: /^ತ್ರೈ[1234]|ತ್ರೈ [1234]| [1234]ತ್ರೈ/i,
      wide: /^[1234](ನೇ)? ತ್ರೈಮಾಸಿಕ/i
    };
    var parseQuarterPatterns$A = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$A = {
      narrow: /^(ಜೂ|ಜು|ಜ|ಫೆ|ಮಾ|ಏ|ಮೇ|ಆ|ಸೆ|ಅ|ನ|ಡಿ)/i,
      abbreviated: /^(ಜನ|ಫೆಬ್ರ|ಮಾರ್ಚ್|ಏಪ್ರಿ|ಮೇ|ಜೂನ್|ಜುಲೈ|ಆಗ|ಸೆಪ್ಟೆಂ|ಅಕ್ಟೋ|ನವೆಂ|ಡಿಸೆಂ)/i,
      wide: /^(ಜನವರಿ|ಫೆಬ್ರವರಿ|ಮಾರ್ಚ್|ಏಪ್ರಿಲ್|ಮೇ|ಜೂನ್|ಜುಲೈ|ಆಗಸ್ಟ್|ಸೆಪ್ಟೆಂಬರ್|ಅಕ್ಟೋಬರ್|ನವೆಂಬರ್|ಡಿಸೆಂಬರ್)/i
    };
    var parseMonthPatterns$A = {
      narrow: [/^ಜ$/i, /^ಫೆ/i, /^ಮಾ/i, /^ಏ/i, /^ಮೇ/i, /^ಜೂ/i, /^ಜು$/i, /^ಆ/i, /^ಸೆ/i, /^ಅ/i, /^ನ/i, /^ಡಿ/i],
      any: [/^ಜನ/i, /^ಫೆ/i, /^ಮಾ/i, /^ಏ/i, /^ಮೇ/i, /^ಜೂನ್/i, /^ಜುಲೈ/i, /^ಆ/i, /^ಸೆ/i, /^ಅ/i, /^ನ/i, /^ಡಿ/i]
    };
    var matchDayPatterns$A = {
      narrow: /^(ಭಾ|ಸೋ|ಮ|ಬು|ಗು|ಶು|ಶ)/i,
      short: /^(ಭಾನು|ಸೋಮ|ಮಂಗಳ|ಬುಧ|ಗುರು|ಶುಕ್ರ|ಶನಿ)/i,
      abbreviated: /^(ಭಾನು|ಸೋಮ|ಮಂಗಳ|ಬುಧ|ಗುರು|ಶುಕ್ರ|ಶನಿ)/i,
      wide: /^(ಭಾನುವಾರ|ಸೋಮವಾರ|ಮಂಗಳವಾರ|ಬುಧವಾರ|ಗುರುವಾರ|ಶುಕ್ರವಾರ|ಶನಿವಾರ)/i
    };
    var parseDayPatterns$A = {
      narrow: [/^ಭಾ/i, /^ಸೋ/i, /^ಮ/i, /^ಬು/i, /^ಗು/i, /^ಶು/i, /^ಶ/i],
      any: [/^ಭಾ/i, /^ಸೋ/i, /^ಮ/i, /^ಬು/i, /^ಗು/i, /^ಶು/i, /^ಶ/i]
    };
    var matchDayPeriodPatterns$A = {
      narrow: /^(ಪೂ|ಅ|ಮಧ್ಯರಾತ್ರಿ|ಮಧ್ಯಾನ್ಹ|ಬೆಳಗ್ಗೆ|ಸಂಜೆ|ರಾತ್ರಿ)/i,
      any: /^(ಪೂರ್ವಾಹ್ನ|ಅಪರಾಹ್ನ|ಮಧ್ಯರಾತ್ರಿ|ಮಧ್ಯಾನ್ಹ|ಬೆಳಗ್ಗೆ|ಸಂಜೆ|ರಾತ್ರಿ)/i
    };
    var parseDayPeriodPatterns$A = {
      any: {
        am: /^ಪೂ/i,
        pm: /^ಅ/i,
        midnight: /ಮಧ್ಯರಾತ್ರಿ/i,
        noon: /ಮಧ್ಯಾನ್ಹ/i,
        morning: /ಬೆಳಗ್ಗೆ/i,
        afternoon: /ಮಧ್ಯಾನ್ಹ/i,
        evening: /ಸಂಜೆ/i,
        night: /ರಾತ್ರಿ/i
      }
    };
    var match$A = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$A,
        parsePattern: parseOrdinalNumberPattern$A,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$A,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$A,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$A,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$A,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$A,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$A,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$A,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$A,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$A,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$A,
        defaultParseWidth: 'any'
      })
    };

    var locale$A = {
      code: 'kn',
      formatDistance: formatDistance$A,
      formatLong: formatLong$A,
      formatRelative: formatRelative$A,
      localize: localize$A,
      match: match$A,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$z = {
      lessThanXSeconds: {
        one: '1초 미만',
        other: '{{count}}초 미만'
      },
      xSeconds: {
        one: '1초',
        other: '{{count}}초'
      },
      halfAMinute: '30초',
      lessThanXMinutes: {
        one: '1분 미만',
        other: '{{count}}분 미만'
      },
      xMinutes: {
        one: '1분',
        other: '{{count}}분'
      },
      aboutXHours: {
        one: '약 1시간',
        other: '약 {{count}}시간'
      },
      xHours: {
        one: '1시간',
        other: '{{count}}시간'
      },
      xDays: {
        one: '1일',
        other: '{{count}}일'
      },
      aboutXWeeks: {
        one: '약 1주',
        other: '약 {{count}}주'
      },
      xWeeks: {
        one: '1주',
        other: '{{count}}주'
      },
      aboutXMonths: {
        one: '약 1개월',
        other: '약 {{count}}개월'
      },
      xMonths: {
        one: '1개월',
        other: '{{count}}개월'
      },
      aboutXYears: {
        one: '약 1년',
        other: '약 {{count}}년'
      },
      xYears: {
        one: '1년',
        other: '{{count}}년'
      },
      overXYears: {
        one: '1년 이상',
        other: '{{count}}년 이상'
      },
      almostXYears: {
        one: '거의 1년',
        other: '거의 {{count}}년'
      }
    };
    var formatDistance$z = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$z[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' 후';
        } else {
          return result + ' 전';
        }
      }
      return result;
    };

    var dateFormats$z = {
      full: 'y년 M월 d일 EEEE',
      long: 'y년 M월 d일',
      medium: 'y.MM.dd',
      short: 'y.MM.dd'
    };
    var timeFormats$z = {
      full: 'a H시 mm분 ss초 zzzz',
      long: 'a H:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$z = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$z = {
      date: buildFormatLongFn({
        formats: dateFormats$z,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$z,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$z,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$z = {
      lastWeek: "'지난' eeee p",
      yesterday: "'어제' p",
      today: "'오늘' p",
      tomorrow: "'내일' p",
      nextWeek: "'다음' eeee p",
      other: 'P'
    };
    var formatRelative$z = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$z[token];
    };

    var eraValues$z = {
      narrow: ['BC', 'AD'],
      abbreviated: ['BC', 'AD'],
      wide: ['기원전', '서기']
    };
    var quarterValues$z = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1분기', '2분기', '3분기', '4분기']
    };
    var monthValues$z = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['1월', '2월', '3월', '4월', '5월', '6월', '7월', '8월', '9월', '10월', '11월', '12월'],
      wide: ['1월', '2월', '3월', '4월', '5월', '6월', '7월', '8월', '9월', '10월', '11월', '12월']
    };
    var dayValues$z = {
      narrow: ['일', '월', '화', '수', '목', '금', '토'],
      short: ['일', '월', '화', '수', '목', '금', '토'],
      abbreviated: ['일', '월', '화', '수', '목', '금', '토'],
      wide: ['일요일', '월요일', '화요일', '수요일', '목요일', '금요일', '토요일']
    };
    var dayPeriodValues$z = {
      narrow: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      abbreviated: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      wide: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      }
    };
    var formattingDayPeriodValues$s = {
      narrow: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      abbreviated: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      wide: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      }
    };
    var ordinalNumber$z = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      switch (unit) {
        case 'minute':
        case 'second':
          return String(number);
        case 'date':
          return number + '일';
        default:
          return number + '번째';
      }
    };
    var localize$z = {
      ordinalNumber: ordinalNumber$z,
      era: buildLocalizeFn({
        values: eraValues$z,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$z,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$z,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$z,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$z,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$s,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$z = /^(\d+)(일|번째)?/i;
    var parseOrdinalNumberPattern$z = /\d+/i;
    var matchEraPatterns$z = {
      narrow: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
      abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
      wide: /^(기원전|서기)/i
    };
    var parseEraPatterns$z = {
      any: [/^(bc|기원전)/i, /^(ad|서기)/i]
    };
    var matchQuarterPatterns$z = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234]사?분기/i
    };
    var parseQuarterPatterns$z = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$z = {
      narrow: /^(1[012]|[123456789])/,
      abbreviated: /^(1[012]|[123456789])월/i,
      wide: /^(1[012]|[123456789])월/i
    };
    var parseMonthPatterns$z = {
      any: [/^1월?$/, /^2/, /^3/, /^4/, /^5/, /^6/, /^7/, /^8/, /^9/, /^10/, /^11/, /^12/]
    };
    var matchDayPatterns$z = {
      narrow: /^[일월화수목금토]/,
      short: /^[일월화수목금토]/,
      abbreviated: /^[일월화수목금토]/,
      wide: /^[일월화수목금토]요일/
    };
    var parseDayPatterns$z = {
      any: [/^일/, /^월/, /^화/, /^수/, /^목/, /^금/, /^토/]
    };
    var matchDayPeriodPatterns$z = {
      any: /^(am|pm|오전|오후|자정|정오|아침|저녁|밤)/i
    };
    var parseDayPeriodPatterns$z = {
      any: {
        am: /^(am|오전)/i,
        pm: /^(pm|오후)/i,
        midnight: /^자정/i,
        noon: /^정오/i,
        morning: /^아침/i,
        afternoon: /^오후/i,
        evening: /^저녁/i,
        night: /^밤/i
      }
    };
    var match$z = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$z,
        parsePattern: parseOrdinalNumberPattern$z,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$z,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$z,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$z,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$z,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$z,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$z,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$z,
        defaultParseWidth: 'any'
      })
    };

    var locale$z = {
      code: 'ko',
      formatDistance: formatDistance$z,
      formatLong: formatLong$z,
      formatRelative: formatRelative$z,
      localize: localize$z,
      match: match$z,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$y = {
      lessThanXSeconds: {
        standalone: {
          one: 'manner wéi eng Sekonn',
          other: 'manner wéi {{count}} Sekonnen'
        },
        withPreposition: {
          one: 'manner wéi enger Sekonn',
          other: 'manner wéi {{count}} Sekonnen'
        }
      },
      xSeconds: {
        standalone: {
          one: 'eng Sekonn',
          other: '{{count}} Sekonnen'
        },
        withPreposition: {
          one: 'enger Sekonn',
          other: '{{count}} Sekonnen'
        }
      },
      halfAMinute: {
        standalone: 'eng hallef Minutt',
        withPreposition: 'enger hallwer Minutt'
      },
      lessThanXMinutes: {
        standalone: {
          one: 'manner wéi eng Minutt',
          other: 'manner wéi {{count}} Minutten'
        },
        withPreposition: {
          one: 'manner wéi enger Minutt',
          other: 'manner wéi {{count}} Minutten'
        }
      },
      xMinutes: {
        standalone: {
          one: 'eng Minutt',
          other: '{{count}} Minutten'
        },
        withPreposition: {
          one: 'enger Minutt',
          other: '{{count}} Minutten'
        }
      },
      aboutXHours: {
        standalone: {
          one: 'ongeféier eng Stonn',
          other: 'ongeféier {{count}} Stonnen'
        },
        withPreposition: {
          one: 'ongeféier enger Stonn',
          other: 'ongeféier {{count}} Stonnen'
        }
      },
      xHours: {
        standalone: {
          one: 'eng Stonn',
          other: '{{count}} Stonnen'
        },
        withPreposition: {
          one: 'enger Stonn',
          other: '{{count}} Stonnen'
        }
      },
      xDays: {
        standalone: {
          one: 'een Dag',
          other: '{{count}} Deeg'
        },
        withPreposition: {
          one: 'engem Dag',
          other: '{{count}} Deeg'
        }
      },
      aboutXWeeks: {
        standalone: {
          one: 'ongeféier eng Woch',
          other: 'ongeféier {{count}} Wochen'
        },
        withPreposition: {
          one: 'ongeféier enger Woche',
          other: 'ongeféier {{count}} Wochen'
        }
      },
      xWeeks: {
        standalone: {
          one: 'eng Woch',
          other: '{{count}} Wochen'
        },
        withPreposition: {
          one: 'enger Woch',
          other: '{{count}} Wochen'
        }
      },
      aboutXMonths: {
        standalone: {
          one: 'ongeféier ee Mount',
          other: 'ongeféier {{count}} Méint'
        },
        withPreposition: {
          one: 'ongeféier engem Mount',
          other: 'ongeféier {{count}} Méint'
        }
      },
      xMonths: {
        standalone: {
          one: 'ee Mount',
          other: '{{count}} Méint'
        },
        withPreposition: {
          one: 'engem Mount',
          other: '{{count}} Méint'
        }
      },
      aboutXYears: {
        standalone: {
          one: 'ongeféier ee Joer',
          other: 'ongeféier {{count}} Joer'
        },
        withPreposition: {
          one: 'ongeféier engem Joer',
          other: 'ongeféier {{count}} Joer'
        }
      },
      xYears: {
        standalone: {
          one: 'ee Joer',
          other: '{{count}} Joer'
        },
        withPreposition: {
          one: 'engem Joer',
          other: '{{count}} Joer'
        }
      },
      overXYears: {
        standalone: {
          one: 'méi wéi ee Joer',
          other: 'méi wéi {{count}} Joer'
        },
        withPreposition: {
          one: 'méi wéi engem Joer',
          other: 'méi wéi {{count}} Joer'
        }
      },
      almostXYears: {
        standalone: {
          one: 'bal ee Joer',
          other: 'bal {{count}} Joer'
        },
        withPreposition: {
          one: 'bal engem Joer',
          other: 'bal {{count}} Joer'
        }
      }
    };
    var EXCEPTION_CONSONANTS = ['d', 'h', 'n', 't', 'z'];
    var VOWELS = ['a,', 'e', 'i', 'o', 'u'];
    var DIGITS_SPOKEN_N_NEEDED = [0, 1, 2, 3, 8, 9];
    var FIRST_TWO_DIGITS_SPOKEN_NO_N_NEEDED = [40, 50, 60, 70];
    function isFinalNNeeded(nextWords) {
      var firstLetter = nextWords.charAt(0).toLowerCase();
      if (VOWELS.indexOf(firstLetter) != -1 || EXCEPTION_CONSONANTS.indexOf(firstLetter) != -1) {
        return true;
      }
      var firstWord = nextWords.split(' ')[0];
      var number = parseInt(firstWord);
      if (!isNaN(number) && DIGITS_SPOKEN_N_NEEDED.indexOf(number % 10) != -1 && FIRST_TWO_DIGITS_SPOKEN_NO_N_NEEDED.indexOf(parseInt(firstWord.substring(0, 2))) == -1) {
        return true;
      }
      return false;
    }
    var formatDistance$y = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$y[token];
      var usageGroup = options !== null && options !== void 0 && options.addSuffix ? tokenValue.withPreposition : tokenValue.standalone;
      if (typeof usageGroup === 'string') {
        result = usageGroup;
      } else if (count === 1) {
        result = usageGroup.one;
      } else {
        result = usageGroup.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'a' + (isFinalNNeeded(result) ? 'n' : '') + ' ' + result;
        } else {
          return 'viru' + (isFinalNNeeded(result) ? 'n' : '') + ' ' + result;
        }
      }
      return result;
    };

    var dateFormats$y = {
      full: 'EEEE, do MMMM y',
      long: 'do MMMM y',
      medium: 'do MMM y',
      short: 'dd.MM.yy'
    };
    var timeFormats$y = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$y = {
      full: "{{date}} 'um' {{time}}",
      long: "{{date}} 'um' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$y = {
      date: buildFormatLongFn({
        formats: dateFormats$y,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$y,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$y,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$y = {
      lastWeek: function (date) {
        var day = date.getUTCDay();
        var result = "'läschte";
        if (day === 2 || day === 4) {
          result += 'n';
        }
        result += "' eeee 'um' p";
        return result;
      },
      yesterday: "'gëschter um' p",
      today: "'haut um' p",
      tomorrow: "'moien um' p",
      nextWeek: "eeee 'um' p",
      other: 'P'
    };
    var formatRelative$y = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$y[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$y = {
      narrow: ['v.Chr.', 'n.Chr.'],
      abbreviated: ['v.Chr.', 'n.Chr.'],
      wide: ['viru Christus', 'no Christus']
    };
    var quarterValues$y = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal']
    };
    var monthValues$y = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mäe', 'Abr', 'Mee', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      wide: ['Januar', 'Februar', 'Mäerz', 'Abrëll', 'Mee', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember']
    };
    var dayValues$y = {
      narrow: ['S', 'M', 'D', 'M', 'D', 'F', 'S'],
      short: ['So', 'Mé', 'Dë', 'Më', 'Do', 'Fr', 'Sa'],
      abbreviated: ['So.', 'Mé.', 'Dë.', 'Më.', 'Do.', 'Fr.', 'Sa.'],
      wide: ['Sonndeg', 'Méindeg', 'Dënschdeg', 'Mëttwoch', 'Donneschdeg', 'Freideg', 'Samschdeg']
    };
    var dayPeriodValues$y = {
      narrow: {
        am: 'mo.',
        pm: 'nomë.',
        midnight: 'Mëtternuecht',
        noon: 'Mëtteg',
        morning: 'Moien',
        afternoon: 'Nomëtteg',
        evening: 'Owend',
        night: 'Nuecht'
      },
      abbreviated: {
        am: 'moies',
        pm: 'nomëttes',
        midnight: 'Mëtternuecht',
        noon: 'Mëtteg',
        morning: 'Moien',
        afternoon: 'Nomëtteg',
        evening: 'Owend',
        night: 'Nuecht'
      },
      wide: {
        am: 'moies',
        pm: 'nomëttes',
        midnight: 'Mëtternuecht',
        noon: 'Mëtteg',
        morning: 'Moien',
        afternoon: 'Nomëtteg',
        evening: 'Owend',
        night: 'Nuecht'
      }
    };
    var formattingDayPeriodValues$r = {
      narrow: {
        am: 'mo.',
        pm: 'nom.',
        midnight: 'Mëtternuecht',
        noon: 'mëttes',
        morning: 'moies',
        afternoon: 'nomëttes',
        evening: 'owes',
        night: 'nuets'
      },
      abbreviated: {
        am: 'moies',
        pm: 'nomëttes',
        midnight: 'Mëtternuecht',
        noon: 'mëttes',
        morning: 'moies',
        afternoon: 'nomëttes',
        evening: 'owes',
        night: 'nuets'
      },
      wide: {
        am: 'moies',
        pm: 'nomëttes',
        midnight: 'Mëtternuecht',
        noon: 'mëttes',
        morning: 'moies',
        afternoon: 'nomëttes',
        evening: 'owes',
        night: 'nuets'
      }
    };
    var ordinalNumber$y = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$y = {
      ordinalNumber: ordinalNumber$y,
      era: buildLocalizeFn({
        values: eraValues$y,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$y,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$y,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$y,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$y,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$r,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$y = /^(\d+)(\.)?/i;
    var parseOrdinalNumberPattern$y = /\d+/i;
    var matchEraPatterns$y = {
      narrow: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
      abbreviated: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
      wide: /^(viru Christus|virun eiser Zäitrechnung|no Christus|eiser Zäitrechnung)/i
    };
    var parseEraPatterns$y = {
      any: [/^v/i, /^n/i]
    };
    var matchQuarterPatterns$y = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](\.)? Quartal/i
    };
    var parseQuarterPatterns$y = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$y = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mäe|abr|mee|jun|jul|aug|sep|okt|nov|dez)/i,
      wide: /^(januar|februar|mäerz|abrëll|mee|juni|juli|august|september|oktober|november|dezember)/i
    };
    var parseMonthPatterns$y = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mä/i, /^ab/i, /^me/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$y = {
      narrow: /^[smdf]/i,
      short: /^(so|mé|dë|më|do|fr|sa)/i,
      abbreviated: /^(son?|méi?|dën?|mët?|don?|fre?|sam?)\.?/i,
      wide: /^(sonndeg|méindeg|dënschdeg|mëttwoch|donneschdeg|freideg|samschdeg)/i
    };
    var parseDayPatterns$y = {
      any: [/^so/i, /^mé/i, /^dë/i, /^më/i, /^do/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$y = {
      narrow: /^(mo\.?|nomë\.?|Mëtternuecht|mëttes|moies|nomëttes|owes|nuets)/i,
      abbreviated: /^(moi\.?|nomët\.?|Mëtternuecht|mëttes|moies|nomëttes|owes|nuets)/i,
      wide: /^(moies|nomëttes|Mëtternuecht|mëttes|moies|nomëttes|owes|nuets)/i
    };
    var parseDayPeriodPatterns$y = {
      any: {
        am: /^m/i,
        pm: /^n/i,
        midnight: /^Mëtter/i,
        noon: /^mëttes/i,
        morning: /moies/i,
        afternoon: /nomëttes/i,
        evening: /owes/i,
        night: /nuets/i
      }
    };
    var match$y = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$y,
        parsePattern: parseOrdinalNumberPattern$y,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$y,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$y,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$y,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$y,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$y,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$y,
        defaultParseWidth: 'any'
      })
    };

    var locale$y = {
      code: 'lb',
      formatDistance: formatDistance$y,
      formatLong: formatLong$y,
      formatRelative: formatRelative$y,
      localize: localize$y,
      match: match$y,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var translations = {
      xseconds_other: 'sekundė_sekundžių_sekundes',
      xminutes_one: 'minutė_minutės_minutę',
      xminutes_other: 'minutės_minučių_minutes',
      xhours_one: 'valanda_valandos_valandą',
      xhours_other: 'valandos_valandų_valandas',
      xdays_one: 'diena_dienos_dieną',
      xdays_other: 'dienos_dienų_dienas',
      xweeks_one: 'savaitė_savaitės_savaitę',
      xweeks_other: 'savaitės_savaičių_savaites',
      xmonths_one: 'mėnuo_mėnesio_mėnesį',
      xmonths_other: 'mėnesiai_mėnesių_mėnesius',
      xyears_one: 'metai_metų_metus',
      xyears_other: 'metai_metų_metus',
      about: 'apie',
      over: 'daugiau nei',
      almost: 'beveik',
      lessthan: 'mažiau nei'
    };
    var translateSeconds = function (_number, addSuffix, _key, isFuture) {
      if (!addSuffix) {
        return 'kelios sekundės';
      } else {
        return isFuture ? 'kelių sekundžių' : 'kelias sekundes';
      }
    };
    var translateSingular = function (_number, addSuffix, key, isFuture) {
      return !addSuffix ? forms(key)[0] : isFuture ? forms(key)[1] : forms(key)[2];
    };
    var translate = function (number, addSuffix, key, isFuture) {
      var result = number + ' ';
      if (number === 1) {
        return result + translateSingular(number, addSuffix, key, isFuture);
      } else if (!addSuffix) {
        return result + (special(number) ? forms(key)[1] : forms(key)[0]);
      } else {
        if (isFuture) {
          return result + forms(key)[1];
        } else {
          return result + (special(number) ? forms(key)[1] : forms(key)[2]);
        }
      }
    };
    function special(number) {
      return number % 10 === 0 || number > 10 && number < 20;
    }
    function forms(key) {
      return translations[key].split('_');
    }
    var formatDistanceLocale$x = {
      lessThanXSeconds: {
        one: translateSeconds,
        other: translate
      },
      xSeconds: {
        one: translateSeconds,
        other: translate
      },
      halfAMinute: 'pusė minutės',
      lessThanXMinutes: {
        one: translateSingular,
        other: translate
      },
      xMinutes: {
        one: translateSingular,
        other: translate
      },
      aboutXHours: {
        one: translateSingular,
        other: translate
      },
      xHours: {
        one: translateSingular,
        other: translate
      },
      xDays: {
        one: translateSingular,
        other: translate
      },
      aboutXWeeks: {
        one: translateSingular,
        other: translate
      },
      xWeeks: {
        one: translateSingular,
        other: translate
      },
      aboutXMonths: {
        one: translateSingular,
        other: translate
      },
      xMonths: {
        one: translateSingular,
        other: translate
      },
      aboutXYears: {
        one: translateSingular,
        other: translate
      },
      xYears: {
        one: translateSingular,
        other: translate
      },
      overXYears: {
        one: translateSingular,
        other: translate
      },
      almostXYears: {
        one: translateSingular,
        other: translate
      }
    };
    var formatDistance$x = function (token, count, options) {
      var adverb = token.match(/about|over|almost|lessthan/i);
      var unit = adverb ? token.replace(adverb[0], '') : token;
      var isFuture = (options === null || options === void 0 ? void 0 : options.comparison) !== undefined && options.comparison > 0;
      var result;
      var tokenValue = formatDistanceLocale$x[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one(count, (options === null || options === void 0 ? void 0 : options.addSuffix) === true, unit.toLowerCase() + '_one', isFuture);
      } else {
        result = tokenValue.other(count, (options === null || options === void 0 ? void 0 : options.addSuffix) === true, unit.toLowerCase() + '_other', isFuture);
      }
      if (adverb) {
        var _key2 = adverb[0].toLowerCase();
        result = translations[_key2] + ' ' + result;
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'po ' + result;
        } else {
          return 'prieš ' + result;
        }
      }
      return result;
    };

    var dateFormats$x = {
      full: "y 'm'. MMMM d 'd'., EEEE",
      long: "y 'm'. MMMM d 'd'.",
      medium: 'y-MM-dd',
      short: 'y-MM-dd'
    };
    var timeFormats$x = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$x = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$x = {
      date: buildFormatLongFn({
        formats: dateFormats$x,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$x,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$x,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$x = {
      lastWeek: "'Praėjusį' eeee p",
      yesterday: "'Vakar' p",
      today: "'Šiandien' p",
      tomorrow: "'Rytoj' p",
      nextWeek: 'eeee p',
      other: 'P'
    };
    var formatRelative$x = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$x[token];
    };

    var eraValues$x = {
      narrow: ['pr. Kr.', 'po Kr.'],
      abbreviated: ['pr. Kr.', 'po Kr.'],
      wide: ['prieš Kristų', 'po Kristaus']
    };
    var quarterValues$x = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['I ketv.', 'II ketv.', 'III ketv.', 'IV ketv.'],
      wide: ['I ketvirtis', 'II ketvirtis', 'III ketvirtis', 'IV ketvirtis']
    };
    var formattingQuarterValues$2 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['I k.', 'II k.', 'III k.', 'IV k.'],
      wide: ['I ketvirtis', 'II ketvirtis', 'III ketvirtis', 'IV ketvirtis']
    };
    var monthValues$x = {
      narrow: ['S', 'V', 'K', 'B', 'G', 'B', 'L', 'R', 'R', 'S', 'L', 'G'],
      abbreviated: ['saus.', 'vas.', 'kov.', 'bal.', 'geg.', 'birž.', 'liep.', 'rugp.', 'rugs.', 'spal.', 'lapkr.', 'gruod.'],
      wide: ['sausis', 'vasaris', 'kovas', 'balandis', 'gegužė', 'birželis', 'liepa', 'rugpjūtis', 'rugsėjis', 'spalis', 'lapkritis', 'gruodis']
    };
    var formattingMonthValues$8 = {
      narrow: ['S', 'V', 'K', 'B', 'G', 'B', 'L', 'R', 'R', 'S', 'L', 'G'],
      abbreviated: ['saus.', 'vas.', 'kov.', 'bal.', 'geg.', 'birž.', 'liep.', 'rugp.', 'rugs.', 'spal.', 'lapkr.', 'gruod.'],
      wide: ['sausio', 'vasario', 'kovo', 'balandžio', 'gegužės', 'birželio', 'liepos', 'rugpjūčio', 'rugsėjo', 'spalio', 'lapkričio', 'gruodžio']
    };
    var dayValues$x = {
      narrow: ['S', 'P', 'A', 'T', 'K', 'P', 'Š'],
      short: ['Sk', 'Pr', 'An', 'Tr', 'Kt', 'Pn', 'Št'],
      abbreviated: ['sk', 'pr', 'an', 'tr', 'kt', 'pn', 'št'],
      wide: ['sekmadienis', 'pirmadienis', 'antradienis', 'trečiadienis', 'ketvirtadienis', 'penktadienis', 'šeštadienis']
    };
    var formattingDayValues$2 = {
      narrow: ['S', 'P', 'A', 'T', 'K', 'P', 'Š'],
      short: ['Sk', 'Pr', 'An', 'Tr', 'Kt', 'Pn', 'Št'],
      abbreviated: ['sk', 'pr', 'an', 'tr', 'kt', 'pn', 'št'],
      wide: ['sekmadienį', 'pirmadienį', 'antradienį', 'trečiadienį', 'ketvirtadienį', 'penktadienį', 'šeštadienį']
    };
    var dayPeriodValues$x = {
      narrow: {
        am: 'pr. p.',
        pm: 'pop.',
        midnight: 'vidurnaktis',
        noon: 'vidurdienis',
        morning: 'rytas',
        afternoon: 'diena',
        evening: 'vakaras',
        night: 'naktis'
      },
      abbreviated: {
        am: 'priešpiet',
        pm: 'popiet',
        midnight: 'vidurnaktis',
        noon: 'vidurdienis',
        morning: 'rytas',
        afternoon: 'diena',
        evening: 'vakaras',
        night: 'naktis'
      },
      wide: {
        am: 'priešpiet',
        pm: 'popiet',
        midnight: 'vidurnaktis',
        noon: 'vidurdienis',
        morning: 'rytas',
        afternoon: 'diena',
        evening: 'vakaras',
        night: 'naktis'
      }
    };
    var formattingDayPeriodValues$q = {
      narrow: {
        am: 'pr. p.',
        pm: 'pop.',
        midnight: 'vidurnaktis',
        noon: 'perpiet',
        morning: 'rytas',
        afternoon: 'popietė',
        evening: 'vakaras',
        night: 'naktis'
      },
      abbreviated: {
        am: 'priešpiet',
        pm: 'popiet',
        midnight: 'vidurnaktis',
        noon: 'perpiet',
        morning: 'rytas',
        afternoon: 'popietė',
        evening: 'vakaras',
        night: 'naktis'
      },
      wide: {
        am: 'priešpiet',
        pm: 'popiet',
        midnight: 'vidurnaktis',
        noon: 'perpiet',
        morning: 'rytas',
        afternoon: 'popietė',
        evening: 'vakaras',
        night: 'naktis'
      }
    };
    var ordinalNumber$x = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '-oji';
    };
    var localize$x = {
      ordinalNumber: ordinalNumber$x,
      era: buildLocalizeFn({
        values: eraValues$x,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$x,
        defaultWidth: 'wide',
        formattingValues: formattingQuarterValues$2,
        defaultFormattingWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$x,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$8,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$x,
        defaultWidth: 'wide',
        formattingValues: formattingDayValues$2,
        defaultFormattingWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$x,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$q,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$x = /^(\d+)(-oji)?/i;
    var parseOrdinalNumberPattern$x = /\d+/i;
    var matchEraPatterns$x = {
      narrow: /^p(r|o)\.?\s?(kr\.?|me)/i,
      abbreviated: /^(pr\.\s?(kr\.|m\.\s?e\.)|po\s?kr\.|mūsų eroje)/i,
      wide: /^(prieš Kristų|prieš mūsų erą|po Kristaus|mūsų eroje)/i
    };
    var parseEraPatterns$x = {
      wide: [/prieš/i, /(po|mūsų)/i],
      any: [/^pr/i, /^(po|m)/i]
    };
    var matchQuarterPatterns$x = {
      narrow: /^([1234])/i,
      abbreviated: /^(I|II|III|IV)\s?ketv?\.?/i,
      wide: /^(I|II|III|IV)\s?ketvirtis/i
    };
    var parseQuarterPatterns$x = {
      narrow: [/1/i, /2/i, /3/i, /4/i],
      any: [/I$/i, /II$/i, /III/i, /IV/i]
    };
    var matchMonthPatterns$x = {
      narrow: /^[svkbglr]/i,
      abbreviated: /^(saus\.|vas\.|kov\.|bal\.|geg\.|birž\.|liep\.|rugp\.|rugs\.|spal\.|lapkr\.|gruod\.)/i,
      wide: /^(sausi(s|o)|vasari(s|o)|kov(a|o)s|balandž?i(s|o)|gegužės?|birželi(s|o)|liep(a|os)|rugpjū(t|č)i(s|o)|rugsėj(is|o)|spali(s|o)|lapkri(t|č)i(s|o)|gruodž?i(s|o))/i
    };
    var parseMonthPatterns$x = {
      narrow: [/^s/i, /^v/i, /^k/i, /^b/i, /^g/i, /^b/i, /^l/i, /^r/i, /^r/i, /^s/i, /^l/i, /^g/i],
      any: [/^saus/i, /^vas/i, /^kov/i, /^bal/i, /^geg/i, /^birž/i, /^liep/i, /^rugp/i, /^rugs/i, /^spal/i, /^lapkr/i, /^gruod/i]
    };
    var matchDayPatterns$x = {
      narrow: /^[spatkš]/i,
      short: /^(sk|pr|an|tr|kt|pn|št)/i,
      abbreviated: /^(sk|pr|an|tr|kt|pn|št)/i,
      wide: /^(sekmadien(is|į)|pirmadien(is|į)|antradien(is|į)|trečiadien(is|į)|ketvirtadien(is|į)|penktadien(is|į)|šeštadien(is|į))/i
    };
    var parseDayPatterns$x = {
      narrow: [/^s/i, /^p/i, /^a/i, /^t/i, /^k/i, /^p/i, /^š/i],
      wide: [/^se/i, /^pi/i, /^an/i, /^tr/i, /^ke/i, /^pe/i, /^še/i],
      any: [/^sk/i, /^pr/i, /^an/i, /^tr/i, /^kt/i, /^pn/i, /^št/i]
    };
    var matchDayPeriodPatterns$x = {
      narrow: /^(pr.\s?p.|pop.|vidurnaktis|(vidurdienis|perpiet)|rytas|(diena|popietė)|vakaras|naktis)/i,
      any: /^(priešpiet|popiet$|vidurnaktis|(vidurdienis|perpiet)|rytas|(diena|popietė)|vakaras|naktis)/i
    };
    var parseDayPeriodPatterns$x = {
      narrow: {
        am: /^pr/i,
        pm: /^pop./i,
        midnight: /^vidurnaktis/i,
        noon: /^(vidurdienis|perp)/i,
        morning: /rytas/i,
        afternoon: /(die|popietė)/i,
        evening: /vakaras/i,
        night: /naktis/i
      },
      any: {
        am: /^pr/i,
        pm: /^popiet$/i,
        midnight: /^vidurnaktis/i,
        noon: /^(vidurdienis|perp)/i,
        morning: /rytas/i,
        afternoon: /(die|popietė)/i,
        evening: /vakaras/i,
        night: /naktis/i
      }
    };
    var match$x = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$x,
        parsePattern: parseOrdinalNumberPattern$x,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$x,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$x,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$x,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$x,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$x,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$x,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$x,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$x,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$x,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$x,
        defaultParseWidth: 'any'
      })
    };

    var locale$x = {
      code: 'lt',
      formatDistance: formatDistance$x,
      formatLong: formatLong$x,
      formatRelative: formatRelative$x,
      localize: localize$x,
      match: match$x,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    function buildLocalizeTokenFn$2(schema) {
      return function (count, options) {
        if (count === 1) {
          if (options !== null && options !== void 0 && options.addSuffix) {
            return schema.one[0].replace('{{time}}', schema.one[2]);
          } else {
            return schema.one[0].replace('{{time}}', schema.one[1]);
          }
        } else {
          var rem = count % 10 === 1 && count % 100 !== 11;
          if (options !== null && options !== void 0 && options.addSuffix) {
            return schema.other[0].replace('{{time}}', rem ? schema.other[3] : schema.other[4]).replace('{{count}}', String(count));
          } else {
            return schema.other[0].replace('{{time}}', rem ? schema.other[1] : schema.other[2]).replace('{{count}}', String(count));
          }
        }
      };
    }
    var formatDistanceLocale$w = {
      lessThanXSeconds: buildLocalizeTokenFn$2({
        one: ['mazāk par {{time}}', 'sekundi', 'sekundi'],
        other: ['mazāk nekā {{count}} {{time}}', 'sekunde', 'sekundes', 'sekundes', 'sekundēm']
      }),
      xSeconds: buildLocalizeTokenFn$2({
        one: ['1 {{time}}', 'sekunde', 'sekundes'],
        other: ['{{count}} {{time}}', 'sekunde', 'sekundes', 'sekundes', 'sekundēm']
      }),
      halfAMinute: function (_count, options) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          return 'pusminūtes';
        } else {
          return 'pusminūte';
        }
      },
      lessThanXMinutes: buildLocalizeTokenFn$2({
        one: ['mazāk par {{time}}', 'minūti', 'minūti'],
        other: ['mazāk nekā {{count}} {{time}}', 'minūte', 'minūtes', 'minūtes', 'minūtēm']
      }),
      xMinutes: buildLocalizeTokenFn$2({
        one: ['1 {{time}}', 'minūte', 'minūtes'],
        other: ['{{count}} {{time}}', 'minūte', 'minūtes', 'minūtes', 'minūtēm']
      }),
      aboutXHours: buildLocalizeTokenFn$2({
        one: ['apmēram 1 {{time}}', 'stunda', 'stundas'],
        other: ['apmēram {{count}} {{time}}', 'stunda', 'stundas', 'stundas', 'stundām']
      }),
      xHours: buildLocalizeTokenFn$2({
        one: ['1 {{time}}', 'stunda', 'stundas'],
        other: ['{{count}} {{time}}', 'stunda', 'stundas', 'stundas', 'stundām']
      }),
      xDays: buildLocalizeTokenFn$2({
        one: ['1 {{time}}', 'diena', 'dienas'],
        other: ['{{count}} {{time}}', 'diena', 'dienas', 'dienas', 'dienām']
      }),
      aboutXWeeks: buildLocalizeTokenFn$2({
        one: ['apmēram 1 {{time}}', 'nedēļa', 'nedēļas'],
        other: ['apmēram {{count}} {{time}}', 'nedēļa', 'nedēļu', 'nedēļas', 'nedēļām']
      }),
      xWeeks: buildLocalizeTokenFn$2({
        one: ['1 {{time}}', 'nedēļa', 'nedēļas'],
        other: ['{{count}} {{time}}',
        'nedēļa', 'nedēļu', 'nedēļas', 'nedēļām']
      }),
      aboutXMonths: buildLocalizeTokenFn$2({
        one: ['apmēram 1 {{time}}', 'mēnesis', 'mēneša'],
        other: ['apmēram {{count}} {{time}}', 'mēnesis', 'mēneši', 'mēneša', 'mēnešiem']
      }),
      xMonths: buildLocalizeTokenFn$2({
        one: ['1 {{time}}', 'mēnesis', 'mēneša'],
        other: ['{{count}} {{time}}', 'mēnesis', 'mēneši', 'mēneša', 'mēnešiem']
      }),
      aboutXYears: buildLocalizeTokenFn$2({
        one: ['apmēram 1 {{time}}', 'gads', 'gada'],
        other: ['apmēram {{count}} {{time}}', 'gads', 'gadi', 'gada', 'gadiem']
      }),
      xYears: buildLocalizeTokenFn$2({
        one: ['1 {{time}}', 'gads', 'gada'],
        other: ['{{count}} {{time}}', 'gads', 'gadi', 'gada', 'gadiem']
      }),
      overXYears: buildLocalizeTokenFn$2({
        one: ['ilgāk par 1 {{time}}', 'gadu', 'gadu'],
        other: ['vairāk nekā {{count}} {{time}}', 'gads', 'gadi', 'gada', 'gadiem']
      }),
      almostXYears: buildLocalizeTokenFn$2({
        one: ['gandrīz 1 {{time}}', 'gads', 'gada'],
        other: ['vairāk nekā {{count}} {{time}}', 'gads', 'gadi', 'gada', 'gadiem']
      })
    };
    var formatDistance$w = function (token, count, options) {
      var result = formatDistanceLocale$w[token](count, options);
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'pēc ' + result;
        } else {
          return 'pirms ' + result;
        }
      }
      return result;
    };

    var dateFormats$w = {
      full: "EEEE, y. 'gada' d. MMMM",
      long: "y. 'gada' d. MMMM",
      medium: 'dd.MM.y.',
      short: 'dd.MM.y.'
    };
    var timeFormats$w = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$w = {
      full: "{{date}} 'plkst.' {{time}}",
      long: "{{date}} 'plkst.' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$w = {
      date: buildFormatLongFn({
        formats: dateFormats$w,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$w,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$w,
        defaultWidth: 'full'
      })
    };

    var weekdays$1 = ['svētdienā', 'pirmdienā', 'otrdienā', 'trešdienā', 'ceturtdienā', 'piektdienā', 'sestdienā'];
    var formatRelativeLocale$w = {
      lastWeek: function (date, baseDate, options) {
        if (isSameUTCWeek(date, baseDate, options)) {
          return "eeee 'plkst.' p";
        }
        var weekday = weekdays$1[date.getUTCDay()];
        return "'Pagājušā " + weekday + " plkst.' p";
      },
      yesterday: "'Vakar plkst.' p",
      today: "'Šodien plkst.' p",
      tomorrow: "'Rīt plkst.' p",
      nextWeek: function (date, baseDate, options) {
        if (isSameUTCWeek(date, baseDate, options)) {
          return "eeee 'plkst.' p";
        }
        var weekday = weekdays$1[date.getUTCDay()];
        return "'Nākamajā " + weekday + " plkst.' p";
      },
      other: 'P'
    };
    var formatRelative$w = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$w[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$w = {
      narrow: ['p.m.ē', 'm.ē'],
      abbreviated: ['p. m. ē.', 'm. ē.'],
      wide: ['pirms mūsu ēras', 'mūsu ērā']
    };
    var quarterValues$w = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1. cet.', '2. cet.', '3. cet.', '4. cet.'],
      wide: ['pirmais ceturksnis', 'otrais ceturksnis', 'trešais ceturksnis', 'ceturtais ceturksnis']
    };
    var formattingQuarterValues$1 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1. cet.', '2. cet.', '3. cet.', '4. cet.'],
      wide: ['pirmajā ceturksnī', 'otrajā ceturksnī', 'trešajā ceturksnī', 'ceturtajā ceturksnī']
    };
    var monthValues$w = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['janv.', 'febr.', 'marts', 'apr.', 'maijs', 'jūn.', 'jūl.', 'aug.', 'sept.', 'okt.', 'nov.', 'dec.'],
      wide: ['janvāris', 'februāris', 'marts', 'aprīlis', 'maijs', 'jūnijs', 'jūlijs', 'augusts', 'septembris', 'oktobris', 'novembris', 'decembris']
    };
    var formattingMonthValues$7 = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['janv.', 'febr.', 'martā', 'apr.', 'maijs', 'jūn.', 'jūl.', 'aug.', 'sept.', 'okt.', 'nov.', 'dec.'],
      wide: ['janvārī', 'februārī', 'martā', 'aprīlī', 'maijā', 'jūnijā', 'jūlijā', 'augustā', 'septembrī', 'oktobrī', 'novembrī', 'decembrī']
    };
    var dayValues$w = {
      narrow: ['S', 'P', 'O', 'T', 'C', 'P', 'S'],
      short: ['Sv', 'P', 'O', 'T', 'C', 'Pk', 'S'],
      abbreviated: ['svētd.', 'pirmd.', 'otrd.', 'trešd.', 'ceturtd.', 'piektd.', 'sestd.'],
      wide: ['svētdiena', 'pirmdiena', 'otrdiena', 'trešdiena', 'ceturtdiena', 'piektdiena', 'sestdiena']
    };
    var formattingDayValues$1 = {
      narrow: ['S', 'P', 'O', 'T', 'C', 'P', 'S'],
      short: ['Sv', 'P', 'O', 'T', 'C', 'Pk', 'S'],
      abbreviated: ['svētd.', 'pirmd.', 'otrd.', 'trešd.', 'ceturtd.', 'piektd.', 'sestd.'],
      wide: ['svētdienā', 'pirmdienā', 'otrdienā', 'trešdienā', 'ceturtdienā', 'piektdienā', 'sestdienā']
    };
    var dayPeriodValues$w = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'pusn.',
        noon: 'pusd.',
        morning: 'rīts',
        afternoon: 'diena',
        evening: 'vakars',
        night: 'nakts'
      },
      abbreviated: {
        am: 'am',
        pm: 'pm',
        midnight: 'pusn.',
        noon: 'pusd.',
        morning: 'rīts',
        afternoon: 'pēcpusd.',
        evening: 'vakars',
        night: 'nakts'
      },
      wide: {
        am: 'am',
        pm: 'pm',
        midnight: 'pusnakts',
        noon: 'pusdienlaiks',
        morning: 'rīts',
        afternoon: 'pēcpusdiena',
        evening: 'vakars',
        night: 'nakts'
      }
    };
    var formattingDayPeriodValues$p = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'pusn.',
        noon: 'pusd.',
        morning: 'rītā',
        afternoon: 'dienā',
        evening: 'vakarā',
        night: 'naktī'
      },
      abbreviated: {
        am: 'am',
        pm: 'pm',
        midnight: 'pusn.',
        noon: 'pusd.',
        morning: 'rītā',
        afternoon: 'pēcpusd.',
        evening: 'vakarā',
        night: 'naktī'
      },
      wide: {
        am: 'am',
        pm: 'pm',
        midnight: 'pusnaktī',
        noon: 'pusdienlaikā',
        morning: 'rītā',
        afternoon: 'pēcpusdienā',
        evening: 'vakarā',
        night: 'naktī'
      }
    };
    var ordinalNumber$w = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$w = {
      ordinalNumber: ordinalNumber$w,
      era: buildLocalizeFn({
        values: eraValues$w,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$w,
        defaultWidth: 'wide',
        formattingValues: formattingQuarterValues$1,
        defaultFormattingWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$w,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$7,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$w,
        defaultWidth: 'wide',
        formattingValues: formattingDayValues$1,
        defaultFormattingWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$w,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$p,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$w = /^(\d+)\./i;
    var parseOrdinalNumberPattern$w = /\d+/i;
    var matchEraPatterns$w = {
      narrow: /^(p\.m\.ē|m\.ē)/i,
      abbreviated: /^(p\. m\. ē\.|m\. ē\.)/i,
      wide: /^(pirms mūsu ēras|mūsu ērā)/i
    };
    var parseEraPatterns$w = {
      any: [/^p/i, /^m/i]
    };
    var matchQuarterPatterns$w = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](\. cet\.)/i,
      wide: /^(pirma(is|jā)|otra(is|jā)|treša(is|jā)|ceturta(is|jā)) ceturksn(is|ī)/i
    };
    var parseQuarterPatterns$w = {
      narrow: [/^1/i, /^2/i, /^3/i, /^4/i],
      abbreviated: [/^1/i, /^2/i, /^3/i, /^4/i],
      wide: [/^p/i, /^o/i, /^t/i, /^c/i]
    };
    var matchMonthPatterns$w = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(janv\.|febr\.|marts|apr\.|maijs|jūn\.|jūl\.|aug\.|sept\.|okt\.|nov\.|dec\.)/i,
      wide: /^(janvār(is|ī)|februār(is|ī)|mart[sā]|aprīl(is|ī)|maij[sā]|jūnij[sā]|jūlij[sā]|august[sā]|septembr(is|ī)|oktobr(is|ī)|novembr(is|ī)|decembr(is|ī))/i
    };
    var parseMonthPatterns$w = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^mai/i, /^jūn/i, /^jūl/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$w = {
      narrow: /^[spotc]/i,
      short: /^(sv|pi|o|t|c|pk|s)/i,
      abbreviated: /^(svētd\.|pirmd\.|otrd.\|trešd\.|ceturtd\.|piektd\.|sestd\.)/i,
      wide: /^(svētdien(a|ā)|pirmdien(a|ā)|otrdien(a|ā)|trešdien(a|ā)|ceturtdien(a|ā)|piektdien(a|ā)|sestdien(a|ā))/i
    };
    var parseDayPatterns$w = {
      narrow: [/^s/i, /^p/i, /^o/i, /^t/i, /^c/i, /^p/i, /^s/i],
      any: [/^sv/i, /^pi/i, /^o/i, /^t/i, /^c/i, /^p/i, /^se/i]
    };
    var matchDayPeriodPatterns$w = {
      narrow: /^(am|pm|pusn\.|pusd\.|rīt(s|ā)|dien(a|ā)|vakar(s|ā)|nakt(s|ī))/,
      abbreviated: /^(am|pm|pusn\.|pusd\.|rīt(s|ā)|pēcpusd\.|vakar(s|ā)|nakt(s|ī))/,
      wide: /^(am|pm|pusnakt(s|ī)|pusdienlaik(s|ā)|rīt(s|ā)|pēcpusdien(a|ā)|vakar(s|ā)|nakt(s|ī))/i
    };
    var parseDayPeriodPatterns$w = {
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /^pusn/i,
        noon: /^pusd/i,
        morning: /^r/i,
        afternoon: /^(d|pēc)/i,
        evening: /^v/i,
        night: /^n/i
      }
    };
    var match$w = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$w,
        parsePattern: parseOrdinalNumberPattern$w,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$w,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$w,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$w,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$w,
        defaultParseWidth: 'wide',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$w,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$w,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$w,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$w,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$w,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$w,
        defaultParseWidth: 'any'
      })
    };

    var locale$w = {
      code: 'lv',
      formatDistance: formatDistance$w,
      formatLong: formatLong$w,
      formatRelative: formatRelative$w,
      localize: localize$w,
      match: match$w,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$v = {
      lessThanXSeconds: {
        one: 'помалку од секунда',
        other: 'помалку од {{count}} секунди'
      },
      xSeconds: {
        one: '1 секунда',
        other: '{{count}} секунди'
      },
      halfAMinute: 'половина минута',
      lessThanXMinutes: {
        one: 'помалку од минута',
        other: 'помалку од {{count}} минути'
      },
      xMinutes: {
        one: '1 минута',
        other: '{{count}} минути'
      },
      aboutXHours: {
        one: 'околу 1 час',
        other: 'околу {{count}} часа'
      },
      xHours: {
        one: '1 час',
        other: '{{count}} часа'
      },
      xDays: {
        one: '1 ден',
        other: '{{count}} дена'
      },
      aboutXWeeks: {
        one: 'околу 1 недела',
        other: 'околу {{count}} месеци'
      },
      xWeeks: {
        one: '1 недела',
        other: '{{count}} недели'
      },
      aboutXMonths: {
        one: 'околу 1 месец',
        other: 'околу {{count}} недели'
      },
      xMonths: {
        one: '1 месец',
        other: '{{count}} месеци'
      },
      aboutXYears: {
        one: 'околу 1 година',
        other: 'околу {{count}} години'
      },
      xYears: {
        one: '1 година',
        other: '{{count}} години'
      },
      overXYears: {
        one: 'повеќе од 1 година',
        other: 'повеќе од {{count}} години'
      },
      almostXYears: {
        one: 'безмалку 1 година',
        other: 'безмалку {{count}} години'
      }
    };
    var formatDistance$v = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$v[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'за ' + result;
        } else {
          return 'пред ' + result;
        }
      }
      return result;
    };

    var dateFormats$v = {
      full: 'EEEE, dd MMMM yyyy',
      long: 'dd MMMM yyyy',
      medium: 'dd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$v = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$v = {
      any: '{{date}} {{time}}'
    };
    var formatLong$v = {
      date: buildFormatLongFn({
        formats: dateFormats$v,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$v,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$v,
        defaultWidth: 'any'
      })
    };

    var weekdays = ['недела', 'понеделник', 'вторник', 'среда', 'четврток', 'петок', 'сабота'];
    function lastWeek$3(day) {
      var weekday = weekdays[day];
      switch (day) {
        case 0:
        case 3:
        case 6:
          return "'минатата " + weekday + " во' p";
        case 1:
        case 2:
        case 4:
        case 5:
          return "'минатиот " + weekday + " во' p";
      }
    }
    function thisWeek$3(day) {
      var weekday = weekdays[day];
      switch (day) {
        case 0:
        case 3:
        case 6:
          return "'ова " + weekday + " вo' p";
        case 1:
        case 2:
        case 4:
        case 5:
          return "'овој " + weekday + " вo' p";
      }
    }
    function nextWeek$3(day) {
      var weekday = weekdays[day];
      switch (day) {
        case 0:
        case 3:
        case 6:
          return "'следната " + weekday + " вo' p";
        case 1:
        case 2:
        case 4:
        case 5:
          return "'следниот " + weekday + " вo' p";
      }
    }
    var formatRelativeLocale$v = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$3(day);
        } else {
          return lastWeek$3(day);
        }
      },
      yesterday: "'вчера во' p",
      today: "'денес во' p",
      tomorrow: "'утре во' p",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$3(day);
        } else {
          return nextWeek$3(day);
        }
      },
      other: 'P'
    };
    var formatRelative$v = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$v[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$v = {
      narrow: ['пр.н.е.', 'н.е.'],
      abbreviated: ['пред н. е.', 'н. е.'],
      wide: ['пред нашата ера', 'нашата ера']
    };
    var quarterValues$v = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-ви кв.', '2-ри кв.', '3-ти кв.', '4-ти кв.'],
      wide: ['1-ви квартал', '2-ри квартал', '3-ти квартал', '4-ти квартал']
    };
    var monthValues$v = {
      abbreviated: ['јан', 'фев', 'мар', 'апр', 'мај', 'јун', 'јул', 'авг', 'септ', 'окт', 'ноем', 'дек'],
      wide: ['јануари', 'февруари', 'март', 'април', 'мај', 'јуни', 'јули', 'август', 'септември', 'октомври', 'ноември', 'декември']
    };
    var dayValues$v = {
      narrow: ['Н', 'П', 'В', 'С', 'Ч', 'П', 'С'],
      short: ['не', 'по', 'вт', 'ср', 'че', 'пе', 'са'],
      abbreviated: ['нед', 'пон', 'вто', 'сре', 'чет', 'пет', 'саб'],
      wide: ['недела', 'понеделник', 'вторник', 'среда', 'четврток', 'петок', 'сабота']
    };
    var dayPeriodValues$v = {
      wide: {
        am: 'претпладне',
        pm: 'попладне',
        midnight: 'полноќ',
        noon: 'напладне',
        morning: 'наутро',
        afternoon: 'попладне',
        evening: 'навечер',
        night: 'ноќе'
      }
    };
    var ordinalNumber$v = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      var rem100 = number % 100;
      if (rem100 > 20 || rem100 < 10) {
        switch (rem100 % 10) {
          case 1:
            return number + '-ви';
          case 2:
            return number + '-ри';
          case 7:
          case 8:
            return number + '-ми';
        }
      }
      return number + '-ти';
    };
    var localize$v = {
      ordinalNumber: ordinalNumber$v,
      era: buildLocalizeFn({
        values: eraValues$v,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$v,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$v,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$v,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$v,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$v = /^(\d+)(-?[врмт][и])?/i;
    var parseOrdinalNumberPattern$v = /\d+/i;
    var matchEraPatterns$v = {
      narrow: /^((пр)?н\.?\s?е\.?)/i,
      abbreviated: /^((пр)?н\.?\s?е\.?)/i,
      wide: /^(пред нашата ера|нашата ера)/i
    };
    var parseEraPatterns$v = {
      any: [/^п/i, /^н/i]
    };
    var matchQuarterPatterns$v = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[врт]?и?)? кв.?/i,
      wide: /^[1234](-?[врт]?и?)? квартал/i
    };
    var parseQuarterPatterns$v = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchDayPatterns$v = {
      narrow: /^[нпвсч]/i,
      short: /^(не|по|вт|ср|че|пе|са)/i,
      abbreviated: /^(нед|пон|вто|сре|чет|пет|саб)/i,
      wide: /^(недела|понеделник|вторник|среда|четврток|петок|сабота)/i
    };
    var parseDayPatterns$v = {
      narrow: [/^н/i, /^п/i, /^в/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^н[ед]/i, /^п[он]/i, /^вт/i, /^ср/i, /^ч[ет]/i, /^п[ет]/i, /^с[аб]/i]
    };
    var matchMonthPatterns$v = {
      abbreviated: /^(јан|фев|мар|апр|мај|јун|јул|авг|сеп|окт|ноем|дек)/i,
      wide: /^(јануари|февруари|март|април|мај|јуни|јули|август|септември|октомври|ноември|декември)/i
    };
    var parseMonthPatterns$v = {
      any: [/^ја/i, /^Ф/i, /^мар/i, /^ап/i, /^мај/i, /^јун/i, /^јул/i, /^ав/i, /^се/i, /^окт/i, /^но/i, /^де/i]
    };
    var matchDayPeriodPatterns$v = {
      any: /^(претп|попл|полноќ|утро|пладне|вечер|ноќ)/i
    };
    var parseDayPeriodPatterns$v = {
      any: {
        am: /претпладне/i,
        pm: /попладне/i,
        midnight: /полноќ/i,
        noon: /напладне/i,
        morning: /наутро/i,
        afternoon: /попладне/i,
        evening: /навечер/i,
        night: /ноќе/i
      }
    };
    var match$v = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$v,
        parsePattern: parseOrdinalNumberPattern$v,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$v,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$v,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$v,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$v,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$v,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$v,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$v,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$v,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$v,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$v,
        defaultParseWidth: 'any'
      })
    };

    var locale$v = {
      code: 'mk',
      formatDistance: formatDistance$v,
      formatLong: formatLong$v,
      formatRelative: formatRelative$v,
      localize: localize$v,
      match: match$v,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$u = {
      lessThanXSeconds: {
        one: 'секунд хүрэхгүй',
        other: '{{count}} секунд хүрэхгүй'
      },
      xSeconds: {
        one: '1 секунд',
        other: '{{count}} секунд'
      },
      halfAMinute: 'хагас минут',
      lessThanXMinutes: {
        one: 'минут хүрэхгүй',
        other: '{{count}} минут хүрэхгүй'
      },
      xMinutes: {
        one: '1 минут',
        other: '{{count}} минут'
      },
      aboutXHours: {
        one: 'ойролцоогоор 1 цаг',
        other: 'ойролцоогоор {{count}} цаг'
      },
      xHours: {
        one: '1 цаг',
        other: '{{count}} цаг'
      },
      xDays: {
        one: '1 өдөр',
        other: '{{count}} өдөр'
      },
      aboutXWeeks: {
        one: 'ойролцоогоор 1 долоо хоног',
        other: 'ойролцоогоор {{count}} долоо хоног'
      },
      xWeeks: {
        one: '1 долоо хоног',
        other: '{{count}} долоо хоног'
      },
      aboutXMonths: {
        one: 'ойролцоогоор 1 сар',
        other: 'ойролцоогоор {{count}} сар'
      },
      xMonths: {
        one: '1 сар',
        other: '{{count}} сар'
      },
      aboutXYears: {
        one: 'ойролцоогоор 1 жил',
        other: 'ойролцоогоор {{count}} жил'
      },
      xYears: {
        one: '1 жил',
        other: '{{count}} жил'
      },
      overXYears: {
        one: '1 жил гаран',
        other: '{{count}} жил гаран'
      },
      almostXYears: {
        one: 'бараг 1 жил',
        other: 'бараг {{count}} жил'
      }
    };
    var formatDistance$u = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$u[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        var words = result.split(' ');
        var lastword = words.pop();
        result = words.join(' ');
        switch (lastword) {
          case 'секунд':
            result += ' секундийн';
            break;
          case 'минут':
            result += ' минутын';
            break;
          case 'цаг':
            result += ' цагийн';
            break;
          case 'өдөр':
            result += ' өдрийн';
            break;
          case 'сар':
            result += ' сарын';
            break;
          case 'жил':
            result += ' жилийн';
            break;
          case 'хоног':
            result += ' хоногийн';
            break;
          case 'гаран':
            result += ' гараны';
            break;
          case 'хүрэхгүй':
            result += ' хүрэхгүй хугацааны';
            break;
          default:
            result += lastword + '-н';
        }
        if (options.comparison && options.comparison > 0) {
          return result + ' дараа';
        } else {
          return result + ' өмнө';
        }
      }
      return result;
    };

    var dateFormats$u = {
      full: "y 'оны' MMMM'ын' d, EEEE 'гараг'",
      long: "y 'оны' MMMM'ын' d",
      medium: "y 'оны' MMM'ын' d",
      short: 'y.MM.dd'
    };
    var timeFormats$u = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$u = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$u = {
      date: buildFormatLongFn({
        formats: dateFormats$u,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$u,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$u,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$u = {
      lastWeek: "'өнгөрсөн' eeee 'гарагийн' p 'цагт'",
      yesterday: "'өчигдөр' p 'цагт'",
      today: "'өнөөдөр' p 'цагт'",
      tomorrow: "'маргааш' p 'цагт'",
      nextWeek: "'ирэх' eeee 'гарагийн' p 'цагт'",
      other: 'P'
    };
    var formatRelative$u = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$u[token];
    };

    var eraValues$u = {
      narrow: ['НТӨ', 'НТ'],
      abbreviated: ['НТӨ', 'НТ'],
      wide: ['нийтийн тооллын өмнөх', 'нийтийн тооллын']
    };
    var quarterValues$u = {
      narrow: ['I', 'II', 'III', 'IV'],
      abbreviated: ['I улирал', 'II улирал', 'III улирал', 'IV улирал'],
      wide: ['1-р улирал', '2-р улирал', '3-р улирал', '4-р улирал']
    };
    var monthValues$u = {
      narrow: ['I', 'II', 'III', 'IV', 'V', 'VI', 'VII', 'VIII', 'IX', 'X', 'XI', 'XII'],
      abbreviated: ['1-р сар', '2-р сар', '3-р сар', '4-р сар', '5-р сар', '6-р сар', '7-р сар', '8-р сар', '9-р сар', '10-р сар', '11-р сар', '12-р сар'],
      wide: ['Нэгдүгээр сар', 'Хоёрдугаар сар', 'Гуравдугаар сар', 'Дөрөвдүгээр сар', 'Тавдугаар сар', 'Зургаадугаар сар', 'Долоодугаар сар', 'Наймдугаар сар', 'Есдүгээр сар', 'Аравдугаар сар', 'Арваннэгдүгээр сар', 'Арван хоёрдугаар сар']
    };
    var formattingMonthValues$6 = {
      narrow: ['I', 'II', 'III', 'IV', 'V', 'VI', 'VII', 'VIII', 'IX', 'X', 'XI', 'XII'],
      abbreviated: ['1-р сар', '2-р сар', '3-р сар', '4-р сар', '5-р сар', '6-р сар', '7-р сар', '8-р сар', '9-р сар', '10-р сар', '11-р сар', '12-р сар'],
      wide: ['нэгдүгээр сар', 'хоёрдугаар сар', 'гуравдугаар сар', 'дөрөвдүгээр сар', 'тавдугаар сар', 'зургаадугаар сар', 'долоодугаар сар', 'наймдугаар сар', 'есдүгээр сар', 'аравдугаар сар', 'арваннэгдүгээр сар', 'арван хоёрдугаар сар']
    };
    var dayValues$u = {
      narrow: ['Н', 'Д', 'М', 'Л', 'П', 'Б', 'Б'],
      short: ['Ня', 'Да', 'Мя', 'Лх', 'Пү', 'Ба', 'Бя'],
      abbreviated: ['Ням', 'Дав', 'Мяг', 'Лха', 'Пүр', 'Баа', 'Бям'],
      wide: ['Ням', 'Даваа', 'Мягмар', 'Лхагва', 'Пүрэв', 'Баасан', 'Бямба']
    };
    var formattingDayValues = {
      narrow: ['Н', 'Д', 'М', 'Л', 'П', 'Б', 'Б'],
      short: ['Ня', 'Да', 'Мя', 'Лх', 'Пү', 'Ба', 'Бя'],
      abbreviated: ['Ням', 'Дав', 'Мяг', 'Лха', 'Пүр', 'Баа', 'Бям'],
      wide: ['ням', 'даваа', 'мягмар', 'лхагва', 'пүрэв', 'баасан', 'бямба']
    };
    var dayPeriodValues$u = {
      narrow: {
        am: 'ү.ө.',
        pm: 'ү.х.',
        midnight: 'шөнө дунд',
        noon: 'үд дунд',
        morning: 'өглөө',
        afternoon: 'өдөр',
        evening: 'орой',
        night: 'шөнө'
      },
      abbreviated: {
        am: 'ү.ө.',
        pm: 'ү.х.',
        midnight: 'шөнө дунд',
        noon: 'үд дунд',
        morning: 'өглөө',
        afternoon: 'өдөр',
        evening: 'орой',
        night: 'шөнө'
      },
      wide: {
        am: 'ү.ө.',
        pm: 'ү.х.',
        midnight: 'шөнө дунд',
        noon: 'үд дунд',
        morning: 'өглөө',
        afternoon: 'өдөр',
        evening: 'орой',
        night: 'шөнө'
      }
    };
    var ordinalNumber$u = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$u = {
      ordinalNumber: ordinalNumber$u,
      era: buildLocalizeFn({
        values: eraValues$u,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$u,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$u,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$6,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$u,
        defaultWidth: 'wide',
        formattingValues: formattingDayValues,
        defaultFormattingWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$u,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$u = /\d+/i;
    var parseOrdinalNumberPattern$u = /\d+/i;
    var matchEraPatterns$u = {
      narrow: /^(нтө|нт)/i,
      abbreviated: /^(нтө|нт)/i,
      wide: /^(нийтийн тооллын өмнө|нийтийн тооллын)/i
    };
    var parseEraPatterns$u = {
      any: [/^(нтө|нийтийн тооллын өмнө)/i, /^(нт|нийтийн тооллын)/i]
    };
    var matchQuarterPatterns$u = {
      narrow: /^(iv|iii|ii|i)/i,
      abbreviated: /^(iv|iii|ii|i) улирал/i,
      wide: /^[1-4]-р улирал/i
    };
    var parseQuarterPatterns$u = {
      any: [/^(i(\s|$)|1)/i, /^(ii(\s|$)|2)/i, /^(iii(\s|$)|3)/i, /^(iv(\s|$)|4)/i]
    };
    var matchMonthPatterns$u = {
      narrow: /^(xii|xi|x|ix|viii|vii|vi|v|iv|iii|ii|i)/i,
      abbreviated: /^(1-р сар|2-р сар|3-р сар|4-р сар|5-р сар|6-р сар|7-р сар|8-р сар|9-р сар|10-р сар|11-р сар|12-р сар)/i,
      wide: /^(нэгдүгээр сар|хоёрдугаар сар|гуравдугаар сар|дөрөвдүгээр сар|тавдугаар сар|зургаадугаар сар|долоодугаар сар|наймдугаар сар|есдүгээр сар|аравдугаар сар|арван нэгдүгээр сар|арван хоёрдугаар сар)/i
    };
    var parseMonthPatterns$u = {
      narrow: [/^i$/i, /^ii$/i, /^iii$/i, /^iv$/i, /^v$/i, /^vi$/i, /^vii$/i, /^viii$/i, /^ix$/i, /^x$/i, /^xi$/i, /^xii$/i],
      any: [/^(1|нэгдүгээр)/i, /^(2|хоёрдугаар)/i, /^(3|гуравдугаар)/i, /^(4|дөрөвдүгээр)/i, /^(5|тавдугаар)/i, /^(6|зургаадугаар)/i, /^(7|долоодугаар)/i, /^(8|наймдугаар)/i, /^(9|есдүгээр)/i, /^(10|аравдугаар)/i, /^(11|арван нэгдүгээр)/i, /^(12|арван хоёрдугаар)/i]
    };
    var matchDayPatterns$u = {
      narrow: /^[ндмлпбб]/i,
      short: /^(ня|да|мя|лх|пү|ба|бя)/i,
      abbreviated: /^(ням|дав|мяг|лха|пүр|баа|бям)/i,
      wide: /^(ням|даваа|мягмар|лхагва|пүрэв|баасан|бямба)/i
    };
    var parseDayPatterns$u = {
      narrow: [/^н/i, /^д/i, /^м/i, /^л/i, /^п/i, /^б/i, /^б/i],
      any: [/^ня/i, /^да/i, /^мя/i, /^лх/i, /^пү/i, /^ба/i, /^бя/i]
    };
    var matchDayPeriodPatterns$u = {
      narrow: /^(ү\.ө\.|ү\.х\.|шөнө дунд|үд дунд|өглөө|өдөр|орой|шөнө)/i,
      any: /^(ү\.ө\.|ү\.х\.|шөнө дунд|үд дунд|өглөө|өдөр|орой|шөнө)/i
    };
    var parseDayPeriodPatterns$u = {
      any: {
        am: /^ү\.ө\./i,
        pm: /^ү\.х\./i,
        midnight: /^шөнө дунд/i,
        noon: /^үд дунд/i,
        morning: /өглөө/i,
        afternoon: /өдөр/i,
        evening: /орой/i,
        night: /шөнө/i
      }
    };
    var match$u = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$u,
        parsePattern: parseOrdinalNumberPattern$u,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$u,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$u,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$u,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$u,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$u,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$u,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$u,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$u,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$u,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$u,
        defaultParseWidth: 'any'
      })
    };

    var locale$u = {
      code: 'mn',
      formatDistance: formatDistance$u,
      formatLong: formatLong$u,
      formatRelative: formatRelative$u,
      localize: localize$u,
      match: match$u,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$t = {
      lessThanXSeconds: {
        one: 'kurang dari 1 saat',
        other: 'kurang dari {{count}} saat'
      },
      xSeconds: {
        one: '1 saat',
        other: '{{count}} saat'
      },
      halfAMinute: 'setengah minit',
      lessThanXMinutes: {
        one: 'kurang dari 1 minit',
        other: 'kurang dari {{count}} minit'
      },
      xMinutes: {
        one: '1 minit',
        other: '{{count}} minit'
      },
      aboutXHours: {
        one: 'sekitar 1 jam',
        other: 'sekitar {{count}} jam'
      },
      xHours: {
        one: '1 jam',
        other: '{{count}} jam'
      },
      xDays: {
        one: '1 hari',
        other: '{{count}} hari'
      },
      aboutXWeeks: {
        one: 'sekitar 1 minggu',
        other: 'sekitar {{count}} minggu'
      },
      xWeeks: {
        one: '1 minggu',
        other: '{{count}} minggu'
      },
      aboutXMonths: {
        one: 'sekitar 1 bulan',
        other: 'sekitar {{count}} bulan'
      },
      xMonths: {
        one: '1 bulan',
        other: '{{count}} bulan'
      },
      aboutXYears: {
        one: 'sekitar 1 tahun',
        other: 'sekitar {{count}} tahun'
      },
      xYears: {
        one: '1 tahun',
        other: '{{count}} tahun'
      },
      overXYears: {
        one: 'lebih dari 1 tahun',
        other: 'lebih dari {{count}} tahun'
      },
      almostXYears: {
        one: 'hampir 1 tahun',
        other: 'hampir {{count}} tahun'
      }
    };
    var formatDistance$t = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$t[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'dalam masa ' + result;
        } else {
          return result + ' yang lalu';
        }
      }
      return result;
    };

    var dateFormats$t = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'd/M/yyyy'
    };
    var timeFormats$t = {
      full: 'HH.mm.ss',
      long: 'HH.mm.ss',
      medium: 'HH.mm',
      short: 'HH.mm'
    };
    var dateTimeFormats$t = {
      full: "{{date}} 'pukul' {{time}}",
      long: "{{date}} 'pukul' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$t = {
      date: buildFormatLongFn({
        formats: dateFormats$t,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$t,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$t,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$t = {
      lastWeek: "eeee 'lepas pada jam' p",
      yesterday: "'Semalam pada jam' p",
      today: "'Hari ini pada jam' p",
      tomorrow: "'Esok pada jam' p",
      nextWeek: "eeee 'pada jam' p",
      other: 'P'
    };
    var formatRelative$t = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$t[token];
    };

    var eraValues$t = {
      narrow: ['SM', 'M'],
      abbreviated: ['SM', 'M'],
      wide: ['Sebelum Masihi', 'Masihi']
    };
    var quarterValues$t = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['S1', 'S2', 'S3', 'S4'],
      wide: ['Suku pertama', 'Suku kedua', 'Suku ketiga', 'Suku keempat']
    };
    var monthValues$t = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'O', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mac', 'Apr', 'Mei', 'Jun', 'Jul', 'Ogo', 'Sep', 'Okt', 'Nov', 'Dis'],
      wide: ['Januari', 'Februari', 'Mac', 'April', 'Mei', 'Jun', 'Julai', 'Ogos', 'September', 'Oktober', 'November', 'Disember']
    };
    var dayValues$t = {
      narrow: ['A', 'I', 'S', 'R', 'K', 'J', 'S'],
      short: ['Ahd', 'Isn', 'Sel', 'Rab', 'Kha', 'Jum', 'Sab'],
      abbreviated: ['Ahd', 'Isn', 'Sel', 'Rab', 'Kha', 'Jum', 'Sab'],
      wide: ['Ahad', 'Isnin', 'Selasa', 'Rabu', 'Khamis', 'Jumaat', 'Sabtu']
    };
    var dayPeriodValues$t = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'tgh malam',
        noon: 'tgh hari',
        morning: 'pagi',
        afternoon: 'tengah hari',
        evening: 'petang',
        night: 'malam'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'tengah hari',
        evening: 'petang',
        night: 'malam'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'tengah hari',
        evening: 'petang',
        night: 'malam'
      }
    };
    var formattingDayPeriodValues$o = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'tengah hari',
        evening: 'petang',
        night: 'malam'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'tengah hari',
        evening: 'petang',
        night: 'malam'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'tengah hari',
        evening: 'petang',
        night: 'malam'
      }
    };
    var ordinalNumber$t = function (dirtyNumber, _options) {
      return 'ke-' + Number(dirtyNumber);
    };
    var localize$t = {
      ordinalNumber: ordinalNumber$t,
      era: buildLocalizeFn({
        values: eraValues$t,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$t,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$t,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$t,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$t,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$o,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$t = /^ke-(\d+)?/i;
    var parseOrdinalNumberPattern$t = /petama|\d+/i;
    var matchEraPatterns$t = {
      narrow: /^(sm|m)/i,
      abbreviated: /^(s\.?\s?m\.?|m\.?)/i,
      wide: /^(sebelum masihi|masihi)/i
    };
    var parseEraPatterns$t = {
      any: [/^s/i, /^(m)/i]
    };
    var matchQuarterPatterns$t = {
      narrow: /^[1234]/i,
      abbreviated: /^S[1234]/i,
      wide: /Suku (pertama|kedua|ketiga|keempat)/i
    };
    var parseQuarterPatterns$t = {
      any: [/pertama|1/i, /kedua|2/i, /ketiga|3/i, /keempat|4/i]
    };
    var matchMonthPatterns$t = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mac|apr|mei|jun|jul|ogo|sep|okt|nov|dis)/i,
      wide: /^(januari|februari|mac|april|mei|jun|julai|ogos|september|oktober|november|disember)/i
    };
    var parseMonthPatterns$t = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^o/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^ma/i, /^ap/i, /^me/i, /^jun/i, /^jul/i, /^og/i, /^s/i, /^ok/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$t = {
      narrow: /^[aisrkj]/i,
      short: /^(ahd|isn|sel|rab|kha|jum|sab)/i,
      abbreviated: /^(ahd|isn|sel|rab|kha|jum|sab)/i,
      wide: /^(ahad|isnin|selasa|rabu|khamis|jumaat|sabtu)/i
    };
    var parseDayPatterns$t = {
      narrow: [/^a/i, /^i/i, /^s/i, /^r/i, /^k/i, /^j/i, /^s/i],
      any: [/^a/i, /^i/i, /^se/i, /^r/i, /^k/i, /^j/i, /^sa/i]
    };
    var matchDayPeriodPatterns$t = {
      narrow: /^(am|pm|tengah malam|tengah hari|pagi|petang|malam)/i,
      any: /^([ap]\.?\s?m\.?|tengah malam|tengah hari|pagi|petang|malam)/i
    };
    var parseDayPeriodPatterns$t = {
      any: {
        am: /^a/i,
        pm: /^pm/i,
        midnight: /^tengah m/i,
        noon: /^tengah h/i,
        morning: /pa/i,
        afternoon: /tengah h/i,
        evening: /pe/i,
        night: /m/i
      }
    };
    var match$t = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$t,
        parsePattern: parseOrdinalNumberPattern$t,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$t,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$t,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$t,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$t,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$t,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$t,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$t,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$t,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$t,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$t,
        defaultParseWidth: 'any'
      })
    };

    var locale$t = {
      code: 'ms',
      formatDistance: formatDistance$t,
      formatLong: formatLong$t,
      formatRelative: formatRelative$t,
      localize: localize$t,
      match: match$t,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$s = {
      lessThanXSeconds: {
        one: 'inqas minn sekonda',
        other: 'inqas minn {{count}} sekondi'
      },
      xSeconds: {
        one: 'sekonda',
        other: '{{count}} sekondi'
      },
      halfAMinute: 'nofs minuta',
      lessThanXMinutes: {
        one: 'inqas minn minuta',
        other: 'inqas minn {{count}} minuti'
      },
      xMinutes: {
        one: 'minuta',
        other: '{{count}} minuti'
      },
      aboutXHours: {
        one: 'madwar siegħa',
        other: 'madwar {{count}} siegħat'
      },
      xHours: {
        one: 'siegħa',
        other: '{{count}} siegħat'
      },
      xDays: {
        one: 'ġurnata',
        other: '{{count}} ġranet'
      },
      aboutXWeeks: {
        one: 'madwar ġimgħa',
        other: 'madwar {{count}} ġimgħat'
      },
      xWeeks: {
        one: 'ġimgħa',
        other: '{{count}} ġimgħat'
      },
      aboutXMonths: {
        one: 'madwar xahar',
        other: 'madwar {{count}} xhur'
      },
      xMonths: {
        one: 'xahar',
        other: '{{count}} xhur'
      },
      aboutXYears: {
        one: 'madwar sena',
        two: 'madwar sentejn',
        other: 'madwar {{count}} snin'
      },
      xYears: {
        one: 'sena',
        two: 'sentejn',
        other: '{{count}} snin'
      },
      overXYears: {
        one: 'aktar minn sena',
        two: 'aktar minn sentejn',
        other: 'aktar minn {{count}} snin'
      },
      almostXYears: {
        one: 'kważi sena',
        two: 'kważi sentejn',
        other: 'kważi {{count}} snin'
      }
    };
    var formatDistance$s = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$s[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else if (count === 2 && tokenValue.two) {
        result = tokenValue.two;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return "f'" + result;
        } else {
          return result + ' ilu';
        }
      }
      return result;
    };

    var dateFormats$s = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$s = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$s = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$s = {
      date: buildFormatLongFn({
        formats: dateFormats$s,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$s,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$s,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$s = {
      lastWeek: "eeee 'li għadda' 'fil-'p",
      yesterday: "'Il-bieraħ fil-'p",
      today: "'Illum fil-'p",
      tomorrow: "'Għada fil-'p",
      nextWeek: "eeee 'fil-'p",
      other: 'P'
    };
    var formatRelative$s = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$s[token];
    };

    var eraValues$s = {
      narrow: ['Q', 'W'],
      abbreviated: ['QK', 'WK'],
      wide: ['qabel Kristu', 'wara Kristu']
    };
    var quarterValues$s = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1. kwart', '2. kwart', '3. kwart', '4. kwart']
    };
    var monthValues$s = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'Ġ', 'L', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Fra', 'Mar', 'Apr', 'Mej', 'Ġun', 'Lul', 'Aww', 'Set', 'Ott', 'Nov', 'Diċ'],
      wide: ['Jannar', 'Frar', 'Marzu', 'April', 'Mejju', 'Ġunju', 'Lulju', 'Awwissu', 'Settembru', 'Ottubru', 'Novembru', 'Diċembru']
    };
    var dayValues$s = {
      narrow: ['Ħ', 'T', 'T', 'E', 'Ħ', 'Ġ', 'S'],
      short: ['Ħa', 'Tn', 'Tl', 'Er', 'Ħa', 'Ġi', 'Si'],
      abbreviated: ['Ħad', 'Tne', 'Tli', 'Erb', 'Ħam', 'Ġim', 'Sib'],
      wide: ['Il-Ħadd', 'It-Tnejn', 'It-Tlieta', 'L-Erbgħa', 'Il-Ħamis', 'Il-Ġimgħa', 'Is-Sibt']
    };
    var dayPeriodValues$s = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'nofsillejl',
        noon: 'nofsinhar',
        morning: 'għodwa',
        afternoon: 'wara nofsinhar',
        evening: 'filgħaxija',
        night: 'lejl'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'nofsillejl',
        noon: 'nofsinhar',
        morning: 'għodwa',
        afternoon: 'wara nofsinhar',
        evening: 'filgħaxija',
        night: 'lejl'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'nofsillejl',
        noon: 'nofsinhar',
        morning: 'għodwa',
        afternoon: 'wara nofsinhar',
        evening: 'filgħaxija',
        night: 'lejl'
      }
    };
    var formattingDayPeriodValues$n = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: "f'nofsillejl",
        noon: "f'nofsinhar",
        morning: 'filgħodu',
        afternoon: 'wara nofsinhar',
        evening: 'filgħaxija',
        night: 'billejl'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: "f'nofsillejl",
        noon: "f'nofsinhar",
        morning: 'filgħodu',
        afternoon: 'wara nofsinhar',
        evening: 'filgħaxija',
        night: 'billejl'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: "f'nofsillejl",
        noon: "f'nofsinhar",
        morning: 'filgħodu',
        afternoon: 'wara nofsinhar',
        evening: 'filgħaxija',
        night: 'billejl'
      }
    };
    var ordinalNumber$s = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'º';
    };
    var localize$s = {
      ordinalNumber: ordinalNumber$s,
      era: buildLocalizeFn({
        values: eraValues$s,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$s,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$s,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$s,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$s,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$n,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$s = /^(\d+)(º)?/i;
    var parseOrdinalNumberPattern$s = /\d+/i;
    var matchEraPatterns$s = {
      narrow: /^(q|w)/i,
      abbreviated: /^(q\.?\s?k\.?|b\.?\s?c\.?\s?e\.?|w\.?\s?k\.?)/i,
      wide: /^(qabel kristu|before common era|wara kristu|common era)/i
    };
    var parseEraPatterns$s = {
      any: [/^(q|b)/i, /^(w|c)/i]
    };
    var matchQuarterPatterns$s = {
      narrow: /^[1234]/i,
      abbreviated: /^k[1234]/i,
      wide: /^[1234](\.)? kwart/i
    };
    var parseQuarterPatterns$s = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$s = {
      narrow: /^[jfmaglsond]/i,
      abbreviated: /^(jan|fra|mar|apr|mej|ġun|lul|aww|set|ott|nov|diċ)/i,
      wide: /^(jannar|frar|marzu|april|mejju|ġunju|lulju|awwissu|settembru|ottubru|novembru|diċembru)/i
    };
    var parseMonthPatterns$s = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^ġ/i, /^l/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^mej/i, /^ġ/i, /^l/i, /^aw/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$s = {
      narrow: /^[ħteġs]/i,
      short: /^(ħa|tn|tl|er|ħa|ġi|si)/i,
      abbreviated: /^(ħad|tne|tli|erb|ħam|ġim|sib)/i,
      wide: /^(il-ħadd|it-tnejn|it-tlieta|l-erbgħa|il-ħamis|il-ġimgħa|is-sibt)/i
    };
    var parseDayPatterns$s = {
      narrow: [/^ħ/i, /^t/i, /^t/i, /^e/i, /^ħ/i, /^ġ/i, /^s/i],
      any: [/^(il-)?ħad/i, /^(it-)?tn/i, /^(it-)?tl/i, /^(l-)?er/i, /^(il-)?ham/i, /^(il-)?ġi/i, /^(is-)?si/i]
    };
    var matchDayPeriodPatterns$s = {
      narrow: /^(a|p|f'nofsillejl|f'nofsinhar|(ta') (għodwa|wara nofsinhar|filgħaxija|lejl))/i,
      any: /^([ap]\.?\s?m\.?|f'nofsillejl|f'nofsinhar|(ta') (għodwa|wara nofsinhar|filgħaxija|lejl))/i
    };
    var parseDayPeriodPatterns$s = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^f'nofsillejl/i,
        noon: /^f'nofsinhar/i,
        morning: /għodwa/i,
        afternoon: /wara(\s.*)nofsinhar/i,
        evening: /filgħaxija/i,
        night: /lejl/i
      }
    };
    var match$s = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$s,
        parsePattern: parseOrdinalNumberPattern$s,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$s,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$s,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$s,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$s,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$s,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$s,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$s,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$s,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$s,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$s,
        defaultParseWidth: 'any'
      })
    };

    var locale$s = {
      code: 'mt',
      formatDistance: formatDistance$s,
      formatLong: formatLong$s,
      formatRelative: formatRelative$s,
      localize: localize$s,
      match: match$s,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$r = {
      lessThanXSeconds: {
        one: 'mindre enn ett sekund',
        other: 'mindre enn {{count}} sekunder'
      },
      xSeconds: {
        one: 'ett sekund',
        other: '{{count}} sekunder'
      },
      halfAMinute: 'et halvt minutt',
      lessThanXMinutes: {
        one: 'mindre enn ett minutt',
        other: 'mindre enn {{count}} minutter'
      },
      xMinutes: {
        one: 'ett minutt',
        other: '{{count}} minutter'
      },
      aboutXHours: {
        one: 'omtrent en time',
        other: 'omtrent {{count}} timer'
      },
      xHours: {
        one: 'en time',
        other: '{{count}} timer'
      },
      xDays: {
        one: 'en dag',
        other: '{{count}} dager'
      },
      aboutXWeeks: {
        one: 'omtrent en uke',
        other: 'omtrent {{count}} uker'
      },
      xWeeks: {
        one: 'en uke',
        other: '{{count}} uker'
      },
      aboutXMonths: {
        one: 'omtrent en måned',
        other: 'omtrent {{count}} måneder'
      },
      xMonths: {
        one: 'en måned',
        other: '{{count}} måneder'
      },
      aboutXYears: {
        one: 'omtrent ett år',
        other: 'omtrent {{count}} år'
      },
      xYears: {
        one: 'ett år',
        other: '{{count}} år'
      },
      overXYears: {
        one: 'over ett år',
        other: 'over {{count}} år'
      },
      almostXYears: {
        one: 'nesten ett år',
        other: 'nesten {{count}} år'
      }
    };
    var formatDistance$r = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$r[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'om ' + result;
        } else {
          return result + ' siden';
        }
      }
      return result;
    };

    var dateFormats$r = {
      full: 'EEEE d. MMMM y',
      long: 'd. MMMM y',
      medium: 'd. MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$r = {
      full: "'kl'. HH:mm:ss zzzz",
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$r = {
      full: "{{date}} 'kl.' {{time}}",
      long: "{{date}} 'kl.' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$r = {
      date: buildFormatLongFn({
        formats: dateFormats$r,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$r,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$r,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$r = {
      lastWeek: "'forrige' eeee 'kl.' p",
      yesterday: "'i går kl.' p",
      today: "'i dag kl.' p",
      tomorrow: "'i morgen kl.' p",
      nextWeek: "EEEE 'kl.' p",
      other: 'P'
    };
    var formatRelative$r = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$r[token];
    };

    var eraValues$r = {
      narrow: ['f.Kr.', 'e.Kr.'],
      abbreviated: ['f.Kr.', 'e.Kr.'],
      wide: ['før Kristus', 'etter Kristus']
    };
    var quarterValues$r = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$r = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mars', 'apr.', 'mai', 'juni', 'juli', 'aug.', 'sep.', 'okt.', 'nov.', 'des.'],
      wide: ['januar', 'februar', 'mars', 'april', 'mai', 'juni', 'juli', 'august', 'september', 'oktober', 'november', 'desember']
    };
    var dayValues$r = {
      narrow: ['S', 'M', 'T', 'O', 'T', 'F', 'L'],
      short: ['sø', 'ma', 'ti', 'on', 'to', 'fr', 'lø'],
      abbreviated: ['søn', 'man', 'tir', 'ons', 'tor', 'fre', 'lør'],
      wide: ['søndag', 'mandag', 'tirsdag', 'onsdag', 'torsdag', 'fredag', 'lørdag']
    };
    var dayPeriodValues$r = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på etterm.',
        evening: 'på kvelden',
        night: 'på natten'
      },
      abbreviated: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på etterm.',
        evening: 'på kvelden',
        night: 'på natten'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morgenen',
        afternoon: 'på ettermiddagen',
        evening: 'på kvelden',
        night: 'på natten'
      }
    };
    var ordinalNumber$r = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$r = {
      ordinalNumber: ordinalNumber$r,
      era: buildLocalizeFn({
        values: eraValues$r,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$r,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$r,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$r,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$r,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$r = /^(\d+)\.?/i;
    var parseOrdinalNumberPattern$r = /\d+/i;
    var matchEraPatterns$r = {
      narrow: /^(f\.? ?Kr\.?|fvt\.?|e\.? ?Kr\.?|evt\.?)/i,
      abbreviated: /^(f\.? ?Kr\.?|fvt\.?|e\.? ?Kr\.?|evt\.?)/i,
      wide: /^(før Kristus|før vår tid|etter Kristus|vår tid)/i
    };
    var parseEraPatterns$r = {
      any: [/^f/i, /^e/i]
    };
    var matchQuarterPatterns$r = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](\.)? kvartal/i
    };
    var parseQuarterPatterns$r = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$r = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mars?|apr|mai|juni?|juli?|aug|sep|okt|nov|des)\.?/i,
      wide: /^(januar|februar|mars|april|mai|juni|juli|august|september|oktober|november|desember)/i
    };
    var parseMonthPatterns$r = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^mai/i, /^jun/i, /^jul/i, /^aug/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$r = {
      narrow: /^[smtofl]/i,
      short: /^(sø|ma|ti|on|to|fr|lø)/i,
      abbreviated: /^(søn|man|tir|ons|tor|fre|lør)/i,
      wide: /^(søndag|mandag|tirsdag|onsdag|torsdag|fredag|lørdag)/i
    };
    var parseDayPatterns$r = {
      any: [/^s/i, /^m/i, /^ti/i, /^o/i, /^to/i, /^f/i, /^l/i]
    };
    var matchDayPeriodPatterns$r = {
      narrow: /^(midnatt|middag|(på) (morgenen|ettermiddagen|kvelden|natten)|[ap])/i,
      any: /^([ap]\.?\s?m\.?|midnatt|middag|(på) (morgenen|ettermiddagen|kvelden|natten))/i
    };
    var parseDayPeriodPatterns$r = {
      any: {
        am: /^a(\.?\s?m\.?)?$/i,
        pm: /^p(\.?\s?m\.?)?$/i,
        midnight: /^midn/i,
        noon: /^midd/i,
        morning: /morgen/i,
        afternoon: /ettermiddag/i,
        evening: /kveld/i,
        night: /natt/i
      }
    };
    var match$r = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$r,
        parsePattern: parseOrdinalNumberPattern$r,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$r,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$r,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$r,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$r,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$r,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$r,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$r,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$r,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$r,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$r,
        defaultParseWidth: 'any'
      })
    };

    var locale$r = {
      code: 'nb',
      formatDistance: formatDistance$r,
      formatLong: formatLong$r,
      formatRelative: formatRelative$r,
      localize: localize$r,
      match: match$r,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$q = {
      lessThanXSeconds: {
        one: 'minder dan een seconde',
        other: 'minder dan {{count}} seconden'
      },
      xSeconds: {
        one: '1 seconde',
        other: '{{count}} seconden'
      },
      halfAMinute: 'een halve minuut',
      lessThanXMinutes: {
        one: 'minder dan een minuut',
        other: 'minder dan {{count}} minuten'
      },
      xMinutes: {
        one: 'een minuut',
        other: '{{count}} minuten'
      },
      aboutXHours: {
        one: 'ongeveer 1 uur',
        other: 'ongeveer {{count}} uur'
      },
      xHours: {
        one: '1 uur',
        other: '{{count}} uur'
      },
      xDays: {
        one: '1 dag',
        other: '{{count}} dagen'
      },
      aboutXWeeks: {
        one: 'ongeveer 1 week',
        other: 'ongeveer {{count}} weken'
      },
      xWeeks: {
        one: '1 week',
        other: '{{count}} weken'
      },
      aboutXMonths: {
        one: 'ongeveer 1 maand',
        other: 'ongeveer {{count}} maanden'
      },
      xMonths: {
        one: '1 maand',
        other: '{{count}} maanden'
      },
      aboutXYears: {
        one: 'ongeveer 1 jaar',
        other: 'ongeveer {{count}} jaar'
      },
      xYears: {
        one: '1 jaar',
        other: '{{count}} jaar'
      },
      overXYears: {
        one: 'meer dan 1 jaar',
        other: 'meer dan {{count}} jaar'
      },
      almostXYears: {
        one: 'bijna 1 jaar',
        other: 'bijna {{count}} jaar'
      }
    };
    var formatDistance$q = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$q[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'over ' + result;
        } else {
          return result + ' geleden';
        }
      }
      return result;
    };

    var dateFormats$q = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd-MM-y'
    };
    var timeFormats$q = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$q = {
      full: "{{date}} 'om' {{time}}",
      long: "{{date}} 'om' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$q = {
      date: buildFormatLongFn({
        formats: dateFormats$q,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$q,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$q,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$q = {
      lastWeek: "'afgelopen' eeee 'om' p",
      yesterday: "'gisteren om' p",
      today: "'vandaag om' p",
      tomorrow: "'morgen om' p",
      nextWeek: "eeee 'om' p",
      other: 'P'
    };
    var formatRelative$q = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$q[token];
    };

    var eraValues$q = {
      narrow: ['v.C.', 'n.C.'],
      abbreviated: ['v.Chr.', 'n.Chr.'],
      wide: ['voor Christus', 'na Christus']
    };
    var quarterValues$q = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1e kwartaal', '2e kwartaal', '3e kwartaal', '4e kwartaal']
    };
    var monthValues$q = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mrt.', 'apr.', 'mei', 'jun.', 'jul.', 'aug.', 'sep.', 'okt.', 'nov.', 'dec.'],
      wide: ['januari', 'februari', 'maart', 'april', 'mei', 'juni', 'juli', 'augustus', 'september', 'oktober', 'november', 'december']
    };
    var dayValues$q = {
      narrow: ['Z', 'M', 'D', 'W', 'D', 'V', 'Z'],
      short: ['zo', 'ma', 'di', 'wo', 'do', 'vr', 'za'],
      abbreviated: ['zon', 'maa', 'din', 'woe', 'don', 'vri', 'zat'],
      wide: ['zondag', 'maandag', 'dinsdag', 'woensdag', 'donderdag', 'vrijdag', 'zaterdag']
    };
    var dayPeriodValues$q = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middaguur',
        morning: "'s ochtends",
        afternoon: "'s middags",
        evening: "'s avonds",
        night: "'s nachts"
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middaguur',
        morning: "'s ochtends",
        afternoon: "'s middags",
        evening: "'s avonds",
        night: "'s nachts"
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middaguur',
        morning: "'s ochtends",
        afternoon: "'s middags",
        evening: "'s avonds",
        night: "'s nachts"
      }
    };
    var ordinalNumber$q = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'e';
    };
    var localize$q = {
      ordinalNumber: ordinalNumber$q,
      era: buildLocalizeFn({
        values: eraValues$q,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$q,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$q,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$q,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$q,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$q = /^(\d+)e?/i;
    var parseOrdinalNumberPattern$q = /\d+/i;
    var matchEraPatterns$q = {
      narrow: /^([vn]\.? ?C\.?)/,
      abbreviated: /^([vn]\. ?Chr\.?)/,
      wide: /^((voor|na) Christus)/
    };
    var parseEraPatterns$q = {
      any: [/^v/, /^n/]
    };
    var matchQuarterPatterns$q = {
      narrow: /^[1234]/i,
      abbreviated: /^K[1234]/i,
      wide: /^[1234]e kwartaal/i
    };
    var parseQuarterPatterns$q = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$q = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan.|feb.|mrt.|apr.|mei|jun.|jul.|aug.|sep.|okt.|nov.|dec.)/i,
      wide: /^(januari|februari|maart|april|mei|juni|juli|augustus|september|oktober|november|december)/i
    };
    var parseMonthPatterns$q = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^jan/i, /^feb/i, /^m(r|a)/i, /^apr/i, /^mei/i, /^jun/i, /^jul/i, /^aug/i, /^sep/i, /^okt/i, /^nov/i, /^dec/i]
    };
    var matchDayPatterns$q = {
      narrow: /^[zmdwv]/i,
      short: /^(zo|ma|di|wo|do|vr|za)/i,
      abbreviated: /^(zon|maa|din|woe|don|vri|zat)/i,
      wide: /^(zondag|maandag|dinsdag|woensdag|donderdag|vrijdag|zaterdag)/i
    };
    var parseDayPatterns$q = {
      narrow: [/^z/i, /^m/i, /^d/i, /^w/i, /^d/i, /^v/i, /^z/i],
      any: [/^zo/i, /^ma/i, /^di/i, /^wo/i, /^do/i, /^vr/i, /^za/i]
    };
    var matchDayPeriodPatterns$q = {
      any: /^(am|pm|middernacht|het middaguur|'s (ochtends|middags|avonds|nachts))/i
    };
    var parseDayPeriodPatterns$q = {
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /^middernacht/i,
        noon: /^het middaguur/i,
        morning: /ochtend/i,
        afternoon: /middag/i,
        evening: /avond/i,
        night: /nacht/i
      }
    };
    var match$q = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$q,
        parsePattern: parseOrdinalNumberPattern$q,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$q,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$q,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$q,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$q,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$q,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$q,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$q,
        defaultParseWidth: 'any'
      })
    };

    var locale$q = {
      code: 'nl',
      formatDistance: formatDistance$q,
      formatLong: formatLong$q,
      formatRelative: formatRelative$q,
      localize: localize$q,
      match: match$q,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$p = {
      lessThanXSeconds: {
        one: 'minder dan een seconde',
        other: 'minder dan {{count}} seconden'
      },
      xSeconds: {
        one: '1 seconde',
        other: '{{count}} seconden'
      },
      halfAMinute: 'een halve minuut',
      lessThanXMinutes: {
        one: 'minder dan een minuut',
        other: 'minder dan {{count}} minuten'
      },
      xMinutes: {
        one: 'een minuut',
        other: '{{count}} minuten'
      },
      aboutXHours: {
        one: 'ongeveer 1 uur',
        other: 'ongeveer {{count}} uur'
      },
      xHours: {
        one: '1 uur',
        other: '{{count}} uur'
      },
      xDays: {
        one: '1 dag',
        other: '{{count}} dagen'
      },
      aboutXWeeks: {
        one: 'ongeveer 1 week',
        other: 'ongeveer {{count}} weken'
      },
      xWeeks: {
        one: '1 week',
        other: '{{count}} weken'
      },
      aboutXMonths: {
        one: 'ongeveer 1 maand',
        other: 'ongeveer {{count}} maanden'
      },
      xMonths: {
        one: '1 maand',
        other: '{{count}} maanden'
      },
      aboutXYears: {
        one: 'ongeveer 1 jaar',
        other: 'ongeveer {{count}} jaar'
      },
      xYears: {
        one: '1 jaar',
        other: '{{count}} jaar'
      },
      overXYears: {
        one: 'meer dan 1 jaar',
        other: 'meer dan {{count}} jaar'
      },
      almostXYears: {
        one: 'bijna 1 jaar',
        other: 'bijna {{count}} jaar'
      }
    };
    var formatDistance$p = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$p[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'over ' + result;
        } else {
          return result + ' geleden';
        }
      }
      return result;
    };

    var dateFormats$p = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$p = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$p = {
      full: "{{date}} 'om' {{time}}",
      long: "{{date}} 'om' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$p = {
      date: buildFormatLongFn({
        formats: dateFormats$p,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$p,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$p,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$p = {
      lastWeek: "'vorige' eeee 'om' p",
      yesterday: "'gisteren om' p",
      today: "'vandaag om' p",
      tomorrow: "'morgen om' p",
      nextWeek: "eeee 'om' p",
      other: 'P'
    };
    var formatRelative$p = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$p[token];
    };

    var eraValues$p = {
      narrow: ['v.C.', 'n.C.'],
      abbreviated: ['v.Chr.', 'n.Chr.'],
      wide: ['voor Christus', 'na Christus']
    };
    var quarterValues$p = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1e kwartaal', '2e kwartaal', '3e kwartaal', '4e kwartaal']
    };
    var monthValues$p = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mrt.', 'apr.', 'mei', 'jun.', 'jul.', 'aug.', 'sep.', 'okt.', 'nov.', 'dec.'],
      wide: ['januari', 'februari', 'maart', 'april', 'mei', 'juni', 'juli', 'augustus', 'september', 'oktober', 'november', 'december']
    };
    var dayValues$p = {
      narrow: ['Z', 'M', 'D', 'W', 'D', 'V', 'Z'],
      short: ['zo', 'ma', 'di', 'wo', 'do', 'vr', 'za'],
      abbreviated: ['zon', 'maa', 'din', 'woe', 'don', 'vri', 'zat'],
      wide: ['zondag', 'maandag', 'dinsdag', 'woensdag', 'donderdag', 'vrijdag', 'zaterdag']
    };
    var dayPeriodValues$p = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middag',
        morning: "'s ochtends",
        afternoon: "'s namiddags",
        evening: "'s avonds",
        night: "'s nachts"
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middag',
        morning: "'s ochtends",
        afternoon: "'s namiddags",
        evening: "'s avonds",
        night: "'s nachts"
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middag',
        morning: "'s ochtends",
        afternoon: "'s namiddags",
        evening: "'s avonds",
        night: "'s nachts"
      }
    };
    var ordinalNumber$p = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'e';
    };
    var localize$p = {
      ordinalNumber: ordinalNumber$p,
      era: buildLocalizeFn({
        values: eraValues$p,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$p,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$p,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$p,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$p,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$p = /^(\d+)e?/i;
    var parseOrdinalNumberPattern$p = /\d+/i;
    var matchEraPatterns$p = {
      narrow: /^([vn]\.? ?C\.?)/,
      abbreviated: /^([vn]\. ?Chr\.?)/,
      wide: /^((voor|na) Christus)/
    };
    var parseEraPatterns$p = {
      any: [/^v/, /^n/]
    };
    var matchQuarterPatterns$p = {
      narrow: /^[1234]/i,
      abbreviated: /^K[1234]/i,
      wide: /^[1234]e kwartaal/i
    };
    var parseQuarterPatterns$p = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$p = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan.|feb.|mrt.|apr.|mei|jun.|jul.|aug.|sep.|okt.|nov.|dec.)/i,
      wide: /^(januari|februari|maart|april|mei|juni|juli|augustus|september|oktober|november|december)/i
    };
    var parseMonthPatterns$p = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^jan/i, /^feb/i, /^m(r|a)/i, /^apr/i, /^mei/i, /^jun/i, /^jul/i, /^aug/i, /^sep/i, /^okt/i, /^nov/i, /^dec/i]
    };
    var matchDayPatterns$p = {
      narrow: /^[zmdwv]/i,
      short: /^(zo|ma|di|wo|do|vr|za)/i,
      abbreviated: /^(zon|maa|din|woe|don|vri|zat)/i,
      wide: /^(zondag|maandag|dinsdag|woensdag|donderdag|vrijdag|zaterdag)/i
    };
    var parseDayPatterns$p = {
      narrow: [/^z/i, /^m/i, /^d/i, /^w/i, /^d/i, /^v/i, /^z/i],
      any: [/^zo/i, /^ma/i, /^di/i, /^wo/i, /^do/i, /^vr/i, /^za/i]
    };
    var matchDayPeriodPatterns$p = {
      any: /^(am|pm|middernacht|het middaguur|'s (ochtends|middags|avonds|nachts))/i
    };
    var parseDayPeriodPatterns$p = {
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /^middernacht/i,
        noon: /^het middaguur/i,
        morning: /ochtend/i,
        afternoon: /middag/i,
        evening: /avond/i,
        night: /nacht/i
      }
    };
    var match$p = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$p,
        parsePattern: parseOrdinalNumberPattern$p,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$p,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$p,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$p,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$p,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$p,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$p,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$p,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$p,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$p,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$p,
        defaultParseWidth: 'any'
      })
    };

    var locale$p = {
      code: 'nl-BE',
      formatDistance: formatDistance$p,
      formatLong: formatLong$p,
      formatRelative: formatRelative$p,
      localize: localize$p,
      match: match$p,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$o = {
      lessThanXSeconds: {
        one: 'mindre enn eitt sekund',
        other: 'mindre enn {{count}} sekund'
      },
      xSeconds: {
        one: 'eitt sekund',
        other: '{{count}} sekund'
      },
      halfAMinute: 'eit halvt minutt',
      lessThanXMinutes: {
        one: 'mindre enn eitt minutt',
        other: 'mindre enn {{count}} minutt'
      },
      xMinutes: {
        one: 'eitt minutt',
        other: '{{count}} minutt'
      },
      aboutXHours: {
        one: 'omtrent ein time',
        other: 'omtrent {{count}} timar'
      },
      xHours: {
        one: 'ein time',
        other: '{{count}} timar'
      },
      xDays: {
        one: 'ein dag',
        other: '{{count}} dagar'
      },
      aboutXWeeks: {
        one: 'omtrent ei veke',
        other: 'omtrent {{count}} veker'
      },
      xWeeks: {
        one: 'ei veke',
        other: '{{count}} veker'
      },
      aboutXMonths: {
        one: 'omtrent ein månad',
        other: 'omtrent {{count}} månader'
      },
      xMonths: {
        one: 'ein månad',
        other: '{{count}} månader'
      },
      aboutXYears: {
        one: 'omtrent eitt år',
        other: 'omtrent {{count}} år'
      },
      xYears: {
        one: 'eitt år',
        other: '{{count}} år'
      },
      overXYears: {
        one: 'over eitt år',
        other: 'over {{count}} år'
      },
      almostXYears: {
        one: 'nesten eitt år',
        other: 'nesten {{count}} år'
      }
    };
    var wordMapping$1 = ['null', 'ein', 'to', 'tre', 'fire', 'fem', 'seks', 'sju', 'åtte', 'ni', 'ti', 'elleve', 'tolv'];
    var formatDistance$o = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$o[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        if (options && options.onlyNumeric) {
          result = tokenValue.other.replace('{{count}}', String(count));
        } else {
          result = tokenValue.other.replace('{{count}}', count < 13 ? wordMapping$1[count] : String(count));
        }
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'om ' + result;
        } else {
          return result + ' sidan';
        }
      }
      return result;
    };

    var dateFormats$o = {
      full: 'EEEE d. MMMM y',
      long: 'd. MMMM y',
      medium: 'd. MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$o = {
      full: "'kl'. HH:mm:ss zzzz",
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$o = {
      full: "{{date}} 'kl.' {{time}}",
      long: "{{date}} 'kl.' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$o = {
      date: buildFormatLongFn({
        formats: dateFormats$o,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$o,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$o,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$o = {
      lastWeek: "'førre' eeee 'kl.' p",
      yesterday: "'i går kl.' p",
      today: "'i dag kl.' p",
      tomorrow: "'i morgon kl.' p",
      nextWeek: "EEEE 'kl.' p",
      other: 'P'
    };
    var formatRelative$o = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$o[token];
    };

    var eraValues$o = {
      narrow: ['f.Kr.', 'e.Kr.'],
      abbreviated: ['f.Kr.', 'e.Kr.'],
      wide: ['før Kristus', 'etter Kristus']
    };
    var quarterValues$o = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$o = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mars', 'apr.', 'mai', 'juni', 'juli', 'aug.', 'sep.', 'okt.', 'nov.', 'des.'],
      wide: ['januar', 'februar', 'mars', 'april', 'mai', 'juni', 'juli', 'august', 'september', 'oktober', 'november', 'desember']
    };
    var dayValues$o = {
      narrow: ['S', 'M', 'T', 'O', 'T', 'F', 'L'],
      short: ['su', 'må', 'ty', 'on', 'to', 'fr', 'lau'],
      abbreviated: ['sun', 'mån', 'tys', 'ons', 'tor', 'fre', 'laur'],
      wide: ['sundag', 'måndag', 'tysdag', 'onsdag', 'torsdag', 'fredag', 'laurdag']
    };
    var dayPeriodValues$o = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på etterm.',
        evening: 'på kvelden',
        night: 'på natta'
      },
      abbreviated: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på etterm.',
        evening: 'på kvelden',
        night: 'på natta'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morgonen',
        afternoon: 'på ettermiddagen',
        evening: 'på kvelden',
        night: 'på natta'
      }
    };
    var ordinalNumber$o = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$o = {
      ordinalNumber: ordinalNumber$o,
      era: buildLocalizeFn({
        values: eraValues$o,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$o,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$o,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$o,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$o,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$o = /^(\d+)\.?/i;
    var parseOrdinalNumberPattern$o = /\d+/i;
    var matchEraPatterns$o = {
      narrow: /^(f\.? ?Kr\.?|fvt\.?|e\.? ?Kr\.?|evt\.?)/i,
      abbreviated: /^(f\.? ?Kr\.?|fvt\.?|e\.? ?Kr\.?|evt\.?)/i,
      wide: /^(før Kristus|før vår tid|etter Kristus|vår tid)/i
    };
    var parseEraPatterns$o = {
      any: [/^f/i, /^e/i]
    };
    var matchQuarterPatterns$o = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](\.)? kvartal/i
    };
    var parseQuarterPatterns$o = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$o = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mars?|apr|mai|juni?|juli?|aug|sep|okt|nov|des)\.?/i,
      wide: /^(januar|februar|mars|april|mai|juni|juli|august|september|oktober|november|desember)/i
    };
    var parseMonthPatterns$o = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^mai/i, /^jun/i, /^jul/i, /^aug/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$o = {
      narrow: /^[smtofl]/i,
      short: /^(su|må|ty|on|to|fr|la)/i,
      abbreviated: /^(sun|mån|tys|ons|tor|fre|laur)/i,
      wide: /^(sundag|måndag|tysdag|onsdag|torsdag|fredag|laurdag)/i
    };
    var parseDayPatterns$o = {
      any: [/^s/i, /^m/i, /^ty/i, /^o/i, /^to/i, /^f/i, /^l/i]
    };
    var matchDayPeriodPatterns$o = {
      narrow: /^(midnatt|middag|(på) (morgonen|ettermiddagen|kvelden|natta)|[ap])/i,
      any: /^([ap]\.?\s?m\.?|midnatt|middag|(på) (morgonen|ettermiddagen|kvelden|natta))/i
    };
    var parseDayPeriodPatterns$o = {
      any: {
        am: /^a(\.?\s?m\.?)?$/i,
        pm: /^p(\.?\s?m\.?)?$/i,
        midnight: /^midn/i,
        noon: /^midd/i,
        morning: /morgon/i,
        afternoon: /ettermiddag/i,
        evening: /kveld/i,
        night: /natt/i
      }
    };
    var match$o = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$o,
        parsePattern: parseOrdinalNumberPattern$o,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$o,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$o,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$o,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$o,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$o,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$o,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$o,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$o,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$o,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$o,
        defaultParseWidth: 'any'
      })
    };

    var locale$o = {
      code: 'nn',
      formatDistance: formatDistance$o,
      formatLong: formatLong$o,
      formatRelative: formatRelative$o,
      localize: localize$o,
      match: match$o,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$n = {
      lessThanXSeconds: {
        one: 'mens d’una segonda',
        other: 'mens de {{count}} segondas'
      },
      xSeconds: {
        one: '1 segonda',
        other: '{{count}} segondas'
      },
      halfAMinute: '30 segondas',
      lessThanXMinutes: {
        one: 'mens d’una minuta',
        other: 'mens de {{count}} minutas'
      },
      xMinutes: {
        one: '1 minuta',
        other: '{{count}} minutas'
      },
      aboutXHours: {
        one: 'environ 1 ora',
        other: 'environ {{count}} oras'
      },
      xHours: {
        one: '1 ora',
        other: '{{count}} oras'
      },
      xDays: {
        one: '1 jorn',
        other: '{{count}} jorns'
      },
      aboutXWeeks: {
        one: 'environ 1 setmana',
        other: 'environ {{count}} setmanas'
      },
      xWeeks: {
        one: '1 setmana',
        other: '{{count}} setmanas'
      },
      aboutXMonths: {
        one: 'environ 1 mes',
        other: 'environ {{count}} meses'
      },
      xMonths: {
        one: '1 mes',
        other: '{{count}} meses'
      },
      aboutXYears: {
        one: 'environ 1 an',
        other: 'environ {{count}} ans'
      },
      xYears: {
        one: '1 an',
        other: '{{count}} ans'
      },
      overXYears: {
        one: 'mai d’un an',
        other: 'mai de {{count}} ans'
      },
      almostXYears: {
        one: 'gaireben un an',
        other: 'gaireben {{count}} ans'
      }
    };
    var formatDistance$n = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$n[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'd’aquí ' + result;
        } else {
          return 'fa ' + result;
        }
      }
      return result;
    };

    var dateFormats$n = {
      full: "EEEE d 'de' MMMM y",
      long: "d 'de' MMMM y",
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$n = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$n = {
      full: "{{date}} 'a' {{time}}",
      long: "{{date}} 'a' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$n = {
      date: buildFormatLongFn({
        formats: dateFormats$n,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$n,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$n,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$n = {
      lastWeek: "eeee 'passat a' p",
      yesterday: "'ièr a' p",
      today: "'uèi a' p",
      tomorrow: "'deman a' p",
      nextWeek: "eeee 'a' p",
      other: 'P'
    };
    var formatRelative$n = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$n[token];
    };

    var eraValues$n = {
      narrow: ['ab. J.C.', 'apr. J.C.'],
      abbreviated: ['ab. J.C.', 'apr. J.C.'],
      wide: ['abans Jèsus-Crist', 'après Jèsus-Crist']
    };
    var quarterValues$n = {
      narrow: ['T1', 'T2', 'T3', 'T4'],
      abbreviated: ['1èr trim.', '2nd trim.', '3en trim.', '4en trim.'],
      wide: ['1èr trimèstre', '2nd trimèstre', '3en trimèstre', '4en trimèstre']
    };
    var monthValues$n = {
      narrow: ['GN', 'FB', 'MÇ', 'AB', 'MA', 'JN', 'JL', 'AG', 'ST', 'OC', 'NV', 'DC'],
      abbreviated: ['gen.', 'febr.', 'març', 'abr.', 'mai', 'junh', 'jul.', 'ag.', 'set.', 'oct.', 'nov.', 'dec.'],
      wide: ['genièr', 'febrièr', 'març', 'abril', 'mai', 'junh', 'julhet', 'agost', 'setembre', 'octòbre', 'novembre', 'decembre']
    };
    var dayValues$n = {
      narrow: ['dg.', 'dl.', 'dm.', 'dc.', 'dj.', 'dv.', 'ds.'],
      short: ['dg.', 'dl.', 'dm.', 'dc.', 'dj.', 'dv.', 'ds.'],
      abbreviated: ['dg.', 'dl.', 'dm.', 'dc.', 'dj.', 'dv.', 'ds.'],
      wide: ['dimenge', 'diluns', 'dimars', 'dimècres', 'dijòus', 'divendres', 'dissabte']
    };
    var dayPeriodValues$n = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'mièjanuèch',
        noon: 'miègjorn',
        morning: 'matin',
        afternoon: 'aprèp-miègjorn',
        evening: 'vèspre',
        night: 'nuèch'
      },
      abbreviated: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'mièjanuèch',
        noon: 'miègjorn',
        morning: 'matin',
        afternoon: 'aprèp-miègjorn',
        evening: 'vèspre',
        night: 'nuèch'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'mièjanuèch',
        noon: 'miègjorn',
        morning: 'matin',
        afternoon: 'aprèp-miègjorn',
        evening: 'vèspre',
        night: 'nuèch'
      }
    };
    var formattingDayPeriodValues$m = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'mièjanuèch',
        noon: 'miègjorn',
        morning: 'del matin',
        afternoon: 'de l’aprèp-miègjorn',
        evening: 'del ser',
        night: 'de la nuèch'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mièjanuèch',
        noon: 'miègjorn',
        morning: 'del matin',
        afternoon: 'de l’aprèp-miègjorn',
        evening: 'del ser',
        night: 'de la nuèch'
      },
      wide: {
        am: 'ante meridiem',
        pm: 'post meridiem',
        midnight: 'mièjanuèch',
        noon: 'miègjorn',
        morning: 'del matin',
        afternoon: 'de l’aprèp-miègjorn',
        evening: 'del ser',
        night: 'de la nuèch'
      }
    };
    var ordinalNumber$n = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      var ordinal;
      switch (number) {
        case 1:
          ordinal = 'èr';
          break;
        case 2:
          ordinal = 'nd';
          break;
        default:
          ordinal = 'en';
      }
      if (unit === 'year' || unit === 'week' || unit === 'hour' || unit === 'minute' || unit === 'second') {
        ordinal += 'a';
      }
      return number + ordinal;
    };
    var localize$n = {
      ordinalNumber: ordinalNumber$n,
      era: buildLocalizeFn({
        values: eraValues$n,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$n,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$n,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$n,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$n,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$m,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$n = /^(\d+)(èr|nd|en)?[a]?/i;
    var parseOrdinalNumberPattern$n = /\d+/i;
    var matchEraPatterns$n = {
      narrow: /^(ab\.J\.C|apr\.J\.C|apr\.J\.-C)/i,
      abbreviated: /^(ab\.J\.-C|ab\.J-C|apr\.J\.-C|apr\.J-C|ap\.J-C)/i,
      wide: /^(abans Jèsus-Crist|après Jèsus-Crist)/i
    };
    var parseEraPatterns$n = {
      any: [/^ab/i, /^ap/i]
    };
    var matchQuarterPatterns$n = {
      narrow: /^T[1234]/i,
      abbreviated: /^[1234](èr|nd|en)? trim\.?/i,
      wide: /^[1234](èr|nd|en)? trimèstre/i
    };
    var parseQuarterPatterns$n = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$n = {
      narrow: /^(GN|FB|MÇ|AB|MA|JN|JL|AG|ST|OC|NV|DC)/i,
      abbreviated: /^(gen|febr|març|abr|mai|junh|jul|ag|set|oct|nov|dec)\.?/i,
      wide: /^(genièr|febrièr|març|abril|mai|junh|julhet|agost|setembre|octòbre|novembre|decembre)/i
    };
    var parseMonthPatterns$n = {
      any: [/^g/i, /^f/i, /^ma[r?]|MÇ/i, /^ab/i, /^ma[i?]/i, /^ju[n?]|JN/i, /^ju[l?]|JL/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$n = {
      narrow: /^d[glmcjvs]\.?/i,
      short: /^d[glmcjvs]\.?/i,
      abbreviated: /^d[glmcjvs]\.?/i,
      wide: /^(dimenge|diluns|dimars|dimècres|dijòus|divendres|dissabte)/i
    };
    var parseDayPatterns$n = {
      narrow: [/^dg/i, /^dl/i, /^dm/i, /^dc/i, /^dj/i, /^dv/i, /^ds/i],
      short: [/^dg/i, /^dl/i, /^dm/i, /^dc/i, /^dj/i, /^dv/i, /^ds/i],
      abbreviated: [/^dg/i, /^dl/i, /^dm/i, /^dc/i, /^dj/i, /^dv/i, /^ds/i],
      any: [/^dg|dime/i, /^dl|dil/i, /^dm|dima/i, /^dc|dimè/i, /^dj|dij/i, /^dv|div/i, /^ds|dis/i]
    };
    var matchDayPeriodPatterns$n = {
      any: /(^(a\.?m|p\.?m))|(ante meridiem|post meridiem)|((del |de la |de l’)(matin|aprèp-miègjorn|vèspre|ser|nuèch))/i
    };
    var parseDayPeriodPatterns$n = {
      any: {
        am: /(^a)|ante meridiem/i,
        pm: /(^p)|post meridiem/i,
        midnight: /^mièj/i,
        noon: /^mièg/i,
        morning: /matin/i,
        afternoon: /aprèp-miègjorn/i,
        evening: /vèspre|ser/i,
        night: /nuèch/i
      }
    };
    var match$n = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$n,
        parsePattern: parseOrdinalNumberPattern$n,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$n,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$n,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$n,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$n,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$n,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$n,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$n,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$n,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$n,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$n,
        defaultParseWidth: 'any'
      })
    };

    var locale$n = {
      code: 'oc',
      formatDistance: formatDistance$n,
      formatLong: formatLong$n,
      formatRelative: formatRelative$n,
      localize: localize$n,
      match: match$n,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$m = {
      lessThanXSeconds: {
        one: {
          regular: 'mniej niż sekunda',
          past: 'mniej niż sekundę',
          future: 'mniej niż sekundę'
        },
        twoFour: 'mniej niż {{count}} sekundy',
        other: 'mniej niż {{count}} sekund'
      },
      xSeconds: {
        one: {
          regular: 'sekunda',
          past: 'sekundę',
          future: 'sekundę'
        },
        twoFour: '{{count}} sekundy',
        other: '{{count}} sekund'
      },
      halfAMinute: {
        one: 'pół minuty',
        twoFour: 'pół minuty',
        other: 'pół minuty'
      },
      lessThanXMinutes: {
        one: {
          regular: 'mniej niż minuta',
          past: 'mniej niż minutę',
          future: 'mniej niż minutę'
        },
        twoFour: 'mniej niż {{count}} minuty',
        other: 'mniej niż {{count}} minut'
      },
      xMinutes: {
        one: {
          regular: 'minuta',
          past: 'minutę',
          future: 'minutę'
        },
        twoFour: '{{count}} minuty',
        other: '{{count}} minut'
      },
      aboutXHours: {
        one: {
          regular: 'około godziny',
          past: 'około godziny',
          future: 'około godzinę'
        },
        twoFour: 'około {{count}} godziny',
        other: 'około {{count}} godzin'
      },
      xHours: {
        one: {
          regular: 'godzina',
          past: 'godzinę',
          future: 'godzinę'
        },
        twoFour: '{{count}} godziny',
        other: '{{count}} godzin'
      },
      xDays: {
        one: {
          regular: 'dzień',
          past: 'dzień',
          future: '1 dzień'
        },
        twoFour: '{{count}} dni',
        other: '{{count}} dni'
      },
      aboutXWeeks: {
        one: 'około tygodnia',
        twoFour: 'około {{count}} tygodni',
        other: 'około {{count}} tygodni'
      },
      xWeeks: {
        one: 'tydzień',
        twoFour: '{{count}} tygodnie',
        other: '{{count}} tygodni'
      },
      aboutXMonths: {
        one: 'około miesiąc',
        twoFour: 'około {{count}} miesiące',
        other: 'około {{count}} miesięcy'
      },
      xMonths: {
        one: 'miesiąc',
        twoFour: '{{count}} miesiące',
        other: '{{count}} miesięcy'
      },
      aboutXYears: {
        one: 'około rok',
        twoFour: 'około {{count}} lata',
        other: 'około {{count}} lat'
      },
      xYears: {
        one: 'rok',
        twoFour: '{{count}} lata',
        other: '{{count}} lat'
      },
      overXYears: {
        one: 'ponad rok',
        twoFour: 'ponad {{count}} lata',
        other: 'ponad {{count}} lat'
      },
      almostXYears: {
        one: 'prawie rok',
        twoFour: 'prawie {{count}} lata',
        other: 'prawie {{count}} lat'
      }
    };
    function declensionGroup$1(scheme, count) {
      if (count === 1) {
        return scheme.one;
      }
      var rem100 = count % 100;
      if (rem100 <= 20 && rem100 > 10) {
        return scheme.other;
      }
      var rem10 = rem100 % 10;
      if (rem10 >= 2 && rem10 <= 4) {
        return scheme.twoFour;
      }
      return scheme.other;
    }
    function declension$3(scheme, count, time) {
      var group = declensionGroup$1(scheme, count);
      var finalText = typeof group === 'string' ? group : group[time];
      return finalText.replace('{{count}}', String(count));
    }
    var formatDistance$m = function (token, count, options) {
      var scheme = formatDistanceLocale$m[token];
      if (!(options !== null && options !== void 0 && options.addSuffix)) {
        return declension$3(scheme, count, 'regular');
      }
      if (options.comparison && options.comparison > 0) {
        return 'za ' + declension$3(scheme, count, 'future');
      } else {
        return declension$3(scheme, count, 'past') + ' temu';
      }
    };

    var dateFormats$m = {
      full: 'EEEE, do MMMM y',
      long: 'do MMMM y',
      medium: 'do MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$m = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$m = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$m = {
      date: buildFormatLongFn({
        formats: dateFormats$m,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$m,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$m,
        defaultWidth: 'full'
      })
    };

    var adjectivesLastWeek = {
      masculine: 'ostatni',
      feminine: 'ostatnia'
    };
    var adjectivesThisWeek = {
      masculine: 'ten',
      feminine: 'ta'
    };
    var adjectivesNextWeek = {
      masculine: 'następny',
      feminine: 'następna'
    };
    var dayGrammaticalGender = {
      0: 'feminine',
      1: 'masculine',
      2: 'masculine',
      3: 'feminine',
      4: 'masculine',
      5: 'masculine',
      6: 'feminine'
    };
    function dayAndTimeWithAdjective(token, date, baseDate, options) {
      var adjectives;
      if (isSameUTCWeek(date, baseDate, options)) {
        adjectives = adjectivesThisWeek;
      } else if (token === 'lastWeek') {
        adjectives = adjectivesLastWeek;
      } else if (token === 'nextWeek') {
        adjectives = adjectivesNextWeek;
      } else {
        throw new Error("Cannot determine adjectives for token ".concat(token));
      }
      var day = date.getUTCDay();
      var grammaticalGender = dayGrammaticalGender[day];
      var adjective = adjectives[grammaticalGender];
      return "'".concat(adjective, "' eeee 'o' p");
    }
    var formatRelativeLocale$m = {
      lastWeek: dayAndTimeWithAdjective,
      yesterday: "'wczoraj o' p",
      today: "'dzisiaj o' p",
      tomorrow: "'jutro o' p",
      nextWeek: dayAndTimeWithAdjective,
      other: 'P'
    };
    var formatRelative$m = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$m[token];
      if (typeof format === 'function') {
        return format(token, date, baseDate, options);
      }
      return format;
    };

    var eraValues$m = {
      narrow: ['p.n.e.', 'n.e.'],
      abbreviated: ['p.n.e.', 'n.e.'],
      wide: ['przed naszą erą', 'naszej ery']
    };
    var quarterValues$m = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['I kw.', 'II kw.', 'III kw.', 'IV kw.'],
      wide: ['I kwartał', 'II kwartał', 'III kwartał', 'IV kwartał']
    };
    var monthValues$m = {
      narrow: ['S', 'L', 'M', 'K', 'M', 'C', 'L', 'S', 'W', 'P', 'L', 'G'],
      abbreviated: ['sty', 'lut', 'mar', 'kwi', 'maj', 'cze', 'lip', 'sie', 'wrz', 'paź', 'lis', 'gru'],
      wide: ['styczeń', 'luty', 'marzec', 'kwiecień', 'maj', 'czerwiec', 'lipiec', 'sierpień', 'wrzesień', 'październik', 'listopad', 'grudzień']
    };
    var monthFormattingValues = {
      narrow: ['s', 'l', 'm', 'k', 'm', 'c', 'l', 's', 'w', 'p', 'l', 'g'],
      abbreviated: ['sty', 'lut', 'mar', 'kwi', 'maj', 'cze', 'lip', 'sie', 'wrz', 'paź', 'lis', 'gru'],
      wide: ['stycznia', 'lutego', 'marca', 'kwietnia', 'maja', 'czerwca', 'lipca', 'sierpnia', 'września', 'października', 'listopada', 'grudnia']
    };
    var dayValues$m = {
      narrow: ['N', 'P', 'W', 'Ś', 'C', 'P', 'S'],
      short: ['nie', 'pon', 'wto', 'śro', 'czw', 'pią', 'sob'],
      abbreviated: ['niedz.', 'pon.', 'wt.', 'śr.', 'czw.', 'pt.', 'sob.'],
      wide: ['niedziela', 'poniedziałek', 'wtorek', 'środa', 'czwartek', 'piątek', 'sobota']
    };
    var dayFormattingValues = {
      narrow: ['n', 'p', 'w', 'ś', 'c', 'p', 's'],
      short: ['nie', 'pon', 'wto', 'śro', 'czw', 'pią', 'sob'],
      abbreviated: ['niedz.', 'pon.', 'wt.', 'śr.', 'czw.', 'pt.', 'sob.'],
      wide: ['niedziela', 'poniedziałek', 'wtorek', 'środa', 'czwartek', 'piątek', 'sobota']
    };
    var dayPeriodValues$m = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'półn.',
        noon: 'poł',
        morning: 'rano',
        afternoon: 'popoł.',
        evening: 'wiecz.',
        night: 'noc'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'północ',
        noon: 'południe',
        morning: 'rano',
        afternoon: 'popołudnie',
        evening: 'wieczór',
        night: 'noc'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'północ',
        noon: 'południe',
        morning: 'rano',
        afternoon: 'popołudnie',
        evening: 'wieczór',
        night: 'noc'
      }
    };
    var dayPeriodFormattingValues = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'o półn.',
        noon: 'w poł.',
        morning: 'rano',
        afternoon: 'po poł.',
        evening: 'wiecz.',
        night: 'w nocy'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o północy',
        noon: 'w południe',
        morning: 'rano',
        afternoon: 'po południu',
        evening: 'wieczorem',
        night: 'w nocy'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o północy',
        noon: 'w południe',
        morning: 'rano',
        afternoon: 'po południu',
        evening: 'wieczorem',
        night: 'w nocy'
      }
    };
    var ordinalNumber$m = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$m = {
      ordinalNumber: ordinalNumber$m,
      era: buildLocalizeFn({
        values: eraValues$m,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$m,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$m,
        defaultWidth: 'wide',
        formattingValues: monthFormattingValues,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$m,
        defaultWidth: 'wide',
        formattingValues: dayFormattingValues,
        defaultFormattingWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$m,
        defaultWidth: 'wide',
        formattingValues: dayPeriodFormattingValues,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$m = /^(\d+)?/i;
    var parseOrdinalNumberPattern$m = /\d+/i;
    var matchEraPatterns$m = {
      narrow: /^(p\.?\s*n\.?\s*e\.?\s*|n\.?\s*e\.?\s*)/i,
      abbreviated: /^(p\.?\s*n\.?\s*e\.?\s*|n\.?\s*e\.?\s*)/i,
      wide: /^(przed\s*nasz(ą|a)\s*er(ą|a)|naszej\s*ery)/i
    };
    var parseEraPatterns$m = {
      any: [/^p/i, /^n/i]
    };
    var matchQuarterPatterns$m = {
      narrow: /^[1234]/i,
      abbreviated: /^(I|II|III|IV)\s*kw\.?/i,
      wide: /^(I|II|III|IV)\s*kwarta(ł|l)/i
    };
    var parseQuarterPatterns$m = {
      narrow: [/1/i, /2/i, /3/i, /4/i],
      any: [/^I kw/i, /^II kw/i, /^III kw/i, /^IV kw/i]
    };
    var matchMonthPatterns$m = {
      narrow: /^[slmkcwpg]/i,
      abbreviated: /^(sty|lut|mar|kwi|maj|cze|lip|sie|wrz|pa(ź|z)|lis|gru)/i,
      wide: /^(stycznia|stycze(ń|n)|lutego|luty|marca|marzec|kwietnia|kwiecie(ń|n)|maja|maj|czerwca|czerwiec|lipca|lipiec|sierpnia|sierpie(ń|n)|wrze(ś|s)nia|wrzesie(ń|n)|pa(ź|z)dziernika|pa(ź|z)dziernik|listopada|listopad|grudnia|grudzie(ń|n))/i
    };
    var parseMonthPatterns$m = {
      narrow: [/^s/i, /^l/i, /^m/i, /^k/i, /^m/i, /^c/i, /^l/i, /^s/i, /^w/i, /^p/i, /^l/i, /^g/i],
      any: [/^st/i, /^lu/i, /^mar/i, /^k/i, /^maj/i, /^c/i, /^lip/i, /^si/i, /^w/i, /^p/i, /^lis/i, /^g/i]
    };
    var matchDayPatterns$m = {
      narrow: /^[npwścs]/i,
      short: /^(nie|pon|wto|(ś|s)ro|czw|pi(ą|a)|sob)/i,
      abbreviated: /^(niedz|pon|wt|(ś|s)r|czw|pt|sob)\.?/i,
      wide: /^(niedziela|poniedzia(ł|l)ek|wtorek|(ś|s)roda|czwartek|pi(ą|a)tek|sobota)/i
    };
    var parseDayPatterns$m = {
      narrow: [/^n/i, /^p/i, /^w/i, /^ś/i, /^c/i, /^p/i, /^s/i],
      abbreviated: [/^n/i, /^po/i, /^w/i, /^(ś|s)r/i, /^c/i, /^pt/i, /^so/i],
      any: [/^n/i, /^po/i, /^w/i, /^(ś|s)r/i, /^c/i, /^pi/i, /^so/i]
    };
    var matchDayPeriodPatterns$m = {
      narrow: /^(^a$|^p$|pó(ł|l)n\.?|o\s*pó(ł|l)n\.?|po(ł|l)\.?|w\s*po(ł|l)\.?|po\s*po(ł|l)\.?|rano|wiecz\.?|noc|w\s*nocy)/i,
      any: /^(am|pm|pó(ł|l)noc|o\s*pó(ł|l)nocy|po(ł|l)udnie|w\s*po(ł|l)udnie|popo(ł|l)udnie|po\s*po(ł|l)udniu|rano|wieczór|wieczorem|noc|w\s*nocy)/i
    };
    var parseDayPeriodPatterns$m = {
      narrow: {
        am: /^a$/i,
        pm: /^p$/i,
        midnight: /pó(ł|l)n/i,
        noon: /po(ł|l)/i,
        morning: /rano/i,
        afternoon: /po\s*po(ł|l)/i,
        evening: /wiecz/i,
        night: /noc/i
      },
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /pó(ł|l)n/i,
        noon: /po(ł|l)/i,
        morning: /rano/i,
        afternoon: /po\s*po(ł|l)/i,
        evening: /wiecz/i,
        night: /noc/i
      }
    };
    var match$m = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$m,
        parsePattern: parseOrdinalNumberPattern$m,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$m,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$m,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$m,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$m,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$m,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$m,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$m,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$m,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$m,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$m,
        defaultParseWidth: 'any'
      })
    };

    var locale$m = {
      code: 'pl',
      formatDistance: formatDistance$m,
      formatLong: formatLong$m,
      formatRelative: formatRelative$m,
      localize: localize$m,
      match: match$m,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$l = {
      lessThanXSeconds: {
        one: 'menos de um segundo',
        other: 'menos de {{count}} segundos'
      },
      xSeconds: {
        one: '1 segundo',
        other: '{{count}} segundos'
      },
      halfAMinute: 'meio minuto',
      lessThanXMinutes: {
        one: 'menos de um minuto',
        other: 'menos de {{count}} minutos'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutos'
      },
      aboutXHours: {
        one: 'aproximadamente 1 hora',
        other: 'aproximadamente {{count}} horas'
      },
      xHours: {
        one: '1 hora',
        other: '{{count}} horas'
      },
      xDays: {
        one: '1 dia',
        other: '{{count}} dias'
      },
      aboutXWeeks: {
        one: 'aproximadamente 1 semana',
        other: 'aproximadamente {{count}} semanas'
      },
      xWeeks: {
        one: '1 semana',
        other: '{{count}} semanas'
      },
      aboutXMonths: {
        one: 'aproximadamente 1 mês',
        other: 'aproximadamente {{count}} meses'
      },
      xMonths: {
        one: '1 mês',
        other: '{{count}} meses'
      },
      aboutXYears: {
        one: 'aproximadamente 1 ano',
        other: 'aproximadamente {{count}} anos'
      },
      xYears: {
        one: '1 ano',
        other: '{{count}} anos'
      },
      overXYears: {
        one: 'mais de 1 ano',
        other: 'mais de {{count}} anos'
      },
      almostXYears: {
        one: 'quase 1 ano',
        other: 'quase {{count}} anos'
      }
    };
    var formatDistance$l = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$l[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'daqui a ' + result;
        } else {
          return 'há ' + result;
        }
      }
      return result;
    };

    var dateFormats$l = {
      full: "EEEE, d 'de' MMMM 'de' y",
      long: "d 'de' MMMM 'de' y",
      medium: "d 'de' MMM 'de' y",
      short: 'dd/MM/y'
    };
    var timeFormats$l = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$l = {
      full: "{{date}} 'às' {{time}}",
      long: "{{date}} 'às' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$l = {
      date: buildFormatLongFn({
        formats: dateFormats$l,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$l,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$l,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$l = {
      lastWeek: function (date) {
        var weekday = date.getUTCDay();
        var last = weekday === 0 || weekday === 6 ? 'último' : 'última';
        return "'" + last + "' eeee 'às' p";
      },
      yesterday: "'ontem às' p",
      today: "'hoje às' p",
      tomorrow: "'amanhã às' p",
      nextWeek: "eeee 'às' p",
      other: 'P'
    };
    var formatRelative$l = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$l[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$l = {
      narrow: ['aC', 'dC'],
      abbreviated: ['a.C.', 'd.C.'],
      wide: ['antes de Cristo', 'depois de Cristo']
    };
    var quarterValues$l = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$l = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan', 'fev', 'mar', 'abr', 'mai', 'jun', 'jul', 'ago', 'set', 'out', 'nov', 'dez'],
      wide: ['janeiro', 'fevereiro', 'março', 'abril', 'maio', 'junho', 'julho', 'agosto', 'setembro', 'outubro', 'novembro', 'dezembro']
    };
    var dayValues$l = {
      narrow: ['d', 's', 't', 'q', 'q', 's', 's'],
      short: ['dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sáb'],
      abbreviated: ['dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sáb'],
      wide: ['domingo', 'segunda-feira', 'terça-feira', 'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado']
    };
    var dayPeriodValues$l = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'noite',
        night: 'madrugada'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'noite',
        night: 'madrugada'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'noite',
        night: 'madrugada'
      }
    };
    var formattingDayPeriodValues$l = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da noite',
        night: 'da madrugada'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da noite',
        night: 'da madrugada'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da noite',
        night: 'da madrugada'
      }
    };
    var ordinalNumber$l = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'º';
    };
    var localize$l = {
      ordinalNumber: ordinalNumber$l,
      era: buildLocalizeFn({
        values: eraValues$l,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$l,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$l,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$l,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$l,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$l,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$l = /^(\d+)(º|ª)?/i;
    var parseOrdinalNumberPattern$l = /\d+/i;
    var matchEraPatterns$l = {
      narrow: /^(ac|dc|a|d)/i,
      abbreviated: /^(a\.?\s?c\.?|a\.?\s?e\.?\s?c\.?|d\.?\s?c\.?|e\.?\s?c\.?)/i,
      wide: /^(antes de cristo|antes da era comum|depois de cristo|era comum)/i
    };
    var parseEraPatterns$l = {
      any: [/^ac/i, /^dc/i],
      wide: [/^(antes de cristo|antes da era comum)/i, /^(depois de cristo|era comum)/i]
    };
    var matchQuarterPatterns$l = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^[1234](º|ª)? trimestre/i
    };
    var parseQuarterPatterns$l = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$l = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|fev|mar|abr|mai|jun|jul|ago|set|out|nov|dez)/i,
      wide: /^(janeiro|fevereiro|março|abril|maio|junho|julho|agosto|setembro|outubro|novembro|dezembro)/i
    };
    var parseMonthPatterns$l = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ab/i, /^mai/i, /^jun/i, /^jul/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$l = {
      narrow: /^[dstq]/i,
      short: /^(dom|seg|ter|qua|qui|sex|s[áa]b)/i,
      abbreviated: /^(dom|seg|ter|qua|qui|sex|s[áa]b)/i,
      wide: /^(domingo|segunda-?\s?feira|terça-?\s?feira|quarta-?\s?feira|quinta-?\s?feira|sexta-?\s?feira|s[áa]bado)/i
    };
    var parseDayPatterns$l = {
      narrow: [/^d/i, /^s/i, /^t/i, /^q/i, /^q/i, /^s/i, /^s/i],
      any: [/^d/i, /^seg/i, /^t/i, /^qua/i, /^qui/i, /^sex/i, /^s[áa]/i]
    };
    var matchDayPeriodPatterns$l = {
      narrow: /^(a|p|meia-?\s?noite|meio-?\s?dia|(da) (manh[ãa]|tarde|noite|madrugada))/i,
      any: /^([ap]\.?\s?m\.?|meia-?\s?noite|meio-?\s?dia|(da) (manh[ãa]|tarde|noite|madrugada))/i
    };
    var parseDayPeriodPatterns$l = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^meia/i,
        noon: /^meio/i,
        morning: /manh[ãa]/i,
        afternoon: /tarde/i,
        evening: /noite/i,
        night: /madrugada/i
      }
    };
    var match$l = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$l,
        parsePattern: parseOrdinalNumberPattern$l,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$l,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$l,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$l,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$l,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$l,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$l,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$l,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$l,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$l,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$l,
        defaultParseWidth: 'any'
      })
    };

    var locale$l = {
      code: 'pt',
      formatDistance: formatDistance$l,
      formatLong: formatLong$l,
      formatRelative: formatRelative$l,
      localize: localize$l,
      match: match$l,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$k = {
      lessThanXSeconds: {
        one: 'menos de um segundo',
        other: 'menos de {{count}} segundos'
      },
      xSeconds: {
        one: '1 segundo',
        other: '{{count}} segundos'
      },
      halfAMinute: 'meio minuto',
      lessThanXMinutes: {
        one: 'menos de um minuto',
        other: 'menos de {{count}} minutos'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutos'
      },
      aboutXHours: {
        one: 'cerca de 1 hora',
        other: 'cerca de {{count}} horas'
      },
      xHours: {
        one: '1 hora',
        other: '{{count}} horas'
      },
      xDays: {
        one: '1 dia',
        other: '{{count}} dias'
      },
      aboutXWeeks: {
        one: 'cerca de 1 semana',
        other: 'cerca de {{count}} semanas'
      },
      xWeeks: {
        one: '1 semana',
        other: '{{count}} semanas'
      },
      aboutXMonths: {
        one: 'cerca de 1 mês',
        other: 'cerca de {{count}} meses'
      },
      xMonths: {
        one: '1 mês',
        other: '{{count}} meses'
      },
      aboutXYears: {
        one: 'cerca de 1 ano',
        other: 'cerca de {{count}} anos'
      },
      xYears: {
        one: '1 ano',
        other: '{{count}} anos'
      },
      overXYears: {
        one: 'mais de 1 ano',
        other: 'mais de {{count}} anos'
      },
      almostXYears: {
        one: 'quase 1 ano',
        other: 'quase {{count}} anos'
      }
    };
    var formatDistance$k = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$k[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'em ' + result;
        } else {
          return 'há ' + result;
        }
      }
      return result;
    };

    var dateFormats$k = {
      full: "EEEE, d 'de' MMMM 'de' y",
      long: "d 'de' MMMM 'de' y",
      medium: 'd MMM y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$k = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$k = {
      full: "{{date}} 'às' {{time}}",
      long: "{{date}} 'às' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$k = {
      date: buildFormatLongFn({
        formats: dateFormats$k,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$k,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$k,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$k = {
      lastWeek: function (date) {
        var weekday = date.getUTCDay();
        var last = weekday === 0 || weekday === 6 ? 'último' : 'última';
        return "'" + last + "' eeee 'às' p";
      },
      yesterday: "'ontem às' p",
      today: "'hoje às' p",
      tomorrow: "'amanhã às' p",
      nextWeek: "eeee 'às' p",
      other: 'P'
    };
    var formatRelative$k = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$k[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$k = {
      narrow: ['AC', 'DC'],
      abbreviated: ['AC', 'DC'],
      wide: ['antes de cristo', 'depois de cristo']
    };
    var quarterValues$k = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$k = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan', 'fev', 'mar', 'abr', 'mai', 'jun', 'jul', 'ago', 'set', 'out', 'nov', 'dez'],
      wide: ['janeiro', 'fevereiro', 'março', 'abril', 'maio', 'junho', 'julho', 'agosto', 'setembro', 'outubro', 'novembro', 'dezembro']
    };
    var dayValues$k = {
      narrow: ['D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      short: ['dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sab'],
      abbreviated: ['domingo', 'segunda', 'terça', 'quarta', 'quinta', 'sexta', 'sábado'],
      wide: ['domingo', 'segunda-feira', 'terça-feira', 'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado']
    };
    var dayPeriodValues$k = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noite'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noite'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noite'
      }
    };
    var formattingDayPeriodValues$k = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da tarde',
        night: 'da noite'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da tarde',
        night: 'da noite'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da tarde',
        night: 'da noite'
      }
    };
    var ordinalNumber$k = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      if ((options === null || options === void 0 ? void 0 : options.unit) === 'week') {
        return number + 'ª';
      }
      return number + 'º';
    };
    var localize$k = {
      ordinalNumber: ordinalNumber$k,
      era: buildLocalizeFn({
        values: eraValues$k,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$k,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$k,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$k,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$k,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$k,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$k = /^(\d+)[ºªo]?/i;
    var parseOrdinalNumberPattern$k = /\d+/i;
    var matchEraPatterns$k = {
      narrow: /^(ac|dc|a|d)/i,
      abbreviated: /^(a\.?\s?c\.?|d\.?\s?c\.?)/i,
      wide: /^(antes de cristo|depois de cristo)/i
    };
    var parseEraPatterns$k = {
      any: [/^ac/i, /^dc/i],
      wide: [/^antes de cristo/i, /^depois de cristo/i]
    };
    var matchQuarterPatterns$k = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^[1234](º)? trimestre/i
    };
    var parseQuarterPatterns$k = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$k = {
      narrow: /^[jfmajsond]/i,
      abbreviated: /^(jan|fev|mar|abr|mai|jun|jul|ago|set|out|nov|dez)/i,
      wide: /^(janeiro|fevereiro|março|abril|maio|junho|julho|agosto|setembro|outubro|novembro|dezembro)/i
    };
    var parseMonthPatterns$k = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^fev/i, /^mar/i, /^abr/i, /^mai/i, /^jun/i, /^jul/i, /^ago/i, /^set/i, /^out/i, /^nov/i, /^dez/i]
    };
    var matchDayPatterns$k = {
      narrow: /^(dom|[23456]ª?|s[aá]b)/i,
      short: /^(dom|[23456]ª?|s[aá]b)/i,
      abbreviated: /^(dom|seg|ter|qua|qui|sex|s[aá]b)/i,
      wide: /^(domingo|(segunda|ter[cç]a|quarta|quinta|sexta)([- ]feira)?|s[aá]bado)/i
    };
    var parseDayPatterns$k = {
      short: [/^d/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^s[aá]/i],
      narrow: [/^d/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^s[aá]/i],
      any: [/^d/i, /^seg/i, /^t/i, /^qua/i, /^qui/i, /^sex/i, /^s[aá]b/i]
    };
    var matchDayPeriodPatterns$k = {
      narrow: /^(a|p|mn|md|(da) (manhã|tarde|noite))/i,
      any: /^([ap]\.?\s?m\.?|meia[-\s]noite|meio[-\s]dia|(da) (manhã|tarde|noite))/i
    };
    var parseDayPeriodPatterns$k = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mn|^meia[-\s]noite/i,
        noon: /^md|^meio[-\s]dia/i,
        morning: /manhã/i,
        afternoon: /tarde/i,
        evening: /tarde/i,
        night: /noite/i
      }
    };
    var match$k = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$k,
        parsePattern: parseOrdinalNumberPattern$k,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$k,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$k,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$k,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$k,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$k,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$k,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$k,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$k,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$k,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$k,
        defaultParseWidth: 'any'
      })
    };

    var locale$k = {
      code: 'pt-BR',
      formatDistance: formatDistance$k,
      formatLong: formatLong$k,
      formatRelative: formatRelative$k,
      localize: localize$k,
      match: match$k,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$j = {
      lessThanXSeconds: {
        one: 'mai puțin de o secundă',
        other: 'mai puțin de {{count}} secunde'
      },
      xSeconds: {
        one: '1 secundă',
        other: '{{count}} secunde'
      },
      halfAMinute: 'jumătate de minut',
      lessThanXMinutes: {
        one: 'mai puțin de un minut',
        other: 'mai puțin de {{count}} minute'
      },
      xMinutes: {
        one: '1 minut',
        other: '{{count}} minute'
      },
      aboutXHours: {
        one: 'circa 1 oră',
        other: 'circa {{count}} ore'
      },
      xHours: {
        one: '1 oră',
        other: '{{count}} ore'
      },
      xDays: {
        one: '1 zi',
        other: '{{count}} zile'
      },
      aboutXWeeks: {
        one: 'circa o săptămână',
        other: 'circa {{count}} săptămâni'
      },
      xWeeks: {
        one: '1 săptămână',
        other: '{{count}} săptămâni'
      },
      aboutXMonths: {
        one: 'circa 1 lună',
        other: 'circa {{count}} luni'
      },
      xMonths: {
        one: '1 lună',
        other: '{{count}} luni'
      },
      aboutXYears: {
        one: 'circa 1 an',
        other: 'circa {{count}} ani'
      },
      xYears: {
        one: '1 an',
        other: '{{count}} ani'
      },
      overXYears: {
        one: 'peste 1 an',
        other: 'peste {{count}} ani'
      },
      almostXYears: {
        one: 'aproape 1 an',
        other: 'aproape {{count}} ani'
      }
    };
    var formatDistance$j = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$j[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'în ' + result;
        } else {
          return result + ' în urmă';
        }
      }
      return result;
    };

    var dateFormats$j = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'dd.MM.yyyy'
    };
    var timeFormats$j = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$j = {
      full: "{{date}} 'la' {{time}}",
      long: "{{date}} 'la' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$j = {
      date: buildFormatLongFn({
        formats: dateFormats$j,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$j,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$j,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$j = {
      lastWeek: "eeee 'trecută la' p",
      yesterday: "'ieri la' p",
      today: "'astăzi la' p",
      tomorrow: "'mâine la' p",
      nextWeek: "eeee 'viitoare la' p",
      other: 'P'
    };
    var formatRelative$j = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$j[token];
    };

    var eraValues$j = {
      narrow: ['Î', 'D'],
      abbreviated: ['Î.d.C.', 'D.C.'],
      wide: ['Înainte de Cristos', 'După Cristos']
    };
    var quarterValues$j = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['primul trimestru', 'al doilea trimestru', 'al treilea trimestru', 'al patrulea trimestru']
    };
    var monthValues$j = {
      narrow: ['I', 'F', 'M', 'A', 'M', 'I', 'I', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['ian', 'feb', 'mar', 'apr', 'mai', 'iun', 'iul', 'aug', 'sep', 'oct', 'noi', 'dec'],
      wide: ['ianuarie', 'februarie', 'martie', 'aprilie', 'mai', 'iunie', 'iulie', 'august', 'septembrie', 'octombrie', 'noiembrie', 'decembrie']
    };
    var dayValues$j = {
      narrow: ['d', 'l', 'm', 'm', 'j', 'v', 's'],
      short: ['du', 'lu', 'ma', 'mi', 'jo', 'vi', 'sâ'],
      abbreviated: ['dum', 'lun', 'mar', 'mie', 'joi', 'vin', 'sâm'],
      wide: ['duminică', 'luni', 'marți', 'miercuri', 'joi', 'vineri', 'sâmbătă']
    };
    var dayPeriodValues$j = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'ami',
        morning: 'dim',
        afternoon: 'da',
        evening: 's',
        night: 'n'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'miezul nopții',
        noon: 'amiază',
        morning: 'dimineață',
        afternoon: 'după-amiază',
        evening: 'seară',
        night: 'noapte'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'miezul nopții',
        noon: 'amiază',
        morning: 'dimineață',
        afternoon: 'după-amiază',
        evening: 'seară',
        night: 'noapte'
      }
    };
    var formattingDayPeriodValues$j = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'amiază',
        morning: 'dimineață',
        afternoon: 'după-amiază',
        evening: 'seară',
        night: 'noapte'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'miezul nopții',
        noon: 'amiază',
        morning: 'dimineață',
        afternoon: 'după-amiază',
        evening: 'seară',
        night: 'noapte'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'miezul nopții',
        noon: 'amiază',
        morning: 'dimineață',
        afternoon: 'după-amiază',
        evening: 'seară',
        night: 'noapte'
      }
    };
    var ordinalNumber$j = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$j = {
      ordinalNumber: ordinalNumber$j,
      era: buildLocalizeFn({
        values: eraValues$j,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$j,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$j,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$j,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$j,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$j,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$j = /^(\d+)?/i;
    var parseOrdinalNumberPattern$j = /\d+/i;
    var matchEraPatterns$j = {
      narrow: /^(Î|D)/i,
      abbreviated: /^(Î\.?\s?d\.?\s?C\.?|Î\.?\s?e\.?\s?n\.?|D\.?\s?C\.?|e\.?\s?n\.?)/i,
      wide: /^(Înainte de Cristos|Înaintea erei noastre|După Cristos|Era noastră)/i
    };
    var parseEraPatterns$j = {
      any: [/^ÎC/i, /^DC/i],
      wide: [/^(Înainte de Cristos|Înaintea erei noastre)/i, /^(După Cristos|Era noastră)/i]
    };
    var matchQuarterPatterns$j = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^trimestrul [1234]/i
    };
    var parseQuarterPatterns$j = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$j = {
      narrow: /^[ifmaasond]/i,
      abbreviated: /^(ian|feb|mar|apr|mai|iun|iul|aug|sep|oct|noi|dec)/i,
      wide: /^(ianuarie|februarie|martie|aprilie|mai|iunie|iulie|august|septembrie|octombrie|noiembrie|decembrie)/i
    };
    var parseMonthPatterns$j = {
      narrow: [/^i/i, /^f/i, /^m/i, /^a/i, /^m/i, /^i/i, /^i/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ia/i, /^f/i, /^mar/i, /^ap/i, /^mai/i, /^iun/i, /^iul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$j = {
      narrow: /^[dlmjvs]/i,
      short: /^(d|l|ma|mi|j|v|s)/i,
      abbreviated: /^(dum|lun|mar|mie|jo|vi|sâ)/i,
      wide: /^(duminica|luni|marţi|miercuri|joi|vineri|sâmbătă)/i
    };
    var parseDayPatterns$j = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i],
      any: [/^d/i, /^l/i, /^ma/i, /^mi/i, /^j/i, /^v/i, /^s/i]
    };
    var matchDayPeriodPatterns$j = {
      narrow: /^(a|p|mn|a|(dimineaţa|după-amiaza|seara|noaptea))/i,
      any: /^([ap]\.?\s?m\.?|miezul nopții|amiaza|(dimineaţa|după-amiaza|seara|noaptea))/i
    };
    var parseDayPeriodPatterns$j = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mn/i,
        noon: /amiaza/i,
        morning: /dimineaţa/i,
        afternoon: /după-amiaza/i,
        evening: /seara/i,
        night: /noaptea/i
      }
    };
    var match$j = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$j,
        parsePattern: parseOrdinalNumberPattern$j,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$j,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$j,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$j,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$j,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$j,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$j,
        defaultParseWidth: 'any'
      })
    };

    var locale$j = {
      code: 'ro',
      formatDistance: formatDistance$j,
      formatLong: formatLong$j,
      formatRelative: formatRelative$j,
      localize: localize$j,
      match: match$j,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    function declension$2(scheme, count) {
      if (scheme.one !== undefined && count === 1) {
        return scheme.one;
      }
      var rem10 = count % 10;
      var rem100 = count % 100;
      if (rem10 === 1 && rem100 !== 11) {
        return scheme.singularNominative.replace('{{count}}', String(count));
      } else if (rem10 >= 2 && rem10 <= 4 && (rem100 < 10 || rem100 > 20)) {
        return scheme.singularGenitive.replace('{{count}}', String(count));
      } else {
        return scheme.pluralGenitive.replace('{{count}}', String(count));
      }
    }
    function buildLocalizeTokenFn$1(scheme) {
      return function (count, options) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            if (scheme.future) {
              return declension$2(scheme.future, count);
            } else {
              return 'через ' + declension$2(scheme.regular, count);
            }
          } else {
            if (scheme.past) {
              return declension$2(scheme.past, count);
            } else {
              return declension$2(scheme.regular, count) + ' назад';
            }
          }
        } else {
          return declension$2(scheme.regular, count);
        }
      };
    }
    var formatDistanceLocale$i = {
      lessThanXSeconds: buildLocalizeTokenFn$1({
        regular: {
          one: 'меньше секунды',
          singularNominative: 'меньше {{count}} секунды',
          singularGenitive: 'меньше {{count}} секунд',
          pluralGenitive: 'меньше {{count}} секунд'
        },
        future: {
          one: 'меньше, чем через секунду',
          singularNominative: 'меньше, чем через {{count}} секунду',
          singularGenitive: 'меньше, чем через {{count}} секунды',
          pluralGenitive: 'меньше, чем через {{count}} секунд'
        }
      }),
      xSeconds: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} секунда',
          singularGenitive: '{{count}} секунды',
          pluralGenitive: '{{count}} секунд'
        },
        past: {
          singularNominative: '{{count}} секунду назад',
          singularGenitive: '{{count}} секунды назад',
          pluralGenitive: '{{count}} секунд назад'
        },
        future: {
          singularNominative: 'через {{count}} секунду',
          singularGenitive: 'через {{count}} секунды',
          pluralGenitive: 'через {{count}} секунд'
        }
      }),
      halfAMinute: function (_count, options) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            return 'через полминуты';
          } else {
            return 'полминуты назад';
          }
        }
        return 'полминуты';
      },
      lessThanXMinutes: buildLocalizeTokenFn$1({
        regular: {
          one: 'меньше минуты',
          singularNominative: 'меньше {{count}} минуты',
          singularGenitive: 'меньше {{count}} минут',
          pluralGenitive: 'меньше {{count}} минут'
        },
        future: {
          one: 'меньше, чем через минуту',
          singularNominative: 'меньше, чем через {{count}} минуту',
          singularGenitive: 'меньше, чем через {{count}} минуты',
          pluralGenitive: 'меньше, чем через {{count}} минут'
        }
      }),
      xMinutes: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} минута',
          singularGenitive: '{{count}} минуты',
          pluralGenitive: '{{count}} минут'
        },
        past: {
          singularNominative: '{{count}} минуту назад',
          singularGenitive: '{{count}} минуты назад',
          pluralGenitive: '{{count}} минут назад'
        },
        future: {
          singularNominative: 'через {{count}} минуту',
          singularGenitive: 'через {{count}} минуты',
          pluralGenitive: 'через {{count}} минут'
        }
      }),
      aboutXHours: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} часа',
          singularGenitive: 'около {{count}} часов',
          pluralGenitive: 'около {{count}} часов'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} час',
          singularGenitive: 'приблизительно через {{count}} часа',
          pluralGenitive: 'приблизительно через {{count}} часов'
        }
      }),
      xHours: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} час',
          singularGenitive: '{{count}} часа',
          pluralGenitive: '{{count}} часов'
        }
      }),
      xDays: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} день',
          singularGenitive: '{{count}} дня',
          pluralGenitive: '{{count}} дней'
        }
      }),
      aboutXWeeks: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} недели',
          singularGenitive: 'около {{count}} недель',
          pluralGenitive: 'около {{count}} недель'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} неделю',
          singularGenitive: 'приблизительно через {{count}} недели',
          pluralGenitive: 'приблизительно через {{count}} недель'
        }
      }),
      xWeeks: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} неделя',
          singularGenitive: '{{count}} недели',
          pluralGenitive: '{{count}} недель'
        }
      }),
      aboutXMonths: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} месяца',
          singularGenitive: 'около {{count}} месяцев',
          pluralGenitive: 'около {{count}} месяцев'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} месяц',
          singularGenitive: 'приблизительно через {{count}} месяца',
          pluralGenitive: 'приблизительно через {{count}} месяцев'
        }
      }),
      xMonths: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} месяц',
          singularGenitive: '{{count}} месяца',
          pluralGenitive: '{{count}} месяцев'
        }
      }),
      aboutXYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} года',
          singularGenitive: 'около {{count}} лет',
          pluralGenitive: 'около {{count}} лет'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} год',
          singularGenitive: 'приблизительно через {{count}} года',
          pluralGenitive: 'приблизительно через {{count}} лет'
        }
      }),
      xYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} год',
          singularGenitive: '{{count}} года',
          pluralGenitive: '{{count}} лет'
        }
      }),
      overXYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'больше {{count}} года',
          singularGenitive: 'больше {{count}} лет',
          pluralGenitive: 'больше {{count}} лет'
        },
        future: {
          singularNominative: 'больше, чем через {{count}} год',
          singularGenitive: 'больше, чем через {{count}} года',
          pluralGenitive: 'больше, чем через {{count}} лет'
        }
      }),
      almostXYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'почти {{count}} год',
          singularGenitive: 'почти {{count}} года',
          pluralGenitive: 'почти {{count}} лет'
        },
        future: {
          singularNominative: 'почти через {{count}} год',
          singularGenitive: 'почти через {{count}} года',
          pluralGenitive: 'почти через {{count}} лет'
        }
      })
    };
    var formatDistance$i = function (token, count, options) {
      return formatDistanceLocale$i[token](count, options);
    };

    var dateFormats$i = {
      full: "EEEE, d MMMM y 'г.'",
      long: "d MMMM y 'г.'",
      medium: "d MMM y 'г.'",
      short: 'dd.MM.y'
    };
    var timeFormats$i = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$i = {
      any: '{{date}}, {{time}}'
    };
    var formatLong$i = {
      date: buildFormatLongFn({
        formats: dateFormats$i,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$i,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$i,
        defaultWidth: 'any'
      })
    };

    var accusativeWeekdays$2 = ['воскресенье', 'понедельник', 'вторник', 'среду', 'четверг', 'пятницу', 'субботу'];
    function lastWeek$2(day) {
      var weekday = accusativeWeekdays$2[day];
      switch (day) {
        case 0:
          return "'в прошлое " + weekday + " в' p";
        case 1:
        case 2:
        case 4:
          return "'в прошлый " + weekday + " в' p";
        case 3:
        case 5:
        case 6:
          return "'в прошлую " + weekday + " в' p";
      }
    }
    function thisWeek$2(day) {
      var weekday = accusativeWeekdays$2[day];
      if (day === 2
      ) {
          return "'во " + weekday + " в' p";
        } else {
        return "'в " + weekday + " в' p";
      }
    }
    function nextWeek$2(day) {
      var weekday = accusativeWeekdays$2[day];
      switch (day) {
        case 0:
          return "'в следующее " + weekday + " в' p";
        case 1:
        case 2:
        case 4:
          return "'в следующий " + weekday + " в' p";
        case 3:
        case 5:
        case 6:
          return "'в следующую " + weekday + " в' p";
      }
    }
    var formatRelativeLocale$i = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$2(day);
        } else {
          return lastWeek$2(day);
        }
      },
      yesterday: "'вчера в' p",
      today: "'сегодня в' p",
      tomorrow: "'завтра в' p",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$2(day);
        } else {
          return nextWeek$2(day);
        }
      },
      other: 'P'
    };
    var formatRelative$i = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$i[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$i = {
      narrow: ['до н.э.', 'н.э.'],
      abbreviated: ['до н. э.', 'н. э.'],
      wide: ['до нашей эры', 'нашей эры']
    };
    var quarterValues$i = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-й кв.', '2-й кв.', '3-й кв.', '4-й кв.'],
      wide: ['1-й квартал', '2-й квартал', '3-й квартал', '4-й квартал']
    };
    var monthValues$i = {
      narrow: ['Я', 'Ф', 'М', 'А', 'М', 'И', 'И', 'А', 'С', 'О', 'Н', 'Д'],
      abbreviated: ['янв.', 'фев.', 'март', 'апр.', 'май', 'июнь', 'июль', 'авг.', 'сент.', 'окт.', 'нояб.', 'дек.'],
      wide: ['январь', 'февраль', 'март', 'апрель', 'май', 'июнь', 'июль', 'август', 'сентябрь', 'октябрь', 'ноябрь', 'декабрь']
    };
    var formattingMonthValues$5 = {
      narrow: ['Я', 'Ф', 'М', 'А', 'М', 'И', 'И', 'А', 'С', 'О', 'Н', 'Д'],
      abbreviated: ['янв.', 'фев.', 'мар.', 'апр.', 'мая', 'июн.', 'июл.', 'авг.', 'сент.', 'окт.', 'нояб.', 'дек.'],
      wide: ['января', 'февраля', 'марта', 'апреля', 'мая', 'июня', 'июля', 'августа', 'сентября', 'октября', 'ноября', 'декабря']
    };
    var dayValues$i = {
      narrow: ['В', 'П', 'В', 'С', 'Ч', 'П', 'С'],
      short: ['вс', 'пн', 'вт', 'ср', 'чт', 'пт', 'сб'],
      abbreviated: ['вск', 'пнд', 'втр', 'срд', 'чтв', 'птн', 'суб'],
      wide: ['воскресенье', 'понедельник', 'вторник', 'среда', 'четверг', 'пятница', 'суббота']
    };
    var dayPeriodValues$i = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утро',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ночь'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утро',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ночь'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полночь',
        noon: 'полдень',
        morning: 'утро',
        afternoon: 'день',
        evening: 'вечер',
        night: 'ночь'
      }
    };
    var formattingDayPeriodValues$i = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утра',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночи'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утра',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночи'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полночь',
        noon: 'полдень',
        morning: 'утра',
        afternoon: 'дня',
        evening: 'вечера',
        night: 'ночи'
      }
    };
    var ordinalNumber$i = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      var suffix;
      if (unit === 'date') {
        suffix = '-е';
      } else if (unit === 'week' || unit === 'minute' || unit === 'second') {
        suffix = '-я';
      } else {
        suffix = '-й';
      }
      return number + suffix;
    };
    var localize$i = {
      ordinalNumber: ordinalNumber$i,
      era: buildLocalizeFn({
        values: eraValues$i,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$i,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$i,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$5,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$i,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$i,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$i,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$i = /^(\d+)(-?(е|я|й|ое|ье|ая|ья|ый|ой|ий|ый))?/i;
    var parseOrdinalNumberPattern$i = /\d+/i;
    var matchEraPatterns$i = {
      narrow: /^((до )?н\.?\s?э\.?)/i,
      abbreviated: /^((до )?н\.?\s?э\.?)/i,
      wide: /^(до нашей эры|нашей эры|наша эра)/i
    };
    var parseEraPatterns$i = {
      any: [/^д/i, /^н/i]
    };
    var matchQuarterPatterns$i = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[ыои]?й?)? кв.?/i,
      wide: /^[1234](-?[ыои]?й?)? квартал/i
    };
    var parseQuarterPatterns$i = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$i = {
      narrow: /^[яфмаисонд]/i,
      abbreviated: /^(янв|фев|март?|апр|ма[йя]|июн[ья]?|июл[ья]?|авг|сент?|окт|нояб?|дек)\.?/i,
      wide: /^(январ[ья]|феврал[ья]|марта?|апрел[ья]|ма[йя]|июн[ья]|июл[ья]|августа?|сентябр[ья]|октябр[ья]|октябр[ья]|ноябр[ья]|декабр[ья])/i
    };
    var parseMonthPatterns$i = {
      narrow: [/^я/i, /^ф/i, /^м/i, /^а/i, /^м/i, /^и/i, /^и/i, /^а/i, /^с/i, /^о/i, /^н/i, /^я/i],
      any: [/^я/i, /^ф/i, /^мар/i, /^ап/i, /^ма[йя]/i, /^июн/i, /^июл/i, /^ав/i, /^с/i, /^о/i, /^н/i, /^д/i]
    };
    var matchDayPatterns$i = {
      narrow: /^[впсч]/i,
      short: /^(вс|во|пн|по|вт|ср|чт|че|пт|пя|сб|су)\.?/i,
      abbreviated: /^(вск|вос|пнд|пон|втр|вто|срд|сре|чтв|чет|птн|пят|суб).?/i,
      wide: /^(воскресень[ея]|понедельника?|вторника?|сред[аы]|четверга?|пятниц[аы]|суббот[аы])/i
    };
    var parseDayPatterns$i = {
      narrow: [/^в/i, /^п/i, /^в/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^в[ос]/i, /^п[он]/i, /^в/i, /^ср/i, /^ч/i, /^п[ят]/i, /^с[уб]/i]
    };
    var matchDayPeriodPatterns$i = {
      narrow: /^([дп]п|полн\.?|полд\.?|утр[оа]|день|дня|веч\.?|ноч[ьи])/i,
      abbreviated: /^([дп]п|полн\.?|полд\.?|утр[оа]|день|дня|веч\.?|ноч[ьи])/i,
      wide: /^([дп]п|полночь|полдень|утр[оа]|день|дня|вечера?|ноч[ьи])/i
    };
    var parseDayPeriodPatterns$i = {
      any: {
        am: /^дп/i,
        pm: /^пп/i,
        midnight: /^полн/i,
        noon: /^полд/i,
        morning: /^у/i,
        afternoon: /^д[ен]/i,
        evening: /^в/i,
        night: /^н/i
      }
    };
    var match$i = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$i,
        parsePattern: parseOrdinalNumberPattern$i,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$i,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$i,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$i,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$i,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$i,
        defaultParseWidth: 'any'
      })
    };

    var locale$i = {
      code: 'ru',
      formatDistance: formatDistance$i,
      formatLong: formatLong$i,
      formatRelative: formatRelative$i,
      localize: localize$i,
      match: match$i,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    function declensionGroup(scheme, count) {
      if (count === 1 && scheme.one) {
        return scheme.one;
      }
      if (count >= 2 && count <= 4 && scheme.twoFour) {
        return scheme.twoFour;
      }
      return scheme.other;
    }
    function declension$1(scheme, count, time) {
      var group = declensionGroup(scheme, count);
      var finalText = group[time];
      return finalText.replace('{{count}}', String(count));
    }
    function extractPreposition(token) {
      var result = ['lessThan', 'about', 'over', 'almost'].filter(function (preposition) {
        return !!token.match(new RegExp('^' + preposition));
      });
      return result[0];
    }
    function prefixPreposition(preposition) {
      var translation = '';
      if (preposition === 'almost') {
        translation = 'takmer';
      }
      if (preposition === 'about') {
        translation = 'približne';
      }
      return translation.length > 0 ? translation + ' ' : '';
    }
    function suffixPreposition(preposition) {
      var translation = '';
      if (preposition === 'lessThan') {
        translation = 'menej než';
      }
      if (preposition === 'over') {
        translation = 'viac než';
      }
      return translation.length > 0 ? translation + ' ' : '';
    }
    function lowercaseFirstLetter(string) {
      return string.charAt(0).toLowerCase() + string.slice(1);
    }
    var formatDistanceLocale$h = {
      xSeconds: {
        one: {
          present: 'sekunda',
          past: 'sekundou',
          future: 'sekundu'
        },
        twoFour: {
          present: '{{count}} sekundy',
          past: '{{count}} sekundami',
          future: '{{count}} sekundy'
        },
        other: {
          present: '{{count}} sekúnd',
          past: '{{count}} sekundami',
          future: '{{count}} sekúnd'
        }
      },
      halfAMinute: {
        other: {
          present: 'pol minúty',
          past: 'pol minútou',
          future: 'pol minúty'
        }
      },
      xMinutes: {
        one: {
          present: 'minúta',
          past: 'minútou',
          future: 'minútu'
        },
        twoFour: {
          present: '{{count}} minúty',
          past: '{{count}} minútami',
          future: '{{count}} minúty'
        },
        other: {
          present: '{{count}} minút',
          past: '{{count}} minútami',
          future: '{{count}} minút'
        }
      },
      xHours: {
        one: {
          present: 'hodina',
          past: 'hodinou',
          future: 'hodinu'
        },
        twoFour: {
          present: '{{count}} hodiny',
          past: '{{count}} hodinami',
          future: '{{count}} hodiny'
        },
        other: {
          present: '{{count}} hodín',
          past: '{{count}} hodinami',
          future: '{{count}} hodín'
        }
      },
      xDays: {
        one: {
          present: 'deň',
          past: 'dňom',
          future: 'deň'
        },
        twoFour: {
          present: '{{count}} dni',
          past: '{{count}} dňami',
          future: '{{count}} dni'
        },
        other: {
          present: '{{count}} dní',
          past: '{{count}} dňami',
          future: '{{count}} dní'
        }
      },
      xWeeks: {
        one: {
          present: 'týždeň',
          past: 'týždňom',
          future: 'týždeň'
        },
        twoFour: {
          present: '{{count}} týždne',
          past: '{{count}} týždňami',
          future: '{{count}} týždne'
        },
        other: {
          present: '{{count}} týždňov',
          past: '{{count}} týždňami',
          future: '{{count}} týždňov'
        }
      },
      xMonths: {
        one: {
          present: 'mesiac',
          past: 'mesiacom',
          future: 'mesiac'
        },
        twoFour: {
          present: '{{count}} mesiace',
          past: '{{count}} mesiacmi',
          future: '{{count}} mesiace'
        },
        other: {
          present: '{{count}} mesiacov',
          past: '{{count}} mesiacmi',
          future: '{{count}} mesiacov'
        }
      },
      xYears: {
        one: {
          present: 'rok',
          past: 'rokom',
          future: 'rok'
        },
        twoFour: {
          present: '{{count}} roky',
          past: '{{count}} rokmi',
          future: '{{count}} roky'
        },
        other: {
          present: '{{count}} rokov',
          past: '{{count}} rokmi',
          future: '{{count}} rokov'
        }
      }
    };
    var formatDistance$h = function (token, count, options) {
      var preposition = extractPreposition(token) || '';
      var key = lowercaseFirstLetter(token.substring(preposition.length));
      var scheme = formatDistanceLocale$h[key];
      if (!(options !== null && options !== void 0 && options.addSuffix)) {
        return prefixPreposition(preposition) + suffixPreposition(preposition) + declension$1(scheme, count, 'present');
      }
      if (options.comparison && options.comparison > 0) {
        return prefixPreposition(preposition) + 'o ' + suffixPreposition(preposition) + declension$1(scheme, count, 'future');
      } else {
        return prefixPreposition(preposition) + 'pred ' + suffixPreposition(preposition) + declension$1(scheme, count, 'past');
      }
    };

    var dateFormats$h = {
      full: 'EEEE d. MMMM y',
      long: 'd. MMMM y',
      medium: 'd. M. y',
      short: 'd. M. y'
    };
    var timeFormats$h = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$h = {
      full: '{{date}}, {{time}}',
      long: '{{date}}, {{time}}',
      medium: '{{date}}, {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$h = {
      date: buildFormatLongFn({
        formats: dateFormats$h,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$h,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$h,
        defaultWidth: 'full'
      })
    };

    var accusativeWeekdays$1 = ['nedeľu', 'pondelok', 'utorok', 'stredu', 'štvrtok', 'piatok', 'sobotu'];
    function lastWeek$1(day) {
      var weekday = accusativeWeekdays$1[day];
      switch (day) {
        case 0:
        case 3:
        case 6
        :
          return "'minulú " + weekday + " o' p";
        default:
          return "'minulý' eeee 'o' p";
      }
    }
    function thisWeek$1(day) {
      var weekday = accusativeWeekdays$1[day];
      if (day === 4
      ) {
          return "'vo' eeee 'o' p";
        } else {
        return "'v " + weekday + " o' p";
      }
    }
    function nextWeek$1(day) {
      var weekday = accusativeWeekdays$1[day];
      switch (day) {
        case 0:
        case 4:
        case 6
        :
          return "'budúcu " + weekday + " o' p";
        default:
          return "'budúci' eeee 'o' p";
      }
    }
    var formatRelativeLocale$h = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$1(day);
        } else {
          return lastWeek$1(day);
        }
      },
      yesterday: "'včera o' p",
      today: "'dnes o' p",
      tomorrow: "'zajtra o' p",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();
        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$1(day);
        } else {
          return nextWeek$1(day);
        }
      },
      other: 'P'
    };
    var formatRelative$h = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$h[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$h = {
      narrow: ['pred Kr.', 'po Kr.'],
      abbreviated: ['pred Kr.', 'po Kr.'],
      wide: ['pred Kristom', 'po Kristovi']
    };
    var quarterValues$h = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. štvrťrok', '2. štvrťrok', '3. štvrťrok', '4. štvrťrok']
    };
    var monthValues$h = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'máj', 'jún', 'júl', 'aug', 'sep', 'okt', 'nov', 'dec'],
      wide: ['január', 'február', 'marec', 'apríl', 'máj', 'jún', 'júl', 'august', 'september', 'október', 'november', 'december']
    };
    var formattingMonthValues$4 = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'máj', 'jún', 'júl', 'aug', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januára', 'februára', 'marca', 'apríla', 'mája', 'júna', 'júla', 'augusta', 'septembra', 'októbra', 'novembra', 'decembra']
    };
    var dayValues$h = {
      narrow: ['n', 'p', 'u', 's', 'š', 'p', 's'],
      short: ['ne', 'po', 'ut', 'st', 'št', 'pi', 'so'],
      abbreviated: ['ne', 'po', 'ut', 'st', 'št', 'pi', 'so'],
      wide: ['nedeľa', 'pondelok', 'utorok', 'streda', 'štvrtok', 'piatok', 'sobota']
    };
    var dayPeriodValues$h = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'poln.',
        noon: 'pol.',
        morning: 'ráno',
        afternoon: 'pop.',
        evening: 'več.',
        night: 'noc'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'poln.',
        noon: 'pol.',
        morning: 'ráno',
        afternoon: 'popol.',
        evening: 'večer',
        night: 'noc'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'polnoc',
        noon: 'poludnie',
        morning: 'ráno',
        afternoon: 'popoludnie',
        evening: 'večer',
        night: 'noc'
      }
    };
    var formattingDayPeriodValues$h = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o poln.',
        noon: 'nap.',
        morning: 'ráno',
        afternoon: 'pop.',
        evening: 'več.',
        night: 'v n.'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o poln.',
        noon: 'napol.',
        morning: 'ráno',
        afternoon: 'popol.',
        evening: 'večer',
        night: 'v noci'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o polnoci',
        noon: 'napoludnie',
        morning: 'ráno',
        afternoon: 'popoludní',
        evening: 'večer',
        night: 'v noci'
      }
    };
    var ordinalNumber$h = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$h = {
      ordinalNumber: ordinalNumber$h,
      era: buildLocalizeFn({
        values: eraValues$h,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$h,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$h,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$4,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$h,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$h,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$h,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$h = /^(\d+)\.?/i;
    var parseOrdinalNumberPattern$h = /\d+/i;
    var matchEraPatterns$h = {
      narrow: /^(pred Kr\.|pred n\. l\.|po Kr\.|n\. l\.)/i,
      abbreviated: /^(pred Kr\.|pred n\. l\.|po Kr\.|n\. l\.)/i,
      wide: /^(pred Kristom|pred na[šs][íi]m letopo[čc]tom|po Kristovi|n[áa][šs]ho letopo[čc]tu)/i
    };
    var parseEraPatterns$h = {
      any: [/^pr/i, /^(po|n)/i]
    };
    var matchQuarterPatterns$h = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234]\. [šs]tvr[ťt]rok/i
    };
    var parseQuarterPatterns$h = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$h = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|m[áa]j|j[úu]n|j[úu]l|aug|sep|okt|nov|dec)/i,
      wide: /^(janu[áa]ra?|febru[áa]ra?|(marec|marca)|apr[íi]la?|m[áa]ja?|j[úu]na?|j[úu]la?|augusta?|(september|septembra)|(okt[óo]ber|okt[óo]bra)|(november|novembra)|(december|decembra))/i
    };
    var parseMonthPatterns$h = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^m[áa]j/i, /^j[úu]n/i, /^j[úu]l/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$h = {
      narrow: /^[npusšp]/i,
      short: /^(ne|po|ut|st|št|pi|so)/i,
      abbreviated: /^(ne|po|ut|st|št|pi|so)/i,
      wide: /^(nede[ľl]a|pondelok|utorok|streda|[šs]tvrtok|piatok|sobota])/i
    };
    var parseDayPatterns$h = {
      narrow: [/^n/i, /^p/i, /^u/i, /^s/i, /^š/i, /^p/i, /^s/i],
      any: [/^n/i, /^po/i, /^u/i, /^st/i, /^(št|stv)/i, /^pi/i, /^so/i]
    };
    var matchDayPeriodPatterns$h = {
      narrow: /^(am|pm|(o )?poln\.?|(nap\.?|pol\.?)|r[áa]no|pop\.?|ve[čc]\.?|(v n\.?|noc))/i,
      abbreviated: /^(am|pm|(o )?poln\.?|(napol\.?|pol\.?)|r[áa]no|pop\.?|ve[čc]er|(v )?noci?)/i,
      any: /^(am|pm|(o )?polnoci?|(na)?poludnie|r[áa]no|popoludn(ie|í|i)|ve[čc]er|(v )?noci?)/i
    };
    var parseDayPeriodPatterns$h = {
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /poln/i,
        noon: /^(nap|(na)?pol(\.|u))/i,
        morning: /^r[áa]no/i,
        afternoon: /^pop/i,
        evening: /^ve[čc]/i,
        night: /^(noc|v n\.)/i
      }
    };
    var match$h = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$h,
        parsePattern: parseOrdinalNumberPattern$h,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$h,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$h,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$h,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$h,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$h,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$h,
        defaultParseWidth: 'any'
      })
    };

    var locale$h = {
      code: 'sk',
      formatDistance: formatDistance$h,
      formatLong: formatLong$h,
      formatRelative: formatRelative$h,
      localize: localize$h,
      match: match$h,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    function isPluralType$1(val) {
      return val.one !== undefined;
    }
    var formatDistanceLocale$g = {
      lessThanXSeconds: {
        present: {
          one: 'manj kot {{count}} sekunda',
          two: 'manj kot {{count}} sekundi',
          few: 'manj kot {{count}} sekunde',
          other: 'manj kot {{count}} sekund'
        },
        past: {
          one: 'manj kot {{count}} sekundo',
          two: 'manj kot {{count}} sekundama',
          few: 'manj kot {{count}} sekundami',
          other: 'manj kot {{count}} sekundami'
        },
        future: {
          one: 'manj kot {{count}} sekundo',
          two: 'manj kot {{count}} sekundi',
          few: 'manj kot {{count}} sekunde',
          other: 'manj kot {{count}} sekund'
        }
      },
      xSeconds: {
        present: {
          one: '{{count}} sekunda',
          two: '{{count}} sekundi',
          few: '{{count}} sekunde',
          other: '{{count}} sekund'
        },
        past: {
          one: '{{count}} sekundo',
          two: '{{count}} sekundama',
          few: '{{count}} sekundami',
          other: '{{count}} sekundami'
        },
        future: {
          one: '{{count}} sekundo',
          two: '{{count}} sekundi',
          few: '{{count}} sekunde',
          other: '{{count}} sekund'
        }
      },
      halfAMinute: 'pol minute',
      lessThanXMinutes: {
        present: {
          one: 'manj kot {{count}} minuta',
          two: 'manj kot {{count}} minuti',
          few: 'manj kot {{count}} minute',
          other: 'manj kot {{count}} minut'
        },
        past: {
          one: 'manj kot {{count}} minuto',
          two: 'manj kot {{count}} minutama',
          few: 'manj kot {{count}} minutami',
          other: 'manj kot {{count}} minutami'
        },
        future: {
          one: 'manj kot {{count}} minuto',
          two: 'manj kot {{count}} minuti',
          few: 'manj kot {{count}} minute',
          other: 'manj kot {{count}} minut'
        }
      },
      xMinutes: {
        present: {
          one: '{{count}} minuta',
          two: '{{count}} minuti',
          few: '{{count}} minute',
          other: '{{count}} minut'
        },
        past: {
          one: '{{count}} minuto',
          two: '{{count}} minutama',
          few: '{{count}} minutami',
          other: '{{count}} minutami'
        },
        future: {
          one: '{{count}} minuto',
          two: '{{count}} minuti',
          few: '{{count}} minute',
          other: '{{count}} minut'
        }
      },
      aboutXHours: {
        present: {
          one: 'približno {{count}} ura',
          two: 'približno {{count}} uri',
          few: 'približno {{count}} ure',
          other: 'približno {{count}} ur'
        },
        past: {
          one: 'približno {{count}} uro',
          two: 'približno {{count}} urama',
          few: 'približno {{count}} urami',
          other: 'približno {{count}} urami'
        },
        future: {
          one: 'približno {{count}} uro',
          two: 'približno {{count}} uri',
          few: 'približno {{count}} ure',
          other: 'približno {{count}} ur'
        }
      },
      xHours: {
        present: {
          one: '{{count}} ura',
          two: '{{count}} uri',
          few: '{{count}} ure',
          other: '{{count}} ur'
        },
        past: {
          one: '{{count}} uro',
          two: '{{count}} urama',
          few: '{{count}} urami',
          other: '{{count}} urami'
        },
        future: {
          one: '{{count}} uro',
          two: '{{count}} uri',
          few: '{{count}} ure',
          other: '{{count}} ur'
        }
      },
      xDays: {
        present: {
          one: '{{count}} dan',
          two: '{{count}} dni',
          few: '{{count}} dni',
          other: '{{count}} dni'
        },
        past: {
          one: '{{count}} dnem',
          two: '{{count}} dnevoma',
          few: '{{count}} dnevi',
          other: '{{count}} dnevi'
        },
        future: {
          one: '{{count}} dan',
          two: '{{count}} dni',
          few: '{{count}} dni',
          other: '{{count}} dni'
        }
      },
      aboutXWeeks: {
        one: 'približno {{count}} teden',
        two: 'približno {{count}} tedna',
        few: 'približno {{count}} tedne',
        other: 'približno {{count}} tednov'
      },
      xWeeks: {
        one: '{{count}} teden',
        two: '{{count}} tedna',
        few: '{{count}} tedne',
        other: '{{count}} tednov'
      },
      aboutXMonths: {
        present: {
          one: 'približno {{count}} mesec',
          two: 'približno {{count}} meseca',
          few: 'približno {{count}} mesece',
          other: 'približno {{count}} mesecev'
        },
        past: {
          one: 'približno {{count}} mesecem',
          two: 'približno {{count}} mesecema',
          few: 'približno {{count}} meseci',
          other: 'približno {{count}} meseci'
        },
        future: {
          one: 'približno {{count}} mesec',
          two: 'približno {{count}} meseca',
          few: 'približno {{count}} mesece',
          other: 'približno {{count}} mesecev'
        }
      },
      xMonths: {
        present: {
          one: '{{count}} mesec',
          two: '{{count}} meseca',
          few: '{{count}} meseci',
          other: '{{count}} mesecev'
        },
        past: {
          one: '{{count}} mesecem',
          two: '{{count}} mesecema',
          few: '{{count}} meseci',
          other: '{{count}} meseci'
        },
        future: {
          one: '{{count}} mesec',
          two: '{{count}} meseca',
          few: '{{count}} mesece',
          other: '{{count}} mesecev'
        }
      },
      aboutXYears: {
        present: {
          one: 'približno {{count}} leto',
          two: 'približno {{count}} leti',
          few: 'približno {{count}} leta',
          other: 'približno {{count}} let'
        },
        past: {
          one: 'približno {{count}} letom',
          two: 'približno {{count}} letoma',
          few: 'približno {{count}} leti',
          other: 'približno {{count}} leti'
        },
        future: {
          one: 'približno {{count}} leto',
          two: 'približno {{count}} leti',
          few: 'približno {{count}} leta',
          other: 'približno {{count}} let'
        }
      },
      xYears: {
        present: {
          one: '{{count}} leto',
          two: '{{count}} leti',
          few: '{{count}} leta',
          other: '{{count}} let'
        },
        past: {
          one: '{{count}} letom',
          two: '{{count}} letoma',
          few: '{{count}} leti',
          other: '{{count}} leti'
        },
        future: {
          one: '{{count}} leto',
          two: '{{count}} leti',
          few: '{{count}} leta',
          other: '{{count}} let'
        }
      },
      overXYears: {
        present: {
          one: 'več kot {{count}} leto',
          two: 'več kot {{count}} leti',
          few: 'več kot {{count}} leta',
          other: 'več kot {{count}} let'
        },
        past: {
          one: 'več kot {{count}} letom',
          two: 'več kot {{count}} letoma',
          few: 'več kot {{count}} leti',
          other: 'več kot {{count}} leti'
        },
        future: {
          one: 'več kot {{count}} leto',
          two: 'več kot {{count}} leti',
          few: 'več kot {{count}} leta',
          other: 'več kot {{count}} let'
        }
      },
      almostXYears: {
        present: {
          one: 'skoraj {{count}} leto',
          two: 'skoraj {{count}} leti',
          few: 'skoraj {{count}} leta',
          other: 'skoraj {{count}} let'
        },
        past: {
          one: 'skoraj {{count}} letom',
          two: 'skoraj {{count}} letoma',
          few: 'skoraj {{count}} leti',
          other: 'skoraj {{count}} leti'
        },
        future: {
          one: 'skoraj {{count}} leto',
          two: 'skoraj {{count}} leti',
          few: 'skoraj {{count}} leta',
          other: 'skoraj {{count}} let'
        }
      }
    };
    function getFormFromCount(count) {
      switch (count % 100) {
        case 1:
          return 'one';
        case 2:
          return 'two';
        case 3:
        case 4:
          return 'few';
        default:
          return 'other';
      }
    }
    var formatDistance$g = function (token, count, options) {
      var result = '';
      var tense = 'present';
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          tense = 'future';
          result = 'čez ';
        } else {
          tense = 'past';
          result = 'pred ';
        }
      }
      var tokenValue = formatDistanceLocale$g[token];
      if (typeof tokenValue === 'string') {
        result += tokenValue;
      } else {
        var form = getFormFromCount(count);
        if (isPluralType$1(tokenValue)) {
          result += tokenValue[form].replace('{{count}}', String(count));
        } else {
          result += tokenValue[tense][form].replace('{{count}}', String(count));
        }
      }
      return result;
    };

    var dateFormats$g = {
      full: 'EEEE, dd. MMMM y',
      long: 'dd. MMMM y',
      medium: 'd. MMM y',
      short: 'd. MM. yy'
    };
    var timeFormats$g = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$g = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$g = {
      date: buildFormatLongFn({
        formats: dateFormats$g,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$g,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$g,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$g = {
      lastWeek: function (date) {
        var day = date.getUTCDay();
        switch (day) {
          case 0:
            return "'prejšnjo nedeljo ob' p";
          case 3:
            return "'prejšnjo sredo ob' p";
          case 6:
            return "'prejšnjo soboto ob' p";
          default:
            return "'prejšnji' EEEE 'ob' p";
        }
      },
      yesterday: "'včeraj ob' p",
      today: "'danes ob' p",
      tomorrow: "'jutri ob' p",
      nextWeek: function (date) {
        var day = date.getUTCDay();
        switch (day) {
          case 0:
            return "'naslednjo nedeljo ob' p";
          case 3:
            return "'naslednjo sredo ob' p";
          case 6:
            return "'naslednjo soboto ob' p";
          default:
            return "'naslednji' EEEE 'ob' p";
        }
      },
      other: 'P'
    };
    var formatRelative$g = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$g[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$g = {
      narrow: ['pr. n. št.', 'po n. št.'],
      abbreviated: ['pr. n. št.', 'po n. št.'],
      wide: ['pred našim štetjem', 'po našem štetju']
    };
    var quarterValues$g = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1. čet.', '2. čet.', '3. čet.', '4. čet.'],
      wide: ['1. četrtletje', '2. četrtletje', '3. četrtletje', '4. četrtletje']
    };
    var monthValues$g = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan.', 'feb.', 'mar.', 'apr.', 'maj', 'jun.', 'jul.', 'avg.', 'sep.', 'okt.', 'nov.', 'dec.'],
      wide: ['januar', 'februar', 'marec', 'april', 'maj', 'junij', 'julij', 'avgust', 'september', 'oktober', 'november', 'december']
    };
    var dayValues$g = {
      narrow: ['n', 'p', 't', 's', 'č', 'p', 's'],
      short: ['ned.', 'pon.', 'tor.', 'sre.', 'čet.', 'pet.', 'sob.'],
      abbreviated: ['ned.', 'pon.', 'tor.', 'sre.', 'čet.', 'pet.', 'sob.'],
      wide: ['nedelja', 'ponedeljek', 'torek', 'sreda', 'četrtek', 'petek', 'sobota']
    };
    var dayPeriodValues$g = {
      narrow: {
        am: 'd',
        pm: 'p',
        midnight: '24.00',
        noon: '12.00',
        morning: 'j',
        afternoon: 'p',
        evening: 'v',
        night: 'n'
      },
      abbreviated: {
        am: 'dop.',
        pm: 'pop.',
        midnight: 'poln.',
        noon: 'pold.',
        morning: 'jut.',
        afternoon: 'pop.',
        evening: 'več.',
        night: 'noč'
      },
      wide: {
        am: 'dop.',
        pm: 'pop.',
        midnight: 'polnoč',
        noon: 'poldne',
        morning: 'jutro',
        afternoon: 'popoldne',
        evening: 'večer',
        night: 'noč'
      }
    };
    var formattingDayPeriodValues$g = {
      narrow: {
        am: 'd',
        pm: 'p',
        midnight: '24.00',
        noon: '12.00',
        morning: 'zj',
        afternoon: 'p',
        evening: 'zv',
        night: 'po'
      },
      abbreviated: {
        am: 'dop.',
        pm: 'pop.',
        midnight: 'opoln.',
        noon: 'opold.',
        morning: 'zjut.',
        afternoon: 'pop.',
        evening: 'zveč.',
        night: 'ponoči'
      },
      wide: {
        am: 'dop.',
        pm: 'pop.',
        midnight: 'opolnoči',
        noon: 'opoldne',
        morning: 'zjutraj',
        afternoon: 'popoldan',
        evening: 'zvečer',
        night: 'ponoči'
      }
    };
    var ordinalNumber$g = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$g = {
      ordinalNumber: ordinalNumber$g,
      era: buildLocalizeFn({
        values: eraValues$g,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$g,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$g,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$g,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$g,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$g,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$g = /^(\d+)\./i;
    var parseOrdinalNumberPattern$g = /\d+/i;
    var matchEraPatterns$g = {
      abbreviated: /^(pr\. n\. št\.|po n\. št\.)/i,
      wide: /^(pred Kristusom|pred na[sš]im [sš]tetjem|po Kristusu|po na[sš]em [sš]tetju|na[sš]ega [sš]tetja)/i
    };
    var parseEraPatterns$g = {
      any: [/^pr/i, /^(po|na[sš]em)/i]
    };
    var matchQuarterPatterns$g = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]\.\s?[čc]et\.?/i,
      wide: /^[1234]\. [čc]etrtletje/i
    };
    var parseQuarterPatterns$g = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$g = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan\.|feb\.|mar\.|apr\.|maj|jun\.|jul\.|avg\.|sep\.|okt\.|nov\.|dec\.)/i,
      wide: /^(januar|februar|marec|april|maj|junij|julij|avgust|september|oktober|november|december)/i
    };
    var parseMonthPatterns$g = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      abbreviated: [/^ja/i, /^fe/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^av/i, /^s/i, /^o/i, /^n/i, /^d/i],
      wide: [/^ja/i, /^fe/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^av/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$g = {
      narrow: /^[nptsčc]/i,
      short: /^(ned\.|pon\.|tor\.|sre\.|[cč]et\.|pet\.|sob\.)/i,
      abbreviated: /^(ned\.|pon\.|tor\.|sre\.|[cč]et\.|pet\.|sob\.)/i,
      wide: /^(nedelja|ponedeljek|torek|sreda|[cč]etrtek|petek|sobota)/i
    };
    var parseDayPatterns$g = {
      narrow: [/^n/i, /^p/i, /^t/i, /^s/i, /^[cč]/i, /^p/i, /^s/i],
      any: [/^n/i, /^po/i, /^t/i, /^sr/i, /^[cč]/i, /^pe/i, /^so/i]
    };
    var matchDayPeriodPatterns$g = {
      narrow: /^(d|po?|z?v|n|z?j|24\.00|12\.00)/i,
      any: /^(dop\.|pop\.|o?poln(\.|o[cč]i?)|o?pold(\.|ne)|z?ve[cč](\.|er)|(po)?no[cč]i?|popold(ne|an)|jut(\.|ro)|zjut(\.|raj))/i
    };
    var parseDayPeriodPatterns$g = {
      narrow: {
        am: /^d/i,
        pm: /^p/i,
        midnight: /^24/i,
        noon: /^12/i,
        morning: /^(z?j)/i,
        afternoon: /^p/i,
        evening: /^(z?v)/i,
        night: /^(n|po)/i
      },
      any: {
        am: /^dop\./i,
        pm: /^pop\./i,
        midnight: /^o?poln/i,
        noon: /^o?pold/i,
        morning: /j/i,
        afternoon: /^pop\./i,
        evening: /^z?ve/i,
        night: /(po)?no/i
      }
    };
    var match$g = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$g,
        parsePattern: parseOrdinalNumberPattern$g,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$g,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$g,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$g,
        defaultParseWidth: 'wide'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$g,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$g,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$g,
        defaultParseWidth: 'any'
      })
    };

    var locale$g = {
      code: 'sl',
      formatDistance: formatDistance$g,
      formatLong: formatLong$g,
      formatRelative: formatRelative$g,
      localize: localize$g,
      match: match$g,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$f = {
      lessThanXSeconds: {
        one: 'më pak se një sekondë',
        other: 'më pak se {{count}} sekonda'
      },
      xSeconds: {
        one: '1 sekondë',
        other: '{{count}} sekonda'
      },
      halfAMinute: 'gjysëm minuti',
      lessThanXMinutes: {
        one: 'më pak se një minute',
        other: 'më pak se {{count}} minuta'
      },
      xMinutes: {
        one: '1 minutë',
        other: '{{count}} minuta'
      },
      aboutXHours: {
        one: 'rreth 1 orë',
        other: 'rreth {{count}} orë'
      },
      xHours: {
        one: '1 orë',
        other: '{{count}} orë'
      },
      xDays: {
        one: '1 ditë',
        other: '{{count}} ditë'
      },
      aboutXWeeks: {
        one: 'rreth 1 javë',
        other: 'rreth {{count}} javë'
      },
      xWeeks: {
        one: '1 javë',
        other: '{{count}} javë'
      },
      aboutXMonths: {
        one: 'rreth 1 muaj',
        other: 'rreth {{count}} muaj'
      },
      xMonths: {
        one: '1 muaj',
        other: '{{count}} muaj'
      },
      aboutXYears: {
        one: 'rreth 1 vit',
        other: 'rreth {{count}} vite'
      },
      xYears: {
        one: '1 vit',
        other: '{{count}} vite'
      },
      overXYears: {
        one: 'mbi 1 vit',
        other: 'mbi {{count}} vite'
      },
      almostXYears: {
        one: 'pothuajse 1 vit',
        other: 'pothuajse {{count}} vite'
      }
    };
    var formatDistance$f = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$f[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'në ' + result;
        } else {
          return result + ' më parë';
        }
      }
      return result;
    };

    var dateFormats$f = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$f = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$f = {
      full: "{{date}} 'në' {{time}}",
      long: "{{date}} 'në' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$f = {
      date: buildFormatLongFn({
        formats: dateFormats$f,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$f,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$f,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$f = {
      lastWeek: "'të' eeee 'e shkuar në' p",
      yesterday: "'dje në' p",
      today: "'sot në' p",
      tomorrow: "'nesër në' p",
      nextWeek: "eeee 'at' p",
      other: 'P'
    };
    var formatRelative$f = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$f[token];
    };

    var eraValues$f = {
      narrow: ['P', 'M'],
      abbreviated: ['PK', 'MK'],
      wide: ['Para Krishtit', 'Mbas Krishtit']
    };
    var quarterValues$f = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['4-mujori I', '4-mujori II', '4-mujori III', '4-mujori IV']
    };
    var monthValues$f = {
      narrow: ['J', 'S', 'M', 'P', 'M', 'Q', 'K', 'G', 'S', 'T', 'N', 'D'],
      abbreviated: ['Jan', 'Shk', 'Mar', 'Pri', 'Maj', 'Qer', 'Kor', 'Gus', 'Sht', 'Tet', 'Nën', 'Dhj'],
      wide: ['Janar', 'Shkurt', 'Mars', 'Prill', 'Maj', 'Qershor', 'Korrik', 'Gusht', 'Shtator', 'Tetor', 'Nëntor', 'Dhjetor']
    };
    var dayValues$f = {
      narrow: ['D', 'H', 'M', 'M', 'E', 'P', 'S'],
      short: ['Di', 'Hë', 'Ma', 'Më', 'En', 'Pr', 'Sh'],
      abbreviated: ['Die', 'Hën', 'Mar', 'Mër', 'Enj', 'Pre', 'Sht'],
      wide: ['Dielë', 'Hënë', 'Martë', 'Mërkurë', 'Enjte', 'Premte', 'Shtunë']
    };
    var dayPeriodValues$f = {
      narrow: {
        am: 'p',
        pm: 'm',
        midnight: 'm',
        noon: 'd',
        morning: 'mëngjes',
        afternoon: 'dite',
        evening: 'mbrëmje',
        night: 'natë'
      },
      abbreviated: {
        am: 'PD',
        pm: 'MD',
        midnight: 'mesnëtë',
        noon: 'drek',
        morning: 'mëngjes',
        afternoon: 'mbasdite',
        evening: 'mbrëmje',
        night: 'natë'
      },
      wide: {
        am: 'p.d.',
        pm: 'm.d.',
        midnight: 'mesnëtë',
        noon: 'drek',
        morning: 'mëngjes',
        afternoon: 'mbasdite',
        evening: 'mbrëmje',
        night: 'natë'
      }
    };
    var formattingDayPeriodValues$f = {
      narrow: {
        am: 'p',
        pm: 'm',
        midnight: 'm',
        noon: 'd',
        morning: 'në mëngjes',
        afternoon: 'në mbasdite',
        evening: 'në mbrëmje',
        night: 'në mesnatë'
      },
      abbreviated: {
        am: 'PD',
        pm: 'MD',
        midnight: 'mesnatë',
        noon: 'drek',
        morning: 'në mëngjes',
        afternoon: 'në mbasdite',
        evening: 'në mbrëmje',
        night: 'në mesnatë'
      },
      wide: {
        am: 'p.d.',
        pm: 'm.d.',
        midnight: 'mesnatë',
        noon: 'drek',
        morning: 'në mëngjes',
        afternoon: 'në mbasdite',
        evening: 'në mbrëmje',
        night: 'në mesnatë'
      }
    };
    var ordinalNumber$f = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      if ((options === null || options === void 0 ? void 0 : options.unit) === 'hour') return String(number);
      if (number === 1) return number + '-rë';
      if (number === 4) return number + 't';
      return number + '-të';
    };
    var localize$f = {
      ordinalNumber: ordinalNumber$f,
      era: buildLocalizeFn({
        values: eraValues$f,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$f,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$f,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$f,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$f,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$f,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$f = /^(\d+)(-rë|-të|t|)?/i;
    var parseOrdinalNumberPattern$f = /\d+/i;
    var matchEraPatterns$f = {
      narrow: /^(p|m)/i,
      abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
      wide: /^(para krishtit|mbas krishtit)/i
    };
    var parseEraPatterns$f = {
      any: [/^b/i, /^(p|m)/i]
    };
    var matchQuarterPatterns$f = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234]-mujori (i{1,3}|iv)/i
    };
    var parseQuarterPatterns$f = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$f = {
      narrow: /^[jsmpqkftnd]/i,
      abbreviated: /^(jan|shk|mar|pri|maj|qer|kor|gus|sht|tet|nën|dhj)/i,
      wide: /^(janar|shkurt|mars|prill|maj|qershor|korrik|gusht|shtator|tetor|nëntor|dhjetor)/i
    };
    var parseMonthPatterns$f = {
      narrow: [/^j/i, /^s/i, /^m/i, /^p/i, /^m/i, /^q/i, /^k/i, /^g/i, /^s/i, /^t/i, /^n/i, /^d/i],
      any: [/^ja/i, /^shk/i, /^mar/i, /^pri/i, /^maj/i, /^qer/i, /^kor/i, /^gu/i, /^sht/i, /^tet/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$f = {
      narrow: /^[dhmeps]/i,
      short: /^(di|hë|ma|më|en|pr|sh)/i,
      abbreviated: /^(die|hën|mar|mër|enj|pre|sht)/i,
      wide: /^(dielë|hënë|martë|mërkurë|enjte|premte|shtunë)/i
    };
    var parseDayPatterns$f = {
      narrow: [/^d/i, /^h/i, /^m/i, /^m/i, /^e/i, /^p/i, /^s/i],
      any: [/^d/i, /^h/i, /^ma/i, /^më/i, /^e/i, /^p/i, /^s/i]
    };
    var matchDayPeriodPatterns$f = {
      narrow: /^(p|m|me|në (mëngjes|mbasdite|mbrëmje|mesnatë))/i,
      any: /^([pm]\.?\s?d\.?|drek|në (mëngjes|mbasdite|mbrëmje|mesnatë))/i
    };
    var parseDayPeriodPatterns$f = {
      any: {
        am: /^p/i,
        pm: /^m/i,
        midnight: /^me/i,
        noon: /^dr/i,
        morning: /mëngjes/i,
        afternoon: /mbasdite/i,
        evening: /mbrëmje/i,
        night: /natë/i
      }
    };
    var match$f = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$f,
        parsePattern: parseOrdinalNumberPattern$f,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$f,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$f,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$f,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$f,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$f,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$f,
        defaultParseWidth: 'any'
      })
    };

    var locale$f = {
      code: 'sq',
      formatDistance: formatDistance$f,
      formatLong: formatLong$f,
      formatRelative: formatRelative$f,
      localize: localize$f,
      match: match$f,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$e = {
      lessThanXSeconds: {
        one: {
          standalone: 'мање од 1 секунде',
          withPrepositionAgo: 'мање од 1 секунде',
          withPrepositionIn: 'мање од 1 секунду'
        },
        dual: 'мање од {{count}} секунде',
        other: 'мање од {{count}} секунди'
      },
      xSeconds: {
        one: {
          standalone: '1 секунда',
          withPrepositionAgo: '1 секунде',
          withPrepositionIn: '1 секунду'
        },
        dual: '{{count}} секунде',
        other: '{{count}} секунди'
      },
      halfAMinute: 'пола минуте',
      lessThanXMinutes: {
        one: {
          standalone: 'мање од 1 минуте',
          withPrepositionAgo: 'мање од 1 минуте',
          withPrepositionIn: 'мање од 1 минуту'
        },
        dual: 'мање од {{count}} минуте',
        other: 'мање од {{count}} минута'
      },
      xMinutes: {
        one: {
          standalone: '1 минута',
          withPrepositionAgo: '1 минуте',
          withPrepositionIn: '1 минуту'
        },
        dual: '{{count}} минуте',
        other: '{{count}} минута'
      },
      aboutXHours: {
        one: {
          standalone: 'око 1 сат',
          withPrepositionAgo: 'око 1 сат',
          withPrepositionIn: 'око 1 сат'
        },
        dual: 'око {{count}} сата',
        other: 'око {{count}} сати'
      },
      xHours: {
        one: {
          standalone: '1 сат',
          withPrepositionAgo: '1 сат',
          withPrepositionIn: '1 сат'
        },
        dual: '{{count}} сата',
        other: '{{count}} сати'
      },
      xDays: {
        one: {
          standalone: '1 дан',
          withPrepositionAgo: '1 дан',
          withPrepositionIn: '1 дан'
        },
        dual: '{{count}} дана',
        other: '{{count}} дана'
      },
      aboutXWeeks: {
        one: {
          standalone: 'око 1 недељу',
          withPrepositionAgo: 'око 1 недељу',
          withPrepositionIn: 'око 1 недељу'
        },
        dual: 'око {{count}} недеље',
        other: 'око {{count}} недеље'
      },
      xWeeks: {
        one: {
          standalone: '1 недељу',
          withPrepositionAgo: '1 недељу',
          withPrepositionIn: '1 недељу'
        },
        dual: '{{count}} недеље',
        other: '{{count}} недеље'
      },
      aboutXMonths: {
        one: {
          standalone: 'око 1 месец',
          withPrepositionAgo: 'око 1 месец',
          withPrepositionIn: 'око 1 месец'
        },
        dual: 'око {{count}} месеца',
        other: 'око {{count}} месеци'
      },
      xMonths: {
        one: {
          standalone: '1 месец',
          withPrepositionAgo: '1 месец',
          withPrepositionIn: '1 месец'
        },
        dual: '{{count}} месеца',
        other: '{{count}} месеци'
      },
      aboutXYears: {
        one: {
          standalone: 'око 1 годину',
          withPrepositionAgo: 'око 1 годину',
          withPrepositionIn: 'око 1 годину'
        },
        dual: 'око {{count}} године',
        other: 'око {{count}} година'
      },
      xYears: {
        one: {
          standalone: '1 година',
          withPrepositionAgo: '1 године',
          withPrepositionIn: '1 годину'
        },
        dual: '{{count}} године',
        other: '{{count}} година'
      },
      overXYears: {
        one: {
          standalone: 'преко 1 годину',
          withPrepositionAgo: 'преко 1 годину',
          withPrepositionIn: 'преко 1 годину'
        },
        dual: 'преко {{count}} године',
        other: 'преко {{count}} година'
      },
      almostXYears: {
        one: {
          standalone: 'готово 1 годину',
          withPrepositionAgo: 'готово 1 годину',
          withPrepositionIn: 'готово 1 годину'
        },
        dual: 'готово {{count}} године',
        other: 'готово {{count}} година'
      }
    };
    var formatDistance$e = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$e[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            result = tokenValue.one.withPrepositionIn;
          } else {
            result = tokenValue.one.withPrepositionAgo;
          }
        } else {
          result = tokenValue.one.standalone;
        }
      } else if (count % 10 > 1 && count % 10 < 5 &&
      String(count).substr(-2, 1) !== '1'
      ) {
          result = tokenValue.dual.replace('{{count}}', String(count));
        } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'за ' + result;
        } else {
          return 'пре ' + result;
        }
      }
      return result;
    };

    var dateFormats$e = {
      full: 'EEEE, d. MMMM yyyy.',
      long: 'd. MMMM yyyy.',
      medium: 'd. MMM yy.',
      short: 'dd. MM. yy.'
    };
    var timeFormats$e = {
      full: 'HH:mm:ss (zzzz)',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$e = {
      full: "{{date}} 'у' {{time}}",
      long: "{{date}} 'у' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$e = {
      date: buildFormatLongFn({
        formats: dateFormats$e,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$e,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$e,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$e = {
      lastWeek: function (date) {
        var day = date.getUTCDay();
        switch (day) {
          case 0:
            return "'прошле недеље у' p";
          case 3:
            return "'прошле среде у' p";
          case 6:
            return "'прошле суботе у' p";
          default:
            return "'прошли' EEEE 'у' p";
        }
      },
      yesterday: "'јуче у' p",
      today: "'данас у' p",
      tomorrow: "'сутра у' p",
      nextWeek: function (date) {
        var day = date.getUTCDay();
        switch (day) {
          case 0:
            return "'следеће недеље у' p";
          case 3:
            return "'следећу среду у' p";
          case 6:
            return "'следећу суботу у' p";
          default:
            return "'следећи' EEEE 'у' p";
        }
      },
      other: 'P'
    };
    var formatRelative$e = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$e[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$e = {
      narrow: ['пр.н.е.', 'АД'],
      abbreviated: ['пр. Хр.', 'по. Хр.'],
      wide: ['Пре Христа', 'После Христа']
    };
    var quarterValues$e = {
      narrow: ['1.', '2.', '3.', '4.'],
      abbreviated: ['1. кв.', '2. кв.', '3. кв.', '4. кв.'],
      wide: ['1. квартал', '2. квартал', '3. квартал', '4. квартал']
    };
    var monthValues$e = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['јан', 'феб', 'мар', 'апр', 'мај', 'јун', 'јул', 'авг', 'сеп', 'окт', 'нов', 'дец'],
      wide: ['јануар', 'фебруар', 'март', 'април', 'мај', 'јун', 'јул', 'август', 'септембар', 'октобар', 'новембар', 'децембар']
    };
    var formattingMonthValues$3 = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['јан', 'феб', 'мар', 'апр', 'мај', 'јун', 'јул', 'авг', 'сеп', 'окт', 'нов', 'дец'],
      wide: ['јануар', 'фебруар', 'март', 'април', 'мај', 'јун', 'јул', 'август', 'септембар', 'октобар', 'новембар', 'децембар']
    };
    var dayValues$e = {
      narrow: ['Н', 'П', 'У', 'С', 'Ч', 'П', 'С'],
      short: ['нед', 'пон', 'уто', 'сре', 'чет', 'пет', 'суб'],
      abbreviated: ['нед', 'пон', 'уто', 'сре', 'чет', 'пет', 'суб'],
      wide: ['недеља', 'понедељак', 'уторак', 'среда', 'четвртак', 'петак', 'субота']
    };
    var formattingDayPeriodValues$e = {
      narrow: {
        am: 'АМ',
        pm: 'ПМ',
        midnight: 'поноћ',
        noon: 'подне',
        morning: 'ујутру',
        afternoon: 'поподне',
        evening: 'увече',
        night: 'ноћу'
      },
      abbreviated: {
        am: 'АМ',
        pm: 'ПМ',
        midnight: 'поноћ',
        noon: 'подне',
        morning: 'ујутру',
        afternoon: 'поподне',
        evening: 'увече',
        night: 'ноћу'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'поноћ',
        noon: 'подне',
        morning: 'ујутру',
        afternoon: 'после подне',
        evening: 'увече',
        night: 'ноћу'
      }
    };
    var dayPeriodValues$e = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'поноћ',
        noon: 'подне',
        morning: 'ујутру',
        afternoon: 'поподне',
        evening: 'увече',
        night: 'ноћу'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'поноћ',
        noon: 'подне',
        morning: 'ујутру',
        afternoon: 'поподне',
        evening: 'увече',
        night: 'ноћу'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'поноћ',
        noon: 'подне',
        morning: 'ујутру',
        afternoon: 'после подне',
        evening: 'увече',
        night: 'ноћу'
      }
    };
    var ordinalNumber$e = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$e = {
      ordinalNumber: ordinalNumber$e,
      era: buildLocalizeFn({
        values: eraValues$e,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$e,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$e,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$3,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$e,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$e,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$e,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$e = /^(\d+)\./i;
    var parseOrdinalNumberPattern$e = /\d+/i;
    var matchEraPatterns$e = {
      narrow: /^(пр\.н\.е\.|АД)/i,
      abbreviated: /^(пр\.\s?Хр\.|по\.\s?Хр\.)/i,
      wide: /^(Пре Христа|пре нове ере|После Христа|нова ера)/i
    };
    var parseEraPatterns$e = {
      any: [/^пр/i, /^(по|нова)/i]
    };
    var matchQuarterPatterns$e = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]\.\s?кв\.?/i,
      wide: /^[1234]\. квартал/i
    };
    var parseQuarterPatterns$e = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$e = {
      narrow: /^(10|11|12|[123456789])\./i,
      abbreviated: /^(јан|феб|мар|апр|мај|јун|јул|авг|сеп|окт|нов|дец)/i,
      wide: /^((јануар|јануара)|(фебруар|фебруара)|(март|марта)|(април|априла)|(мја|маја)|(јун|јуна)|(јул|јула)|(август|августа)|(септембар|септембра)|(октобар|октобра)|(новембар|новембра)|(децембар|децембра))/i
    };
    var parseMonthPatterns$e = {
      narrow: [/^1/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^7/i, /^8/i, /^9/i, /^10/i, /^11/i, /^12/i],
      any: [/^ја/i, /^ф/i, /^мар/i, /^ап/i, /^мај/i, /^јун/i, /^јул/i, /^авг/i, /^с/i, /^о/i, /^н/i, /^д/i]
    };
    var matchDayPatterns$e = {
      narrow: /^[пусчн]/i,
      short: /^(нед|пон|уто|сре|чет|пет|суб)/i,
      abbreviated: /^(нед|пон|уто|сре|чет|пет|суб)/i,
      wide: /^(недеља|понедељак|уторак|среда|четвртак|петак|субота)/i
    };
    var parseDayPatterns$e = {
      narrow: [/^п/i, /^у/i, /^с/i, /^ч/i, /^п/i, /^с/i, /^н/i],
      any: [/^нед/i, /^пон/i, /^уто/i, /^сре/i, /^чет/i, /^пет/i, /^суб/i]
    };
    var matchDayPeriodPatterns$e = {
      any: /^(ам|пм|поноћ|(по)?подне|увече|ноћу|после подне|ујутру)/i
    };
    var parseDayPeriodPatterns$e = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^поно/i,
        noon: /^под/i,
        morning: /ујутру/i,
        afternoon: /(после\s|по)+подне/i,
        evening: /(увече)/i,
        night: /(ноћу)/i
      }
    };
    var match$e = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$e,
        parsePattern: parseOrdinalNumberPattern$e,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$e,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$e,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$e,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$e,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$e,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$e,
        defaultParseWidth: 'any'
      })
    };

    var locale$e = {
      code: 'sr',
      formatDistance: formatDistance$e,
      formatLong: formatLong$e,
      formatRelative: formatRelative$e,
      localize: localize$e,
      match: match$e,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$d = {
      lessThanXSeconds: {
        one: {
          standalone: 'manje od 1 sekunde',
          withPrepositionAgo: 'manje od 1 sekunde',
          withPrepositionIn: 'manje od 1 sekundu'
        },
        dual: 'manje od {{count}} sekunde',
        other: 'manje od {{count}} sekundi'
      },
      xSeconds: {
        one: {
          standalone: '1 sekunda',
          withPrepositionAgo: '1 sekunde',
          withPrepositionIn: '1 sekundu'
        },
        dual: '{{count}} sekunde',
        other: '{{count}} sekundi'
      },
      halfAMinute: 'pola minute',
      lessThanXMinutes: {
        one: {
          standalone: 'manje od 1 minute',
          withPrepositionAgo: 'manje od 1 minute',
          withPrepositionIn: 'manje od 1 minutu'
        },
        dual: 'manje od {{count}} minute',
        other: 'manje od {{count}} minuta'
      },
      xMinutes: {
        one: {
          standalone: '1 minuta',
          withPrepositionAgo: '1 minute',
          withPrepositionIn: '1 minutu'
        },
        dual: '{{count}} minute',
        other: '{{count}} minuta'
      },
      aboutXHours: {
        one: {
          standalone: 'oko 1 sat',
          withPrepositionAgo: 'oko 1 sat',
          withPrepositionIn: 'oko 1 sat'
        },
        dual: 'oko {{count}} sata',
        other: 'oko {{count}} sati'
      },
      xHours: {
        one: {
          standalone: '1 sat',
          withPrepositionAgo: '1 sat',
          withPrepositionIn: '1 sat'
        },
        dual: '{{count}} sata',
        other: '{{count}} sati'
      },
      xDays: {
        one: {
          standalone: '1 dan',
          withPrepositionAgo: '1 dan',
          withPrepositionIn: '1 dan'
        },
        dual: '{{count}} dana',
        other: '{{count}} dana'
      },
      aboutXWeeks: {
        one: {
          standalone: 'oko 1 nedelju',
          withPrepositionAgo: 'oko 1 nedelju',
          withPrepositionIn: 'oko 1 nedelju'
        },
        dual: 'oko {{count}} nedelje',
        other: 'oko {{count}} nedelje'
      },
      xWeeks: {
        one: {
          standalone: '1 nedelju',
          withPrepositionAgo: '1 nedelju',
          withPrepositionIn: '1 nedelju'
        },
        dual: '{{count}} nedelje',
        other: '{{count}} nedelje'
      },
      aboutXMonths: {
        one: {
          standalone: 'oko 1 mesec',
          withPrepositionAgo: 'oko 1 mesec',
          withPrepositionIn: 'oko 1 mesec'
        },
        dual: 'oko {{count}} meseca',
        other: 'oko {{count}} meseci'
      },
      xMonths: {
        one: {
          standalone: '1 mesec',
          withPrepositionAgo: '1 mesec',
          withPrepositionIn: '1 mesec'
        },
        dual: '{{count}} meseca',
        other: '{{count}} meseci'
      },
      aboutXYears: {
        one: {
          standalone: 'oko 1 godinu',
          withPrepositionAgo: 'oko 1 godinu',
          withPrepositionIn: 'oko 1 godinu'
        },
        dual: 'oko {{count}} godine',
        other: 'oko {{count}} godina'
      },
      xYears: {
        one: {
          standalone: '1 godina',
          withPrepositionAgo: '1 godine',
          withPrepositionIn: '1 godinu'
        },
        dual: '{{count}} godine',
        other: '{{count}} godina'
      },
      overXYears: {
        one: {
          standalone: 'preko 1 godinu',
          withPrepositionAgo: 'preko 1 godinu',
          withPrepositionIn: 'preko 1 godinu'
        },
        dual: 'preko {{count}} godine',
        other: 'preko {{count}} godina'
      },
      almostXYears: {
        one: {
          standalone: 'gotovo 1 godinu',
          withPrepositionAgo: 'gotovo 1 godinu',
          withPrepositionIn: 'gotovo 1 godinu'
        },
        dual: 'gotovo {{count}} godine',
        other: 'gotovo {{count}} godina'
      }
    };
    var formatDistance$d = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$d[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            result = tokenValue.one.withPrepositionIn;
          } else {
            result = tokenValue.one.withPrepositionAgo;
          }
        } else {
          result = tokenValue.one.standalone;
        }
      } else if (count % 10 > 1 && count % 10 < 5 &&
      String(count).substr(-2, 1) !== '1'
      ) {
          result = tokenValue.dual.replace('{{count}}', String(count));
        } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'za ' + result;
        } else {
          return 'pre ' + result;
        }
      }
      return result;
    };

    var dateFormats$d = {
      full: 'EEEE, d. MMMM yyyy.',
      long: 'd. MMMM yyyy.',
      medium: 'd. MMM yy.',
      short: 'dd. MM. yy.'
    };
    var timeFormats$d = {
      full: 'HH:mm:ss (zzzz)',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$d = {
      full: "{{date}} 'u' {{time}}",
      long: "{{date}} 'u' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$d = {
      date: buildFormatLongFn({
        formats: dateFormats$d,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$d,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$d,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$d = {
      lastWeek: function (date) {
        switch (date.getUTCDay()) {
          case 0:
            return "'prošle nedelje u' p";
          case 3:
            return "'prošle srede u' p";
          case 6:
            return "'prošle subote u' p";
          default:
            return "'prošli' EEEE 'u' p";
        }
      },
      yesterday: "'juče u' p",
      today: "'danas u' p",
      tomorrow: "'sutra u' p",
      nextWeek: function (date) {
        switch (date.getUTCDay()) {
          case 0:
            return "'sledeće nedelje u' p";
          case 3:
            return "'sledeću sredu u' p";
          case 6:
            return "'sledeću subotu u' p";
          default:
            return "'sledeći' EEEE 'u' p";
        }
      },
      other: 'P'
    };
    var formatRelative$d = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$d[token];
      if (typeof format === 'function') {
        return format(date);
      }
      return format;
    };

    var eraValues$d = {
      narrow: ['pr.n.e.', 'AD'],
      abbreviated: ['pr. Hr.', 'po. Hr.'],
      wide: ['Pre Hrista', 'Posle Hrista']
    };
    var quarterValues$d = {
      narrow: ['1.', '2.', '3.', '4.'],
      abbreviated: ['1. kv.', '2. kv.', '3. kv.', '4. kv.'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$d = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'avg', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januar', 'februar', 'mart', 'april', 'maj', 'jun', 'jul', 'avgust', 'septembar', 'oktobar', 'novembar', 'decembar']
    };
    var formattingMonthValues$2 = {
      narrow: ['1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.', '9.', '10.', '11.', '12.'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'avg', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januar', 'februar', 'mart', 'april', 'maj', 'jun', 'jul', 'avgust', 'septembar', 'oktobar', 'novembar', 'decembar']
    };
    var dayValues$d = {
      narrow: ['N', 'P', 'U', 'S', 'Č', 'P', 'S'],
      short: ['ned', 'pon', 'uto', 'sre', 'čet', 'pet', 'sub'],
      abbreviated: ['ned', 'pon', 'uto', 'sre', 'čet', 'pet', 'sub'],
      wide: ['nedelja', 'ponedeljak', 'utorak', 'sreda', 'četvrtak', 'petak', 'subota']
    };
    var formattingDayPeriodValues$d = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'posle podne',
        evening: 'uveče',
        night: 'noću'
      }
    };
    var dayPeriodValues$d = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'popodne',
        evening: 'uveče',
        night: 'noću'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'ponoć',
        noon: 'podne',
        morning: 'ujutru',
        afternoon: 'posle podne',
        evening: 'uveče',
        night: 'noću'
      }
    };
    var ordinalNumber$d = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$d = {
      ordinalNumber: ordinalNumber$d,
      era: buildLocalizeFn({
        values: eraValues$d,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$d,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$d,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$2,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$d,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$d,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$d,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$d = /^(\d+)\./i;
    var parseOrdinalNumberPattern$d = /\d+/i;
    var matchEraPatterns$d = {
      narrow: /^(pr\.n\.e\.|AD)/i,
      abbreviated: /^(pr\.\s?Hr\.|po\.\s?Hr\.)/i,
      wide: /^(Pre Hrista|pre nove ere|Posle Hrista|nova era)/i
    };
    var parseEraPatterns$d = {
      any: [/^pr/i, /^(po|nova)/i]
    };
    var matchQuarterPatterns$d = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]\.\s?kv\.?/i,
      wide: /^[1234]\. kvartal/i
    };
    var parseQuarterPatterns$d = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$d = {
      narrow: /^(10|11|12|[123456789])\./i,
      abbreviated: /^(jan|feb|mar|apr|maj|jun|jul|avg|sep|okt|nov|dec)/i,
      wide: /^((januar|januara)|(februar|februara)|(mart|marta)|(april|aprila)|(maj|maja)|(jun|juna)|(jul|jula)|(avgust|avgusta)|(septembar|septembra)|(oktobar|oktobra)|(novembar|novembra)|(decembar|decembra))/i
    };
    var parseMonthPatterns$d = {
      narrow: [/^1/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^7/i, /^8/i, /^9/i, /^10/i, /^11/i, /^12/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^avg/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$d = {
      narrow: /^[npusčc]/i,
      short: /^(ned|pon|uto|sre|(čet|cet)|pet|sub)/i,
      abbreviated: /^(ned|pon|uto|sre|(čet|cet)|pet|sub)/i,
      wide: /^(nedelja|ponedeljak|utorak|sreda|(četvrtak|cetvrtak)|petak|subota)/i
    };
    var parseDayPatterns$d = {
      narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
      any: [/^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$d = {
      any: /^(am|pm|ponoc|ponoć|(po)?podne|uvece|uveče|noću|posle podne|ujutru)/i
    };
    var parseDayPeriodPatterns$d = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^pono/i,
        noon: /^pod/i,
        morning: /jutro/i,
        afternoon: /(posle\s|po)+podne/i,
        evening: /(uvece|uveče)/i,
        night: /(nocu|noću)/i
      }
    };
    var match$d = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$d,
        parsePattern: parseOrdinalNumberPattern$d,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$d,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$d,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$d,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$d,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$d,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$d,
        defaultParseWidth: 'any'
      })
    };

    var locale$d = {
      code: 'sr-Latn',
      formatDistance: formatDistance$d,
      formatLong: formatLong$d,
      formatRelative: formatRelative$d,
      localize: localize$d,
      match: match$d,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$c = {
      lessThanXSeconds: {
        one: 'mindre än en sekund',
        other: 'mindre än {{count}} sekunder'
      },
      xSeconds: {
        one: 'en sekund',
        other: '{{count}} sekunder'
      },
      halfAMinute: 'en halv minut',
      lessThanXMinutes: {
        one: 'mindre än en minut',
        other: 'mindre än {{count}} minuter'
      },
      xMinutes: {
        one: 'en minut',
        other: '{{count}} minuter'
      },
      aboutXHours: {
        one: 'ungefär en timme',
        other: 'ungefär {{count}} timmar'
      },
      xHours: {
        one: 'en timme',
        other: '{{count}} timmar'
      },
      xDays: {
        one: 'en dag',
        other: '{{count}} dagar'
      },
      aboutXWeeks: {
        one: 'ungefär en vecka',
        other: 'ungefär {{count}} vecka'
      },
      xWeeks: {
        one: 'en vecka',
        other: '{{count}} vecka'
      },
      aboutXMonths: {
        one: 'ungefär en månad',
        other: 'ungefär {{count}} månader'
      },
      xMonths: {
        one: 'en månad',
        other: '{{count}} månader'
      },
      aboutXYears: {
        one: 'ungefär ett år',
        other: 'ungefär {{count}} år'
      },
      xYears: {
        one: 'ett år',
        other: '{{count}} år'
      },
      overXYears: {
        one: 'över ett år',
        other: 'över {{count}} år'
      },
      almostXYears: {
        one: 'nästan ett år',
        other: 'nästan {{count}} år'
      }
    };
    var wordMapping = ['noll', 'en', 'två', 'tre', 'fyra', 'fem', 'sex', 'sju', 'åtta', 'nio', 'tio', 'elva', 'tolv'];
    var formatDistance$c = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$c[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        if (options && options.onlyNumeric) {
          result = tokenValue.other.replace('{{count}}', String(count));
        } else {
          result = tokenValue.other.replace('{{count}}', count < 13 ? wordMapping[count] : String(count));
        }
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'om ' + result;
        } else {
          return result + ' sedan';
        }
      }
      return result;
    };

    var dateFormats$c = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'y-MM-dd'
    };
    var timeFormats$c = {
      full: "'kl'. HH:mm:ss zzzz",
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$c = {
      full: "{{date}} 'kl.' {{time}}",
      long: "{{date}} 'kl.' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$c = {
      date: buildFormatLongFn({
        formats: dateFormats$c,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$c,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$c,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$c = {
      lastWeek: "'i' EEEE's kl.' p",
      yesterday: "'igår kl.' p",
      today: "'idag kl.' p",
      tomorrow: "'imorgon kl.' p",
      nextWeek: "EEEE 'kl.' p",
      other: 'P'
    };
    var formatRelative$c = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$c[token];
    };

    var eraValues$c = {
      narrow: ['f.Kr.', 'e.Kr.'],
      abbreviated: ['f.Kr.', 'e.Kr.'],
      wide: ['före Kristus', 'efter Kristus']
    };
    var quarterValues$c = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1:a kvartalet', '2:a kvartalet', '3:e kvartalet', '4:e kvartalet']
    };
    var monthValues$c = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mars', 'apr.', 'maj', 'juni', 'juli', 'aug.', 'sep.', 'okt.', 'nov.', 'dec.'],
      wide: ['januari', 'februari', 'mars', 'april', 'maj', 'juni', 'juli', 'augusti', 'september', 'oktober', 'november', 'december']
    };
    var dayValues$c = {
      narrow: ['S', 'M', 'T', 'O', 'T', 'F', 'L'],
      short: ['sö', 'må', 'ti', 'on', 'to', 'fr', 'lö'],
      abbreviated: ['sön', 'mån', 'tis', 'ons', 'tors', 'fre', 'lör'],
      wide: ['söndag', 'måndag', 'tisdag', 'onsdag', 'torsdag', 'fredag', 'lördag']
    };
    var dayPeriodValues$c = {
      narrow: {
        am: 'fm',
        pm: 'em',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'morg.',
        afternoon: 'efterm.',
        evening: 'kväll',
        night: 'natt'
      },
      abbreviated: {
        am: 'f.m.',
        pm: 'e.m.',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'morgon',
        afternoon: 'efterm.',
        evening: 'kväll',
        night: 'natt'
      },
      wide: {
        am: 'förmiddag',
        pm: 'eftermiddag',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'morgon',
        afternoon: 'eftermiddag',
        evening: 'kväll',
        night: 'natt'
      }
    };
    var formattingDayPeriodValues$c = {
      narrow: {
        am: 'fm',
        pm: 'em',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på efterm.',
        evening: 'på kvällen',
        night: 'på natten'
      },
      abbreviated: {
        am: 'fm',
        pm: 'em',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på efterm.',
        evening: 'på kvällen',
        night: 'på natten'
      },
      wide: {
        am: 'fm',
        pm: 'em',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morgonen',
        afternoon: 'på eftermiddagen',
        evening: 'på kvällen',
        night: 'på natten'
      }
    };
    var ordinalNumber$c = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      var rem100 = number % 100;
      if (rem100 > 20 || rem100 < 10) {
        switch (rem100 % 10) {
          case 1:
          case 2:
            return number + ':a';
        }
      }
      return number + ':e';
    };
    var localize$c = {
      ordinalNumber: ordinalNumber$c,
      era: buildLocalizeFn({
        values: eraValues$c,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$c,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$c,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$c,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$c,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$c,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$c = /^(\d+)(:a|:e)?/i;
    var parseOrdinalNumberPattern$c = /\d+/i;
    var matchEraPatterns$c = {
      narrow: /^(f\.? ?Kr\.?|f\.? ?v\.? ?t\.?|e\.? ?Kr\.?|v\.? ?t\.?)/i,
      abbreviated: /^(f\.? ?Kr\.?|f\.? ?v\.? ?t\.?|e\.? ?Kr\.?|v\.? ?t\.?)/i,
      wide: /^(före Kristus|före vår tid|efter Kristus|vår tid)/i
    };
    var parseEraPatterns$c = {
      any: [/^f/i, /^[ev]/i]
    };
    var matchQuarterPatterns$c = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](:a|:e)? kvartalet/i
    };
    var parseQuarterPatterns$c = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$c = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar[s]?|apr|maj|jun[i]?|jul[i]?|aug|sep|okt|nov|dec)\.?/i,
      wide: /^(januari|februari|mars|april|maj|juni|juli|augusti|september|oktober|november|december)/i
    };
    var parseMonthPatterns$c = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$c = {
      narrow: /^[smtofl]/i,
      short: /^(sö|må|ti|on|to|fr|lö)/i,
      abbreviated: /^(sön|mån|tis|ons|tors|fre|lör)/i,
      wide: /^(söndag|måndag|tisdag|onsdag|torsdag|fredag|lördag)/i
    };
    var parseDayPatterns$c = {
      any: [/^s/i, /^m/i, /^ti/i, /^o/i, /^to/i, /^f/i, /^l/i]
    };
    var matchDayPeriodPatterns$c = {
      any: /^([fe]\.?\s?m\.?|midn(att)?|midd(ag)?|(på) (morgonen|eftermiddagen|kvällen|natten))/i
    };
    var parseDayPeriodPatterns$c = {
      any: {
        am: /^f/i,
        pm: /^e/i,
        midnight: /^midn/i,
        noon: /^midd/i,
        morning: /morgon/i,
        afternoon: /eftermiddag/i,
        evening: /kväll/i,
        night: /natt/i
      }
    };
    var match$c = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$c,
        parsePattern: parseOrdinalNumberPattern$c,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$c,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$c,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$c,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$c,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$c,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$c,
        defaultParseWidth: 'any'
      })
    };

    var locale$c = {
      code: 'sv',
      formatDistance: formatDistance$c,
      formatLong: formatLong$c,
      formatRelative: formatRelative$c,
      localize: localize$c,
      match: match$c,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    function isPluralType(val) {
      return val.one !== undefined;
    }
    var formatDistanceLocale$b = {
      lessThanXSeconds: {
        one: {
          default: 'ஒரு வினாடிக்கு குறைவாக',
          in: 'ஒரு வினாடிக்குள்',
          ago: 'ஒரு வினாடிக்கு முன்பு'
        },
        other: {
          default: '{{count}} வினாடிகளுக்கு குறைவாக',
          in: '{{count}} வினாடிகளுக்குள்',
          ago: '{{count}} வினாடிகளுக்கு முன்பு'
        }
      },
      xSeconds: {
        one: {
          default: '1 வினாடி',
          in: '1 வினாடியில்',
          ago: '1 வினாடி முன்பு'
        },
        other: {
          default: '{{count}} விநாடிகள்',
          in: '{{count}} வினாடிகளில்',
          ago: '{{count}} விநாடிகளுக்கு முன்பு'
        }
      },
      halfAMinute: {
        default: 'அரை நிமிடம்',
        in: 'அரை நிமிடத்தில்',
        ago: 'அரை நிமிடம் முன்பு'
      },
      lessThanXMinutes: {
        one: {
          default: 'ஒரு நிமிடத்திற்கும் குறைவாக',
          in: 'ஒரு நிமிடத்திற்குள்',
          ago: 'ஒரு நிமிடத்திற்கு முன்பு'
        },
        other: {
          default: '{{count}} நிமிடங்களுக்கும் குறைவாக',
          in: '{{count}} நிமிடங்களுக்குள்',
          ago: '{{count}} நிமிடங்களுக்கு முன்பு'
        }
      },
      xMinutes: {
        one: {
          default: '1 நிமிடம்',
          in: '1 நிமிடத்தில்',
          ago: '1 நிமிடம் முன்பு'
        },
        other: {
          default: '{{count}} நிமிடங்கள்',
          in: '{{count}} நிமிடங்களில்',
          ago: '{{count}} நிமிடங்களுக்கு முன்பு'
        }
      },
      aboutXHours: {
        one: {
          default: 'சுமார் 1 மணி நேரம்',
          in: 'சுமார் 1 மணி நேரத்தில்',
          ago: 'சுமார் 1 மணி நேரத்திற்கு முன்பு'
        },
        other: {
          default: 'சுமார் {{count}} மணி நேரம்',
          in: 'சுமார் {{count}} மணி நேரத்திற்கு முன்பு',
          ago: 'சுமார் {{count}} மணி நேரத்தில்'
        }
      },
      xHours: {
        one: {
          default: '1 மணி நேரம்',
          in: '1 மணி நேரத்தில்',
          ago: '1 மணி நேரத்திற்கு முன்பு'
        },
        other: {
          default: '{{count}} மணி நேரம்',
          in: '{{count}} மணி நேரத்தில்',
          ago: '{{count}} மணி நேரத்திற்கு முன்பு'
        }
      },
      xDays: {
        one: {
          default: '1 நாள்',
          in: '1 நாளில்',
          ago: '1 நாள் முன்பு'
        },
        other: {
          default: '{{count}} நாட்கள்',
          in: '{{count}} நாட்களில்',
          ago: '{{count}} நாட்களுக்கு முன்பு'
        }
      },
      aboutXWeeks: {
        one: {
          default: 'சுமார் 1 வாரம்',
          in: 'சுமார் 1 வாரத்தில்',
          ago: 'சுமார் 1 வாரம் முன்பு'
        },
        other: {
          default: 'சுமார் {{count}} வாரங்கள்',
          in: 'சுமார் {{count}} வாரங்களில்',
          ago: 'சுமார் {{count}} வாரங்களுக்கு முன்பு'
        }
      },
      xWeeks: {
        one: {
          default: '1 வாரம்',
          in: '1 வாரத்தில்',
          ago: '1 வாரம் முன்பு'
        },
        other: {
          default: '{{count}} வாரங்கள்',
          in: '{{count}} வாரங்களில்',
          ago: '{{count}} வாரங்களுக்கு முன்பு'
        }
      },
      aboutXMonths: {
        one: {
          default: 'சுமார் 1 மாதம்',
          in: 'சுமார் 1 மாதத்தில்',
          ago: 'சுமார் 1 மாதத்திற்கு முன்பு'
        },
        other: {
          default: 'சுமார் {{count}} மாதங்கள்',
          in: 'சுமார் {{count}} மாதங்களில்',
          ago: 'சுமார் {{count}} மாதங்களுக்கு முன்பு'
        }
      },
      xMonths: {
        one: {
          default: '1 மாதம்',
          in: '1 மாதத்தில்',
          ago: '1 மாதம் முன்பு'
        },
        other: {
          default: '{{count}} மாதங்கள்',
          in: '{{count}} மாதங்களில்',
          ago: '{{count}} மாதங்களுக்கு முன்பு'
        }
      },
      aboutXYears: {
        one: {
          default: 'சுமார் 1 வருடம்',
          in: 'சுமார் 1 ஆண்டில்',
          ago: 'சுமார் 1 வருடம் முன்பு'
        },
        other: {
          default: 'சுமார் {{count}} ஆண்டுகள்',
          in: 'சுமார் {{count}} ஆண்டுகளில்',
          ago: 'சுமார் {{count}} ஆண்டுகளுக்கு முன்பு'
        }
      },
      xYears: {
        one: {
          default: '1 வருடம்',
          in: '1 ஆண்டில்',
          ago: '1 வருடம் முன்பு'
        },
        other: {
          default: '{{count}} ஆண்டுகள்',
          in: '{{count}} ஆண்டுகளில்',
          ago: '{{count}} ஆண்டுகளுக்கு முன்பு'
        }
      },
      overXYears: {
        one: {
          default: '1 வருடத்திற்கு மேல்',
          in: '1 வருடத்திற்கும் மேலாக',
          ago: '1 வருடம் முன்பு'
        },
        other: {
          default: '{{count}} ஆண்டுகளுக்கும் மேலாக',
          in: '{{count}} ஆண்டுகளில்',
          ago: '{{count}} ஆண்டுகளுக்கு முன்பு'
        }
      },
      almostXYears: {
        one: {
          default: 'கிட்டத்தட்ட 1 வருடம்',
          in: 'கிட்டத்தட்ட 1 ஆண்டில்',
          ago: 'கிட்டத்தட்ட 1 வருடம் முன்பு'
        },
        other: {
          default: 'கிட்டத்தட்ட {{count}} ஆண்டுகள்',
          in: 'கிட்டத்தட்ட {{count}} ஆண்டுகளில்',
          ago: 'கிட்டத்தட்ட {{count}} ஆண்டுகளுக்கு முன்பு'
        }
      }
    };
    var formatDistance$b = function (token, count, options) {
      var tense = options !== null && options !== void 0 && options.addSuffix ? options.comparison && options.comparison > 0 ? 'in' : 'ago' : 'default';
      var tokenValue = formatDistanceLocale$b[token];
      if (!isPluralType(tokenValue)) return tokenValue[tense];
      if (count === 1) {
        return tokenValue.one[tense];
      } else {
        return tokenValue.other[tense].replace('{{count}}', String(count));
      }
    };

    var dateFormats$b = {
      full: 'EEEE, d MMMM, y',
      long: 'd MMMM, y',
      medium: 'd MMM, y',
      short: 'd/M/yy'
    };
    var timeFormats$b = {
      full: 'a h:mm:ss zzzz',
      long: 'a h:mm:ss z',
      medium: 'a h:mm:ss',
      short: 'a h:mm'
    };
    var dateTimeFormats$b = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$b = {
      date: buildFormatLongFn({
        formats: dateFormats$b,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$b,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$b,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$b = {
      lastWeek: "'கடந்த' eeee p 'மணிக்கு'",
      yesterday: "'நேற்று ' p 'மணிக்கு'",
      today: "'இன்று ' p 'மணிக்கு'",
      tomorrow: "'நாளை ' p 'மணிக்கு'",
      nextWeek: "eeee p 'மணிக்கு'",
      other: 'P'
    };
    var formatRelative$b = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$b[token];
    };

    var eraValues$b = {
      narrow: ['கி.மு.', 'கி.பி.'],
      abbreviated: ['கி.மு.', 'கி.பி.'],
      wide: ['கிறிஸ்துவுக்கு முன்', 'அன்னோ டோமினி']
    };
    var quarterValues$b = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['காலா.1', 'காலா.2', 'காலா.3', 'காலா.4'],
      wide: ['ஒன்றாம் காலாண்டு', 'இரண்டாம் காலாண்டு', 'மூன்றாம் காலாண்டு', 'நான்காம் காலாண்டு']
    };
    var monthValues$b = {
      narrow: ['ஜ', 'பி', 'மா', 'ஏ', 'மே', 'ஜூ', 'ஜூ', 'ஆ', 'செ', 'அ', 'ந', 'டி'],
      abbreviated: ['ஜன.', 'பிப்.', 'மார்.', 'ஏப்.', 'மே', 'ஜூன்', 'ஜூலை', 'ஆக.', 'செப்.', 'அக்.', 'நவ.', 'டிச.'],
      wide: ['ஜனவரி',
      'பிப்ரவரி',
      'மார்ச்',
      'ஏப்ரல்',
      'மே',
      'ஜூன்',
      'ஜூலை',
      'ஆகஸ்ட்',
      'செப்டம்பர்',
      'அக்டோபர்',
      'நவம்பர்',
      'டிசம்பர்'
      ]
    };
    var dayValues$b = {
      narrow: ['ஞா', 'தி', 'செ', 'பு', 'வி', 'வெ', 'ச'],
      short: ['ஞா', 'தி', 'செ', 'பு', 'வி', 'வெ', 'ச'],
      abbreviated: ['ஞாயி.', 'திங்.', 'செவ்.', 'புத.', 'வியா.', 'வெள்.', 'சனி'],
      wide: ['ஞாயிறு',
      'திங்கள்',
      'செவ்வாய்',
      'புதன்',
      'வியாழன்',
      'வெள்ளி',
      'சனி'
      ]
    };
    var dayPeriodValues$b = {
      narrow: {
        am: 'மு.ப',
        pm: 'பி.ப',
        midnight: 'நள்.',
        noon: 'நண்.',
        morning: 'கா.',
        afternoon: 'மதி.',
        evening: 'மா.',
        night: 'இர.'
      },
      abbreviated: {
        am: 'முற்பகல்',
        pm: 'பிற்பகல்',
        midnight: 'நள்ளிரவு',
        noon: 'நண்பகல்',
        morning: 'காலை',
        afternoon: 'மதியம்',
        evening: 'மாலை',
        night: 'இரவு'
      },
      wide: {
        am: 'முற்பகல்',
        pm: 'பிற்பகல்',
        midnight: 'நள்ளிரவு',
        noon: 'நண்பகல்',
        morning: 'காலை',
        afternoon: 'மதியம்',
        evening: 'மாலை',
        night: 'இரவு'
      }
    };
    var formattingDayPeriodValues$b = {
      narrow: {
        am: 'மு.ப',
        pm: 'பி.ப',
        midnight: 'நள்.',
        noon: 'நண்.',
        morning: 'கா.',
        afternoon: 'மதி.',
        evening: 'மா.',
        night: 'இர.'
      },
      abbreviated: {
        am: 'முற்பகல்',
        pm: 'பிற்பகல்',
        midnight: 'நள்ளிரவு',
        noon: 'நண்பகல்',
        morning: 'காலை',
        afternoon: 'மதியம்',
        evening: 'மாலை',
        night: 'இரவு'
      },
      wide: {
        am: 'முற்பகல்',
        pm: 'பிற்பகல்',
        midnight: 'நள்ளிரவு',
        noon: 'நண்பகல்',
        morning: 'காலை',
        afternoon: 'மதியம்',
        evening: 'மாலை',
        night: 'இரவு'
      }
    };
    var ordinalNumber$b = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$b = {
      ordinalNumber: ordinalNumber$b,
      era: buildLocalizeFn({
        values: eraValues$b,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$b,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$b,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$b,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$b,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$b,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$b = /^(\d+)(வது)?/i;
    var parseOrdinalNumberPattern$b = /\d+/i;
    var matchEraPatterns$b = {
      narrow: /^(கி.மு.|கி.பி.)/i,
      abbreviated: /^(கி\.?\s?மு\.?|கி\.?\s?பி\.?)/,
      wide: /^(கிறிஸ்துவுக்கு\sமுன்|அன்னோ\sடோமினி)/i
    };
    var parseEraPatterns$b = {
      any: [/கி\.?\s?மு\.?/, /கி\.?\s?பி\.?/]
    };
    var matchQuarterPatterns$b = {
      narrow: /^[1234]/i,
      abbreviated: /^காலா.[1234]/i,
      wide: /^(ஒன்றாம்|இரண்டாம்|மூன்றாம்|நான்காம்) காலாண்டு/i
    };
    var parseQuarterPatterns$b = {
      narrow: [/1/i, /2/i, /3/i, /4/i],
      any: [/(1|காலா.1|ஒன்றாம்)/i, /(2|காலா.2|இரண்டாம்)/i, /(3|காலா.3|மூன்றாம்)/i, /(4|காலா.4|நான்காம்)/i]
    };
    var matchMonthPatterns$b = {
      narrow: /^(ஜ|பி|மா|ஏ|மே|ஜூ|ஆ|செ|அ|ந|டி)$/i,
      abbreviated: /^(ஜன.|பிப்.|மார்.|ஏப்.|மே|ஜூன்|ஜூலை|ஆக.|செப்.|அக்.|நவ.|டிச.)/i,
      wide: /^(ஜனவரி|பிப்ரவரி|மார்ச்|ஏப்ரல்|மே|ஜூன்|ஜூலை|ஆகஸ்ட்|செப்டம்பர்|அக்டோபர்|நவம்பர்|டிசம்பர்)/i
    };
    var parseMonthPatterns$b = {
      narrow: [/^ஜ$/i, /^பி/i, /^மா/i, /^ஏ/i, /^மே/i, /^ஜூ/i, /^ஜூ/i, /^ஆ/i, /^செ/i, /^அ/i, /^ந/i, /^டி/i],
      any: [/^ஜன/i, /^பி/i, /^மா/i, /^ஏ/i, /^மே/i, /^ஜூன்/i, /^ஜூலை/i, /^ஆ/i, /^செ/i, /^அ/i, /^ந/i, /^டி/i]
    };
    var matchDayPatterns$b = {
      narrow: /^(ஞா|தி|செ|பு|வி|வெ|ச)/i,
      short: /^(ஞா|தி|செ|பு|வி|வெ|ச)/i,
      abbreviated: /^(ஞாயி.|திங்.|செவ்.|புத.|வியா.|வெள்.|சனி)/i,
      wide: /^(ஞாயிறு|திங்கள்|செவ்வாய்|புதன்|வியாழன்|வெள்ளி|சனி)/i
    };
    var parseDayPatterns$b = {
      narrow: [/^ஞா/i, /^தி/i, /^செ/i, /^பு/i, /^வி/i, /^வெ/i, /^ச/i],
      any: [/^ஞா/i, /^தி/i, /^செ/i, /^பு/i, /^வி/i, /^வெ/i, /^ச/i]
    };
    var matchDayPeriodPatterns$b = {
      narrow: /^(மு.ப|பி.ப|நள்|நண்|காலை|மதியம்|மாலை|இரவு)/i,
      any: /^(மு.ப|பி.ப|முற்பகல்|பிற்பகல்|நள்ளிரவு|நண்பகல்|காலை|மதியம்|மாலை|இரவு)/i
    };
    var parseDayPeriodPatterns$b = {
      any: {
        am: /^மு/i,
        pm: /^பி/i,
        midnight: /^நள்/i,
        noon: /^நண்/i,
        morning: /காலை/i,
        afternoon: /மதியம்/i,
        evening: /மாலை/i,
        night: /இரவு/i
      }
    };
    var match$b = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$b,
        parsePattern: parseOrdinalNumberPattern$b,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$b,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$b,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$b,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$b,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$b,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$b,
        defaultParseWidth: 'any'
      })
    };

    var locale$b = {
      code: 'ta',
      formatDistance: formatDistance$b,
      formatLong: formatLong$b,
      formatRelative: formatRelative$b,
      localize: localize$b,
      match: match$b,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$a = {
      lessThanXSeconds: {
        standalone: {
          one: 'సెకను కన్నా తక్కువ',
          other: '{{count}} సెకన్ల కన్నా తక్కువ'
        },
        withPreposition: {
          one: 'సెకను',
          other: '{{count}} సెకన్ల'
        }
      },
      xSeconds: {
        standalone: {
          one: 'ఒక సెకను',
          other: '{{count}} సెకన్ల'
        },
        withPreposition: {
          one: 'ఒక సెకను',
          other: '{{count}} సెకన్ల'
        }
      },
      halfAMinute: {
        standalone: 'అర నిమిషం',
        withPreposition: 'అర నిమిషం'
      },
      lessThanXMinutes: {
        standalone: {
          one: 'ఒక నిమిషం కన్నా తక్కువ',
          other: '{{count}} నిమిషాల కన్నా తక్కువ'
        },
        withPreposition: {
          one: 'ఒక నిమిషం',
          other: '{{count}} నిమిషాల'
        }
      },
      xMinutes: {
        standalone: {
          one: 'ఒక నిమిషం',
          other: '{{count}} నిమిషాలు'
        },
        withPreposition: {
          one: 'ఒక నిమిషం',
          other: '{{count}} నిమిషాల'
        }
      },
      aboutXHours: {
        standalone: {
          one: 'సుమారు ఒక గంట',
          other: 'సుమారు {{count}} గంటలు'
        },
        withPreposition: {
          one: 'సుమారు ఒక గంట',
          other: 'సుమారు {{count}} గంటల'
        }
      },
      xHours: {
        standalone: {
          one: 'ఒక గంట',
          other: '{{count}} గంటలు'
        },
        withPreposition: {
          one: 'ఒక గంట',
          other: '{{count}} గంటల'
        }
      },
      xDays: {
        standalone: {
          one: 'ఒక రోజు',
          other: '{{count}} రోజులు'
        },
        withPreposition: {
          one: 'ఒక రోజు',
          other: '{{count}} రోజుల'
        }
      },
      aboutXWeeks: {
        standalone: {
          one: 'సుమారు ఒక వారం',
          other: 'సుమారు {{count}} వారాలు'
        },
        withPreposition: {
          one: 'సుమారు ఒక వారం',
          other: 'సుమారు {{count}} వారాలల'
        }
      },
      xWeeks: {
        standalone: {
          one: 'ఒక వారం',
          other: '{{count}} వారాలు'
        },
        withPreposition: {
          one: 'ఒక వారం',
          other: '{{count}} వారాలల'
        }
      },
      aboutXMonths: {
        standalone: {
          one: 'సుమారు ఒక నెల',
          other: 'సుమారు {{count}} నెలలు'
        },
        withPreposition: {
          one: 'సుమారు ఒక నెల',
          other: 'సుమారు {{count}} నెలల'
        }
      },
      xMonths: {
        standalone: {
          one: 'ఒక నెల',
          other: '{{count}} నెలలు'
        },
        withPreposition: {
          one: 'ఒక నెల',
          other: '{{count}} నెలల'
        }
      },
      aboutXYears: {
        standalone: {
          one: 'సుమారు ఒక సంవత్సరం',
          other: 'సుమారు {{count}} సంవత్సరాలు'
        },
        withPreposition: {
          one: 'సుమారు ఒక సంవత్సరం',
          other: 'సుమారు {{count}} సంవత్సరాల'
        }
      },
      xYears: {
        standalone: {
          one: 'ఒక సంవత్సరం',
          other: '{{count}} సంవత్సరాలు'
        },
        withPreposition: {
          one: 'ఒక సంవత్సరం',
          other: '{{count}} సంవత్సరాల'
        }
      },
      overXYears: {
        standalone: {
          one: 'ఒక సంవత్సరం పైగా',
          other: '{{count}} సంవత్సరాలకు పైగా'
        },
        withPreposition: {
          one: 'ఒక సంవత్సరం',
          other: '{{count}} సంవత్సరాల'
        }
      },
      almostXYears: {
        standalone: {
          one: 'దాదాపు ఒక సంవత్సరం',
          other: 'దాదాపు {{count}} సంవత్సరాలు'
        },
        withPreposition: {
          one: 'దాదాపు ఒక సంవత్సరం',
          other: 'దాదాపు {{count}} సంవత్సరాల'
        }
      }
    };
    var formatDistance$a = function (token, count, options) {
      var result;
      var tokenValue = options !== null && options !== void 0 && options.addSuffix ? formatDistanceLocale$a[token].withPreposition : formatDistanceLocale$a[token].standalone;
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + 'లో';
        } else {
          return result + ' క్రితం';
        }
      }
      return result;
    };

    var dateFormats$a = {
      full: 'd, MMMM y, EEEE',
      long: 'd MMMM, y',
      medium: 'd MMM, y',
      short: 'dd-MM-yy'
    };
    var timeFormats$a = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$a = {
      full: "{{date}} {{time}}'కి'",
      long: "{{date}} {{time}}'కి'",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$a = {
      date: buildFormatLongFn({
        formats: dateFormats$a,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$a,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$a,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$a = {
      lastWeek: "'గత' eeee p",
      yesterday: "'నిన్న' p",
      today: "'ఈ రోజు' p",
      tomorrow: "'రేపు' p",
      nextWeek: "'తదుపరి' eeee p",
      other: 'P'
    };
    var formatRelative$a = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$a[token];
    };

    var eraValues$a = {
      narrow: ['క్రీ.పూ.', 'క్రీ.శ.'],
      abbreviated: ['క్రీ.పూ.', 'క్రీ.శ.'],
      wide: ['క్రీస్తు పూర్వం', 'క్రీస్తుశకం']
    };
    var quarterValues$a = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['త్రై1', 'త్రై2', 'త్రై3', 'త్రై4'],
      wide: ['1వ త్రైమాసికం', '2వ త్రైమాసికం', '3వ త్రైమాసికం', '4వ త్రైమాసికం']
    };
    var monthValues$a = {
      narrow: ['జ', 'ఫి', 'మా', 'ఏ', 'మే', 'జూ', 'జు', 'ఆ', 'సె', 'అ', 'న', 'డి'],
      abbreviated: ['జన', 'ఫిబ్ర', 'మార్చి', 'ఏప్రి', 'మే', 'జూన్', 'జులై', 'ఆగ', 'సెప్టెం', 'అక్టో', 'నవం', 'డిసెం'],
      wide: ['జనవరి', 'ఫిబ్రవరి', 'మార్చి', 'ఏప్రిల్', 'మే', 'జూన్', 'జులై', 'ఆగస్టు', 'సెప్టెంబర్', 'అక్టోబర్', 'నవంబర్', 'డిసెంబర్']
    };
    var dayValues$a = {
      narrow: ['ఆ', 'సో', 'మ', 'బు', 'గు', 'శు', 'శ'],
      short: ['ఆది', 'సోమ', 'మంగళ', 'బుధ', 'గురు', 'శుక్ర', 'శని'],
      abbreviated: ['ఆది', 'సోమ', 'మంగళ', 'బుధ', 'గురు', 'శుక్ర', 'శని'],
      wide: ['ఆదివారం', 'సోమవారం', 'మంగళవారం', 'బుధవారం', 'గురువారం', 'శుక్రవారం', 'శనివారం']
    };
    var dayPeriodValues$a = {
      narrow: {
        am: 'పూర్వాహ్నం',
        pm: 'అపరాహ్నం',
        midnight: 'అర్ధరాత్రి',
        noon: 'మిట్టమధ్యాహ్నం',
        morning: 'ఉదయం',
        afternoon: 'మధ్యాహ్నం',
        evening: 'సాయంత్రం',
        night: 'రాత్రి'
      },
      abbreviated: {
        am: 'పూర్వాహ్నం',
        pm: 'అపరాహ్నం',
        midnight: 'అర్ధరాత్రి',
        noon: 'మిట్టమధ్యాహ్నం',
        morning: 'ఉదయం',
        afternoon: 'మధ్యాహ్నం',
        evening: 'సాయంత్రం',
        night: 'రాత్రి'
      },
      wide: {
        am: 'పూర్వాహ్నం',
        pm: 'అపరాహ్నం',
        midnight: 'అర్ధరాత్రి',
        noon: 'మిట్టమధ్యాహ్నం',
        morning: 'ఉదయం',
        afternoon: 'మధ్యాహ్నం',
        evening: 'సాయంత్రం',
        night: 'రాత్రి'
      }
    };
    var formattingDayPeriodValues$a = {
      narrow: {
        am: 'పూర్వాహ్నం',
        pm: 'అపరాహ్నం',
        midnight: 'అర్ధరాత్రి',
        noon: 'మిట్టమధ్యాహ్నం',
        morning: 'ఉదయం',
        afternoon: 'మధ్యాహ్నం',
        evening: 'సాయంత్రం',
        night: 'రాత్రి'
      },
      abbreviated: {
        am: 'పూర్వాహ్నం',
        pm: 'అపరాహ్నం',
        midnight: 'అర్ధరాత్రి',
        noon: 'మిట్టమధ్యాహ్నం',
        morning: 'ఉదయం',
        afternoon: 'మధ్యాహ్నం',
        evening: 'సాయంత్రం',
        night: 'రాత్రి'
      },
      wide: {
        am: 'పూర్వాహ్నం',
        pm: 'అపరాహ్నం',
        midnight: 'అర్ధరాత్రి',
        noon: 'మిట్టమధ్యాహ్నం',
        morning: 'ఉదయం',
        afternoon: 'మధ్యాహ్నం',
        evening: 'సాయంత్రం',
        night: 'రాత్రి'
      }
    };
    var ordinalNumber$a = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'వ';
    };
    var localize$a = {
      ordinalNumber: ordinalNumber$a,
      era: buildLocalizeFn({
        values: eraValues$a,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$a,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$a,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$a,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$a,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$a,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$a = /^(\d+)(వ)?/i;
    var parseOrdinalNumberPattern$a = /\d+/i;
    var matchEraPatterns$a = {
      narrow: /^(క్రీ\.పూ\.|క్రీ\.శ\.)/i,
      abbreviated: /^(క్రీ\.?\s?పూ\.?|ప్ర\.?\s?శ\.?\s?పూ\.?|క్రీ\.?\s?శ\.?|సా\.?\s?శ\.?)/i,
      wide: /^(క్రీస్తు పూర్వం|ప్రస్తుత శకానికి పూర్వం|క్రీస్తు శకం|ప్రస్తుత శకం)/i
    };
    var parseEraPatterns$a = {
      any: [/^(పూ|శ)/i, /^సా/i]
    };
    var matchQuarterPatterns$a = {
      narrow: /^[1234]/i,
      abbreviated: /^త్రై[1234]/i,
      wide: /^[1234](వ)? త్రైమాసికం/i
    };
    var parseQuarterPatterns$a = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$a = {
      narrow: /^(జూ|జు|జ|ఫి|మా|ఏ|మే|ఆ|సె|అ|న|డి)/i,
      abbreviated: /^(జన|ఫిబ్ర|మార్చి|ఏప్రి|మే|జూన్|జులై|ఆగ|సెప్|అక్టో|నవ|డిసె)/i,
      wide: /^(జనవరి|ఫిబ్రవరి|మార్చి|ఏప్రిల్|మే|జూన్|జులై|ఆగస్టు|సెప్టెంబర్|అక్టోబర్|నవంబర్|డిసెంబర్)/i
    };
    var parseMonthPatterns$a = {
      narrow: [/^జ/i, /^ఫి/i, /^మా/i, /^ఏ/i, /^మే/i, /^జూ/i, /^జు/i, /^ఆ/i, /^సె/i, /^అ/i, /^న/i, /^డి/i],
      any: [/^జన/i, /^ఫి/i, /^మా/i, /^ఏ/i, /^మే/i, /^జూన్/i, /^జులై/i, /^ఆగ/i, /^సె/i, /^అ/i, /^న/i, /^డి/i]
    };
    var matchDayPatterns$a = {
      narrow: /^(ఆ|సో|మ|బు|గు|శు|శ)/i,
      short: /^(ఆది|సోమ|మం|బుధ|గురు|శుక్ర|శని)/i,
      abbreviated: /^(ఆది|సోమ|మం|బుధ|గురు|శుక్ర|శని)/i,
      wide: /^(ఆదివారం|సోమవారం|మంగళవారం|బుధవారం|గురువారం|శుక్రవారం|శనివారం)/i
    };
    var parseDayPatterns$a = {
      narrow: [/^ఆ/i, /^సో/i, /^మ/i, /^బు/i, /^గు/i, /^శు/i, /^శ/i],
      any: [/^ఆది/i, /^సోమ/i, /^మం/i, /^బుధ/i, /^గురు/i, /^శుక్ర/i, /^శని/i]
    };
    var matchDayPeriodPatterns$a = {
      narrow: /^(పూర్వాహ్నం|అపరాహ్నం|అర్ధరాత్రి|మిట్టమధ్యాహ్నం|ఉదయం|మధ్యాహ్నం|సాయంత్రం|రాత్రి)/i,
      any: /^(పూర్వాహ్నం|అపరాహ్నం|అర్ధరాత్రి|మిట్టమధ్యాహ్నం|ఉదయం|మధ్యాహ్నం|సాయంత్రం|రాత్రి)/i
    };
    var parseDayPeriodPatterns$a = {
      any: {
        am: /^పూర్వాహ్నం/i,
        pm: /^అపరాహ్నం/i,
        midnight: /^అర్ధ/i,
        noon: /^మిట్ట/i,
        morning: /ఉదయం/i,
        afternoon: /మధ్యాహ్నం/i,
        evening: /సాయంత్రం/i,
        night: /రాత్రి/i
      }
    };
    var match$a = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$a,
        parsePattern: parseOrdinalNumberPattern$a,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$a,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$a,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$a,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$a,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$a,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$a,
        defaultParseWidth: 'any'
      })
    };

    var locale$a = {
      code: 'te',
      formatDistance: formatDistance$a,
      formatLong: formatLong$a,
      formatRelative: formatRelative$a,
      localize: localize$a,
      match: match$a,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$9 = {
      lessThanXSeconds: {
        one: 'น้อยกว่า 1 วินาที',
        other: 'น้อยกว่า {{count}} วินาที'
      },
      xSeconds: {
        one: '1 วินาที',
        other: '{{count}} วินาที'
      },
      halfAMinute: 'ครึ่งนาที',
      lessThanXMinutes: {
        one: 'น้อยกว่า 1 นาที',
        other: 'น้อยกว่า {{count}} นาที'
      },
      xMinutes: {
        one: '1 นาที',
        other: '{{count}} นาที'
      },
      aboutXHours: {
        one: 'ประมาณ 1 ชั่วโมง',
        other: 'ประมาณ {{count}} ชั่วโมง'
      },
      xHours: {
        one: '1 ชั่วโมง',
        other: '{{count}} ชั่วโมง'
      },
      xDays: {
        one: '1 วัน',
        other: '{{count}} วัน'
      },
      aboutXWeeks: {
        one: 'ประมาณ 1 สัปดาห์',
        other: 'ประมาณ {{count}} สัปดาห์'
      },
      xWeeks: {
        one: '1 สัปดาห์',
        other: '{{count}} สัปดาห์'
      },
      aboutXMonths: {
        one: 'ประมาณ 1 เดือน',
        other: 'ประมาณ {{count}} เดือน'
      },
      xMonths: {
        one: '1 เดือน',
        other: '{{count}} เดือน'
      },
      aboutXYears: {
        one: 'ประมาณ 1 ปี',
        other: 'ประมาณ {{count}} ปี'
      },
      xYears: {
        one: '1 ปี',
        other: '{{count}} ปี'
      },
      overXYears: {
        one: 'มากกว่า 1 ปี',
        other: 'มากกว่า {{count}} ปี'
      },
      almostXYears: {
        one: 'เกือบ 1 ปี',
        other: 'เกือบ {{count}} ปี'
      }
    };
    var formatDistance$9 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$9[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          if (token === 'halfAMinute') {
            return 'ใน' + result;
          } else {
            return 'ใน ' + result;
          }
        } else {
          return result + 'ที่ผ่านมา';
        }
      }
      return result;
    };

    var dateFormats$9 = {
      full: 'วันEEEEที่ do MMMM y',
      long: 'do MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$9 = {
      full: 'H:mm:ss น. zzzz',
      long: 'H:mm:ss น. z',
      medium: 'H:mm:ss น.',
      short: 'H:mm น.'
    };
    var dateTimeFormats$9 = {
      full: "{{date}} 'เวลา' {{time}}",
      long: "{{date}} 'เวลา' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$9 = {
      date: buildFormatLongFn({
        formats: dateFormats$9,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$9,
        defaultWidth: 'medium'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$9,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$9 = {
      lastWeek: "eeee'ที่แล้วเวลา' p",
      yesterday: "'เมื่อวานนี้เวลา' p",
      today: "'วันนี้เวลา' p",
      tomorrow: "'พรุ่งนี้เวลา' p",
      nextWeek: "eeee 'เวลา' p",
      other: 'P'
    };
    var formatRelative$9 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$9[token];
    };

    var eraValues$9 = {
      narrow: ['B', 'คศ'],
      abbreviated: ['BC', 'ค.ศ.'],
      wide: ['ปีก่อนคริสตกาล', 'คริสต์ศักราช']
    };
    var quarterValues$9 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['ไตรมาสแรก', 'ไตรมาสที่สอง', 'ไตรมาสที่สาม', 'ไตรมาสที่สี่']
    };
    var dayValues$9 = {
      narrow: ['อา.', 'จ.', 'อ.', 'พ.', 'พฤ.', 'ศ.', 'ส.'],
      short: ['อา.', 'จ.', 'อ.', 'พ.', 'พฤ.', 'ศ.', 'ส.'],
      abbreviated: ['อา.', 'จ.', 'อ.', 'พ.', 'พฤ.', 'ศ.', 'ส.'],
      wide: ['อาทิตย์', 'จันทร์', 'อังคาร', 'พุธ', 'พฤหัสบดี', 'ศุกร์', 'เสาร์']
    };
    var monthValues$9 = {
      narrow: ['ม.ค.', 'ก.พ.', 'มี.ค.', 'เม.ย.', 'พ.ค.', 'มิ.ย.', 'ก.ค.', 'ส.ค.', 'ก.ย.', 'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      abbreviated: ['ม.ค.', 'ก.พ.', 'มี.ค.', 'เม.ย.', 'พ.ค.', 'มิ.ย.', 'ก.ค.', 'ส.ค.', 'ก.ย.', 'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      wide: ['มกราคม', 'กุมภาพันธ์', 'มีนาคม', 'เมษายน', 'พฤษภาคม', 'มิถุนายน', 'กรกฎาคม', 'สิงหาคม', 'กันยายน', 'ตุลาคม', 'พฤศจิกายน', 'ธันวาคม']
    };
    var dayPeriodValues$9 = {
      narrow: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'เช้า',
        afternoon: 'บ่าย',
        evening: 'เย็น',
        night: 'กลางคืน'
      },
      abbreviated: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'เช้า',
        afternoon: 'บ่าย',
        evening: 'เย็น',
        night: 'กลางคืน'
      },
      wide: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'เช้า',
        afternoon: 'บ่าย',
        evening: 'เย็น',
        night: 'กลางคืน'
      }
    };
    var formattingDayPeriodValues$9 = {
      narrow: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'ตอนเช้า',
        afternoon: 'ตอนกลางวัน',
        evening: 'ตอนเย็น',
        night: 'ตอนกลางคืน'
      },
      abbreviated: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'ตอนเช้า',
        afternoon: 'ตอนกลางวัน',
        evening: 'ตอนเย็น',
        night: 'ตอนกลางคืน'
      },
      wide: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'ตอนเช้า',
        afternoon: 'ตอนกลางวัน',
        evening: 'ตอนเย็น',
        night: 'ตอนกลางคืน'
      }
    };
    var ordinalNumber$9 = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$9 = {
      ordinalNumber: ordinalNumber$9,
      era: buildLocalizeFn({
        values: eraValues$9,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$9,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$9,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$9,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$9,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$9,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$9 = /^\d+/i;
    var parseOrdinalNumberPattern$9 = /\d+/i;
    var matchEraPatterns$9 = {
      narrow: /^([bB]|[aA]|คศ)/i,
      abbreviated: /^([bB]\.?\s?[cC]\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?|ค\.?ศ\.?)/i,
      wide: /^(ก่อนคริสตกาล|คริสต์ศักราช|คริสตกาล)/i
    };
    var parseEraPatterns$9 = {
      any: [/^[bB]/i, /^(^[aA]|ค\.?ศ\.?|คริสตกาล|คริสต์ศักราช|)/i]
    };
    var matchQuarterPatterns$9 = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^ไตรมาส(ที่)? ?[1234]/i
    };
    var parseQuarterPatterns$9 = {
      any: [/(1|แรก|หนึ่ง)/i, /(2|สอง)/i, /(3|สาม)/i, /(4|สี่)/i]
    };
    var matchMonthPatterns$9 = {
      narrow: /^(ม\.?ค\.?|ก\.?พ\.?|มี\.?ค\.?|เม\.?ย\.?|พ\.?ค\.?|มิ\.?ย\.?|ก\.?ค\.?|ส\.?ค\.?|ก\.?ย\.?|ต\.?ค\.?|พ\.?ย\.?|ธ\.?ค\.?)/i,
      abbreviated: /^(ม\.?ค\.?|ก\.?พ\.?|มี\.?ค\.?|เม\.?ย\.?|พ\.?ค\.?|มิ\.?ย\.?|ก\.?ค\.?|ส\.?ค\.?|ก\.?ย\.?|ต\.?ค\.?|พ\.?ย\.?|ธ\.?ค\.?')/i,
      wide: /^(มกราคม|กุมภาพันธ์|มีนาคม|เมษายน|พฤษภาคม|มิถุนายน|กรกฎาคม|สิงหาคม|กันยายน|ตุลาคม|พฤศจิกายน|ธันวาคม)/i
    };
    var parseMonthPatterns$9 = {
      wide: [/^มก/i, /^กุม/i, /^มี/i, /^เม/i, /^พฤษ/i, /^มิ/i, /^กรก/i, /^ส/i, /^กัน/i, /^ต/i, /^พฤศ/i, /^ธ/i],
      any: [/^ม\.?ค\.?/i, /^ก\.?พ\.?/i, /^มี\.?ค\.?/i, /^เม\.?ย\.?/i, /^พ\.?ค\.?/i, /^มิ\.?ย\.?/i, /^ก\.?ค\.?/i, /^ส\.?ค\.?/i, /^ก\.?ย\.?/i, /^ต\.?ค\.?/i, /^พ\.?ย\.?/i, /^ธ\.?ค\.?/i]
    };
    var matchDayPatterns$9 = {
      narrow: /^(อา\.?|จ\.?|อ\.?|พฤ\.?|พ\.?|ศ\.?|ส\.?)/i,
      short: /^(อา\.?|จ\.?|อ\.?|พฤ\.?|พ\.?|ศ\.?|ส\.?)/i,
      abbreviated: /^(อา\.?|จ\.?|อ\.?|พฤ\.?|พ\.?|ศ\.?|ส\.?)/i,
      wide: /^(อาทิตย์|จันทร์|อังคาร|พุธ|พฤหัสบดี|ศุกร์|เสาร์)/i
    };
    var parseDayPatterns$9 = {
      wide: [/^อา/i, /^จั/i, /^อั/i, /^พุธ/i, /^พฤ/i, /^ศ/i, /^เส/i],
      any: [/^อา/i, /^จ/i, /^อ/i, /^พ(?!ฤ)/i, /^พฤ/i, /^ศ/i, /^ส/i]
    };
    var matchDayPeriodPatterns$9 = {
      any: /^(ก่อนเที่ยง|หลังเที่ยง|เที่ยงคืน|เที่ยง|(ตอน.*?)?.*(เที่ยง|เช้า|บ่าย|เย็น|กลางคืน))/i
    };
    var parseDayPeriodPatterns$9 = {
      any: {
        am: /^ก่อนเที่ยง/i,
        pm: /^หลังเที่ยง/i,
        midnight: /^เที่ยงคืน/i,
        noon: /^เที่ยง/i,
        morning: /เช้า/i,
        afternoon: /บ่าย/i,
        evening: /เย็น/i,
        night: /กลางคืน/i
      }
    };
    var match$9 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$9,
        parsePattern: parseOrdinalNumberPattern$9,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$9,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$9,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$9,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$9,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$9,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$9,
        defaultParseWidth: 'any'
      })
    };

    var locale$9 = {
      code: 'th',
      formatDistance: formatDistance$9,
      formatLong: formatLong$9,
      formatRelative: formatRelative$9,
      localize: localize$9,
      match: match$9,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$8 = {
      lessThanXSeconds: {
        one: 'bir saniyeden az',
        other: '{{count}} saniyeden az'
      },
      xSeconds: {
        one: '1 saniye',
        other: '{{count}} saniye'
      },
      halfAMinute: 'yarım dakika',
      lessThanXMinutes: {
        one: 'bir dakikadan az',
        other: '{{count}} dakikadan az'
      },
      xMinutes: {
        one: '1 dakika',
        other: '{{count}} dakika'
      },
      aboutXHours: {
        one: 'yaklaşık 1 saat',
        other: 'yaklaşık {{count}} saat'
      },
      xHours: {
        one: '1 saat',
        other: '{{count}} saat'
      },
      xDays: {
        one: '1 gün',
        other: '{{count}} gün'
      },
      aboutXWeeks: {
        one: 'yaklaşık 1 hafta',
        other: 'yaklaşık {{count}} hafta'
      },
      xWeeks: {
        one: '1 hafta',
        other: '{{count}} hafta'
      },
      aboutXMonths: {
        one: 'yaklaşık 1 ay',
        other: 'yaklaşık {{count}} ay'
      },
      xMonths: {
        one: '1 ay',
        other: '{{count}} ay'
      },
      aboutXYears: {
        one: 'yaklaşık 1 yıl',
        other: 'yaklaşık {{count}} yıl'
      },
      xYears: {
        one: '1 yıl',
        other: '{{count}} yıl'
      },
      overXYears: {
        one: '1 yıldan fazla',
        other: '{{count}} yıldan fazla'
      },
      almostXYears: {
        one: 'neredeyse 1 yıl',
        other: 'neredeyse {{count}} yıl'
      }
    };
    var formatDistance$8 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$8[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' sonra';
        } else {
          return result + ' önce';
        }
      }
      return result;
    };

    var dateFormats$8 = {
      full: 'd MMMM y EEEE',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd.MM.yyyy'
    };
    var timeFormats$8 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$8 = {
      full: "{{date}} 'saat' {{time}}",
      long: "{{date}} 'saat' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$8 = {
      date: buildFormatLongFn({
        formats: dateFormats$8,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$8,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$8,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$8 = {
      lastWeek: "'geçen hafta' eeee 'saat' p",
      yesterday: "'dün saat' p",
      today: "'bugün saat' p",
      tomorrow: "'yarın saat' p",
      nextWeek: "eeee 'saat' p",
      other: 'P'
    };
    var formatRelative$8 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$8[token];
    };

    var eraValues$8 = {
      narrow: ['MÖ', 'MS'],
      abbreviated: ['MÖ', 'MS'],
      wide: ['Milattan Önce', 'Milattan Sonra']
    };
    var quarterValues$8 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1Ç', '2Ç', '3Ç', '4Ç'],
      wide: ['İlk çeyrek', 'İkinci Çeyrek', 'Üçüncü çeyrek', 'Son çeyrek']
    };
    var monthValues$8 = {
      narrow: ['O', 'Ş', 'M', 'N', 'M', 'H', 'T', 'A', 'E', 'E', 'K', 'A'],
      abbreviated: ['Oca', 'Şub', 'Mar', 'Nis', 'May', 'Haz', 'Tem', 'Ağu', 'Eyl', 'Eki', 'Kas', 'Ara'],
      wide: ['Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs', 'Haziran', 'Temmuz', 'Ağustos', 'Eylül', 'Ekim', 'Kasım', 'Aralık']
    };
    var dayValues$8 = {
      narrow: ['P', 'P', 'S', 'Ç', 'P', 'C', 'C'],
      short: ['Pz', 'Pt', 'Sa', 'Ça', 'Pe', 'Cu', 'Ct'],
      abbreviated: ['Paz', 'Pzt', 'Sal', 'Çar', 'Per', 'Cum', 'Cts'],
      wide: ['Pazar', 'Pazartesi', 'Salı', 'Çarşamba', 'Perşembe', 'Cuma', 'Cumartesi']
    };
    var dayPeriodValues$8 = {
      narrow: {
        am: 'öö',
        pm: 'ös',
        midnight: 'gy',
        noon: 'ö',
        morning: 'sa',
        afternoon: 'ös',
        evening: 'ak',
        night: 'ge'
      },
      abbreviated: {
        am: 'ÖÖ',
        pm: 'ÖS',
        midnight: 'gece yarısı',
        noon: 'öğle',
        morning: 'sabah',
        afternoon: 'öğleden sonra',
        evening: 'akşam',
        night: 'gece'
      },
      wide: {
        am: 'Ö.Ö.',
        pm: 'Ö.S.',
        midnight: 'gece yarısı',
        noon: 'öğle',
        morning: 'sabah',
        afternoon: 'öğleden sonra',
        evening: 'akşam',
        night: 'gece'
      }
    };
    var formattingDayPeriodValues$8 = {
      narrow: {
        am: 'öö',
        pm: 'ös',
        midnight: 'gy',
        noon: 'ö',
        morning: 'sa',
        afternoon: 'ös',
        evening: 'ak',
        night: 'ge'
      },
      abbreviated: {
        am: 'ÖÖ',
        pm: 'ÖS',
        midnight: 'gece yarısı',
        noon: 'öğlen',
        morning: 'sabahleyin',
        afternoon: 'öğleden sonra',
        evening: 'akşamleyin',
        night: 'geceleyin'
      },
      wide: {
        am: 'ö.ö.',
        pm: 'ö.s.',
        midnight: 'gece yarısı',
        noon: 'öğlen',
        morning: 'sabahleyin',
        afternoon: 'öğleden sonra',
        evening: 'akşamleyin',
        night: 'geceleyin'
      }
    };
    var ordinalNumber$8 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };
    var localize$8 = {
      ordinalNumber: ordinalNumber$8,
      era: buildLocalizeFn({
        values: eraValues$8,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$8,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$8,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$8,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$8,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$8,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$8 = /^(\d+)(\.)?/i;
    var parseOrdinalNumberPattern$8 = /\d+/i;
    var matchEraPatterns$8 = {
      narrow: /^(mö|ms)/i,
      abbreviated: /^(mö|ms)/i,
      wide: /^(milattan önce|milattan sonra)/i
    };
    var parseEraPatterns$8 = {
      any: [/(^mö|^milattan önce)/i, /(^ms|^milattan sonra)/i]
    };
    var matchQuarterPatterns$8 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]ç/i,
      wide: /^((i|İ)lk|(i|İ)kinci|üçüncü|son) çeyrek/i
    };
    var parseQuarterPatterns$8 = {
      any: [/1/i, /2/i, /3/i, /4/i],
      abbreviated: [/1ç/i, /2ç/i, /3ç/i, /4ç/i],
      wide: [/^(i|İ)lk çeyrek/i, /(i|İ)kinci çeyrek/i, /üçüncü çeyrek/i, /son çeyrek/i]
    };
    var matchMonthPatterns$8 = {
      narrow: /^[oşmnhtaek]/i,
      abbreviated: /^(oca|şub|mar|nis|may|haz|tem|ağu|eyl|eki|kas|ara)/i,
      wide: /^(ocak|şubat|mart|nisan|mayıs|haziran|temmuz|ağustos|eylül|ekim|kasım|aralık)/i
    };
    var parseMonthPatterns$8 = {
      narrow: [/^o/i, /^ş/i, /^m/i, /^n/i, /^m/i, /^h/i, /^t/i, /^a/i, /^e/i, /^e/i, /^k/i, /^a/i],
      any: [/^o/i, /^ş/i, /^mar/i, /^n/i, /^may/i, /^h/i, /^t/i, /^ağ/i, /^ey/i, /^ek/i, /^k/i, /^ar/i]
    };
    var matchDayPatterns$8 = {
      narrow: /^[psçc]/i,
      short: /^(pz|pt|sa|ça|pe|cu|ct)/i,
      abbreviated: /^(paz|pzt|sal|çar|per|cum|cts)/i,
      wide: /^(pazar(?!tesi)|pazartesi|salı|çarşamba|perşembe|cuma(?!rtesi)|cumartesi)/i
    };
    var parseDayPatterns$8 = {
      narrow: [/^p/i, /^p/i, /^s/i, /^ç/i, /^p/i, /^c/i, /^c/i],
      any: [/^pz/i, /^pt/i, /^sa/i, /^ça/i, /^pe/i, /^cu/i, /^ct/i],
      wide: [/^pazar(?!tesi)/i, /^pazartesi/i, /^salı/i, /^çarşamba/i, /^perşembe/i, /^cuma(?!rtesi)/i, /^cumartesi/i]
    };
    var matchDayPeriodPatterns$8 = {
      narrow: /^(öö|ös|gy|ö|sa|ös|ak|ge)/i,
      any: /^(ö\.?\s?[ös]\.?|öğleden sonra|gece yarısı|öğle|(sabah|öğ|akşam|gece)(leyin))/i
    };
    var parseDayPeriodPatterns$8 = {
      any: {
        am: /^ö\.?ö\.?/i,
        pm: /^ö\.?s\.?/i,
        midnight: /^(gy|gece yarısı)/i,
        noon: /^öğ/i,
        morning: /^sa/i,
        afternoon: /^öğleden sonra/i,
        evening: /^ak/i,
        night: /^ge/i
      }
    };
    var match$8 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$8,
        parsePattern: parseOrdinalNumberPattern$8,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$8,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$8,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$8,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$8,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$8,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$8,
        defaultParseWidth: 'any'
      })
    };

    var locale$8 = {
      code: 'tr',
      formatDistance: formatDistance$8,
      formatLong: formatLong$8,
      formatRelative: formatRelative$8,
      localize: localize$8,
      match: match$8,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$7 = {
      lessThanXSeconds: {
        one: 'بىر سىكۇنت ئىچىدە',
        other: 'سىكۇنت ئىچىدە {{count}}'
      },
      xSeconds: {
        one: 'بىر سىكۇنت',
        other: 'سىكۇنت {{count}}'
      },
      halfAMinute: 'يىرىم مىنۇت',
      lessThanXMinutes: {
        one: 'بىر مىنۇت ئىچىدە',
        other: 'مىنۇت ئىچىدە {{count}}'
      },
      xMinutes: {
        one: 'بىر مىنۇت',
        other: 'مىنۇت {{count}}'
      },
      aboutXHours: {
        one: 'تەخمىنەن بىر سائەت',
        other: 'سائەت {{count}} تەخمىنەن'
      },
      xHours: {
        one: 'بىر سائەت',
        other: 'سائەت {{count}}'
      },
      xDays: {
        one: 'بىر كۈن',
        other: 'كۈن {{count}}'
      },
      aboutXWeeks: {
        one: 'تەخمىنەن بىرھەپتە',
        other: 'ھەپتە {{count}} تەخمىنەن'
      },
      xWeeks: {
        one: 'بىرھەپتە',
        other: 'ھەپتە {{count}}'
      },
      aboutXMonths: {
        one: 'تەخمىنەن بىر ئاي',
        other: 'ئاي {{count}} تەخمىنەن'
      },
      xMonths: {
        one: 'بىر ئاي',
        other: 'ئاي {{count}}'
      },
      aboutXYears: {
        one: 'تەخمىنەن بىر يىل',
        other: 'يىل {{count}} تەخمىنەن'
      },
      xYears: {
        one: 'بىر يىل',
        other: 'يىل {{count}}'
      },
      overXYears: {
        one: 'بىر يىلدىن ئارتۇق',
        other: 'يىلدىن ئارتۇق {{count}}'
      },
      almostXYears: {
        one: 'ئاساسەن بىر يىل',
        other: 'يىل {{count}} ئاساسەن'
      }
    };
    var formatDistance$7 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$7[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result;
        } else {
          return result + ' بولدى';
        }
      }
      return result;
    };

    var dateFormats$7 = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$7 = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$7 = {
      full: "{{date}} 'دە' {{time}}",
      long: "{{date}} 'دە' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$7 = {
      date: buildFormatLongFn({
        formats: dateFormats$7,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$7,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$7,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$7 = {
      lastWeek: "'ئ‍ۆتكەن' eeee 'دە' p",
      yesterday: "'تۈنۈگۈن دە' p",
      today: "'بۈگۈن دە' p",
      tomorrow: "'ئەتە دە' p",
      nextWeek: "eeee 'دە' p",
      other: 'P'
    };
    var formatRelative$7 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$7[token];
    };

    var eraValues$7 = {
      narrow: ['ب', 'ك'],
      abbreviated: ['ب', 'ك'],
      wide: ['مىيلادىدىن بۇرۇن', 'مىيلادىدىن كىيىن']
    };
    var quarterValues$7 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1', '2', '3', '4'],
      wide: ['بىرىنجى چارەك', 'ئىككىنجى چارەك', 'ئۈچىنجى چارەك', 'تۆتىنجى چارەك']
    };
    var monthValues$7 = {
      narrow: ['ي', 'ف', 'م', 'ا', 'م', 'ى', 'ى', 'ا', 'س', 'ۆ', 'ن', 'د'],
      abbreviated: ['يانۋار', 'فېۋىرال', 'مارت', 'ئاپرىل', 'ماي', 'ئىيۇن', 'ئىيول', 'ئاۋغۇست', 'سىنتەبىر', 'ئۆكتەبىر', 'نويابىر', 'دىكابىر'],
      wide: ['يانۋار', 'فېۋىرال', 'مارت', 'ئاپرىل', 'ماي', 'ئىيۇن', 'ئىيول', 'ئاۋغۇست', 'سىنتەبىر', 'ئۆكتەبىر', 'نويابىر', 'دىكابىر']
    };
    var dayValues$7 = {
      narrow: ['ي', 'د', 'س', 'چ', 'پ', 'ج', 'ش'],
      short: ['ي', 'د', 'س', 'چ', 'پ', 'ج', 'ش'],
      abbreviated: ['يەكشەنبە', 'دۈشەنبە', 'سەيشەنبە', 'چارشەنبە', 'پەيشەنبە', 'جۈمە', 'شەنبە'],
      wide: ['يەكشەنبە', 'دۈشەنبە', 'سەيشەنبە', 'چارشەنبە', 'پەيشەنبە', 'جۈمە', 'شەنبە']
    };
    var dayPeriodValues$7 = {
      narrow: {
        am: 'ئە',
        pm: 'چ',
        midnight: 'ك',
        noon: 'چ',
        morning: 'ئەتىگەن',
        afternoon: 'چۈشتىن كىيىن',
        evening: 'ئاخشىم',
        night: 'كىچە'
      },
      abbreviated: {
        am: 'ئە',
        pm: 'چ',
        midnight: 'ك',
        noon: 'چ',
        morning: 'ئەتىگەن',
        afternoon: 'چۈشتىن كىيىن',
        evening: 'ئاخشىم',
        night: 'كىچە'
      },
      wide: {
        am: 'ئە',
        pm: 'چ',
        midnight: 'ك',
        noon: 'چ',
        morning: 'ئەتىگەن',
        afternoon: 'چۈشتىن كىيىن',
        evening: 'ئاخشىم',
        night: 'كىچە'
      }
    };
    var formattingDayPeriodValues$7 = {
      narrow: {
        am: 'ئە',
        pm: 'چ',
        midnight: 'ك',
        noon: 'چ',
        morning: 'ئەتىگەندە',
        afternoon: 'چۈشتىن كىيىن',
        evening: 'ئاخشامدا',
        night: 'كىچىدە'
      },
      abbreviated: {
        am: 'ئە',
        pm: 'چ',
        midnight: 'ك',
        noon: 'چ',
        morning: 'ئەتىگەندە',
        afternoon: 'چۈشتىن كىيىن',
        evening: 'ئاخشامدا',
        night: 'كىچىدە'
      },
      wide: {
        am: 'ئە',
        pm: 'چ',
        midnight: 'ك',
        noon: 'چ',
        morning: 'ئەتىگەندە',
        afternoon: 'چۈشتىن كىيىن',
        evening: 'ئاخشامدا',
        night: 'كىچىدە'
      }
    };
    var ordinalNumber$7 = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$7 = {
      ordinalNumber: ordinalNumber$7,
      era: buildLocalizeFn({
        values: eraValues$7,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$7,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$7,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$7,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$7,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$7,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$7 = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$7 = /\d+/i;
    var matchEraPatterns$7 = {
      narrow: /^(ب|ك)/i,
      wide: /^(مىيلادىدىن بۇرۇن|مىيلادىدىن كىيىن)/i
    };
    var parseEraPatterns$7 = {
      any: [/^بۇرۇن/i, /^كىيىن/i]
    };
    var matchQuarterPatterns$7 = {
      narrow: /^[1234]/i,
      abbreviated: /^چ[1234]/i,
      wide: /^چارەك [1234]/i
    };
    var parseQuarterPatterns$7 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$7 = {
      narrow: /^[يفمئامئ‍ئاسۆند]/i,
      abbreviated: /^(يانۋار|فېۋىرال|مارت|ئاپرىل|ماي|ئىيۇن|ئىيول|ئاۋغۇست|سىنتەبىر|ئۆكتەبىر|نويابىر|دىكابىر)/i,
      wide: /^(يانۋار|فېۋىرال|مارت|ئاپرىل|ماي|ئىيۇن|ئىيول|ئاۋغۇست|سىنتەبىر|ئۆكتەبىر|نويابىر|دىكابىر)/i
    };
    var parseMonthPatterns$7 = {
      narrow: [/^ي/i, /^ف/i, /^م/i, /^ا/i, /^م/i, /^ى‍/i, /^ى‍/i, /^ا‍/i, /^س/i, /^ۆ/i, /^ن/i, /^د/i],
      any: [/^يان/i, /^فېۋ/i, /^مار/i, /^ئاپ/i, /^ماي/i, /^ئىيۇن/i, /^ئىيول/i, /^ئاۋ/i, /^سىن/i, /^ئۆك/i, /^نوي/i, /^دىك/i]
    };
    var matchDayPatterns$7 = {
      narrow: /^[دسچپجشي]/i,
      short: /^(يە|دۈ|سە|چا|پە|جۈ|شە)/i,
      abbreviated: /^(يە|دۈ|سە|چا|پە|جۈ|شە)/i,
      wide: /^(يەكشەنبە|دۈشەنبە|سەيشەنبە|چارشەنبە|پەيشەنبە|جۈمە|شەنبە)/i
    };
    var parseDayPatterns$7 = {
      narrow: [/^ي/i, /^د/i, /^س/i, /^چ/i, /^پ/i, /^ج/i, /^ش/i],
      any: [/^ي/i, /^د/i, /^س/i, /^چ/i, /^پ/i, /^ج/i, /^ش/i]
    };
    var matchDayPeriodPatterns$7 = {
      narrow: /^(ئە|چ|ك|چ|(دە|ئەتىگەن) ( ئە‍|چۈشتىن كىيىن|ئاخشىم|كىچە))/i,
      any: /^(ئە|چ|ك|چ|(دە|ئەتىگەن) ( ئە‍|چۈشتىن كىيىن|ئاخشىم|كىچە))/i
    };
    var parseDayPeriodPatterns$7 = {
      any: {
        am: /^ئە/i,
        pm: /^چ/i,
        midnight: /^ك/i,
        noon: /^چ/i,
        morning: /ئەتىگەن/i,
        afternoon: /چۈشتىن كىيىن/i,
        evening: /ئاخشىم/i,
        night: /كىچە/i
      }
    };
    var match$7 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$7,
        parsePattern: parseOrdinalNumberPattern$7,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$7,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$7,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$7,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$7,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$7,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$7,
        defaultParseWidth: 'any'
      })
    };

    var locale$7 = {
      code: 'ug',
      formatDistance: formatDistance$7,
      formatLong: formatLong$7,
      formatRelative: formatRelative$7,
      localize: localize$7,
      match: match$7,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    function declension(scheme, count) {
      if (scheme.one !== undefined && count === 1) {
        return scheme.one;
      }
      var rem10 = count % 10;
      var rem100 = count % 100;
      if (rem10 === 1 && rem100 !== 11) {
        return scheme.singularNominative.replace('{{count}}', String(count));
      } else if (rem10 >= 2 && rem10 <= 4 && (rem100 < 10 || rem100 > 20)) {
        return scheme.singularGenitive.replace('{{count}}', String(count));
      } else {
        return scheme.pluralGenitive.replace('{{count}}', String(count));
      }
    }
    function buildLocalizeTokenFn(scheme) {
      return function (count, options) {
        if (options && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            if (scheme.future) {
              return declension(scheme.future, count);
            } else {
              return 'за ' + declension(scheme.regular, count);
            }
          } else {
            if (scheme.past) {
              return declension(scheme.past, count);
            } else {
              return declension(scheme.regular, count) + ' тому';
            }
          }
        } else {
          return declension(scheme.regular, count);
        }
      };
    }
    var halfAtMinute = function (_, options) {
      if (options && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'за півхвилини';
        } else {
          return 'півхвилини тому';
        }
      }
      return 'півхвилини';
    };
    var formatDistanceLocale$6 = {
      lessThanXSeconds: buildLocalizeTokenFn({
        regular: {
          one: 'менше секунди',
          singularNominative: 'менше {{count}} секунди',
          singularGenitive: 'менше {{count}} секунд',
          pluralGenitive: 'менше {{count}} секунд'
        },
        future: {
          one: 'менше, ніж за секунду',
          singularNominative: 'менше, ніж за {{count}} секунду',
          singularGenitive: 'менше, ніж за {{count}} секунди',
          pluralGenitive: 'менше, ніж за {{count}} секунд'
        }
      }),
      xSeconds: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} секунда',
          singularGenitive: '{{count}} секунди',
          pluralGenitive: '{{count}} секунд'
        },
        past: {
          singularNominative: '{{count}} секунду тому',
          singularGenitive: '{{count}} секунди тому',
          pluralGenitive: '{{count}} секунд тому'
        },
        future: {
          singularNominative: 'за {{count}} секунду',
          singularGenitive: 'за {{count}} секунди',
          pluralGenitive: 'за {{count}} секунд'
        }
      }),
      halfAMinute: halfAtMinute,
      lessThanXMinutes: buildLocalizeTokenFn({
        regular: {
          one: 'менше хвилини',
          singularNominative: 'менше {{count}} хвилини',
          singularGenitive: 'менше {{count}} хвилин',
          pluralGenitive: 'менше {{count}} хвилин'
        },
        future: {
          one: 'менше, ніж за хвилину',
          singularNominative: 'менше, ніж за {{count}} хвилину',
          singularGenitive: 'менше, ніж за {{count}} хвилини',
          pluralGenitive: 'менше, ніж за {{count}} хвилин'
        }
      }),
      xMinutes: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} хвилина',
          singularGenitive: '{{count}} хвилини',
          pluralGenitive: '{{count}} хвилин'
        },
        past: {
          singularNominative: '{{count}} хвилину тому',
          singularGenitive: '{{count}} хвилини тому',
          pluralGenitive: '{{count}} хвилин тому'
        },
        future: {
          singularNominative: 'за {{count}} хвилину',
          singularGenitive: 'за {{count}} хвилини',
          pluralGenitive: 'за {{count}} хвилин'
        }
      }),
      aboutXHours: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} години',
          singularGenitive: 'близько {{count}} годин',
          pluralGenitive: 'близько {{count}} годин'
        },
        future: {
          singularNominative: 'приблизно за {{count}} годину',
          singularGenitive: 'приблизно за {{count}} години',
          pluralGenitive: 'приблизно за {{count}} годин'
        }
      }),
      xHours: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} годину',
          singularGenitive: '{{count}} години',
          pluralGenitive: '{{count}} годин'
        }
      }),
      xDays: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} день',
          singularGenitive: '{{count}} дня',
          pluralGenitive: '{{count}} днів'
        }
      }),
      aboutXWeeks: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} тижня',
          singularGenitive: 'близько {{count}} тижнів',
          pluralGenitive: 'близько {{count}} тижнів'
        },
        future: {
          singularNominative: 'приблизно за {{count}} тиждень',
          singularGenitive: 'приблизно за {{count}} тижні',
          pluralGenitive: 'приблизно за {{count}} тижні'
        }
      }),
      xWeeks: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} тиждень',
          singularGenitive: '{{count}} тижня',
          pluralGenitive: '{{count}} тижні'
        }
      }),
      aboutXMonths: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} місяця',
          singularGenitive: 'близько {{count}} місяців',
          pluralGenitive: 'близько {{count}} місяців'
        },
        future: {
          singularNominative: 'приблизно за {{count}} місяць',
          singularGenitive: 'приблизно за {{count}} місяця',
          pluralGenitive: 'приблизно за {{count}} місяців'
        }
      }),
      xMonths: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} місяць',
          singularGenitive: '{{count}} місяця',
          pluralGenitive: '{{count}} місяців'
        }
      }),
      aboutXYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} року',
          singularGenitive: 'близько {{count}} років',
          pluralGenitive: 'близько {{count}} років'
        },
        future: {
          singularNominative: 'приблизно за {{count}} рік',
          singularGenitive: 'приблизно за {{count}} роки',
          pluralGenitive: 'приблизно за {{count}} років'
        }
      }),
      xYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} рік',
          singularGenitive: '{{count}} роки',
          pluralGenitive: '{{count}} років'
        }
      }),
      overXYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'більше {{count}} року',
          singularGenitive: 'більше {{count}} років',
          pluralGenitive: 'більше {{count}} років'
        },
        future: {
          singularNominative: 'більше, ніж за {{count}} рік',
          singularGenitive: 'більше, ніж за {{count}} роки',
          pluralGenitive: 'більше, ніж за {{count}} років'
        }
      }),
      almostXYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'майже {{count}} рік',
          singularGenitive: 'майже {{count}} роки',
          pluralGenitive: 'майже {{count}} років'
        },
        future: {
          singularNominative: 'майже за {{count}} рік',
          singularGenitive: 'майже за {{count}} роки',
          pluralGenitive: 'майже за {{count}} років'
        }
      })
    };
    var formatDistance$6 = function (token, count, options) {
      options = options || {};
      return formatDistanceLocale$6[token](count, options);
    };

    var dateFormats$6 = {
      full: "EEEE, do MMMM y 'р.'",
      long: "do MMMM y 'р.'",
      medium: "d MMM y 'р.'",
      short: 'dd.MM.y'
    };
    var timeFormats$6 = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$6 = {
      full: "{{date}} 'о' {{time}}",
      long: "{{date}} 'о' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$6 = {
      date: buildFormatLongFn({
        formats: dateFormats$6,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$6,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$6,
        defaultWidth: 'full'
      })
    };

    var accusativeWeekdays = ['неділю', 'понеділок', 'вівторок', 'середу', 'четвер', 'п’ятницю', 'суботу'];
    function lastWeek(day) {
      var weekday = accusativeWeekdays[day];
      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у минулу " + weekday + " о' p";
        case 1:
        case 2:
        case 4:
          return "'у минулий " + weekday + " о' p";
      }
    }
    function thisWeek(day) {
      var weekday = accusativeWeekdays[day];
      return "'у " + weekday + " о' p";
    }
    function nextWeek(day) {
      var weekday = accusativeWeekdays[day];
      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у наступну " + weekday + " о' p";
        case 1:
        case 2:
        case 4:
          return "'у наступний " + weekday + " о' p";
      }
    }
    var lastWeekFormat = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek(day);
      } else {
        return lastWeek(day);
      }
    };
    var nextWeekFormat = function (dirtyDate, baseDate, options) {
      var date = toDate(dirtyDate);
      var day = date.getUTCDay();
      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek(day);
      } else {
        return nextWeek(day);
      }
    };
    var formatRelativeLocale$6 = {
      lastWeek: lastWeekFormat,
      yesterday: "'вчора о' p",
      today: "'сьогодні о' p",
      tomorrow: "'завтра о' p",
      nextWeek: nextWeekFormat,
      other: 'P'
    };
    var formatRelative$6 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$6[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$6 = {
      narrow: ['до н.е.', 'н.е.'],
      abbreviated: ['до н. е.', 'н. е.'],
      wide: ['до нашої ери', 'нашої ери']
    };
    var quarterValues$6 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-й кв.', '2-й кв.', '3-й кв.', '4-й кв.'],
      wide: ['1-й квартал', '2-й квартал', '3-й квартал', '4-й квартал']
    };
    var monthValues$6 = {
      narrow: ['С', 'Л', 'Б', 'К', 'Т', 'Ч', 'Л', 'С', 'В', 'Ж', 'Л', 'Г'],
      abbreviated: ['січ.', 'лют.', 'берез.', 'квіт.', 'трав.', 'черв.', 'лип.', 'серп.', 'верес.', 'жовт.', 'листоп.', 'груд.'],
      wide: ['січень', 'лютий', 'березень', 'квітень', 'травень', 'червень', 'липень', 'серпень', 'вересень', 'жовтень', 'листопад', 'грудень']
    };
    var formattingMonthValues$1 = {
      narrow: ['С', 'Л', 'Б', 'К', 'Т', 'Ч', 'Л', 'С', 'В', 'Ж', 'Л', 'Г'],
      abbreviated: ['січ.', 'лют.', 'берез.', 'квіт.', 'трав.', 'черв.', 'лип.', 'серп.', 'верес.', 'жовт.', 'листоп.', 'груд.'],
      wide: ['січня', 'лютого', 'березня', 'квітня', 'травня', 'червня', 'липня', 'серпня', 'вересня', 'жовтня', 'листопада', 'грудня']
    };
    var dayValues$6 = {
      narrow: ['Н', 'П', 'В', 'С', 'Ч', 'П', 'С'],
      short: ['нд', 'пн', 'вт', 'ср', 'чт', 'пт', 'сб'],
      abbreviated: ['нед', 'пон', 'вів', 'сер', 'чтв', 'птн', 'суб'],
      wide: ['неділя', 'понеділок', 'вівторок', 'середа', 'четвер', 'п’ятниця', 'субота']
    };
    var dayPeriodValues$6 = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранок',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ніч'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранок',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ніч'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'північ',
        noon: 'полудень',
        morning: 'ранок',
        afternoon: 'день',
        evening: 'вечір',
        night: 'ніч'
      }
    };
    var formattingDayPeriodValues$6 = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранку',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночі'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранку',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночі'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'північ',
        noon: 'полудень',
        morning: 'ранку',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночі'
      }
    };
    var ordinalNumber$6 = function (dirtyNumber, options) {
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      var number = Number(dirtyNumber);
      var suffix;
      if (unit === 'date') {
        if (number === 3 || number === 23) {
          suffix = '-є';
        } else {
          suffix = '-е';
        }
      } else if (unit === 'minute' || unit === 'second' || unit === 'hour') {
        suffix = '-а';
      } else {
        suffix = '-й';
      }
      return number + suffix;
    };
    var localize$6 = {
      ordinalNumber: ordinalNumber$6,
      era: buildLocalizeFn({
        values: eraValues$6,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$6,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$6,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$1,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$6,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$6,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$6,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$6 = /^(\d+)(-?(е|й|є|а|я))?/i;
    var parseOrdinalNumberPattern$6 = /\d+/i;
    var matchEraPatterns$6 = {
      narrow: /^((до )?н\.?\s?е\.?)/i,
      abbreviated: /^((до )?н\.?\s?е\.?)/i,
      wide: /^(до нашої ери|нашої ери|наша ера)/i
    };
    var parseEraPatterns$6 = {
      any: [/^д/i, /^н/i]
    };
    var matchQuarterPatterns$6 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[иі]?й?)? кв.?/i,
      wide: /^[1234](-?[иі]?й?)? квартал/i
    };
    var parseQuarterPatterns$6 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$6 = {
      narrow: /^[слбктчвжг]/i,
      abbreviated: /^(січ|лют|бер(ез)?|квіт|трав|черв|лип|серп|вер(ес)?|жовт|лис(топ)?|груд)\.?/i,
      wide: /^(січень|січня|лютий|лютого|березень|березня|квітень|квітня|травень|травня|червня|червень|липень|липня|серпень|серпня|вересень|вересня|жовтень|жовтня|листопад[а]?|грудень|грудня)/i
    };
    var parseMonthPatterns$6 = {
      narrow: [/^с/i, /^л/i, /^б/i, /^к/i, /^т/i, /^ч/i, /^л/i, /^с/i, /^в/i, /^ж/i, /^л/i, /^г/i],
      any: [/^сі/i, /^лю/i, /^б/i, /^к/i, /^т/i, /^ч/i, /^лип/i, /^се/i, /^в/i, /^ж/i, /^лис/i, /^г/i]
    };
    var matchDayPatterns$6 = {
      narrow: /^[нпвсч]/i,
      short: /^(нд|пн|вт|ср|чт|пт|сб)\.?/i,
      abbreviated: /^(нед|пон|вів|сер|че?тв|птн?|суб)\.?/i,
      wide: /^(неділ[яі]|понеділ[ок][ка]|вівтор[ок][ка]|серед[аи]|четвер(га)?|п\W*?ятниц[яі]|субот[аи])/i
    };
    var parseDayPatterns$6 = {
      narrow: [/^н/i, /^п/i, /^в/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^н/i, /^п[он]/i, /^в/i, /^с[ер]/i, /^ч/i, /^п\W*?[ят]/i, /^с[уб]/i]
    };
    var matchDayPeriodPatterns$6 = {
      narrow: /^([дп]п|півн\.?|пол\.?|ранок|ранку|день|дня|веч\.?|ніч|ночі)/i,
      abbreviated: /^([дп]п|півн\.?|пол\.?|ранок|ранку|день|дня|веч\.?|ніч|ночі)/i,
      wide: /^([дп]п|північ|полудень|ранок|ранку|день|дня|вечір|вечора|ніч|ночі)/i
    };
    var parseDayPeriodPatterns$6 = {
      any: {
        am: /^дп/i,
        pm: /^пп/i,
        midnight: /^півн/i,
        noon: /^пол/i,
        morning: /^р/i,
        afternoon: /^д[ен]/i,
        evening: /^в/i,
        night: /^н/i
      }
    };
    var match$6 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$6,
        parsePattern: parseOrdinalNumberPattern$6,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$6,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$6,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$6,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$6,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$6,
        defaultParseWidth: 'any'
      })
    };

    var locale$6 = {
      code: 'uk',
      formatDistance: formatDistance$6,
      formatLong: formatLong$6,
      formatRelative: formatRelative$6,
      localize: localize$6,
      match: match$6,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$5 = {
      lessThanXSeconds: {
        one: 'sekunddan kam',
        other: '{{count}} sekunddan kam'
      },
      xSeconds: {
        one: '1 sekund',
        other: '{{count}} sekund'
      },
      halfAMinute: 'yarim minut',
      lessThanXMinutes: {
        one: 'bir minutdan kam',
        other: '{{count}} minutdan kam'
      },
      xMinutes: {
        one: '1 minut',
        other: '{{count}} minut'
      },
      aboutXHours: {
        one: 'tahminan 1 soat',
        other: 'tahminan {{count}} soat'
      },
      xHours: {
        one: '1 soat',
        other: '{{count}} soat'
      },
      xDays: {
        one: '1 kun',
        other: '{{count}} kun'
      },
      aboutXWeeks: {
        one: 'tahminan 1 hafta',
        other: 'tahminan {{count}} hafta'
      },
      xWeeks: {
        one: '1 hafta',
        other: '{{count}} hafta'
      },
      aboutXMonths: {
        one: 'tahminan 1 oy',
        other: 'tahminan {{count}} oy'
      },
      xMonths: {
        one: '1 oy',
        other: '{{count}} oy'
      },
      aboutXYears: {
        one: 'tahminan 1 yil',
        other: 'tahminan {{count}} yil'
      },
      xYears: {
        one: '1 yil',
        other: '{{count}} yil'
      },
      overXYears: {
        one: "1 yildan ko'p",
        other: "{{count}} yildan ko'p"
      },
      almostXYears: {
        one: 'deyarli 1 yil',
        other: 'deyarli {{count}} yil'
      }
    };
    var formatDistance$5 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$5[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' dan keyin';
        } else {
          return result + ' oldin';
        }
      }
      return result;
    };

    var dateFormats$5 = {
      full: 'EEEE, do MMMM, y',
      long: 'do MMMM, y',
      medium: 'd MMM, y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$5 = {
      full: 'h:mm:ss zzzz',
      long: 'h:mm:ss z',
      medium: 'h:mm:ss',
      short: 'h:mm'
    };
    var dateTimeFormats$5 = {
      any: '{{date}}, {{time}}'
    };
    var formatLong$5 = {
      date: buildFormatLongFn({
        formats: dateFormats$5,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$5,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$5,
        defaultWidth: 'any'
      })
    };

    var formatRelativeLocale$5 = {
      lastWeek: "'oldingi' eeee p 'da'",
      yesterday: "'kecha' p 'da'",
      today: "'bugun' p 'da'",
      tomorrow: "'ertaga' p 'da'",
      nextWeek: "eeee p 'da'",
      other: 'P'
    };
    var formatRelative$5 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$5[token];
    };

    var eraValues$5 = {
      narrow: ['M.A', 'M.'],
      abbreviated: ['M.A', 'M.'],
      wide: ['Miloddan Avvalgi', 'Milodiy']
    };
    var quarterValues$5 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['CH.1', 'CH.2', 'CH.3', 'CH.4'],
      wide: ['1-chi chorak', '2-chi chorak', '3-chi chorak', '4-chi chorak']
    };
    var monthValues$5 = {
      narrow: ['Y', 'F', 'M', 'A', 'M', 'I', 'I', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Yan', 'Fev', 'Mar', 'Apr', 'May', 'Iyun', 'Iyul', 'Avg', 'Sen', 'Okt', 'Noy', 'Dek'],
      wide: ['Yanvar', 'Fevral', 'Mart', 'Aprel', 'May', 'Iyun', 'Iyul', 'Avgust', 'Sentabr', 'Oktabr', 'Noyabr', 'Dekabr']
    };
    var dayValues$5 = {
      narrow: ['Y', 'D', 'S', 'CH', 'P', 'J', 'SH'],
      short: ['Ya', 'Du', 'Se', 'Cho', 'Pa', 'Ju', 'Sha'],
      abbreviated: ['Yak', 'Dush', 'Sesh', 'Chor', 'Pay', 'Jum', 'Shan'],
      wide: ['Yakshanba', 'Dushanba', 'Seshanba', 'Chorshanba', 'Payshanba', 'Juma', 'Shanba']
    };
    var dayPeriodValues$5 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'y.t',
        noon: 'p.',
        morning: 'ertalab',
        afternoon: 'tushdan keyin',
        evening: 'kechqurun',
        night: 'tun'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'yarim tun',
        noon: 'peshin',
        morning: 'ertalab',
        afternoon: 'tushdan keyin',
        evening: 'kechqurun',
        night: 'tun'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'yarim tun',
        noon: 'peshin',
        morning: 'ertalab',
        afternoon: 'tushdan keyin',
        evening: 'kechqurun',
        night: 'tun'
      }
    };
    var formattingDayPeriodValues$5 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'y.t',
        noon: 'p.',
        morning: 'ertalab',
        afternoon: 'tushdan keyin',
        evening: 'kechqurun',
        night: 'tun'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'yarim tun',
        noon: 'peshin',
        morning: 'ertalab',
        afternoon: 'tushdan keyin',
        evening: 'kechqurun',
        night: 'tun'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'yarim tun',
        noon: 'peshin',
        morning: 'ertalab',
        afternoon: 'tushdan keyin',
        evening: 'kechqurun',
        night: 'tun'
      }
    };
    var ordinalNumber$5 = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$5 = {
      ordinalNumber: ordinalNumber$5,
      era: buildLocalizeFn({
        values: eraValues$5,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$5,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$5,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$5,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$5,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$5,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$5 = /^(\d+)(chi)?/i;
    var parseOrdinalNumberPattern$5 = /\d+/i;
    var matchEraPatterns$5 = {
      narrow: /^(m\.a|m\.)/i,
      abbreviated: /^(m\.a\.?\s?m\.?)/i,
      wide: /^(miloddan avval|miloddan keyin)/i
    };
    var parseEraPatterns$5 = {
      any: [/^b/i, /^(a|c)/i]
    };
    var matchQuarterPatterns$5 = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](chi)? chorak/i
    };
    var parseQuarterPatterns$5 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$5 = {
      narrow: /^[yfmasond]/i,
      abbreviated: /^(yan|fev|mar|apr|may|iyun|iyul|avg|sen|okt|noy|dek)/i,
      wide: /^(yanvar|fevral|mart|aprel|may|iyun|iyul|avgust|sentabr|oktabr|noyabr|dekabr)/i
    };
    var parseMonthPatterns$5 = {
      narrow: [/^y/i, /^f/i, /^m/i, /^a/i, /^m/i, /^i/i, /^i/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ya/i, /^f/i, /^mar/i, /^ap/i, /^may/i, /^iyun/i, /^iyul/i, /^av/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$5 = {
      narrow: /^[ydschj]/i,
      short: /^(ya|du|se|cho|pa|ju|sha)/i,
      abbreviated: /^(yak|dush|sesh|chor|pay|jum|shan)/i,
      wide: /^(yakshanba|dushanba|seshanba|chorshanba|payshanba|juma|shanba)/i
    };
    var parseDayPatterns$5 = {
      narrow: [/^y/i, /^d/i, /^s/i, /^ch/i, /^p/i, /^j/i, /^sh/i],
      any: [/^ya/i, /^d/i, /^se/i, /^ch/i, /^p/i, /^j/i, /^sh/i]
    };
    var matchDayPeriodPatterns$5 = {
      narrow: /^(a|p|y\.t|p| (ertalab|tushdan keyin|kechqurun|tun))/i,
      any: /^([ap]\.?\s?m\.?|yarim tun|peshin| (ertalab|tushdan keyin|kechqurun|tun))/i
    };
    var parseDayPeriodPatterns$5 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^y\.t/i,
        noon: /^pe/i,
        morning: /ertalab/i,
        afternoon: /tushdan keyin/i,
        evening: /kechqurun/i,
        night: /tun/i
      }
    };
    var match$5 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$5,
        parsePattern: parseOrdinalNumberPattern$5,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$5,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$5,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$5,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$5,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$5,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$5,
        defaultParseWidth: 'any'
      })
    };

    var locale$5 = {
      code: 'uz',
      formatDistance: formatDistance$5,
      formatLong: formatLong$5,
      formatRelative: formatRelative$5,
      localize: localize$5,
      match: match$5,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$4 = {
      lessThanXSeconds: {
        one: '1 сониядан кам',
        other: '{{count}} сониядан кам'
      },
      xSeconds: {
        one: '1 сония',
        other: '{{count}} сония'
      },
      halfAMinute: 'ярим дақиқа',
      lessThanXMinutes: {
        one: '1 дақиқадан кам',
        other: '{{count}} дақиқадан кам'
      },
      xMinutes: {
        one: '1 дақиқа',
        other: '{{count}} дақиқа'
      },
      aboutXHours: {
        one: 'тахминан 1 соат',
        other: 'тахминан {{count}} соат'
      },
      xHours: {
        one: '1 соат',
        other: '{{count}} соат'
      },
      xDays: {
        one: '1 кун',
        other: '{{count}} кун'
      },
      aboutXWeeks: {
        one: 'тахминан 1 хафта',
        other: 'тахминан {{count}} хафта'
      },
      xWeeks: {
        one: '1 хафта',
        other: '{{count}} хафта'
      },
      aboutXMonths: {
        one: 'тахминан 1 ой',
        other: 'тахминан {{count}} ой'
      },
      xMonths: {
        one: '1 ой',
        other: '{{count}} ой'
      },
      aboutXYears: {
        one: 'тахминан 1 йил',
        other: 'тахминан {{count}} йил'
      },
      xYears: {
        one: '1 йил',
        other: '{{count}} йил'
      },
      overXYears: {
        one: '1 йилдан кўп',
        other: '{{count}} йилдан кўп'
      },
      almostXYears: {
        one: 'деярли 1 йил',
        other: 'деярли {{count}} йил'
      }
    };
    var formatDistance$4 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$4[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + 'дан кейин';
        } else {
          return result + ' олдин';
        }
      }
      return result;
    };

    var dateFormats$4 = {
      full: 'EEEE, do MMMM, y',
      long: 'do MMMM, y',
      medium: 'd MMM, y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$4 = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$4 = {
      any: '{{date}}, {{time}}'
    };
    var formatLong$4 = {
      date: buildFormatLongFn({
        formats: dateFormats$4,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$4,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$4,
        defaultWidth: 'any'
      })
    };

    var formatRelativeLocale$4 = {
      lastWeek: "'ўтган' eeee p 'да'",
      yesterday: "'кеча' p 'да'",
      today: "'бугун' p 'да'",
      tomorrow: "'эртага' p 'да'",
      nextWeek: "eeee p 'да'",
      other: 'P'
    };
    var formatRelative$4 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$4[token];
    };

    var eraValues$4 = {
      narrow: ['М.А', 'М'],
      abbreviated: ['М.А', 'М'],
      wide: ['Милоддан Аввалги', 'Милодий']
    };
    var quarterValues$4 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-чор.', '2-чор.', '3-чор.', '4-чор.'],
      wide: ['1-чорак', '2-чорак', '3-чорак', '4-чорак']
    };
    var monthValues$4 = {
      narrow: ['Я', 'Ф', 'М', 'А', 'М', 'И', 'И', 'А', 'С', 'О', 'Н', 'Д'],
      abbreviated: ['янв', 'фев', 'мар', 'апр', 'май', 'июн', 'июл', 'авг', 'сен', 'окт', 'ноя', 'дек'],
      wide: ['январ', 'феврал', 'март', 'апрел', 'май', 'июн', 'июл', 'август', 'сентабр', 'октабр', 'ноябр', 'декабр']
    };
    var dayValues$4 = {
      narrow: ['Я', 'Д', 'С', 'Ч', 'П', 'Ж', 'Ш'],
      short: ['як', 'ду', 'се', 'чо', 'па', 'жу', 'ша'],
      abbreviated: ['якш', 'душ', 'сеш', 'чор', 'пай', 'жум', 'шан'],
      wide: ['якшанба', 'душанба', 'сешанба', 'чоршанба', 'пайшанба', 'жума', 'шанба']
    };
    var dayPeriodValues$4 = {
      any: {
        am: 'П.О.',
        pm: 'П.К.',
        midnight: 'ярим тун',
        noon: 'пешин',
        morning: 'эрталаб',
        afternoon: 'пешиндан кейин',
        evening: 'кечаси',
        night: 'тун'
      }
    };
    var formattingDayPeriodValues$4 = {
      any: {
        am: 'П.О.',
        pm: 'П.К.',
        midnight: 'ярим тун',
        noon: 'пешин',
        morning: 'эрталаб',
        afternoon: 'пешиндан кейин',
        evening: 'кечаси',
        night: 'тун'
      }
    };
    var ordinalNumber$4 = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };
    var localize$4 = {
      ordinalNumber: ordinalNumber$4,
      era: buildLocalizeFn({
        values: eraValues$4,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$4,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$4,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$4,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$4,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$4,
        defaultFormattingWidth: 'any'
      })
    };

    var matchOrdinalNumberPattern$4 = /^(\d+)(чи)?/i;
    var parseOrdinalNumberPattern$4 = /\d+/i;
    var matchEraPatterns$4 = {
      narrow: /^(м\.а|м\.)/i,
      abbreviated: /^(м\.а|м\.)/i,
      wide: /^(милоддан аввал|милоддан кейин)/i
    };
    var parseEraPatterns$4 = {
      any: [/^м/i, /^а/i]
    };
    var matchQuarterPatterns$4 = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234]-чор./i,
      wide: /^[1234]-чорак/i
    };
    var parseQuarterPatterns$4 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$4 = {
      narrow: /^[яфмамииасонд]/i,
      abbreviated: /^(янв|фев|мар|апр|май|июн|июл|авг|сен|окт|ноя|дек)/i,
      wide: /^(январ|феврал|март|апрел|май|июн|июл|август|сентабр|октабр|ноябр|декабр)/i
    };
    var parseMonthPatterns$4 = {
      narrow: [/^я/i, /^ф/i, /^м/i, /^а/i, /^м/i, /^и/i, /^и/i, /^а/i, /^с/i, /^о/i, /^н/i, /^д/i],
      any: [/^я/i, /^ф/i, /^мар/i, /^ап/i, /^май/i, /^июн/i, /^июл/i, /^ав/i, /^с/i, /^о/i, /^н/i, /^д/i]
    };
    var matchDayPatterns$4 = {
      narrow: /^[ядсчпжш]/i,
      short: /^(як|ду|се|чо|па|жу|ша)/i,
      abbreviated: /^(якш|душ|сеш|чор|пай|жум|шан)/i,
      wide: /^(якшанба|душанба|сешанба|чоршанба|пайшанба|жума|шанба)/i
    };
    var parseDayPatterns$4 = {
      narrow: [/^я/i, /^д/i, /^с/i, /^ч/i, /^п/i, /^ж/i, /^ш/i],
      any: [/^як/i, /^ду/i, /^се/i, /^чор/i, /^пай/i, /^жу/i, /^шан/i]
    };
    var matchDayPeriodPatterns$4 = {
      any: /^(п\.о\.|п\.к\.|ярим тун|пешиндан кейин|(эрталаб|пешиндан кейин|кечаси|тун))/i
    };
    var parseDayPeriodPatterns$4 = {
      any: {
        am: /^п\.о\./i,
        pm: /^п\.к\./i,
        midnight: /^ярим тун/i,
        noon: /^пешиндан кейин/i,
        morning: /эрталаб/i,
        afternoon: /пешиндан кейин/i,
        evening: /кечаси/i,
        night: /тун/i
      }
    };
    var match$4 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$4,
        parsePattern: parseOrdinalNumberPattern$4,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$4,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$4,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$4,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$4,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$4,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$4,
        defaultParseWidth: 'any'
      })
    };

    var locale$4 = {
      code: 'uz-Cyrl',
      formatDistance: formatDistance$4,
      formatLong: formatLong$4,
      formatRelative: formatRelative$4,
      localize: localize$4,
      match: match$4,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$3 = {
      lessThanXSeconds: {
        one: 'dưới 1 giây',
        other: 'dưới {{count}} giây'
      },
      xSeconds: {
        one: '1 giây',
        other: '{{count}} giây'
      },
      halfAMinute: 'nửa phút',
      lessThanXMinutes: {
        one: 'dưới 1 phút',
        other: 'dưới {{count}} phút'
      },
      xMinutes: {
        one: '1 phút',
        other: '{{count}} phút'
      },
      aboutXHours: {
        one: 'khoảng 1 giờ',
        other: 'khoảng {{count}} giờ'
      },
      xHours: {
        one: '1 giờ',
        other: '{{count}} giờ'
      },
      xDays: {
        one: '1 ngày',
        other: '{{count}} ngày'
      },
      aboutXWeeks: {
        one: 'khoảng 1 tuần',
        other: 'khoảng {{count}} tuần'
      },
      xWeeks: {
        one: '1 tuần',
        other: '{{count}} tuần'
      },
      aboutXMonths: {
        one: 'khoảng 1 tháng',
        other: 'khoảng {{count}} tháng'
      },
      xMonths: {
        one: '1 tháng',
        other: '{{count}} tháng'
      },
      aboutXYears: {
        one: 'khoảng 1 năm',
        other: 'khoảng {{count}} năm'
      },
      xYears: {
        one: '1 năm',
        other: '{{count}} năm'
      },
      overXYears: {
        one: 'hơn 1 năm',
        other: 'hơn {{count}} năm'
      },
      almostXYears: {
        one: 'gần 1 năm',
        other: 'gần {{count}} năm'
      }
    };
    var formatDistance$3 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$3[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' nữa';
        } else {
          return result + ' trước';
        }
      }
      return result;
    };

    var dateFormats$3 = {
      full: "EEEE, 'ngày' d MMMM 'năm' y",
      long: "'ngày' d MMMM 'năm' y",
      medium: "d MMM 'năm' y",
      short: 'dd/MM/y'
    };
    var timeFormats$3 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$3 = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$3 = {
      date: buildFormatLongFn({
        formats: dateFormats$3,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$3,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$3,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$3 = {
      lastWeek: "eeee 'tuần trước vào lúc' p",
      yesterday: "'hôm qua vào lúc' p",
      today: "'hôm nay vào lúc' p",
      tomorrow: "'ngày mai vào lúc' p",
      nextWeek: "eeee 'tới vào lúc' p",
      other: 'P'
    };
    var formatRelative$3 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$3[token];
    };

    var eraValues$3 = {
      narrow: ['TCN', 'SCN'],
      abbreviated: ['trước CN', 'sau CN'],
      wide: ['trước Công Nguyên', 'sau Công Nguyên']
    };
    var quarterValues$3 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['Quý 1', 'Quý 2', 'Quý 3', 'Quý 4']
    };
    var formattingQuarterValues = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['quý I', 'quý II', 'quý III', 'quý IV']
    };
    var monthValues$3 = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['Thg 1', 'Thg 2', 'Thg 3', 'Thg 4', 'Thg 5', 'Thg 6', 'Thg 7', 'Thg 8', 'Thg 9', 'Thg 10', 'Thg 11', 'Thg 12'],
      wide: ['Tháng Một', 'Tháng Hai', 'Tháng Ba', 'Tháng Tư', 'Tháng Năm', 'Tháng Sáu', 'Tháng Bảy', 'Tháng Tám', 'Tháng Chín', 'Tháng Mười', 'Tháng Mười Một', 'Tháng Mười Hai']
    };
    var formattingMonthValues = {
      narrow: ['01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12'],
      abbreviated: ['thg 1', 'thg 2', 'thg 3', 'thg 4', 'thg 5', 'thg 6', 'thg 7', 'thg 8', 'thg 9', 'thg 10', 'thg 11', 'thg 12'],
      wide: ['tháng 01', 'tháng 02', 'tháng 03', 'tháng 04', 'tháng 05', 'tháng 06', 'tháng 07', 'tháng 08', 'tháng 09', 'tháng 10', 'tháng 11', 'tháng 12']
    };
    var dayValues$3 = {
      narrow: ['CN', 'T2', 'T3', 'T4', 'T5', 'T6', 'T7'],
      short: ['CN', 'Th 2', 'Th 3', 'Th 4', 'Th 5', 'Th 6', 'Th 7'],
      abbreviated: ['CN', 'Thứ 2', 'Thứ 3', 'Thứ 4', 'Thứ 5', 'Thứ 6', 'Thứ 7'],
      wide: ['Chủ Nhật', 'Thứ Hai', 'Thứ Ba', 'Thứ Tư', 'Thứ Năm', 'Thứ Sáu', 'Thứ Bảy']
    };
    var dayPeriodValues$3 = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'nửa đêm',
        noon: 'tr',
        morning: 'sg',
        afternoon: 'ch',
        evening: 'tối',
        night: 'đêm'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'nửa đêm',
        noon: 'trưa',
        morning: 'sáng',
        afternoon: 'chiều',
        evening: 'tối',
        night: 'đêm'
      },
      wide: {
        am: 'SA',
        pm: 'CH',
        midnight: 'nửa đêm',
        noon: 'trưa',
        morning: 'sáng',
        afternoon: 'chiều',
        evening: 'tối',
        night: 'đêm'
      }
    };
    var formattingDayPeriodValues$3 = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'nửa đêm',
        noon: 'tr',
        morning: 'sg',
        afternoon: 'ch',
        evening: 'tối',
        night: 'đêm'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'nửa đêm',
        noon: 'trưa',
        morning: 'sáng',
        afternoon: 'chiều',
        evening: 'tối',
        night: 'đêm'
      },
      wide: {
        am: 'SA',
        pm: 'CH',
        midnight: 'nửa đêm',
        noon: 'giữa trưa',
        morning: 'vào buổi sáng',
        afternoon: 'vào buổi chiều',
        evening: 'vào buổi tối',
        night: 'vào ban đêm'
      }
    };
    var ordinalNumber$3 = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      if (unit === 'quarter') {
        switch (number) {
          case 1:
            return 'I';
          case 2:
            return 'II';
          case 3:
            return 'III';
          case 4:
            return 'IV';
        }
      } else if (unit === 'day') {
        switch (number) {
          case 1:
            return 'thứ 2';
          case 2:
            return 'thứ 3';
          case 3:
            return 'thứ 4';
          case 4:
            return 'thứ 5';
          case 5:
            return 'thứ 6';
          case 6:
            return 'thứ 7';
          case 7:
            return 'chủ nhật';
        }
      } else if (unit === 'week') {
        if (number === 1) {
          return 'thứ nhất';
        } else {
          return 'thứ ' + number;
        }
      } else if (unit === 'dayOfYear') {
        if (number === 1) {
          return 'đầu tiên';
        } else {
          return 'thứ ' + number;
        }
      }
      return String(number);
    };
    var localize$3 = {
      ordinalNumber: ordinalNumber$3,
      era: buildLocalizeFn({
        values: eraValues$3,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$3,
        defaultWidth: 'wide',
        formattingValues: formattingQuarterValues,
        defaultFormattingWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$3,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$3,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$3,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$3,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$3 = /^(\d+)/i;
    var parseOrdinalNumberPattern$3 = /\d+/i;
    var matchEraPatterns$3 = {
      narrow: /^(tcn|scn)/i,
      abbreviated: /^(trước CN|sau CN)/i,
      wide: /^(trước Công Nguyên|sau Công Nguyên)/i
    };
    var parseEraPatterns$3 = {
      any: [/^t/i, /^s/i]
    };
    var matchQuarterPatterns$3 = {
      narrow: /^([1234]|i{1,3}v?)/i,
      abbreviated: /^q([1234]|i{1,3}v?)/i,
      wide: /^quý ([1234]|i{1,3}v?)/i
    };
    var parseQuarterPatterns$3 = {
      any: [/(1|i)$/i, /(2|ii)$/i, /(3|iii)$/i, /(4|iv)$/i]
    };
    var matchMonthPatterns$3 = {
      narrow: /^(0?[2-9]|10|11|12|0?1)/i,
      abbreviated: /^thg[ _]?(0?[1-9](?!\d)|10|11|12)/i,
      wide: /^tháng ?(Một|Hai|Ba|Tư|Năm|Sáu|Bảy|Tám|Chín|Mười|Mười ?Một|Mười ?Hai|0?[1-9](?!\d)|10|11|12)/i
    };
    var parseMonthPatterns$3 = {
      narrow: [/0?1$/i, /0?2/i, /3/, /4/, /5/, /6/, /7/, /8/, /9/, /10/, /11/, /12/],
      abbreviated: [/^thg[ _]?0?1(?!\d)/i, /^thg[ _]?0?2/i, /^thg[ _]?0?3/i, /^thg[ _]?0?4/i, /^thg[ _]?0?5/i, /^thg[ _]?0?6/i, /^thg[ _]?0?7/i, /^thg[ _]?0?8/i, /^thg[ _]?0?9/i, /^thg[ _]?10/i, /^thg[ _]?11/i, /^thg[ _]?12/i],
      wide: [/^tháng ?(Một|0?1(?!\d))/i, /^tháng ?(Hai|0?2)/i, /^tháng ?(Ba|0?3)/i, /^tháng ?(Tư|0?4)/i, /^tháng ?(Năm|0?5)/i, /^tháng ?(Sáu|0?6)/i, /^tháng ?(Bảy|0?7)/i, /^tháng ?(Tám|0?8)/i, /^tháng ?(Chín|0?9)/i, /^tháng ?(Mười|10)/i, /^tháng ?(Mười ?Một|11)/i, /^tháng ?(Mười ?Hai|12)/i]
    };
    var matchDayPatterns$3 = {
      narrow: /^(CN|T2|T3|T4|T5|T6|T7)/i,
      short: /^(CN|Th ?2|Th ?3|Th ?4|Th ?5|Th ?6|Th ?7)/i,
      abbreviated: /^(CN|Th ?2|Th ?3|Th ?4|Th ?5|Th ?6|Th ?7)/i,
      wide: /^(Chủ ?Nhật|Chúa ?Nhật|thứ ?Hai|thứ ?Ba|thứ ?Tư|thứ ?Năm|thứ ?Sáu|thứ ?Bảy)/i
    };
    var parseDayPatterns$3 = {
      narrow: [/CN/i, /2/i, /3/i, /4/i, /5/i, /6/i, /7/i],
      short: [/CN/i, /2/i, /3/i, /4/i, /5/i, /6/i, /7/i],
      abbreviated: [/CN/i, /2/i, /3/i, /4/i, /5/i, /6/i, /7/i],
      wide: [/(Chủ|Chúa) ?Nhật/i, /Hai/i, /Ba/i, /Tư/i, /Năm/i, /Sáu/i, /Bảy/i]
    };
    var matchDayPeriodPatterns$3 = {
      narrow: /^(a|p|nửa đêm|trưa|(giờ) (sáng|chiều|tối|đêm))/i,
      abbreviated: /^(am|pm|nửa đêm|trưa|(giờ) (sáng|chiều|tối|đêm))/i,
      wide: /^(ch[^i]*|sa|nửa đêm|trưa|(giờ) (sáng|chiều|tối|đêm))/i
    };
    var parseDayPeriodPatterns$3 = {
      any: {
        am: /^(a|sa)/i,
        pm: /^(p|ch[^i]*)/i,
        midnight: /nửa đêm/i,
        noon: /trưa/i,
        morning: /sáng/i,
        afternoon: /chiều/i,
        evening: /tối/i,
        night: /^đêm/i
      }
    };
    var match$3 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$3,
        parsePattern: parseOrdinalNumberPattern$3,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$3,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$3,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$3,
        defaultParseWidth: 'wide'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$3,
        defaultParseWidth: 'wide'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$3,
        defaultParseWidth: 'any'
      })
    };

    var locale$3 = {
      code: 'vi',
      formatDistance: formatDistance$3,
      formatLong: formatLong$3,
      formatRelative: formatRelative$3,
      localize: localize$3,
      match: match$3,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale$2 = {
      lessThanXSeconds: {
        one: '不到 1 秒',
        other: '不到 {{count}} 秒'
      },
      xSeconds: {
        one: '1 秒',
        other: '{{count}} 秒'
      },
      halfAMinute: '半分钟',
      lessThanXMinutes: {
        one: '不到 1 分钟',
        other: '不到 {{count}} 分钟'
      },
      xMinutes: {
        one: '1 分钟',
        other: '{{count}} 分钟'
      },
      xHours: {
        one: '1 小时',
        other: '{{count}} 小时'
      },
      aboutXHours: {
        one: '大约 1 小时',
        other: '大约 {{count}} 小时'
      },
      xDays: {
        one: '1 天',
        other: '{{count}} 天'
      },
      aboutXWeeks: {
        one: '大约 1 个星期',
        other: '大约 {{count}} 个星期'
      },
      xWeeks: {
        one: '1 个星期',
        other: '{{count}} 个星期'
      },
      aboutXMonths: {
        one: '大约 1 个月',
        other: '大约 {{count}} 个月'
      },
      xMonths: {
        one: '1 个月',
        other: '{{count}} 个月'
      },
      aboutXYears: {
        one: '大约 1 年',
        other: '大约 {{count}} 年'
      },
      xYears: {
        one: '1 年',
        other: '{{count}} 年'
      },
      overXYears: {
        one: '超过 1 年',
        other: '超过 {{count}} 年'
      },
      almostXYears: {
        one: '将近 1 年',
        other: '将近 {{count}} 年'
      }
    };
    var formatDistance$2 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$2[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + '内';
        } else {
          return result + '前';
        }
      }
      return result;
    };

    var dateFormats$2 = {
      full: "y'年'M'月'd'日' EEEE",
      long: "y'年'M'月'd'日'",
      medium: 'yyyy-MM-dd',
      short: 'yy-MM-dd'
    };
    var timeFormats$2 = {
      full: 'zzzz a h:mm:ss',
      long: 'z a h:mm:ss',
      medium: 'a h:mm:ss',
      short: 'a h:mm'
    };
    var dateTimeFormats$2 = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$2 = {
      date: buildFormatLongFn({
        formats: dateFormats$2,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$2,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$2,
        defaultWidth: 'full'
      })
    };

    function checkWeek(date, baseDate, options) {
      var baseFormat = 'eeee p';
      if (isSameUTCWeek(date, baseDate, options)) {
        return baseFormat;
      } else if (date.getTime() > baseDate.getTime()) {
        return "'下个'" + baseFormat;
      }
      return "'上个'" + baseFormat;
    }
    var formatRelativeLocale$2 = {
      lastWeek: checkWeek,
      yesterday: "'昨天' p",
      today: "'今天' p",
      tomorrow: "'明天' p",
      nextWeek: checkWeek,
      other: 'PP p'
    };
    var formatRelative$2 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$2[token];
      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }
      return format;
    };

    var eraValues$2 = {
      narrow: ['前', '公元'],
      abbreviated: ['前', '公元'],
      wide: ['公元前', '公元']
    };
    var quarterValues$2 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['第一季', '第二季', '第三季', '第四季'],
      wide: ['第一季度', '第二季度', '第三季度', '第四季度']
    };
    var monthValues$2 = {
      narrow: ['一', '二', '三', '四', '五', '六', '七', '八', '九', '十', '十一', '十二'],
      abbreviated: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      wide: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    };
    var dayValues$2 = {
      narrow: ['日', '一', '二', '三', '四', '五', '六'],
      short: ['日', '一', '二', '三', '四', '五', '六'],
      abbreviated: ['周日', '周一', '周二', '周三', '周四', '周五', '周六'],
      wide: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六']
    };
    var dayPeriodValues$2 = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      }
    };
    var formattingDayPeriodValues$2 = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      }
    };
    var ordinalNumber$2 = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      switch (options === null || options === void 0 ? void 0 : options.unit) {
        case 'date':
          return number.toString() + '日';
        case 'hour':
          return number.toString() + '时';
        case 'minute':
          return number.toString() + '分';
        case 'second':
          return number.toString() + '秒';
        default:
          return '第 ' + number.toString();
      }
    };
    var localize$2 = {
      ordinalNumber: ordinalNumber$2,
      era: buildLocalizeFn({
        values: eraValues$2,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$2,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$2,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$2,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$2,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$2,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$2 = /^(第\s*)?\d+(日|时|分|秒)?/i;
    var parseOrdinalNumberPattern$2 = /\d+/i;
    var matchEraPatterns$2 = {
      narrow: /^(前)/i,
      abbreviated: /^(前)/i,
      wide: /^(公元前|公元)/i
    };
    var parseEraPatterns$2 = {
      any: [/^(前)/i, /^(公元)/i]
    };
    var matchQuarterPatterns$2 = {
      narrow: /^[1234]/i,
      abbreviated: /^第[一二三四]刻/i,
      wide: /^第[一二三四]刻钟/i
    };
    var parseQuarterPatterns$2 = {
      any: [/(1|一)/i, /(2|二)/i, /(3|三)/i, /(4|四)/i]
    };
    var matchMonthPatterns$2 = {
      narrow: /^(一|二|三|四|五|六|七|八|九|十[二一])/i,
      abbreviated: /^(一|二|三|四|五|六|七|八|九|十[二一]|\d|1[12])月/i,
      wide: /^(一|二|三|四|五|六|七|八|九|十[二一])月/i
    };
    var parseMonthPatterns$2 = {
      narrow: [/^一/i, /^二/i, /^三/i, /^四/i, /^五/i, /^六/i, /^七/i, /^八/i, /^九/i, /^十(?!(一|二))/i, /^十一/i, /^十二/i],
      any: [/^一|1/i, /^二|2/i, /^三|3/i, /^四|4/i, /^五|5/i, /^六|6/i, /^七|7/i, /^八|8/i, /^九|9/i, /^十(?!(一|二))|10/i, /^十一|11/i, /^十二|12/i]
    };
    var matchDayPatterns$2 = {
      narrow: /^[一二三四五六日]/i,
      short: /^[一二三四五六日]/i,
      abbreviated: /^周[一二三四五六日]/i,
      wide: /^星期[一二三四五六日]/i
    };
    var parseDayPatterns$2 = {
      any: [/日/i, /一/i, /二/i, /三/i, /四/i, /五/i, /六/i]
    };
    var matchDayPeriodPatterns$2 = {
      any: /^(上午?|下午?|午夜|[中正]午|早上?|下午|晚上?|凌晨|)/i
    };
    var parseDayPeriodPatterns$2 = {
      any: {
        am: /^上午?/i,
        pm: /^下午?/i,
        midnight: /^午夜/i,
        noon: /^[中正]午/i,
        morning: /^早上/i,
        afternoon: /^下午/i,
        evening: /^晚上?/i,
        night: /^凌晨/i
      }
    };
    var match$2 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$2,
        parsePattern: parseOrdinalNumberPattern$2,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$2,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$2,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$2,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$2,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$2,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$2,
        defaultParseWidth: 'any'
      })
    };

    var locale$2 = {
      code: 'zh-CN',
      formatDistance: formatDistance$2,
      formatLong: formatLong$2,
      formatRelative: formatRelative$2,
      localize: localize$2,
      match: match$2,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var formatDistanceLocale$1 = {
      lessThanXSeconds: {
        one: '少於 1 秒',
        other: '少於 {{count}} 秒'
      },
      xSeconds: {
        one: '1 秒',
        other: '{{count}} 秒'
      },
      halfAMinute: '半分鐘',
      lessThanXMinutes: {
        one: '少於 1 分鐘',
        other: '少於 {{count}} 分鐘'
      },
      xMinutes: {
        one: '1 分鐘',
        other: '{{count}} 分鐘'
      },
      xHours: {
        one: '1 小時',
        other: '{{count}} 小時'
      },
      aboutXHours: {
        one: '大約 1 小時',
        other: '大約 {{count}} 小時'
      },
      xDays: {
        one: '1 天',
        other: '{{count}} 天'
      },
      aboutXWeeks: {
        one: '大約 1 個星期',
        other: '大約 {{count}} 個星期'
      },
      xWeeks: {
        one: '1 個星期',
        other: '{{count}} 個星期'
      },
      aboutXMonths: {
        one: '大約 1 個月',
        other: '大約 {{count}} 個月'
      },
      xMonths: {
        one: '1 個月',
        other: '{{count}} 個月'
      },
      aboutXYears: {
        one: '大約 1 年',
        other: '大約 {{count}} 年'
      },
      xYears: {
        one: '1 年',
        other: '{{count}} 年'
      },
      overXYears: {
        one: '超過 1 年',
        other: '超過 {{count}} 年'
      },
      almostXYears: {
        one: '將近 1 年',
        other: '將近 {{count}} 年'
      }
    };
    var formatDistance$1 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$1[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + '內';
        } else {
          return result + '前';
        }
      }
      return result;
    };

    var dateFormats$1 = {
      full: "y'年'M'月'd'日' EEEE",
      long: "y'年'M'月'd'日'",
      medium: 'yyyy-MM-dd',
      short: 'yy-MM-dd'
    };
    var timeFormats$1 = {
      full: 'zzzz a h:mm:ss',
      long: 'z a h:mm:ss',
      medium: 'a h:mm:ss',
      short: 'a h:mm'
    };
    var dateTimeFormats$1 = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$1 = {
      date: buildFormatLongFn({
        formats: dateFormats$1,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats$1,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats$1,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$1 = {
      lastWeek: "'上個'eeee p",
      yesterday: "'昨天' p",
      today: "'今天' p",
      tomorrow: "'明天' p",
      nextWeek: "'下個'eeee p",
      other: 'P'
    };
    var formatRelative$1 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1[token];
    };

    var eraValues$1 = {
      narrow: ['前', '公元'],
      abbreviated: ['前', '公元'],
      wide: ['公元前', '公元']
    };
    var quarterValues$1 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['第一季', '第二季', '第三季', '第四季'],
      wide: ['第一季度', '第二季度', '第三季度', '第四季度']
    };
    var monthValues$1 = {
      narrow: ['一', '二', '三', '四', '五', '六', '七', '八', '九', '十', '十一', '十二'],
      abbreviated: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      wide: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    };
    var dayValues$1 = {
      narrow: ['日', '一', '二', '三', '四', '五', '六'],
      short: ['日', '一', '二', '三', '四', '五', '六'],
      abbreviated: ['週日', '週一', '週二', '週三', '週四', '週五', '週六'],
      wide: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六']
    };
    var dayPeriodValues$1 = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '午夜',
        noon: '晌',
        morning: '早',
        afternoon: '午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '午夜',
        noon: '中午',
        morning: '上午',
        afternoon: '下午',
        evening: '晚上',
        night: '夜晚'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '午夜',
        noon: '中午',
        morning: '上午',
        afternoon: '下午',
        evening: '晚上',
        night: '夜晚'
      }
    };
    var formattingDayPeriodValues$1 = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '午夜',
        noon: '晌',
        morning: '早',
        afternoon: '午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '午夜',
        noon: '中午',
        morning: '上午',
        afternoon: '下午',
        evening: '晚上',
        night: '夜晚'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '午夜',
        noon: '中午',
        morning: '上午',
        afternoon: '下午',
        evening: '晚上',
        night: '夜晚'
      }
    };
    var ordinalNumber$1 = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      switch (options === null || options === void 0 ? void 0 : options.unit) {
        case 'date':
          return number + '日';
        case 'hour':
          return number + '時';
        case 'minute':
          return number + '分';
        case 'second':
          return number + '秒';
        default:
          return '第 ' + number;
      }
    };
    var localize$1 = {
      ordinalNumber: ordinalNumber$1,
      era: buildLocalizeFn({
        values: eraValues$1,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues$1,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues$1,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues$1,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues$1,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$1,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1 = /^(第\s*)?\d+(日|時|分|秒)?/i;
    var parseOrdinalNumberPattern$1 = /\d+/i;
    var matchEraPatterns$1 = {
      narrow: /^(前)/i,
      abbreviated: /^(前)/i,
      wide: /^(公元前|公元)/i
    };
    var parseEraPatterns$1 = {
      any: [/^(前)/i, /^(公元)/i]
    };
    var matchQuarterPatterns$1 = {
      narrow: /^[1234]/i,
      abbreviated: /^第[一二三四]季/i,
      wide: /^第[一二三四]季度/i
    };
    var parseQuarterPatterns$1 = {
      any: [/(1|一)/i, /(2|二)/i, /(3|三)/i, /(4|四)/i]
    };
    var matchMonthPatterns$1 = {
      narrow: /^(一|二|三|四|五|六|七|八|九|十[二一])/i,
      abbreviated: /^(一|二|三|四|五|六|七|八|九|十[二一]|\d|1[12])月/i,
      wide: /^(一|二|三|四|五|六|七|八|九|十[二一])月/i
    };
    var parseMonthPatterns$1 = {
      narrow: [/^一/i, /^二/i, /^三/i, /^四/i, /^五/i, /^六/i, /^七/i, /^八/i, /^九/i, /^十(?!(一|二))/i, /^十一/i, /^十二/i],
      any: [/^一|1/i, /^二|2/i, /^三|3/i, /^四|4/i, /^五|5/i, /^六|6/i, /^七|7/i, /^八|8/i, /^九|9/i, /^十(?!(一|二))|10/i, /^十一|11/i, /^十二|12/i]
    };
    var matchDayPatterns$1 = {
      narrow: /^[一二三四五六日]/i,
      short: /^[一二三四五六日]/i,
      abbreviated: /^週[一二三四五六日]/i,
      wide: /^星期[一二三四五六日]/i
    };
    var parseDayPatterns$1 = {
      any: [/日/i, /一/i, /二/i, /三/i, /四/i, /五/i, /六/i]
    };
    var matchDayPeriodPatterns$1 = {
      any: /^(上午?|下午?|午夜|[中正]午|早上?|下午|晚上?|凌晨)/i
    };
    var parseDayPeriodPatterns$1 = {
      any: {
        am: /^上午?/i,
        pm: /^下午?/i,
        midnight: /^午夜/i,
        noon: /^[中正]午/i,
        morning: /^早上/i,
        afternoon: /^下午/i,
        evening: /^晚上?/i,
        night: /^凌晨/i
      }
    };
    var match$1 = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern$1,
        parsePattern: parseOrdinalNumberPattern$1,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns$1,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$1,
        defaultParseWidth: 'any'
      })
    };

    var locale$1 = {
      code: 'zh-HK',
      formatDistance: formatDistance$1,
      formatLong: formatLong$1,
      formatRelative: formatRelative$1,
      localize: localize$1,
      match: match$1,
      options: {
        weekStartsOn: 0
        ,
        firstWeekContainsDate: 1
      }
    };

    var formatDistanceLocale = {
      lessThanXSeconds: {
        one: '少於 1 秒',
        other: '少於 {{count}} 秒'
      },
      xSeconds: {
        one: '1 秒',
        other: '{{count}} 秒'
      },
      halfAMinute: '半分鐘',
      lessThanXMinutes: {
        one: '少於 1 分鐘',
        other: '少於 {{count}} 分鐘'
      },
      xMinutes: {
        one: '1 分鐘',
        other: '{{count}} 分鐘'
      },
      xHours: {
        one: '1 小時',
        other: '{{count}} 小時'
      },
      aboutXHours: {
        one: '大約 1 小時',
        other: '大約 {{count}} 小時'
      },
      xDays: {
        one: '1 天',
        other: '{{count}} 天'
      },
      aboutXWeeks: {
        one: '大約 1 個星期',
        other: '大約 {{count}} 個星期'
      },
      xWeeks: {
        one: '1 個星期',
        other: '{{count}} 個星期'
      },
      aboutXMonths: {
        one: '大約 1 個月',
        other: '大約 {{count}} 個月'
      },
      xMonths: {
        one: '1 個月',
        other: '{{count}} 個月'
      },
      aboutXYears: {
        one: '大約 1 年',
        other: '大約 {{count}} 年'
      },
      xYears: {
        one: '1 年',
        other: '{{count}} 年'
      },
      overXYears: {
        one: '超過 1 年',
        other: '超過 {{count}} 年'
      },
      almostXYears: {
        one: '將近 1 年',
        other: '將近 {{count}} 年'
      }
    };
    var formatDistance = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale[token];
      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }
      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + '內';
        } else {
          return result + '前';
        }
      }
      return result;
    };

    var dateFormats = {
      full: "y'年'M'月'd'日' EEEE",
      long: "y'年'M'月'd'日'",
      medium: 'yyyy-MM-dd',
      short: 'yy-MM-dd'
    };
    var timeFormats = {
      full: 'zzzz a h:mm:ss',
      long: 'z a h:mm:ss',
      medium: 'a h:mm:ss',
      short: 'a h:mm'
    };
    var dateTimeFormats = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong = {
      date: buildFormatLongFn({
        formats: dateFormats,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn({
        formats: timeFormats,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn({
        formats: dateTimeFormats,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale = {
      lastWeek: "'上個'eeee p",
      yesterday: "'昨天' p",
      today: "'今天' p",
      tomorrow: "'明天' p",
      nextWeek: "'下個'eeee p",
      other: 'P'
    };
    var formatRelative = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale[token];
    };

    var eraValues = {
      narrow: ['前', '公元'],
      abbreviated: ['前', '公元'],
      wide: ['公元前', '公元']
    };
    var quarterValues = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['第一刻', '第二刻', '第三刻', '第四刻'],
      wide: ['第一刻鐘', '第二刻鐘', '第三刻鐘', '第四刻鐘']
    };
    var monthValues = {
      narrow: ['一', '二', '三', '四', '五', '六', '七', '八', '九', '十', '十一', '十二'],
      abbreviated: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      wide: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    };
    var dayValues = {
      narrow: ['日', '一', '二', '三', '四', '五', '六'],
      short: ['日', '一', '二', '三', '四', '五', '六'],
      abbreviated: ['週日', '週一', '週二', '週三', '週四', '週五', '週六'],
      wide: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六']
    };
    var dayPeriodValues = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      }
    };
    var formattingDayPeriodValues = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      }
    };
    var ordinalNumber = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      switch (options === null || options === void 0 ? void 0 : options.unit) {
        case 'date':
          return number + '日';
        case 'hour':
          return number + '時';
        case 'minute':
          return number + '分';
        case 'second':
          return number + '秒';
        default:
          return '第 ' + number;
      }
    };
    var localize = {
      ordinalNumber: ordinalNumber,
      era: buildLocalizeFn({
        values: eraValues,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn({
        values: quarterValues,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn({
        values: monthValues,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn({
        values: dayValues,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn({
        values: dayPeriodValues,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern = /^(第\s*)?\d+(日|時|分|秒)?/i;
    var parseOrdinalNumberPattern = /\d+/i;
    var matchEraPatterns = {
      narrow: /^(前)/i,
      abbreviated: /^(前)/i,
      wide: /^(公元前|公元)/i
    };
    var parseEraPatterns = {
      any: [/^(前)/i, /^(公元)/i]
    };
    var matchQuarterPatterns = {
      narrow: /^[1234]/i,
      abbreviated: /^第[一二三四]刻/i,
      wide: /^第[一二三四]刻鐘/i
    };
    var parseQuarterPatterns = {
      any: [/(1|一)/i, /(2|二)/i, /(3|三)/i, /(4|四)/i]
    };
    var matchMonthPatterns = {
      narrow: /^(一|二|三|四|五|六|七|八|九|十[二一])/i,
      abbreviated: /^(一|二|三|四|五|六|七|八|九|十[二一]|\d|1[12])月/i,
      wide: /^(一|二|三|四|五|六|七|八|九|十[二一])月/i
    };
    var parseMonthPatterns = {
      narrow: [/^一/i, /^二/i, /^三/i, /^四/i, /^五/i, /^六/i, /^七/i, /^八/i, /^九/i, /^十(?!(一|二))/i, /^十一/i, /^十二/i],
      any: [/^一|1/i, /^二|2/i, /^三|3/i, /^四|4/i, /^五|5/i, /^六|6/i, /^七|7/i, /^八|8/i, /^九|9/i, /^十(?!(一|二))|10/i, /^十一|11/i, /^十二|12/i]
    };
    var matchDayPatterns = {
      narrow: /^[一二三四五六日]/i,
      short: /^[一二三四五六日]/i,
      abbreviated: /^週[一二三四五六日]/i,
      wide: /^星期[一二三四五六日]/i
    };
    var parseDayPatterns = {
      any: [/日/i, /一/i, /二/i, /三/i, /四/i, /五/i, /六/i]
    };
    var matchDayPeriodPatterns = {
      any: /^(上午?|下午?|午夜|[中正]午|早上?|下午|晚上?|凌晨)/i
    };
    var parseDayPeriodPatterns = {
      any: {
        am: /^上午?/i,
        pm: /^下午?/i,
        midnight: /^午夜/i,
        noon: /^[中正]午/i,
        morning: /^早上/i,
        afternoon: /^下午/i,
        evening: /^晚上?/i,
        night: /^凌晨/i
      }
    };
    var match = {
      ordinalNumber: buildMatchPatternFn({
        matchPattern: matchOrdinalNumberPattern,
        parsePattern: parseOrdinalNumberPattern,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn({
        matchPatterns: matchEraPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn({
        matchPatterns: matchQuarterPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn({
        matchPatterns: matchMonthPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn({
        matchPatterns: matchDayPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn({
        matchPatterns: matchDayPeriodPatterns,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns,
        defaultParseWidth: 'any'
      })
    };

    var locale = {
      code: 'zh-TW',
      formatDistance: formatDistance,
      formatLong: formatLong,
      formatRelative: formatRelative,
      localize: localize,
      match: match,
      options: {
        weekStartsOn: 1
        ,
        firstWeekContainsDate: 4
      }
    };

    var dateLocale = /*#__PURE__*/Object.freeze({
        __proto__: null,
        af: locale$1r,
        ar: locale$1q,
        arDZ: locale$1p,
        arEG: locale$1o,
        arMA: locale$1n,
        arSA: locale$1m,
        arTN: locale$1l,
        az: locale$1k,
        be: locale$1j,
        beTarask: locale$1i,
        bg: locale$1h,
        bn: locale$1g,
        bs: locale$1f,
        ca: locale$1e,
        cs: locale$1d,
        cy: locale$1c,
        da: locale$1b,
        de: locale$1a,
        deAT: locale$19,
        el: locale$18,
        enAU: locale$17,
        enCA: locale$16,
        enGB: locale$15,
        enIE: locale$14,
        enIN: locale$13,
        enNZ: locale$12,
        enUS: locale$1s,
        enZA: locale$11,
        eo: locale$10,
        es: locale$$,
        et: locale$_,
        eu: locale$Z,
        faIR: locale$Y,
        fi: locale$X,
        fr: locale$W,
        frCA: locale$V,
        frCH: locale$U,
        fy: locale$T,
        gd: locale$S,
        gl: locale$R,
        gu: locale$Q,
        he: locale$P,
        hi: locale$O,
        hr: locale$N,
        ht: locale$M,
        hu: locale$L,
        hy: locale$K,
        id: locale$J,
        is: locale$I,
        it: locale$H,
        itCH: locale$G,
        ja: locale$F,
        jaHira: locale$E,
        ka: locale$D,
        kk: locale$C,
        km: locale$B,
        kn: locale$A,
        ko: locale$z,
        lb: locale$y,
        lt: locale$x,
        lv: locale$w,
        mk: locale$v,
        mn: locale$u,
        ms: locale$t,
        mt: locale$s,
        nb: locale$r,
        nl: locale$q,
        nlBE: locale$p,
        nn: locale$o,
        oc: locale$n,
        pl: locale$m,
        pt: locale$l,
        ptBR: locale$k,
        ro: locale$j,
        ru: locale$i,
        sk: locale$h,
        sl: locale$g,
        sq: locale$f,
        sr: locale$e,
        srLatn: locale$d,
        sv: locale$c,
        ta: locale$b,
        te: locale$a,
        th: locale$9,
        tr: locale$8,
        ug: locale$7,
        uk: locale$6,
        uz: locale$5,
        uzCyrl: locale$4,
        vi: locale$3,
        zhCN: locale$2,
        zhHK: locale$1,
        zhTW: locale
    });

    const langs = glib2.get_language_names_with_category('LC_MESSAGES').map((l) => l.replaceAll('_', '').replaceAll('-', '').split('.')[0]);
    const localeKey = Object.keys(dateLocale).find((key) => langs.includes(key));
    let PanoItemHeader = class PanoItemHeader extends st1.BoxLayout {
        constructor(itemType, date) {
            super({
                style_class: `pano-item-header pano-item-header-${itemType.classSuffix}`,
                vertical: false,
                x_expand: true,
                y_expand: false,
                x_align: clutter10.ActorAlign.FILL,
                y_align: clutter10.ActorAlign.START,
            });
            const titleContainer = new st1.BoxLayout({
                style_class: 'pano-item-title-container',
                vertical: true,
                x_expand: true,
            });
            const iconContainer = new st1.BoxLayout({
                style_class: 'pano-icon-container',
            });
            iconContainer.add_child(new st1.Icon({
                gicon: gio2.icon_new_for_string(`${getCurrentExtension().path}/icons/hicolor/scalable/actions/${itemType.iconPath}`),
            }));
            titleContainer.add_child(new st1.Label({
                text: itemType.title,
                style_class: 'pano-item-title',
                x_expand: true,
            }));
            const dateLabel = new st1.Label({
                text: formatDistanceToNow(date, { addSuffix: true, locale: localeKey ? dateLocale[localeKey] : undefined }),
                style_class: 'pano-item-date',
                x_expand: true,
                y_expand: true,
            });
            this.dateUpdateIntervalId = setInterval(() => {
                dateLabel.set_text(formatDistanceToNow(date, { addSuffix: true, locale: localeKey ? dateLocale[localeKey] : undefined }));
            }, 60000);
            titleContainer.add_child(dateLabel);
            const actionContainer = new st1.BoxLayout({
                style_class: 'pano-item-actions',
                x_expand: false,
                y_expand: true,
                x_align: clutter10.ActorAlign.END,
                y_align: clutter10.ActorAlign.START,
            });
            const favoriteIcon = new st1.Icon({
                icon_name: 'starred-symbolic',
                icon_size: 10,
            });
            this.favoriteButton = new st1.Button({
                style_class: 'pano-item-favorite-button',
                child: favoriteIcon,
            });
            this.favoriteButton.connect('clicked', () => {
                this.emit('on-favorite');
                return clutter10.EVENT_PROPAGATE;
            });
            const removeIcon = new st1.Icon({
                icon_name: 'window-close-symbolic',
                icon_size: 10,
            });
            const removeButton = new st1.Button({
                style_class: 'pano-item-remove-button',
                child: removeIcon,
            });
            removeButton.connect('clicked', () => {
                this.emit('on-remove');
                return clutter10.EVENT_PROPAGATE;
            });
            actionContainer.add_child(this.favoriteButton);
            actionContainer.add_child(removeButton);
            this.add_child(iconContainer);
            this.add_child(titleContainer);
            this.add_child(actionContainer);
        }
        setFavorite(isFavorite) {
            if (isFavorite) {
                this.favoriteButton.add_style_pseudo_class('active');
            }
            else {
                this.favoriteButton.remove_style_pseudo_class('active');
            }
        }
        destroy() {
            clearInterval(this.dateUpdateIntervalId);
            super.destroy();
        }
    };
    PanoItemHeader.metaInfo = {
        GTypeName: 'PanoItemHeader',
        Signals: {
            'on-remove': {},
            'on-favorite': {},
        },
    };
    PanoItemHeader = __decorate([
        registerGObjectClass
    ], PanoItemHeader);

    const PanoItemTypes = {
        LINK: { classSuffix: 'link', title: _('Link'), iconPath: 'link-symbolic.svg', iconName: 'link-symbolic' },
        TEXT: { classSuffix: 'text', title: _('Text'), iconPath: 'text-symbolic.svg', iconName: 'text-symbolic' },
        EMOJI: { classSuffix: 'emoji', title: _('Emoji'), iconPath: 'emoji-symbolic.svg', iconName: 'emoji-symbolic' },
        FILE: { classSuffix: 'file', title: _('File'), iconPath: 'file-symbolic.svg', iconName: 'file-symbolic' },
        IMAGE: { classSuffix: 'image', title: _('Image'), iconPath: 'image-symbolic.svg', iconName: 'image-symbolic' },
        CODE: { classSuffix: 'code', title: _('Code'), iconPath: 'code-symbolic.svg', iconName: 'code-symbolic' },
        COLOR: { classSuffix: 'color', title: _('Color'), iconPath: 'color-symbolic.svg', iconName: 'color-symbolic' },
    };

    let PanoItem = class PanoItem extends st1.BoxLayout {
        constructor(dbItem) {
            super({
                name: 'pano-item',
                visible: true,
                pivot_point: new graphene1.Point({ x: 0.5, y: 0.5 }),
                reactive: true,
                style_class: 'pano-item',
                vertical: true,
                track_hover: true,
            });
            this.dbItem = dbItem;
            this.settings = getCurrentExtensionSettings();
            this.connect('key-focus-in', () => this.setSelected(true));
            this.connect('key-focus-out', () => this.setSelected(false));
            this.connect('enter-event', () => {
                shell0.Global.get().display.set_cursor(meta10.Cursor.POINTING_HAND);
                if (!this.selected) {
                    this.set_style(`border: 4px solid ${this.settings.get_string('hovered-item-border-color')}`);
                }
            });
            this.connect('motion-event', () => {
                shell0.Global.get().display.set_cursor(meta10.Cursor.POINTING_HAND);
            });
            this.connect('leave-event', () => {
                shell0.Global.get().display.set_cursor(meta10.Cursor.DEFAULT);
                if (!this.selected) {
                    this.set_style('');
                }
            });
            this.connect('activated', () => {
                this.get_parent()?.get_parent()?.get_parent()?.hide();
                if (this.dbItem.itemType === 'LINK' && this.settings.get_boolean('open-links-in-browser')) {
                    return;
                }
                if (this.settings.get_boolean('paste-on-select')) {
                    // See https://github.com/SUPERCILEX/gnome-clipboard-history/blob/master/extension.js#L606
                    this.timeoutId = glib2.timeout_add(glib2.PRIORITY_DEFAULT, 250, () => {
                        getVirtualKeyboard().notify_keyval(clutter10.get_current_event_time(), clutter10.KEY_Control_L, clutter10.KeyState.RELEASED);
                        getVirtualKeyboard().notify_keyval(clutter10.get_current_event_time(), clutter10.KEY_Control_L, clutter10.KeyState.PRESSED);
                        getVirtualKeyboard().notify_keyval(clutter10.get_current_event_time(), clutter10.KEY_v, clutter10.KeyState.PRESSED);
                        getVirtualKeyboard().notify_keyval(clutter10.get_current_event_time(), clutter10.KEY_Control_L, clutter10.KeyState.RELEASED);
                        getVirtualKeyboard().notify_keyval(clutter10.get_current_event_time(), clutter10.KEY_v, clutter10.KeyState.RELEASED);
                        if (this.timeoutId) {
                            glib2.Source.remove(this.timeoutId);
                        }
                        this.timeoutId = undefined;
                        return glib2.SOURCE_REMOVE;
                    });
                }
            });
            this.header = new PanoItemHeader(PanoItemTypes[dbItem.itemType], dbItem.copyDate);
            this.header.setFavorite(this.dbItem.isFavorite);
            this.header.connect('on-remove', () => {
                this.emit('on-remove', JSON.stringify(this.dbItem));
                return clutter10.EVENT_PROPAGATE;
            });
            this.header.connect('on-favorite', () => {
                this.dbItem = { ...this.dbItem, isFavorite: !this.dbItem.isFavorite };
                this.emit('on-favorite', JSON.stringify(this.dbItem));
                return clutter10.EVENT_PROPAGATE;
            });
            this.connect('on-favorite', () => {
                this.header.setFavorite(this.dbItem.isFavorite);
                return clutter10.EVENT_PROPAGATE;
            });
            this.body = new st1.BoxLayout({
                style_class: 'pano-item-body',
                clip_to_allocation: true,
                vertical: true,
                x_expand: true,
                y_expand: true,
            });
            this.add_child(this.header);
            this.add_child(this.body);
            this.set_height(this.settings.get_int('window-height') - 80);
            this.set_width(this.settings.get_int('window-height') - 80);
            this.body.set_height(this.settings.get_int('window-height') - 80 - 57);
            this.settings.connect('changed::window-height', () => {
                this.set_height(this.settings.get_int('window-height') - 80);
                this.set_width(this.settings.get_int('window-height') - 80);
                this.body.set_height(this.settings.get_int('window-height') - 80 - 57);
            });
        }
        setSelected(selected) {
            if (selected) {
                const activeItemBorderColor = this.settings.get_string('active-item-border-color');
                this.set_style(`border: 4px solid ${activeItemBorderColor} !important;`);
                this.grab_key_focus();
            }
            else {
                this.set_style('');
            }
            this.selected = selected;
        }
        vfunc_key_press_event(event) {
            if (event.keyval === clutter10.KEY_Return || event.keyval === clutter10.KEY_ISO_Enter || event.keyval === clutter10.KEY_KP_Enter) {
                this.emit('activated');
                return clutter10.EVENT_STOP;
            }
            if (event.keyval === clutter10.KEY_Delete || event.keyval === clutter10.KEY_KP_Delete) {
                this.emit('on-remove', JSON.stringify(this.dbItem));
                return clutter10.EVENT_STOP;
            }
            if ((event.keyval === clutter10.KEY_S || event.keyval === clutter10.KEY_s) && event.modifier_state === clutter10.ModifierType.CONTROL_MASK) {
                this.dbItem = { ...this.dbItem, isFavorite: !this.dbItem.isFavorite };
                this.emit('on-favorite', JSON.stringify(this.dbItem));
                return clutter10.EVENT_STOP;
            }
            return clutter10.EVENT_PROPAGATE;
        }
        vfunc_button_release_event(event) {
            if (event.button === 1) {
                this.emit('activated');
                return clutter10.EVENT_STOP;
            }
            return clutter10.EVENT_PROPAGATE;
        }
        destroy() {
            if (this.timeoutId) {
                glib2.Source.remove(this.timeoutId);
            }
            this.header.destroy();
            super.destroy();
        }
    };
    PanoItem.metaInfo = {
        GTypeName: 'PanoItem',
        Signals: {
            activated: {},
            'on-remove': {
                param_types: [gobject2.TYPE_STRING],
                accumulator: 0,
            },
            'on-favorite': {
                param_types: [gobject2.TYPE_STRING],
                accumulator: 0,
            },
        },
    };
    PanoItem = __decorate([
        registerGObjectClass
    ], PanoItem);

    var prism = {exports: {}};

    (function (module) {
    	var _self = (typeof window !== 'undefined')
    		? window
    		: (
    			(typeof WorkerGlobalScope !== 'undefined' && self instanceof WorkerGlobalScope)
    				? self
    				: {}
    		);
    	var Prism = (function (_self) {
    		var lang = /(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i;
    		var uniqueId = 0;
    		var plainTextGrammar = {};
    		var _ = {
    			manual: _self.Prism && _self.Prism.manual,
    			disableWorkerMessageHandler: _self.Prism && _self.Prism.disableWorkerMessageHandler,
    			util: {
    				encode: function encode(tokens) {
    					if (tokens instanceof Token) {
    						return new Token(tokens.type, encode(tokens.content), tokens.alias);
    					} else if (Array.isArray(tokens)) {
    						return tokens.map(encode);
    					} else {
    						return tokens.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/\u00a0/g, ' ');
    					}
    				},
    				type: function (o) {
    					return Object.prototype.toString.call(o).slice(8, -1);
    				},
    				objId: function (obj) {
    					if (!obj['__id']) {
    						Object.defineProperty(obj, '__id', { value: ++uniqueId });
    					}
    					return obj['__id'];
    				},
    				clone: function deepClone(o, visited) {
    					visited = visited || {};
    					var clone; var id;
    					switch (_.util.type(o)) {
    						case 'Object':
    							id = _.util.objId(o);
    							if (visited[id]) {
    								return visited[id];
    							}
    							clone =  ({});
    							visited[id] = clone;
    							for (var key in o) {
    								if (o.hasOwnProperty(key)) {
    									clone[key] = deepClone(o[key], visited);
    								}
    							}
    							return  (clone);
    						case 'Array':
    							id = _.util.objId(o);
    							if (visited[id]) {
    								return visited[id];
    							}
    							clone = [];
    							visited[id] = clone;
    							(((o))).forEach(function (v, i) {
    								clone[i] = deepClone(v, visited);
    							});
    							return  (clone);
    						default:
    							return o;
    					}
    				},
    				getLanguage: function (element) {
    					while (element) {
    						var m = lang.exec(element.className);
    						if (m) {
    							return m[1].toLowerCase();
    						}
    						element = element.parentElement;
    					}
    					return 'none';
    				},
    				setLanguage: function (element, language) {
    					element.className = element.className.replace(RegExp(lang, 'gi'), '');
    					element.classList.add('language-' + language);
    				},
    				currentScript: function () {
    					if (typeof document === 'undefined') {
    						return null;
    					}
    					if ('currentScript' in document && 1 < 2 ) {
    						return  (document.currentScript);
    					}
    					try {
    						throw new Error();
    					} catch (err) {
    						var src = (/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(err.stack) || [])[1];
    						if (src) {
    							var scripts = document.getElementsByTagName('script');
    							for (var i in scripts) {
    								if (scripts[i].src == src) {
    									return scripts[i];
    								}
    							}
    						}
    						return null;
    					}
    				},
    				isActive: function (element, className, defaultActivation) {
    					var no = 'no-' + className;
    					while (element) {
    						var classList = element.classList;
    						if (classList.contains(className)) {
    							return true;
    						}
    						if (classList.contains(no)) {
    							return false;
    						}
    						element = element.parentElement;
    					}
    					return !!defaultActivation;
    				}
    			},
    			languages: {
    				plain: plainTextGrammar,
    				plaintext: plainTextGrammar,
    				text: plainTextGrammar,
    				txt: plainTextGrammar,
    				extend: function (id, redef) {
    					var lang = _.util.clone(_.languages[id]);
    					for (var key in redef) {
    						lang[key] = redef[key];
    					}
    					return lang;
    				},
    				insertBefore: function (inside, before, insert, root) {
    					root = root ||  (_.languages);
    					var grammar = root[inside];
    					var ret = {};
    					for (var token in grammar) {
    						if (grammar.hasOwnProperty(token)) {
    							if (token == before) {
    								for (var newToken in insert) {
    									if (insert.hasOwnProperty(newToken)) {
    										ret[newToken] = insert[newToken];
    									}
    								}
    							}
    							if (!insert.hasOwnProperty(token)) {
    								ret[token] = grammar[token];
    							}
    						}
    					}
    					var old = root[inside];
    					root[inside] = ret;
    					_.languages.DFS(_.languages, function (key, value) {
    						if (value === old && key != inside) {
    							this[key] = ret;
    						}
    					});
    					return ret;
    				},
    				DFS: function DFS(o, callback, type, visited) {
    					visited = visited || {};
    					var objId = _.util.objId;
    					for (var i in o) {
    						if (o.hasOwnProperty(i)) {
    							callback.call(o, i, o[i], type || i);
    							var property = o[i];
    							var propertyType = _.util.type(property);
    							if (propertyType === 'Object' && !visited[objId(property)]) {
    								visited[objId(property)] = true;
    								DFS(property, callback, null, visited);
    							} else if (propertyType === 'Array' && !visited[objId(property)]) {
    								visited[objId(property)] = true;
    								DFS(property, callback, i, visited);
    							}
    						}
    					}
    				}
    			},
    			plugins: {},
    			highlightAll: function (async, callback) {
    				_.highlightAllUnder(document, async, callback);
    			},
    			highlightAllUnder: function (container, async, callback) {
    				var env = {
    					callback: callback,
    					container: container,
    					selector: 'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'
    				};
    				_.hooks.run('before-highlightall', env);
    				env.elements = Array.prototype.slice.apply(env.container.querySelectorAll(env.selector));
    				_.hooks.run('before-all-elements-highlight', env);
    				for (var i = 0, element; (element = env.elements[i++]);) {
    					_.highlightElement(element, async === true, env.callback);
    				}
    			},
    			highlightElement: function (element, async, callback) {
    				var language = _.util.getLanguage(element);
    				var grammar = _.languages[language];
    				_.util.setLanguage(element, language);
    				var parent = element.parentElement;
    				if (parent && parent.nodeName.toLowerCase() === 'pre') {
    					_.util.setLanguage(parent, language);
    				}
    				var code = element.textContent;
    				var env = {
    					element: element,
    					language: language,
    					grammar: grammar,
    					code: code
    				};
    				function insertHighlightedCode(highlightedCode) {
    					env.highlightedCode = highlightedCode;
    					_.hooks.run('before-insert', env);
    					env.element.innerHTML = env.highlightedCode;
    					_.hooks.run('after-highlight', env);
    					_.hooks.run('complete', env);
    					callback && callback.call(env.element);
    				}
    				_.hooks.run('before-sanity-check', env);
    				parent = env.element.parentElement;
    				if (parent && parent.nodeName.toLowerCase() === 'pre' && !parent.hasAttribute('tabindex')) {
    					parent.setAttribute('tabindex', '0');
    				}
    				if (!env.code) {
    					_.hooks.run('complete', env);
    					callback && callback.call(env.element);
    					return;
    				}
    				_.hooks.run('before-highlight', env);
    				if (!env.grammar) {
    					insertHighlightedCode(_.util.encode(env.code));
    					return;
    				}
    				if (async && _self.Worker) {
    					var worker = new Worker(_.filename);
    					worker.onmessage = function (evt) {
    						insertHighlightedCode(evt.data);
    					};
    					worker.postMessage(JSON.stringify({
    						language: env.language,
    						code: env.code,
    						immediateClose: true
    					}));
    				} else {
    					insertHighlightedCode(_.highlight(env.code, env.grammar, env.language));
    				}
    			},
    			highlight: function (text, grammar, language) {
    				var env = {
    					code: text,
    					grammar: grammar,
    					language: language
    				};
    				_.hooks.run('before-tokenize', env);
    				if (!env.grammar) {
    					throw new Error('The language "' + env.language + '" has no grammar.');
    				}
    				env.tokens = _.tokenize(env.code, env.grammar);
    				_.hooks.run('after-tokenize', env);
    				return Token.stringify(_.util.encode(env.tokens), env.language);
    			},
    			tokenize: function (text, grammar) {
    				var rest = grammar.rest;
    				if (rest) {
    					for (var token in rest) {
    						grammar[token] = rest[token];
    					}
    					delete grammar.rest;
    				}
    				var tokenList = new LinkedList();
    				addAfter(tokenList, tokenList.head, text);
    				matchGrammar(text, tokenList, grammar, tokenList.head, 0);
    				return toArray(tokenList);
    			},
    			hooks: {
    				all: {},
    				add: function (name, callback) {
    					var hooks = _.hooks.all;
    					hooks[name] = hooks[name] || [];
    					hooks[name].push(callback);
    				},
    				run: function (name, env) {
    					var callbacks = _.hooks.all[name];
    					if (!callbacks || !callbacks.length) {
    						return;
    					}
    					for (var i = 0, callback; (callback = callbacks[i++]);) {
    						callback(env);
    					}
    				}
    			},
    			Token: Token
    		};
    		_self.Prism = _;
    		function Token(type, content, alias, matchedStr) {
    			this.type = type;
    			this.content = content;
    			this.alias = alias;
    			this.length = (matchedStr || '').length | 0;
    		}
    		Token.stringify = function stringify(o, language) {
    			if (typeof o == 'string') {
    				return o;
    			}
    			if (Array.isArray(o)) {
    				var s = '';
    				o.forEach(function (e) {
    					s += stringify(e, language);
    				});
    				return s;
    			}
    			var env = {
    				type: o.type,
    				content: stringify(o.content, language),
    				tag: 'span',
    				classes: ['token', o.type],
    				attributes: {},
    				language: language
    			};
    			var aliases = o.alias;
    			if (aliases) {
    				if (Array.isArray(aliases)) {
    					Array.prototype.push.apply(env.classes, aliases);
    				} else {
    					env.classes.push(aliases);
    				}
    			}
    			_.hooks.run('wrap', env);
    			var attributes = '';
    			for (var name in env.attributes) {
    				attributes += ' ' + name + '="' + (env.attributes[name] || '').replace(/"/g, '&quot;') + '"';
    			}
    			return '<' + env.tag + ' class="' + env.classes.join(' ') + '"' + attributes + '>' + env.content + '</' + env.tag + '>';
    		};
    		function matchPattern(pattern, pos, text, lookbehind) {
    			pattern.lastIndex = pos;
    			var match = pattern.exec(text);
    			if (match && lookbehind && match[1]) {
    				var lookbehindLength = match[1].length;
    				match.index += lookbehindLength;
    				match[0] = match[0].slice(lookbehindLength);
    			}
    			return match;
    		}
    		function matchGrammar(text, tokenList, grammar, startNode, startPos, rematch) {
    			for (var token in grammar) {
    				if (!grammar.hasOwnProperty(token) || !grammar[token]) {
    					continue;
    				}
    				var patterns = grammar[token];
    				patterns = Array.isArray(patterns) ? patterns : [patterns];
    				for (var j = 0; j < patterns.length; ++j) {
    					if (rematch && rematch.cause == token + ',' + j) {
    						return;
    					}
    					var patternObj = patterns[j];
    					var inside = patternObj.inside;
    					var lookbehind = !!patternObj.lookbehind;
    					var greedy = !!patternObj.greedy;
    					var alias = patternObj.alias;
    					if (greedy && !patternObj.pattern.global) {
    						var flags = patternObj.pattern.toString().match(/[imsuy]*$/)[0];
    						patternObj.pattern = RegExp(patternObj.pattern.source, flags + 'g');
    					}
    					var pattern = patternObj.pattern || patternObj;
    					for (
    						var currentNode = startNode.next, pos = startPos;
    						currentNode !== tokenList.tail;
    						pos += currentNode.value.length, currentNode = currentNode.next
    					) {
    						if (rematch && pos >= rematch.reach) {
    							break;
    						}
    						var str = currentNode.value;
    						if (tokenList.length > text.length) {
    							return;
    						}
    						if (str instanceof Token) {
    							continue;
    						}
    						var removeCount = 1;
    						var match;
    						if (greedy) {
    							match = matchPattern(pattern, pos, text, lookbehind);
    							if (!match || match.index >= text.length) {
    								break;
    							}
    							var from = match.index;
    							var to = match.index + match[0].length;
    							var p = pos;
    							p += currentNode.value.length;
    							while (from >= p) {
    								currentNode = currentNode.next;
    								p += currentNode.value.length;
    							}
    							p -= currentNode.value.length;
    							pos = p;
    							if (currentNode.value instanceof Token) {
    								continue;
    							}
    							for (
    								var k = currentNode;
    								k !== tokenList.tail && (p < to || typeof k.value === 'string');
    								k = k.next
    							) {
    								removeCount++;
    								p += k.value.length;
    							}
    							removeCount--;
    							str = text.slice(pos, p);
    							match.index -= pos;
    						} else {
    							match = matchPattern(pattern, 0, str, lookbehind);
    							if (!match) {
    								continue;
    							}
    						}
    						var from = match.index;
    						var matchStr = match[0];
    						var before = str.slice(0, from);
    						var after = str.slice(from + matchStr.length);
    						var reach = pos + str.length;
    						if (rematch && reach > rematch.reach) {
    							rematch.reach = reach;
    						}
    						var removeFrom = currentNode.prev;
    						if (before) {
    							removeFrom = addAfter(tokenList, removeFrom, before);
    							pos += before.length;
    						}
    						removeRange(tokenList, removeFrom, removeCount);
    						var wrapped = new Token(token, inside ? _.tokenize(matchStr, inside) : matchStr, alias, matchStr);
    						currentNode = addAfter(tokenList, removeFrom, wrapped);
    						if (after) {
    							addAfter(tokenList, currentNode, after);
    						}
    						if (removeCount > 1) {
    							var nestedRematch = {
    								cause: token + ',' + j,
    								reach: reach
    							};
    							matchGrammar(text, tokenList, grammar, currentNode.prev, pos, nestedRematch);
    							if (rematch && nestedRematch.reach > rematch.reach) {
    								rematch.reach = nestedRematch.reach;
    							}
    						}
    					}
    				}
    			}
    		}
    		function LinkedList() {
    			var head = { value: null, prev: null, next: null };
    			var tail = { value: null, prev: head, next: null };
    			head.next = tail;
    			this.head = head;
    			this.tail = tail;
    			this.length = 0;
    		}
    		function addAfter(list, node, value) {
    			var next = node.next;
    			var newNode = { value: value, prev: node, next: next };
    			node.next = newNode;
    			next.prev = newNode;
    			list.length++;
    			return newNode;
    		}
    		function removeRange(list, node, count) {
    			var next = node.next;
    			for (var i = 0; i < count && next !== list.tail; i++) {
    				next = next.next;
    			}
    			node.next = next;
    			next.prev = node;
    			list.length -= i;
    		}
    		function toArray(list) {
    			var array = [];
    			var node = list.head.next;
    			while (node !== list.tail) {
    				array.push(node.value);
    				node = node.next;
    			}
    			return array;
    		}
    		if (!_self.document) {
    			if (!_self.addEventListener) {
    				return _;
    			}
    			if (!_.disableWorkerMessageHandler) {
    				_self.addEventListener('message', function (evt) {
    					var message = JSON.parse(evt.data);
    					var lang = message.language;
    					var code = message.code;
    					var immediateClose = message.immediateClose;
    					_self.postMessage(_.highlight(code, _.languages[lang], lang));
    					if (immediateClose) {
    						_self.close();
    					}
    				}, false);
    			}
    			return _;
    		}
    		var script = _.util.currentScript();
    		if (script) {
    			_.filename = script.src;
    			if (script.hasAttribute('data-manual')) {
    				_.manual = true;
    			}
    		}
    		function highlightAutomaticallyCallback() {
    			if (!_.manual) {
    				_.highlightAll();
    			}
    		}
    		if (!_.manual) {
    			var readyState = document.readyState;
    			if (readyState === 'loading' || readyState === 'interactive' && script && script.defer) {
    				document.addEventListener('DOMContentLoaded', highlightAutomaticallyCallback);
    			} else {
    				if (window.requestAnimationFrame) {
    					window.requestAnimationFrame(highlightAutomaticallyCallback);
    				} else {
    					window.setTimeout(highlightAutomaticallyCallback, 16);
    				}
    			}
    		}
    		return _;
    	}(_self));
    	if (module.exports) {
    		module.exports = Prism;
    	}
    	if (typeof commonjsGlobal !== 'undefined') {
    		commonjsGlobal.Prism = Prism;
    	}
    	Prism.languages.markup = {
    		'comment': {
    			pattern: /<!--(?:(?!<!--)[\s\S])*?-->/,
    			greedy: true
    		},
    		'prolog': {
    			pattern: /<\?[\s\S]+?\?>/,
    			greedy: true
    		},
    		'doctype': {
    			pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,
    			greedy: true,
    			inside: {
    				'internal-subset': {
    					pattern: /(^[^\[]*\[)[\s\S]+(?=\]>$)/,
    					lookbehind: true,
    					greedy: true,
    					inside: null
    				},
    				'string': {
    					pattern: /"[^"]*"|'[^']*'/,
    					greedy: true
    				},
    				'punctuation': /^<!|>$|[[\]]/,
    				'doctype-tag': /^DOCTYPE/i,
    				'name': /[^\s<>'"]+/
    			}
    		},
    		'cdata': {
    			pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
    			greedy: true
    		},
    		'tag': {
    			pattern: /<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,
    			greedy: true,
    			inside: {
    				'tag': {
    					pattern: /^<\/?[^\s>\/]+/,
    					inside: {
    						'punctuation': /^<\/?/,
    						'namespace': /^[^\s>\/:]+:/
    					}
    				},
    				'special-attr': [],
    				'attr-value': {
    					pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,
    					inside: {
    						'punctuation': [
    							{
    								pattern: /^=/,
    								alias: 'attr-equals'
    							},
    							/"|'/
    						]
    					}
    				},
    				'punctuation': /\/?>/,
    				'attr-name': {
    					pattern: /[^\s>\/]+/,
    					inside: {
    						'namespace': /^[^\s>\/:]+:/
    					}
    				}
    			}
    		},
    		'entity': [
    			{
    				pattern: /&[\da-z]{1,8};/i,
    				alias: 'named-entity'
    			},
    			/&#x?[\da-f]{1,8};/i
    		]
    	};
    	Prism.languages.markup['tag'].inside['attr-value'].inside['entity'] =
    		Prism.languages.markup['entity'];
    	Prism.languages.markup['doctype'].inside['internal-subset'].inside = Prism.languages.markup;
    	Prism.hooks.add('wrap', function (env) {
    		if (env.type === 'entity') {
    			env.attributes['title'] = env.content.replace(/&amp;/, '&');
    		}
    	});
    	Object.defineProperty(Prism.languages.markup.tag, 'addInlined', {
    		value: function addInlined(tagName, lang) {
    			var includedCdataInside = {};
    			includedCdataInside['language-' + lang] = {
    				pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,
    				lookbehind: true,
    				inside: Prism.languages[lang]
    			};
    			includedCdataInside['cdata'] = /^<!\[CDATA\[|\]\]>$/i;
    			var inside = {
    				'included-cdata': {
    					pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
    					inside: includedCdataInside
    				}
    			};
    			inside['language-' + lang] = {
    				pattern: /[\s\S]+/,
    				inside: Prism.languages[lang]
    			};
    			var def = {};
    			def[tagName] = {
    				pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function () { return tagName; }), 'i'),
    				lookbehind: true,
    				greedy: true,
    				inside: inside
    			};
    			Prism.languages.insertBefore('markup', 'cdata', def);
    		}
    	});
    	Object.defineProperty(Prism.languages.markup.tag, 'addAttribute', {
    		value: function (attrName, lang) {
    			Prism.languages.markup.tag.inside['special-attr'].push({
    				pattern: RegExp(
    					/(^|["'\s])/.source + '(?:' + attrName + ')' + /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,
    					'i'
    				),
    				lookbehind: true,
    				inside: {
    					'attr-name': /^[^\s=]+/,
    					'attr-value': {
    						pattern: /=[\s\S]+/,
    						inside: {
    							'value': {
    								pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,
    								lookbehind: true,
    								alias: [lang, 'language-' + lang],
    								inside: Prism.languages[lang]
    							},
    							'punctuation': [
    								{
    									pattern: /^=/,
    									alias: 'attr-equals'
    								},
    								/"|'/
    							]
    						}
    					}
    				}
    			});
    		}
    	});
    	Prism.languages.html = Prism.languages.markup;
    	Prism.languages.mathml = Prism.languages.markup;
    	Prism.languages.svg = Prism.languages.markup;
    	Prism.languages.xml = Prism.languages.extend('markup', {});
    	Prism.languages.ssml = Prism.languages.xml;
    	Prism.languages.atom = Prism.languages.xml;
    	Prism.languages.rss = Prism.languages.xml;
    	(function (Prism) {
    		var string = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
    		Prism.languages.css = {
    			'comment': /\/\*[\s\S]*?\*\//,
    			'atrule': {
    				pattern: /@[\w-](?:[^;{\s]|\s+(?![\s{]))*(?:;|(?=\s*\{))/,
    				inside: {
    					'rule': /^@[\w-]+/,
    					'selector-function-argument': {
    						pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,
    						lookbehind: true,
    						alias: 'selector'
    					},
    					'keyword': {
    						pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/,
    						lookbehind: true
    					}
    				}
    			},
    			'url': {
    				pattern: RegExp('\\burl\\((?:' + string.source + '|' + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ')\\)', 'i'),
    				greedy: true,
    				inside: {
    					'function': /^url/i,
    					'punctuation': /^\(|\)$/,
    					'string': {
    						pattern: RegExp('^' + string.source + '$'),
    						alias: 'url'
    					}
    				}
    			},
    			'selector': {
    				pattern: RegExp('(^|[{}\\s])[^{}\\s](?:[^{};"\'\\s]|\\s+(?![\\s{])|' + string.source + ')*(?=\\s*\\{)'),
    				lookbehind: true
    			},
    			'string': {
    				pattern: string,
    				greedy: true
    			},
    			'property': {
    				pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,
    				lookbehind: true
    			},
    			'important': /!important\b/i,
    			'function': {
    				pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,
    				lookbehind: true
    			},
    			'punctuation': /[(){};:,]/
    		};
    		Prism.languages.css['atrule'].inside.rest = Prism.languages.css;
    		var markup = Prism.languages.markup;
    		if (markup) {
    			markup.tag.addInlined('style', 'css');
    			markup.tag.addAttribute('style', 'css');
    		}
    	}(Prism));
    	Prism.languages.clike = {
    		'comment': [
    			{
    				pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,
    				lookbehind: true,
    				greedy: true
    			},
    			{
    				pattern: /(^|[^\\:])\/\/.*/,
    				lookbehind: true,
    				greedy: true
    			}
    		],
    		'string': {
    			pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
    			greedy: true
    		},
    		'class-name': {
    			pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,
    			lookbehind: true,
    			inside: {
    				'punctuation': /[.\\]/
    			}
    		},
    		'keyword': /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,
    		'boolean': /\b(?:false|true)\b/,
    		'function': /\b\w+(?=\()/,
    		'number': /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,
    		'operator': /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,
    		'punctuation': /[{}[\];(),.:]/
    	};
    	Prism.languages.javascript = Prism.languages.extend('clike', {
    		'class-name': [
    			Prism.languages.clike['class-name'],
    			{
    				pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,
    				lookbehind: true
    			}
    		],
    		'keyword': [
    			{
    				pattern: /((?:^|\})\s*)catch\b/,
    				lookbehind: true
    			},
    			{
    				pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,
    				lookbehind: true
    			},
    		],
    		'function': /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,
    		'number': {
    			pattern: RegExp(
    				/(^|[^\w$])/.source +
    				'(?:' +
    				(
    					/NaN|Infinity/.source +
    					'|' +
    					/0[bB][01]+(?:_[01]+)*n?/.source +
    					'|' +
    					/0[oO][0-7]+(?:_[0-7]+)*n?/.source +
    					'|' +
    					/0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source +
    					'|' +
    					/\d+(?:_\d+)*n/.source +
    					'|' +
    					/(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source
    				) +
    				')' +
    				/(?![\w$])/.source
    			),
    			lookbehind: true
    		},
    		'operator': /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/
    	});
    	Prism.languages.javascript['class-name'][0].pattern = /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/;
    	Prism.languages.insertBefore('javascript', 'keyword', {
    		'regex': {
    			pattern: RegExp(
    				/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source +
    				/\//.source +
    				'(?:' +
    				/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source +
    				'|' +
    				/(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source +
    				')' +
    				/(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source
    			),
    			lookbehind: true,
    			greedy: true,
    			inside: {
    				'regex-source': {
    					pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/,
    					lookbehind: true,
    					alias: 'language-regex',
    					inside: Prism.languages.regex
    				},
    				'regex-delimiter': /^\/|\/$/,
    				'regex-flags': /^[a-z]+$/,
    			}
    		},
    		'function-variable': {
    			pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,
    			alias: 'function'
    		},
    		'parameter': [
    			{
    				pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,
    				lookbehind: true,
    				inside: Prism.languages.javascript
    			},
    			{
    				pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,
    				lookbehind: true,
    				inside: Prism.languages.javascript
    			},
    			{
    				pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,
    				lookbehind: true,
    				inside: Prism.languages.javascript
    			},
    			{
    				pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,
    				lookbehind: true,
    				inside: Prism.languages.javascript
    			}
    		],
    		'constant': /\b[A-Z](?:[A-Z_]|\dx?)*\b/
    	});
    	Prism.languages.insertBefore('javascript', 'string', {
    		'hashbang': {
    			pattern: /^#!.*/,
    			greedy: true,
    			alias: 'comment'
    		},
    		'template-string': {
    			pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,
    			greedy: true,
    			inside: {
    				'template-punctuation': {
    					pattern: /^`|`$/,
    					alias: 'string'
    				},
    				'interpolation': {
    					pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,
    					lookbehind: true,
    					inside: {
    						'interpolation-punctuation': {
    							pattern: /^\$\{|\}$/,
    							alias: 'punctuation'
    						},
    						rest: Prism.languages.javascript
    					}
    				},
    				'string': /[\s\S]+/
    			}
    		},
    		'string-property': {
    			pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,
    			lookbehind: true,
    			greedy: true,
    			alias: 'property'
    		}
    	});
    	Prism.languages.insertBefore('javascript', 'operator', {
    		'literal-property': {
    			pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,
    			lookbehind: true,
    			alias: 'property'
    		},
    	});
    	if (Prism.languages.markup) {
    		Prism.languages.markup.tag.addInlined('script', 'javascript');
    		Prism.languages.markup.tag.addAttribute(
    			/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,
    			'javascript'
    		);
    	}
    	Prism.languages.js = Prism.languages.javascript;
    	(function () {
    		if (typeof Prism === 'undefined' || typeof document === 'undefined') {
    			return;
    		}
    		if (!Element.prototype.matches) {
    			Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector;
    		}
    		var LOADING_MESSAGE = 'Loading…';
    		var FAILURE_MESSAGE = function (status, message) {
    			return '✖ Error ' + status + ' while fetching file: ' + message;
    		};
    		var FAILURE_EMPTY_MESSAGE = '✖ Error: File does not exist or is empty';
    		var EXTENSIONS = {
    			'js': 'javascript',
    			'py': 'python',
    			'rb': 'ruby',
    			'ps1': 'powershell',
    			'psm1': 'powershell',
    			'sh': 'bash',
    			'bat': 'batch',
    			'h': 'c',
    			'tex': 'latex'
    		};
    		var STATUS_ATTR = 'data-src-status';
    		var STATUS_LOADING = 'loading';
    		var STATUS_LOADED = 'loaded';
    		var STATUS_FAILED = 'failed';
    		var SELECTOR = 'pre[data-src]:not([' + STATUS_ATTR + '="' + STATUS_LOADED + '"])'
    			+ ':not([' + STATUS_ATTR + '="' + STATUS_LOADING + '"])';
    		function loadFile(src, success, error) {
    			var xhr = new XMLHttpRequest();
    			xhr.open('GET', src, true);
    			xhr.onreadystatechange = function () {
    				if (xhr.readyState == 4) {
    					if (xhr.status < 400 && xhr.responseText) {
    						success(xhr.responseText);
    					} else {
    						if (xhr.status >= 400) {
    							error(FAILURE_MESSAGE(xhr.status, xhr.statusText));
    						} else {
    							error(FAILURE_EMPTY_MESSAGE);
    						}
    					}
    				}
    			};
    			xhr.send(null);
    		}
    		function parseRange(range) {
    			var m = /^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(range || '');
    			if (m) {
    				var start = Number(m[1]);
    				var comma = m[2];
    				var end = m[3];
    				if (!comma) {
    					return [start, start];
    				}
    				if (!end) {
    					return [start, undefined];
    				}
    				return [start, Number(end)];
    			}
    			return undefined;
    		}
    		Prism.hooks.add('before-highlightall', function (env) {
    			env.selector += ', ' + SELECTOR;
    		});
    		Prism.hooks.add('before-sanity-check', function (env) {
    			var pre =  (env.element);
    			if (pre.matches(SELECTOR)) {
    				env.code = '';
    				pre.setAttribute(STATUS_ATTR, STATUS_LOADING);
    				var code = pre.appendChild(document.createElement('CODE'));
    				code.textContent = LOADING_MESSAGE;
    				var src = pre.getAttribute('data-src');
    				var language = env.language;
    				if (language === 'none') {
    					var extension = (/\.(\w+)$/.exec(src) || [, 'none'])[1];
    					language = EXTENSIONS[extension] || extension;
    				}
    				Prism.util.setLanguage(code, language);
    				Prism.util.setLanguage(pre, language);
    				var autoloader = Prism.plugins.autoloader;
    				if (autoloader) {
    					autoloader.loadLanguages(language);
    				}
    				loadFile(
    					src,
    					function (text) {
    						pre.setAttribute(STATUS_ATTR, STATUS_LOADED);
    						var range = parseRange(pre.getAttribute('data-range'));
    						if (range) {
    							var lines = text.split(/\r\n?|\n/g);
    							var start = range[0];
    							var end = range[1] == null ? lines.length : range[1];
    							if (start < 0) { start += lines.length; }
    							start = Math.max(0, Math.min(start - 1, lines.length));
    							if (end < 0) { end += lines.length; }
    							end = Math.max(0, Math.min(end, lines.length));
    							text = lines.slice(start, end).join('\n');
    							if (!pre.hasAttribute('data-start')) {
    								pre.setAttribute('data-start', String(start + 1));
    							}
    						}
    						code.textContent = text;
    						Prism.highlightElement(code);
    					},
    					function (error) {
    						pre.setAttribute(STATUS_ATTR, STATUS_FAILED);
    						code.textContent = error;
    					}
    				);
    			}
    		});
    		Prism.plugins.fileHighlight = {
    			highlight: function highlight(container) {
    				var elements = (container || document).querySelectorAll(SELECTOR);
    				for (var i = 0, element; (element = elements[i++]);) {
    					Prism.highlightElement(element);
    				}
    			}
    		};
    		var logged = false;
    		Prism.fileHighlight = function () {
    			if (!logged) {
    				console.warn('Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead.');
    				logged = true;
    			}
    			Prism.plugins.fileHighlight.highlight.apply(this, arguments);
    		};
    	}());
    } (prism));

    const debug$3 = logger('pango');
    const INVISIBLE_SPACE = '​';
    const CLASS_NAMES = [
        { classNames: 'comment', fgcolor: '#636f88' },
        { classNames: 'prolog', fgcolor: '#636f88' },
        { classNames: 'doctype', fgcolor: '#636f88' },
        { classNames: 'cdata', fgcolor: '#636f88' },
        { classNames: 'punctuation', fgcolor: '#81A1C1' },
        { classNames: 'interpolation-punctuation', fgcolor: '#81A1C1' },
        { classNames: 'template-punctuation', fgcolor: '#81A1C1' },
        { classNames: 'property', fgcolor: '#81A1C1' },
        { classNames: 'string-property', fgcolor: '#81A1C1' },
        { classNames: 'parameter', fgcolor: '#81A1C1' },
        { classNames: 'literal-property', fgcolor: '#81A1C1' },
        { classNames: 'tag', fgcolor: '#81A1C1' },
        { classNames: 'constant', fgcolor: '#81A1C1' },
        { classNames: 'symbol', fgcolor: '#81A1C1' },
        { classNames: 'deleted', fgcolor: '#81A1C1' },
        { classNames: 'number', fgcolor: '#B48EAD' },
        { classNames: 'boolean', fgcolor: '#81A1C1' },
        { classNames: 'selector', fgcolor: '#A3BE8C' },
        { classNames: 'attr-name', fgcolor: '#A3BE8C' },
        { classNames: 'string', fgcolor: '#A3BE8C' },
        { classNames: 'template-string', fgcolor: '#A3BE8C' },
        { classNames: 'char', fgcolor: '#A3BE8C' },
        { classNames: 'builtin', fgcolor: '#A3BE8C' },
        { classNames: 'interpolation', fgcolor: '#A3BE8C' },
        { classNames: 'inserted', fgcolor: '#A3BE8C' },
        { classNames: 'operator', fgcolor: '#81A1C1' },
        { classNames: 'entity', fgcolor: '#81A1C1' },
        { classNames: 'url', fgcolor: '#81A1C1' },
        { classNames: 'variable', fgcolor: '#81A1C1' },
        { classNames: 'function-variable', fgcolor: '#81A1C1' },
        { classNames: 'atrule', fgcolor: '#88C0D0' },
        { classNames: 'attr-value', fgcolor: '#88C0D0' },
        { classNames: 'function', fgcolor: '#88C0D0' },
        { classNames: 'class-name', fgcolor: '#88C0D0' },
        { classNames: 'keyword', fgcolor: '#81A1C1' },
        { classNames: 'regex', fgcolor: '#EBCB8B' },
        { classNames: 'regex-delimiter', fgcolor: '#EBCB8B' },
        { classNames: 'regex-source', fgcolor: '#EBCB8B' },
        { classNames: 'regex-flags', fgcolor: '#EBCB8B' },
        { classNames: 'important', fgcolor: '#EBCB8B' },
    ];
    const getColor = (classNames) => {
        const item = CLASS_NAMES.find((n) => classNames === n.classNames);
        if (!item) {
            debug$3(`class names not found: ${classNames}`);
            return '#fff';
        }
        return item.fgcolor;
    };
    const stringify = (o, language) => {
        if (typeof o == 'string') {
            return o;
        }
        if (Array.isArray(o)) {
            let s = '';
            o.forEach(function (e) {
                s += stringify(e, language);
            });
            return s;
        }
        const env = {
            type: o.type,
            content: stringify(o.content, language),
            tag: 'span',
            classes: [o.type],
            attributes: {},
            language: language,
        };
        let attributes = '';
        for (const name in env.attributes) {
            attributes += ` ${name}="${(env.attributes[name] || '').replace(/"/g, '&quot;')}"`;
        }
        return `<${env.tag} fgcolor="${getColor(env.classes.join(' '))}" ${attributes}>${env.content}</${env.tag}>`;
    };
    const markupCode = (text, charLength) => {
        const result = INVISIBLE_SPACE + stringify(prism.exports.util.encode(prism.exports.tokenize(text.slice(0, charLength), prism.exports.languages.javascript)), 'javascript');
        return result;
    };

    let CodePanoItem = class CodePanoItem extends PanoItem {
        constructor(dbItem) {
            super(dbItem);
            this.codeItemSettings = this.settings.get_child('code-item');
            this.label = new st1.Label({
                style_class: 'pano-item-body-code-content',
                clip_to_allocation: true,
            });
            this.label.clutter_text.use_markup = true;
            this.label.clutter_text.ellipsize = pango1.EllipsizeMode.END;
            this.body.add_child(this.label);
            this.connect('activated', this.setClipboardContent.bind(this));
            this.setStyle();
            this.codeItemSettings.connect('changed', this.setStyle.bind(this));
        }
        setStyle() {
            const headerBgColor = this.codeItemSettings.get_string('header-bg-color');
            const headerColor = this.codeItemSettings.get_string('header-color');
            const bodyBgColor = this.codeItemSettings.get_string('body-bg-color');
            const bodyFontFamily = this.codeItemSettings.get_string('body-font-family');
            const bodyFontSize = this.codeItemSettings.get_int('body-font-size');
            const characterLength = this.codeItemSettings.get_int('char-length');
            this.header.set_style(`background-color: ${headerBgColor}; color: ${headerColor};`);
            this.body.set_style(`background-color: ${bodyBgColor}`);
            this.label.set_style(`font-size: ${bodyFontSize}px; font-family: ${bodyFontFamily};`);
            this.label.clutter_text.set_markup(markupCode(this.dbItem.content, characterLength));
        }
        setClipboardContent() {
            clipboardManager.setContent(new ClipboardContent({
                type: ContentType.TEXT,
                value: this.dbItem.content,
            }));
        }
    };
    CodePanoItem = __decorate([
        registerGObjectClass
    ], CodePanoItem);

    let ColorPanoItem = class ColorPanoItem extends PanoItem {
        constructor(dbItem) {
            super(dbItem);
            this.body.add_style_class_name('pano-item-body-color');
            this.colorItemSettings = this.settings.get_child('color-item');
            const colorContainer = new st1.BoxLayout({
                vertical: false,
                x_expand: true,
                y_expand: true,
                y_align: clutter10.ActorAlign.FILL,
                x_align: clutter10.ActorAlign.FILL,
                style_class: 'color-container',
                style: `background-color: ${this.dbItem.content};`,
            });
            this.label = new st1.Label({
                x_align: clutter10.ActorAlign.CENTER,
                y_align: clutter10.ActorAlign.CENTER,
                x_expand: true,
                y_expand: true,
                text: this.dbItem.content,
                style_class: 'color-label',
            });
            colorContainer.add_child(this.label);
            colorContainer.add_constraint(new clutter10.AlignConstraint({
                source: this,
                align_axis: clutter10.AlignAxis.Y_AXIS,
                factor: 0.005,
            }));
            this.body.add_child(colorContainer);
            this.connect('activated', this.setClipboardContent.bind(this));
            this.setStyle();
            this.colorItemSettings.connect('changed', this.setStyle.bind(this));
        }
        setStyle() {
            const headerBgColor = this.colorItemSettings.get_string('header-bg-color');
            const headerColor = this.colorItemSettings.get_string('header-color');
            const metadataBgColor = this.colorItemSettings.get_string('metadata-bg-color');
            const metadataColor = this.colorItemSettings.get_string('metadata-color');
            const metadataFontFamily = this.colorItemSettings.get_string('metadata-font-family');
            const metadataFontSize = this.colorItemSettings.get_int('metadata-font-size');
            this.header.set_style(`background-color: ${headerBgColor}; color: ${headerColor};`);
            this.label.set_style(`background-color: ${metadataBgColor}; color: ${metadataColor}; font-family: ${metadataFontFamily}; font-size: ${metadataFontSize}px;`);
        }
        setClipboardContent() {
            clipboardManager.setContent(new ClipboardContent({
                type: ContentType.TEXT,
                value: this.dbItem.content,
            }));
        }
    };
    ColorPanoItem = __decorate([
        registerGObjectClass
    ], ColorPanoItem);

    let EmojiPanoItem = class EmojiPanoItem extends PanoItem {
        constructor(dbItem) {
            super(dbItem);
            this.body.add_style_class_name('pano-item-body-emoji');
            this.emojiItemSettings = this.settings.get_child('emoji-item');
            const emojiContainer = new st1.BoxLayout({
                vertical: false,
                x_expand: true,
                y_expand: true,
                y_align: clutter10.ActorAlign.FILL,
                x_align: clutter10.ActorAlign.FILL,
                style_class: 'emoji-container',
            });
            this.label = new st1.Label({
                x_align: clutter10.ActorAlign.CENTER,
                y_align: clutter10.ActorAlign.CENTER,
                x_expand: true,
                y_expand: true,
                text: this.dbItem.content,
                style_class: 'pano-item-body-emoji-content',
            });
            this.label.clutter_text.line_wrap = true;
            this.label.clutter_text.line_wrap_mode = pango1.WrapMode.WORD_CHAR;
            this.label.clutter_text.ellipsize = pango1.EllipsizeMode.END;
            emojiContainer.add_child(this.label);
            this.body.add_child(emojiContainer);
            this.connect('activated', this.setClipboardContent.bind(this));
            this.setStyle();
            this.emojiItemSettings.connect('changed', this.setStyle.bind(this));
        }
        setStyle() {
            const headerBgColor = this.emojiItemSettings.get_string('header-bg-color');
            const headerColor = this.emojiItemSettings.get_string('header-color');
            const bodyBgColor = this.emojiItemSettings.get_string('body-bg-color');
            const emojiSize = this.emojiItemSettings.get_int('emoji-size');
            this.header.set_style(`background-color: ${headerBgColor}; color: ${headerColor};`);
            this.body.set_style(`background-color: ${bodyBgColor};`);
            this.label.set_style(`font-size: ${emojiSize}px;`);
        }
        setClipboardContent() {
            clipboardManager.setContent(new ClipboardContent({
                type: ContentType.TEXT,
                value: this.dbItem.content,
            }));
        }
    };
    EmojiPanoItem = __decorate([
        registerGObjectClass
    ], EmojiPanoItem);

    let FilePanoItem = class FilePanoItem extends PanoItem {
        constructor(dbItem) {
            super(dbItem);
            this.fileList = JSON.parse(this.dbItem.content);
            this.operation = this.dbItem.metaData || 'copy';
            this.body.add_style_class_name('pano-item-body-file');
            this.fileItemSettings = this.settings.get_child('file-item');
            const container = new st1.BoxLayout({
                style_class: 'copied-files-container',
                vertical: true,
                x_expand: true,
                y_expand: false,
                y_align: clutter10.ActorAlign.FILL,
            });
            this.fileList
                .map((f) => {
                const items = f.split('://').filter((c) => !!c);
                return decodeURIComponent(items[items.length - 1]);
            })
                .forEach((uri) => {
                const bl = new st1.BoxLayout({
                    vertical: false,
                    style_class: 'copied-file-name',
                    x_expand: true,
                    x_align: clutter10.ActorAlign.FILL,
                    clip_to_allocation: true,
                    y_align: clutter10.ActorAlign.FILL,
                });
                bl.add_child(new st1.Icon({
                    icon_name: this.operation === FileOperation.CUT ? 'edit-cut-symbolic' : 'edit-copy-symbolic',
                    x_align: clutter10.ActorAlign.START,
                    icon_size: 14,
                    style_class: 'file-icon',
                }));
                const uriLabel = new st1.Label({
                    text: uri,
                    style_class: 'pano-item-body-file-name-label',
                    x_align: clutter10.ActorAlign.FILL,
                    x_expand: true,
                });
                uriLabel.clutter_text.ellipsize = pango1.EllipsizeMode.MIDDLE;
                bl.add_child(uriLabel);
                container.add_child(bl);
            });
            this.body.add_child(container);
            this.connect('activated', this.setClipboardContent.bind(this));
            this.setStyle();
            this.fileItemSettings.connect('changed', this.setStyle.bind(this));
        }
        setStyle() {
            const headerBgColor = this.fileItemSettings.get_string('header-bg-color');
            const headerColor = this.fileItemSettings.get_string('header-color');
            const bodyBgColor = this.fileItemSettings.get_string('body-bg-color');
            const bodyColor = this.fileItemSettings.get_string('body-color');
            const bodyFontFamily = this.fileItemSettings.get_string('body-font-family');
            const bodyFontSize = this.fileItemSettings.get_int('body-font-size');
            this.header.set_style(`background-color: ${headerBgColor}; color: ${headerColor};`);
            this.body.set_style(`background-color: ${bodyBgColor}; color: ${bodyColor}; font-family: ${bodyFontFamily}; font-size: ${bodyFontSize}px;`);
        }
        setClipboardContent() {
            clipboardManager.setContent(new ClipboardContent({
                type: ContentType.FILE,
                value: { fileList: this.fileList, operation: this.operation },
            }));
        }
    };
    FilePanoItem = __decorate([
        registerGObjectClass
    ], FilePanoItem);

    const BYTE_UNITS = [
    	'B',
    	'kB',
    	'MB',
    	'GB',
    	'TB',
    	'PB',
    	'EB',
    	'ZB',
    	'YB',
    ];
    const BIBYTE_UNITS = [
    	'B',
    	'kiB',
    	'MiB',
    	'GiB',
    	'TiB',
    	'PiB',
    	'EiB',
    	'ZiB',
    	'YiB',
    ];
    const BIT_UNITS = [
    	'b',
    	'kbit',
    	'Mbit',
    	'Gbit',
    	'Tbit',
    	'Pbit',
    	'Ebit',
    	'Zbit',
    	'Ybit',
    ];
    const BIBIT_UNITS = [
    	'b',
    	'kibit',
    	'Mibit',
    	'Gibit',
    	'Tibit',
    	'Pibit',
    	'Eibit',
    	'Zibit',
    	'Yibit',
    ];
    const toLocaleString = (number, locale, options) => {
    	let result = number;
    	if (typeof locale === 'string' || Array.isArray(locale)) {
    		result = number.toLocaleString(locale, options);
    	} else if (locale === true || options !== undefined) {
    		result = number.toLocaleString(undefined, options);
    	}
    	return result;
    };
    function prettyBytes(number, options) {
    	if (!Number.isFinite(number)) {
    		throw new TypeError(`Expected a finite number, got ${typeof number}: ${number}`);
    	}
    	options = {
    		bits: false,
    		binary: false,
    		...options,
    	};
    	const UNITS = options.bits
    		? (options.binary ? BIBIT_UNITS : BIT_UNITS)
    		: (options.binary ? BIBYTE_UNITS : BYTE_UNITS);
    	if (options.signed && number === 0) {
    		return ` 0 ${UNITS[0]}`;
    	}
    	const isNegative = number < 0;
    	const prefix = isNegative ? '-' : (options.signed ? '+' : '');
    	if (isNegative) {
    		number = -number;
    	}
    	let localeOptions;
    	if (options.minimumFractionDigits !== undefined) {
    		localeOptions = {minimumFractionDigits: options.minimumFractionDigits};
    	}
    	if (options.maximumFractionDigits !== undefined) {
    		localeOptions = {maximumFractionDigits: options.maximumFractionDigits, ...localeOptions};
    	}
    	if (number < 1) {
    		const numberString = toLocaleString(number, options.locale, localeOptions);
    		return prefix + numberString + ' ' + UNITS[0];
    	}
    	const exponent = Math.min(Math.floor(options.binary ? Math.log(number) / Math.log(1024) : Math.log10(number) / 3), UNITS.length - 1);
    	number /= (options.binary ? 1024 : 1000) ** exponent;
    	if (!localeOptions) {
    		number = number.toPrecision(3);
    	}
    	const numberString = toLocaleString(Number(number), options.locale, localeOptions);
    	const unit = UNITS[exponent];
    	return prefix + numberString + ' ' + unit;
    }

    const NO_IMAGE_FOUND_FILE_NAME = 'no-image-found.svg';
    let ImagePanoItem = class ImagePanoItem extends PanoItem {
        constructor(dbItem) {
            super(dbItem);
            this.body.add_style_class_name('pano-item-body-image');
            this.imageItemSettings = this.settings.get_child('image-item');
            const { width, height, size } = JSON.parse(dbItem.metaData || '{}');
            this.metaContainer = new st1.BoxLayout({
                style_class: 'pano-item-body-meta-container',
                vertical: true,
                x_expand: true,
                y_expand: true,
                y_align: clutter10.ActorAlign.END,
                x_align: clutter10.ActorAlign.FILL,
            });
            const resolutionContainer = new st1.BoxLayout({
                vertical: false,
                x_expand: true,
                y_align: clutter10.ActorAlign.FILL,
                x_align: clutter10.ActorAlign.FILL,
                style_class: 'pano-item-body-image-resolution-container',
            });
            this.resolutionTitle = new st1.Label({
                text: 'Resolution',
                x_align: clutter10.ActorAlign.START,
                x_expand: true,
                style_class: 'pano-item-body-image-meta-title',
            });
            this.resolutionValue = new st1.Label({
                text: `${width} x ${height}`,
                x_align: clutter10.ActorAlign.END,
                x_expand: false,
                style_class: 'pano-item-body-image-meta-value',
            });
            resolutionContainer.add_child(this.resolutionTitle);
            resolutionContainer.add_child(this.resolutionValue);
            const sizeContainer = new st1.BoxLayout({
                vertical: false,
                x_expand: true,
                y_align: clutter10.ActorAlign.FILL,
                x_align: clutter10.ActorAlign.FILL,
                style_class: 'pano-item-body-image-size-container',
            });
            this.sizeLabel = new st1.Label({
                text: 'Size',
                x_align: clutter10.ActorAlign.START,
                x_expand: true,
                style_class: 'pano-item-body-image-meta-title',
            });
            this.sizeValue = new st1.Label({
                text: prettyBytes(size),
                x_align: clutter10.ActorAlign.END,
                x_expand: false,
                style_class: 'pano-item-body-image-meta-value',
            });
            sizeContainer.add_child(this.sizeLabel);
            sizeContainer.add_child(this.sizeValue);
            this.metaContainer.add_child(resolutionContainer);
            this.metaContainer.add_child(sizeContainer);
            this.metaContainer.add_constraint(new clutter10.AlignConstraint({
                source: this,
                align_axis: clutter10.AlignAxis.Y_AXIS,
                factor: 0.001,
            }));
            this.body.add_child(this.metaContainer);
            this.connect('activated', this.setClipboardContent.bind(this));
            this.setStyle();
            this.imageItemSettings.connect('changed', this.setStyle.bind(this));
        }
        setStyle() {
            const headerBgColor = this.imageItemSettings.get_string('header-bg-color');
            const headerColor = this.imageItemSettings.get_string('header-color');
            const bodyBgColor = this.imageItemSettings.get_string('body-bg-color');
            const metadataBgColor = this.imageItemSettings.get_string('metadata-bg-color');
            const metadataColor = this.imageItemSettings.get_string('metadata-color');
            const metadataFontFamily = this.imageItemSettings.get_string('metadata-font-family');
            const metadataFontSize = this.imageItemSettings.get_int('metadata-font-size');
            let imageFilePath = `file://${getImagesPath()}/${this.dbItem.content}.png`;
            let backgroundSize = 'contain';
            const imageFile = gio2.File.new_for_uri(imageFilePath);
            if (!imageFile.query_exists(null)) {
                imageFilePath = `file://${getCurrentExtension().path}/images/${NO_IMAGE_FOUND_FILE_NAME}`;
                backgroundSize = 'cover';
            }
            this.body.set_style(`background-color: ${bodyBgColor}; background-image: url(${imageFilePath}); background-size: ${backgroundSize};`);
            this.header.set_style(`background-color: ${headerBgColor}; color: ${headerColor};`);
            this.resolutionTitle.set_style(`color: ${metadataColor}; font-family: ${metadataFontFamily}; font-size: ${metadataFontSize}px;`);
            this.resolutionValue.set_style(`color: ${metadataColor}; font-family: ${metadataFontFamily}; font-size: ${metadataFontSize}px; font-weight: bold;`);
            this.sizeLabel.set_style(`color: ${metadataColor}; font-family: ${metadataFontFamily}; font-size: ${metadataFontSize}px;`);
            this.sizeValue.set_style(`color: ${metadataColor}; font-family: ${metadataFontFamily}; font-size: ${metadataFontSize}px; font-weight: bold;`);
            this.metaContainer.set_style(`background-color: ${metadataBgColor};`);
        }
        setClipboardContent() {
            const imageFile = gio2.File.new_for_path(`${getImagesPath()}/${this.dbItem.content}.png`);
            if (!imageFile.query_exists(null)) {
                return;
            }
            const [bytes] = imageFile.load_bytes(null);
            const data = bytes.get_data();
            if (!data) {
                return;
            }
            clipboardManager.setContent(new ClipboardContent({
                type: ContentType.IMAGE,
                value: data,
            }));
        }
    };
    ImagePanoItem = __decorate([
        registerGObjectClass
    ], ImagePanoItem);

    const DEFAULT_LINK_PREVIEW_IMAGE_NAME = 'link-preview.svg';
    let LinkPanoItem = class LinkPanoItem extends PanoItem {
        constructor(dbItem) {
            super(dbItem);
            this.linkItemSettings = this.settings.get_child('link-item');
            const { title, description, image } = JSON.parse(dbItem.metaData || '{"title": "", "description": ""}');
            let titleText = title;
            let descriptionText = description;
            if (!title) {
                titleText = glib2.uri_parse(dbItem.content, glib2.UriFlags.NONE).get_host() || this.dbItem.content;
            }
            else {
                titleText = decodeURI(title);
            }
            if (!description) {
                descriptionText = _('No Description');
            }
            else {
                descriptionText = decodeURI(description);
            }
            this.body.add_style_class_name('pano-item-body-link');
            this.metaContainer = new st1.BoxLayout({
                style_class: 'pano-item-body-meta-container',
                vertical: true,
                x_expand: true,
                y_expand: false,
                y_align: clutter10.ActorAlign.END,
                x_align: clutter10.ActorAlign.FILL,
            });
            this.titleLabel = new st1.Label({
                text: titleText,
                style_class: 'link-title-label',
            });
            this.descriptionLabel = new st1.Label({
                text: descriptionText,
                style_class: 'link-description-label',
            });
            this.descriptionLabel.clutter_text.single_line_mode = true;
            this.linkLabel = new st1.Label({
                text: this.dbItem.content,
                style_class: 'link-label',
            });
            let imageFilePath = `file:///${getCurrentExtension().path}/images/${DEFAULT_LINK_PREVIEW_IMAGE_NAME}`;
            if (image && gio2.File.new_for_uri(`file://${getCachePath()}/${image}.png`).query_exists(null)) {
                imageFilePath = `file://${getCachePath()}/${image}.png`;
            }
            const imageContainer = new st1.BoxLayout({
                vertical: true,
                x_expand: true,
                y_expand: true,
                y_align: clutter10.ActorAlign.FILL,
                x_align: clutter10.ActorAlign.FILL,
                style_class: 'image-container',
                style: `background-image: url(${imageFilePath});`,
            });
            this.metaContainer.add_child(this.titleLabel);
            this.metaContainer.add_child(this.descriptionLabel);
            this.metaContainer.add_child(this.linkLabel);
            this.body.add_child(imageContainer);
            this.body.add_child(this.metaContainer);
            this.connect('activated', this.setClipboardContent.bind(this));
            this.setStyle();
            this.linkItemSettings.connect('changed', this.setStyle.bind(this));
        }
        setStyle() {
            const headerBgColor = this.linkItemSettings.get_string('header-bg-color');
            const headerColor = this.linkItemSettings.get_string('header-color');
            const bodyBgColor = this.linkItemSettings.get_string('body-bg-color');
            const metadataBgColor = this.linkItemSettings.get_string('metadata-bg-color');
            const metadataTitleColor = this.linkItemSettings.get_string('metadata-title-color');
            const metadataDescriptionColor = this.linkItemSettings.get_string('metadata-description-color');
            const metadataLinkColor = this.linkItemSettings.get_string('metadata-link-color');
            const metadataTitleFontFamily = this.linkItemSettings.get_string('metadata-title-font-family');
            const metadataDescriptionFontFamily = this.linkItemSettings.get_string('metadata-description-font-family');
            const metadataLinkFontFamily = this.linkItemSettings.get_string('metadata-link-font-family');
            const metadataTitleFontSize = this.linkItemSettings.get_int('metadata-title-font-size');
            const metadataDescriptionFontSize = this.linkItemSettings.get_int('metadata-description-font-size');
            const metadataLinkFontSize = this.linkItemSettings.get_int('metadata-link-font-size');
            this.header.set_style(`background-color: ${headerBgColor}; color: ${headerColor};`);
            this.body.set_style(`background-color: ${bodyBgColor};`);
            this.metaContainer.set_style(`background-color: ${metadataBgColor};`);
            this.titleLabel.set_style(`color: ${metadataTitleColor}; font-family: ${metadataTitleFontFamily}; font-size: ${metadataTitleFontSize}px;`);
            this.descriptionLabel.set_style(`color: ${metadataDescriptionColor}; font-family: ${metadataDescriptionFontFamily}; font-size: ${metadataDescriptionFontSize}px;`);
            this.linkLabel.set_style(`color: ${metadataLinkColor}; font-family: ${metadataLinkFontFamily}; font-size: ${metadataLinkFontSize}px;`);
        }
        setClipboardContent() {
            clipboardManager.setContent(new ClipboardContent({
                type: ContentType.TEXT,
                value: this.dbItem.content,
            }));
            if (this.settings.get_boolean('open-links-in-browser')) {
                openUrlInBrowser(this.dbItem.content);
            }
        }
    };
    LinkPanoItem = __decorate([
        registerGObjectClass
    ], LinkPanoItem);

    let TextPanoItem = class TextPanoItem extends PanoItem {
        constructor(dbItem) {
            super(dbItem);
            this.textItemSettings = this.settings.get_child('text-item');
            this.label = new st1.Label({
                style_class: 'pano-item-body-text-content',
            });
            this.label.clutter_text.line_wrap = true;
            this.label.clutter_text.line_wrap_mode = pango1.WrapMode.WORD_CHAR;
            this.label.clutter_text.ellipsize = pango1.EllipsizeMode.END;
            this.body.add_child(this.label);
            this.connect('activated', this.setClipboardContent.bind(this));
            this.setStyle();
            this.textItemSettings.connect('changed', this.setStyle.bind(this));
        }
        setStyle() {
            const headerBgColor = this.textItemSettings.get_string('header-bg-color');
            const headerColor = this.textItemSettings.get_string('header-color');
            const bodyBgColor = this.textItemSettings.get_string('body-bg-color');
            const bodyColor = this.textItemSettings.get_string('body-color');
            const bodyFontFamily = this.textItemSettings.get_string('body-font-family');
            const bodyFontSize = this.textItemSettings.get_int('body-font-size');
            const characterLength = this.textItemSettings.get_int('char-length');
            // Set header styles
            this.header.set_style(`background-color: ${headerBgColor}; color: ${headerColor};`);
            // Set body styles
            this.body.set_style(`background-color: ${bodyBgColor}`);
            // set label styles
            this.label.set_text(this.dbItem.content.slice(0, characterLength));
            this.label.set_style(`color: ${bodyColor}; font-family: ${bodyFontFamily}; font-size: ${bodyFontSize}px;`);
        }
        setClipboardContent() {
            clipboardManager.setContent(new ClipboardContent({
                type: ContentType.TEXT,
                value: this.dbItem.content,
            }));
        }
    };
    TextPanoItem = __decorate([
        registerGObjectClass
    ], TextPanoItem);

    var htmlDecodeTree = new Uint16Array([7489, 60, 213, 305, 650, 1181, 1403, 1488, 1653, 1758, 1954, 2006, 2063, 2634, 2705, 3489, 3693, 3849, 3878, 4298, 4648, 4833, 5141, 5277, 5315, 5343, 5413, 0, 0, 0, 0, 0, 0, 5483, 5837, 6541, 7186, 7645, 8062, 8288, 8624, 8845, 9152, 9211, 9282, 10276, 10514, 11528, 11848, 12238, 12310, 12986, 13881, 14252, 14590, 14888, 14961, 15072, 15150, 2048, 69, 77, 97, 98, 99, 102, 103, 108, 109, 110, 111, 112, 114, 115, 116, 117, 92, 98, 102, 109, 115, 127, 132, 139, 144, 149, 152, 166, 179, 185, 200, 207, 108, 105, 103, 32827, 198, 16582, 80, 32827, 38, 16422, 99, 117, 116, 101, 32827, 193, 16577, 114, 101, 118, 101, 59, 16642, 256, 105, 121, 120, 125, 114, 99, 32827, 194, 16578, 59, 17424, 114, 59, 49152, 55349, 56580, 114, 97, 118, 101, 32827, 192, 16576, 112, 104, 97, 59, 17297, 97, 99, 114, 59, 16640, 100, 59, 27219, 256, 103, 112, 157, 161, 111, 110, 59, 16644, 102, 59, 49152, 55349, 56632, 112, 108, 121, 70, 117, 110, 99, 116, 105, 111, 110, 59, 24673, 105, 110, 103, 32827, 197, 16581, 256, 99, 115, 190, 195, 114, 59, 49152, 55349, 56476, 105, 103, 110, 59, 25172, 105, 108, 100, 101, 32827, 195, 16579, 109, 108, 32827, 196, 16580, 1024, 97, 99, 101, 102, 111, 114, 115, 117, 229, 251, 254, 279, 284, 290, 295, 298, 256, 99, 114, 234, 242, 107, 115, 108, 97, 115, 104, 59, 25110, 374, 246, 248, 59, 27367, 101, 100, 59, 25350, 121, 59, 17425, 384, 99, 114, 116, 261, 267, 276, 97, 117, 115, 101, 59, 25141, 110, 111, 117, 108, 108, 105, 115, 59, 24876, 97, 59, 17298, 114, 59, 49152, 55349, 56581, 112, 102, 59, 49152, 55349, 56633, 101, 118, 101, 59, 17112, 99, 242, 275, 109, 112, 101, 113, 59, 25166, 1792, 72, 79, 97, 99, 100, 101, 102, 104, 105, 108, 111, 114, 115, 117, 333, 337, 342, 384, 414, 418, 437, 439, 442, 476, 533, 627, 632, 638, 99, 121, 59, 17447, 80, 89, 32827, 169, 16553, 384, 99, 112, 121, 349, 354, 378, 117, 116, 101, 59, 16646, 256, 59, 105, 359, 360, 25298, 116, 97, 108, 68, 105, 102, 102, 101, 114, 101, 110, 116, 105, 97, 108, 68, 59, 24901, 108, 101, 121, 115, 59, 24877, 512, 97, 101, 105, 111, 393, 398, 404, 408, 114, 111, 110, 59, 16652, 100, 105, 108, 32827, 199, 16583, 114, 99, 59, 16648, 110, 105, 110, 116, 59, 25136, 111, 116, 59, 16650, 256, 100, 110, 423, 429, 105, 108, 108, 97, 59, 16568, 116, 101, 114, 68, 111, 116, 59, 16567, 242, 383, 105, 59, 17319, 114, 99, 108, 101, 512, 68, 77, 80, 84, 455, 459, 465, 470, 111, 116, 59, 25241, 105, 110, 117, 115, 59, 25238, 108, 117, 115, 59, 25237, 105, 109, 101, 115, 59, 25239, 111, 256, 99, 115, 482, 504, 107, 119, 105, 115, 101, 67, 111, 110, 116, 111, 117, 114, 73, 110, 116, 101, 103, 114, 97, 108, 59, 25138, 101, 67, 117, 114, 108, 121, 256, 68, 81, 515, 527, 111, 117, 98, 108, 101, 81, 117, 111, 116, 101, 59, 24605, 117, 111, 116, 101, 59, 24601, 512, 108, 110, 112, 117, 542, 552, 583, 597, 111, 110, 256, 59, 101, 549, 550, 25143, 59, 27252, 384, 103, 105, 116, 559, 566, 570, 114, 117, 101, 110, 116, 59, 25185, 110, 116, 59, 25135, 111, 117, 114, 73, 110, 116, 101, 103, 114, 97, 108, 59, 25134, 256, 102, 114, 588, 590, 59, 24834, 111, 100, 117, 99, 116, 59, 25104, 110, 116, 101, 114, 67, 108, 111, 99, 107, 119, 105, 115, 101, 67, 111, 110, 116, 111, 117, 114, 73, 110, 116, 101, 103, 114, 97, 108, 59, 25139, 111, 115, 115, 59, 27183, 99, 114, 59, 49152, 55349, 56478, 112, 256, 59, 67, 644, 645, 25299, 97, 112, 59, 25165, 1408, 68, 74, 83, 90, 97, 99, 101, 102, 105, 111, 115, 672, 684, 688, 692, 696, 715, 727, 737, 742, 819, 1165, 256, 59, 111, 377, 677, 116, 114, 97, 104, 100, 59, 26897, 99, 121, 59, 17410, 99, 121, 59, 17413, 99, 121, 59, 17423, 384, 103, 114, 115, 703, 708, 711, 103, 101, 114, 59, 24609, 114, 59, 24993, 104, 118, 59, 27364, 256, 97, 121, 720, 725, 114, 111, 110, 59, 16654, 59, 17428, 108, 256, 59, 116, 733, 734, 25095, 97, 59, 17300, 114, 59, 49152, 55349, 56583, 256, 97, 102, 747, 807, 256, 99, 109, 752, 802, 114, 105, 116, 105, 99, 97, 108, 512, 65, 68, 71, 84, 768, 774, 790, 796, 99, 117, 116, 101, 59, 16564, 111, 372, 779, 781, 59, 17113, 98, 108, 101, 65, 99, 117, 116, 101, 59, 17117, 114, 97, 118, 101, 59, 16480, 105, 108, 100, 101, 59, 17116, 111, 110, 100, 59, 25284, 102, 101, 114, 101, 110, 116, 105, 97, 108, 68, 59, 24902, 1136, 829, 0, 0, 0, 834, 852, 0, 1029, 102, 59, 49152, 55349, 56635, 384, 59, 68, 69, 840, 841, 845, 16552, 111, 116, 59, 24796, 113, 117, 97, 108, 59, 25168, 98, 108, 101, 768, 67, 68, 76, 82, 85, 86, 867, 882, 898, 975, 994, 1016, 111, 110, 116, 111, 117, 114, 73, 110, 116, 101, 103, 114, 97, 236, 569, 111, 628, 889, 0, 0, 891, 187, 841, 110, 65, 114, 114, 111, 119, 59, 25043, 256, 101, 111, 903, 932, 102, 116, 384, 65, 82, 84, 912, 918, 929, 114, 114, 111, 119, 59, 25040, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 25044, 101, 229, 714, 110, 103, 256, 76, 82, 939, 964, 101, 102, 116, 256, 65, 82, 947, 953, 114, 114, 111, 119, 59, 26616, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 26618, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 26617, 105, 103, 104, 116, 256, 65, 84, 984, 990, 114, 114, 111, 119, 59, 25042, 101, 101, 59, 25256, 112, 577, 1001, 0, 0, 1007, 114, 114, 111, 119, 59, 25041, 111, 119, 110, 65, 114, 114, 111, 119, 59, 25045, 101, 114, 116, 105, 99, 97, 108, 66, 97, 114, 59, 25125, 110, 768, 65, 66, 76, 82, 84, 97, 1042, 1066, 1072, 1118, 1151, 892, 114, 114, 111, 119, 384, 59, 66, 85, 1053, 1054, 1058, 24979, 97, 114, 59, 26899, 112, 65, 114, 114, 111, 119, 59, 25077, 114, 101, 118, 101, 59, 17169, 101, 102, 116, 722, 1082, 0, 1094, 0, 1104, 105, 103, 104, 116, 86, 101, 99, 116, 111, 114, 59, 26960, 101, 101, 86, 101, 99, 116, 111, 114, 59, 26974, 101, 99, 116, 111, 114, 256, 59, 66, 1113, 1114, 25021, 97, 114, 59, 26966, 105, 103, 104, 116, 468, 1127, 0, 1137, 101, 101, 86, 101, 99, 116, 111, 114, 59, 26975, 101, 99, 116, 111, 114, 256, 59, 66, 1146, 1147, 25025, 97, 114, 59, 26967, 101, 101, 256, 59, 65, 1158, 1159, 25252, 114, 114, 111, 119, 59, 24999, 256, 99, 116, 1170, 1175, 114, 59, 49152, 55349, 56479, 114, 111, 107, 59, 16656, 2048, 78, 84, 97, 99, 100, 102, 103, 108, 109, 111, 112, 113, 115, 116, 117, 120, 1213, 1216, 1220, 1227, 1246, 1250, 1255, 1262, 1269, 1313, 1327, 1334, 1362, 1373, 1376, 1381, 71, 59, 16714, 72, 32827, 208, 16592, 99, 117, 116, 101, 32827, 201, 16585, 384, 97, 105, 121, 1234, 1239, 1244, 114, 111, 110, 59, 16666, 114, 99, 32827, 202, 16586, 59, 17453, 111, 116, 59, 16662, 114, 59, 49152, 55349, 56584, 114, 97, 118, 101, 32827, 200, 16584, 101, 109, 101, 110, 116, 59, 25096, 256, 97, 112, 1274, 1278, 99, 114, 59, 16658, 116, 121, 595, 1286, 0, 0, 1298, 109, 97, 108, 108, 83, 113, 117, 97, 114, 101, 59, 26107, 101, 114, 121, 83, 109, 97, 108, 108, 83, 113, 117, 97, 114, 101, 59, 26027, 256, 103, 112, 1318, 1322, 111, 110, 59, 16664, 102, 59, 49152, 55349, 56636, 115, 105, 108, 111, 110, 59, 17301, 117, 256, 97, 105, 1340, 1353, 108, 256, 59, 84, 1346, 1347, 27253, 105, 108, 100, 101, 59, 25154, 108, 105, 98, 114, 105, 117, 109, 59, 25036, 256, 99, 105, 1367, 1370, 114, 59, 24880, 109, 59, 27251, 97, 59, 17303, 109, 108, 32827, 203, 16587, 256, 105, 112, 1386, 1391, 115, 116, 115, 59, 25091, 111, 110, 101, 110, 116, 105, 97, 108, 69, 59, 24903, 640, 99, 102, 105, 111, 115, 1413, 1416, 1421, 1458, 1484, 121, 59, 17444, 114, 59, 49152, 55349, 56585, 108, 108, 101, 100, 595, 1431, 0, 0, 1443, 109, 97, 108, 108, 83, 113, 117, 97, 114, 101, 59, 26108, 101, 114, 121, 83, 109, 97, 108, 108, 83, 113, 117, 97, 114, 101, 59, 26026, 880, 1466, 0, 1471, 0, 0, 1476, 102, 59, 49152, 55349, 56637, 65, 108, 108, 59, 25088, 114, 105, 101, 114, 116, 114, 102, 59, 24881, 99, 242, 1483, 1536, 74, 84, 97, 98, 99, 100, 102, 103, 111, 114, 115, 116, 1512, 1516, 1519, 1530, 1536, 1554, 1558, 1563, 1565, 1571, 1644, 1650, 99, 121, 59, 17411, 32827, 62, 16446, 109, 109, 97, 256, 59, 100, 1527, 1528, 17299, 59, 17372, 114, 101, 118, 101, 59, 16670, 384, 101, 105, 121, 1543, 1548, 1552, 100, 105, 108, 59, 16674, 114, 99, 59, 16668, 59, 17427, 111, 116, 59, 16672, 114, 59, 49152, 55349, 56586, 59, 25305, 112, 102, 59, 49152, 55349, 56638, 101, 97, 116, 101, 114, 768, 69, 70, 71, 76, 83, 84, 1589, 1604, 1614, 1622, 1627, 1638, 113, 117, 97, 108, 256, 59, 76, 1598, 1599, 25189, 101, 115, 115, 59, 25307, 117, 108, 108, 69, 113, 117, 97, 108, 59, 25191, 114, 101, 97, 116, 101, 114, 59, 27298, 101, 115, 115, 59, 25207, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 27262, 105, 108, 100, 101, 59, 25203, 99, 114, 59, 49152, 55349, 56482, 59, 25195, 1024, 65, 97, 99, 102, 105, 111, 115, 117, 1669, 1675, 1686, 1691, 1694, 1706, 1726, 1738, 82, 68, 99, 121, 59, 17450, 256, 99, 116, 1680, 1684, 101, 107, 59, 17095, 59, 16478, 105, 114, 99, 59, 16676, 114, 59, 24844, 108, 98, 101, 114, 116, 83, 112, 97, 99, 101, 59, 24843, 496, 1711, 0, 1714, 102, 59, 24845, 105, 122, 111, 110, 116, 97, 108, 76, 105, 110, 101, 59, 25856, 256, 99, 116, 1731, 1733, 242, 1705, 114, 111, 107, 59, 16678, 109, 112, 324, 1744, 1752, 111, 119, 110, 72, 117, 109, 240, 303, 113, 117, 97, 108, 59, 25167, 1792, 69, 74, 79, 97, 99, 100, 102, 103, 109, 110, 111, 115, 116, 117, 1786, 1790, 1795, 1799, 1806, 1818, 1822, 1825, 1832, 1860, 1912, 1931, 1935, 1941, 99, 121, 59, 17429, 108, 105, 103, 59, 16690, 99, 121, 59, 17409, 99, 117, 116, 101, 32827, 205, 16589, 256, 105, 121, 1811, 1816, 114, 99, 32827, 206, 16590, 59, 17432, 111, 116, 59, 16688, 114, 59, 24849, 114, 97, 118, 101, 32827, 204, 16588, 384, 59, 97, 112, 1824, 1839, 1855, 256, 99, 103, 1844, 1847, 114, 59, 16682, 105, 110, 97, 114, 121, 73, 59, 24904, 108, 105, 101, 243, 989, 500, 1865, 0, 1890, 256, 59, 101, 1869, 1870, 25132, 256, 103, 114, 1875, 1880, 114, 97, 108, 59, 25131, 115, 101, 99, 116, 105, 111, 110, 59, 25282, 105, 115, 105, 98, 108, 101, 256, 67, 84, 1900, 1906, 111, 109, 109, 97, 59, 24675, 105, 109, 101, 115, 59, 24674, 384, 103, 112, 116, 1919, 1923, 1928, 111, 110, 59, 16686, 102, 59, 49152, 55349, 56640, 97, 59, 17305, 99, 114, 59, 24848, 105, 108, 100, 101, 59, 16680, 491, 1946, 0, 1950, 99, 121, 59, 17414, 108, 32827, 207, 16591, 640, 99, 102, 111, 115, 117, 1964, 1975, 1980, 1986, 2000, 256, 105, 121, 1969, 1973, 114, 99, 59, 16692, 59, 17433, 114, 59, 49152, 55349, 56589, 112, 102, 59, 49152, 55349, 56641, 483, 1991, 0, 1996, 114, 59, 49152, 55349, 56485, 114, 99, 121, 59, 17416, 107, 99, 121, 59, 17412, 896, 72, 74, 97, 99, 102, 111, 115, 2020, 2024, 2028, 2033, 2045, 2050, 2056, 99, 121, 59, 17445, 99, 121, 59, 17420, 112, 112, 97, 59, 17306, 256, 101, 121, 2038, 2043, 100, 105, 108, 59, 16694, 59, 17434, 114, 59, 49152, 55349, 56590, 112, 102, 59, 49152, 55349, 56642, 99, 114, 59, 49152, 55349, 56486, 1408, 74, 84, 97, 99, 101, 102, 108, 109, 111, 115, 116, 2085, 2089, 2092, 2128, 2147, 2483, 2488, 2503, 2509, 2615, 2631, 99, 121, 59, 17417, 32827, 60, 16444, 640, 99, 109, 110, 112, 114, 2103, 2108, 2113, 2116, 2125, 117, 116, 101, 59, 16697, 98, 100, 97, 59, 17307, 103, 59, 26602, 108, 97, 99, 101, 116, 114, 102, 59, 24850, 114, 59, 24990, 384, 97, 101, 121, 2135, 2140, 2145, 114, 111, 110, 59, 16701, 100, 105, 108, 59, 16699, 59, 17435, 256, 102, 115, 2152, 2416, 116, 1280, 65, 67, 68, 70, 82, 84, 85, 86, 97, 114, 2174, 2217, 2225, 2272, 2278, 2300, 2351, 2395, 912, 2410, 256, 110, 114, 2179, 2191, 103, 108, 101, 66, 114, 97, 99, 107, 101, 116, 59, 26600, 114, 111, 119, 384, 59, 66, 82, 2201, 2202, 2206, 24976, 97, 114, 59, 25060, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 25030, 101, 105, 108, 105, 110, 103, 59, 25352, 111, 501, 2231, 0, 2243, 98, 108, 101, 66, 114, 97, 99, 107, 101, 116, 59, 26598, 110, 468, 2248, 0, 2258, 101, 101, 86, 101, 99, 116, 111, 114, 59, 26977, 101, 99, 116, 111, 114, 256, 59, 66, 2267, 2268, 25027, 97, 114, 59, 26969, 108, 111, 111, 114, 59, 25354, 105, 103, 104, 116, 256, 65, 86, 2287, 2293, 114, 114, 111, 119, 59, 24980, 101, 99, 116, 111, 114, 59, 26958, 256, 101, 114, 2305, 2327, 101, 384, 59, 65, 86, 2313, 2314, 2320, 25251, 114, 114, 111, 119, 59, 24996, 101, 99, 116, 111, 114, 59, 26970, 105, 97, 110, 103, 108, 101, 384, 59, 66, 69, 2340, 2341, 2345, 25266, 97, 114, 59, 27087, 113, 117, 97, 108, 59, 25268, 112, 384, 68, 84, 86, 2359, 2370, 2380, 111, 119, 110, 86, 101, 99, 116, 111, 114, 59, 26961, 101, 101, 86, 101, 99, 116, 111, 114, 59, 26976, 101, 99, 116, 111, 114, 256, 59, 66, 2390, 2391, 25023, 97, 114, 59, 26968, 101, 99, 116, 111, 114, 256, 59, 66, 2405, 2406, 25020, 97, 114, 59, 26962, 105, 103, 104, 116, 225, 924, 115, 768, 69, 70, 71, 76, 83, 84, 2430, 2443, 2453, 2461, 2466, 2477, 113, 117, 97, 108, 71, 114, 101, 97, 116, 101, 114, 59, 25306, 117, 108, 108, 69, 113, 117, 97, 108, 59, 25190, 114, 101, 97, 116, 101, 114, 59, 25206, 101, 115, 115, 59, 27297, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 27261, 105, 108, 100, 101, 59, 25202, 114, 59, 49152, 55349, 56591, 256, 59, 101, 2493, 2494, 25304, 102, 116, 97, 114, 114, 111, 119, 59, 25050, 105, 100, 111, 116, 59, 16703, 384, 110, 112, 119, 2516, 2582, 2587, 103, 512, 76, 82, 108, 114, 2526, 2551, 2562, 2576, 101, 102, 116, 256, 65, 82, 2534, 2540, 114, 114, 111, 119, 59, 26613, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 26615, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 26614, 101, 102, 116, 256, 97, 114, 947, 2570, 105, 103, 104, 116, 225, 959, 105, 103, 104, 116, 225, 970, 102, 59, 49152, 55349, 56643, 101, 114, 256, 76, 82, 2594, 2604, 101, 102, 116, 65, 114, 114, 111, 119, 59, 24985, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 24984, 384, 99, 104, 116, 2622, 2624, 2626, 242, 2124, 59, 25008, 114, 111, 107, 59, 16705, 59, 25194, 1024, 97, 99, 101, 102, 105, 111, 115, 117, 2650, 2653, 2656, 2679, 2684, 2693, 2699, 2702, 112, 59, 26885, 121, 59, 17436, 256, 100, 108, 2661, 2671, 105, 117, 109, 83, 112, 97, 99, 101, 59, 24671, 108, 105, 110, 116, 114, 102, 59, 24883, 114, 59, 49152, 55349, 56592, 110, 117, 115, 80, 108, 117, 115, 59, 25107, 112, 102, 59, 49152, 55349, 56644, 99, 242, 2678, 59, 17308, 1152, 74, 97, 99, 101, 102, 111, 115, 116, 117, 2723, 2727, 2733, 2752, 2836, 2841, 3473, 3479, 3486, 99, 121, 59, 17418, 99, 117, 116, 101, 59, 16707, 384, 97, 101, 121, 2740, 2745, 2750, 114, 111, 110, 59, 16711, 100, 105, 108, 59, 16709, 59, 17437, 384, 103, 115, 119, 2759, 2800, 2830, 97, 116, 105, 118, 101, 384, 77, 84, 86, 2771, 2783, 2792, 101, 100, 105, 117, 109, 83, 112, 97, 99, 101, 59, 24587, 104, 105, 256, 99, 110, 2790, 2776, 235, 2777, 101, 114, 121, 84, 104, 105, 238, 2777, 116, 101, 100, 256, 71, 76, 2808, 2822, 114, 101, 97, 116, 101, 114, 71, 114, 101, 97, 116, 101, 242, 1651, 101, 115, 115, 76, 101, 115, 243, 2632, 76, 105, 110, 101, 59, 16394, 114, 59, 49152, 55349, 56593, 512, 66, 110, 112, 116, 2850, 2856, 2871, 2874, 114, 101, 97, 107, 59, 24672, 66, 114, 101, 97, 107, 105, 110, 103, 83, 112, 97, 99, 101, 59, 16544, 102, 59, 24853, 1664, 59, 67, 68, 69, 71, 72, 76, 78, 80, 82, 83, 84, 86, 2901, 2902, 2922, 2940, 2977, 3051, 3076, 3166, 3204, 3238, 3288, 3425, 3461, 27372, 256, 111, 117, 2907, 2916, 110, 103, 114, 117, 101, 110, 116, 59, 25186, 112, 67, 97, 112, 59, 25197, 111, 117, 98, 108, 101, 86, 101, 114, 116, 105, 99, 97, 108, 66, 97, 114, 59, 25126, 384, 108, 113, 120, 2947, 2954, 2971, 101, 109, 101, 110, 116, 59, 25097, 117, 97, 108, 256, 59, 84, 2962, 2963, 25184, 105, 108, 100, 101, 59, 49152, 8770, 824, 105, 115, 116, 115, 59, 25092, 114, 101, 97, 116, 101, 114, 896, 59, 69, 70, 71, 76, 83, 84, 2998, 2999, 3005, 3017, 3027, 3032, 3045, 25199, 113, 117, 97, 108, 59, 25201, 117, 108, 108, 69, 113, 117, 97, 108, 59, 49152, 8807, 824, 114, 101, 97, 116, 101, 114, 59, 49152, 8811, 824, 101, 115, 115, 59, 25209, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 49152, 10878, 824, 105, 108, 100, 101, 59, 25205, 117, 109, 112, 324, 3058, 3069, 111, 119, 110, 72, 117, 109, 112, 59, 49152, 8782, 824, 113, 117, 97, 108, 59, 49152, 8783, 824, 101, 256, 102, 115, 3082, 3111, 116, 84, 114, 105, 97, 110, 103, 108, 101, 384, 59, 66, 69, 3098, 3099, 3105, 25322, 97, 114, 59, 49152, 10703, 824, 113, 117, 97, 108, 59, 25324, 115, 768, 59, 69, 71, 76, 83, 84, 3125, 3126, 3132, 3140, 3147, 3160, 25198, 113, 117, 97, 108, 59, 25200, 114, 101, 97, 116, 101, 114, 59, 25208, 101, 115, 115, 59, 49152, 8810, 824, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 49152, 10877, 824, 105, 108, 100, 101, 59, 25204, 101, 115, 116, 101, 100, 256, 71, 76, 3176, 3193, 114, 101, 97, 116, 101, 114, 71, 114, 101, 97, 116, 101, 114, 59, 49152, 10914, 824, 101, 115, 115, 76, 101, 115, 115, 59, 49152, 10913, 824, 114, 101, 99, 101, 100, 101, 115, 384, 59, 69, 83, 3218, 3219, 3227, 25216, 113, 117, 97, 108, 59, 49152, 10927, 824, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 25312, 256, 101, 105, 3243, 3257, 118, 101, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 59, 25100, 103, 104, 116, 84, 114, 105, 97, 110, 103, 108, 101, 384, 59, 66, 69, 3275, 3276, 3282, 25323, 97, 114, 59, 49152, 10704, 824, 113, 117, 97, 108, 59, 25325, 256, 113, 117, 3293, 3340, 117, 97, 114, 101, 83, 117, 256, 98, 112, 3304, 3321, 115, 101, 116, 256, 59, 69, 3312, 3315, 49152, 8847, 824, 113, 117, 97, 108, 59, 25314, 101, 114, 115, 101, 116, 256, 59, 69, 3331, 3334, 49152, 8848, 824, 113, 117, 97, 108, 59, 25315, 384, 98, 99, 112, 3347, 3364, 3406, 115, 101, 116, 256, 59, 69, 3355, 3358, 49152, 8834, 8402, 113, 117, 97, 108, 59, 25224, 99, 101, 101, 100, 115, 512, 59, 69, 83, 84, 3378, 3379, 3387, 3398, 25217, 113, 117, 97, 108, 59, 49152, 10928, 824, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 25313, 105, 108, 100, 101, 59, 49152, 8831, 824, 101, 114, 115, 101, 116, 256, 59, 69, 3416, 3419, 49152, 8835, 8402, 113, 117, 97, 108, 59, 25225, 105, 108, 100, 101, 512, 59, 69, 70, 84, 3438, 3439, 3445, 3455, 25153, 113, 117, 97, 108, 59, 25156, 117, 108, 108, 69, 113, 117, 97, 108, 59, 25159, 105, 108, 100, 101, 59, 25161, 101, 114, 116, 105, 99, 97, 108, 66, 97, 114, 59, 25124, 99, 114, 59, 49152, 55349, 56489, 105, 108, 100, 101, 32827, 209, 16593, 59, 17309, 1792, 69, 97, 99, 100, 102, 103, 109, 111, 112, 114, 115, 116, 117, 118, 3517, 3522, 3529, 3541, 3547, 3552, 3559, 3580, 3586, 3616, 3618, 3634, 3647, 3652, 108, 105, 103, 59, 16722, 99, 117, 116, 101, 32827, 211, 16595, 256, 105, 121, 3534, 3539, 114, 99, 32827, 212, 16596, 59, 17438, 98, 108, 97, 99, 59, 16720, 114, 59, 49152, 55349, 56594, 114, 97, 118, 101, 32827, 210, 16594, 384, 97, 101, 105, 3566, 3570, 3574, 99, 114, 59, 16716, 103, 97, 59, 17321, 99, 114, 111, 110, 59, 17311, 112, 102, 59, 49152, 55349, 56646, 101, 110, 67, 117, 114, 108, 121, 256, 68, 81, 3598, 3610, 111, 117, 98, 108, 101, 81, 117, 111, 116, 101, 59, 24604, 117, 111, 116, 101, 59, 24600, 59, 27220, 256, 99, 108, 3623, 3628, 114, 59, 49152, 55349, 56490, 97, 115, 104, 32827, 216, 16600, 105, 364, 3639, 3644, 100, 101, 32827, 213, 16597, 101, 115, 59, 27191, 109, 108, 32827, 214, 16598, 101, 114, 256, 66, 80, 3659, 3680, 256, 97, 114, 3664, 3667, 114, 59, 24638, 97, 99, 256, 101, 107, 3674, 3676, 59, 25566, 101, 116, 59, 25524, 97, 114, 101, 110, 116, 104, 101, 115, 105, 115, 59, 25564, 1152, 97, 99, 102, 104, 105, 108, 111, 114, 115, 3711, 3719, 3722, 3727, 3730, 3732, 3741, 3760, 3836, 114, 116, 105, 97, 108, 68, 59, 25090, 121, 59, 17439, 114, 59, 49152, 55349, 56595, 105, 59, 17318, 59, 17312, 117, 115, 77, 105, 110, 117, 115, 59, 16561, 256, 105, 112, 3746, 3757, 110, 99, 97, 114, 101, 112, 108, 97, 110, 229, 1693, 102, 59, 24857, 512, 59, 101, 105, 111, 3769, 3770, 3808, 3812, 27323, 99, 101, 100, 101, 115, 512, 59, 69, 83, 84, 3784, 3785, 3791, 3802, 25210, 113, 117, 97, 108, 59, 27311, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 25212, 105, 108, 100, 101, 59, 25214, 109, 101, 59, 24627, 256, 100, 112, 3817, 3822, 117, 99, 116, 59, 25103, 111, 114, 116, 105, 111, 110, 256, 59, 97, 549, 3833, 108, 59, 25117, 256, 99, 105, 3841, 3846, 114, 59, 49152, 55349, 56491, 59, 17320, 512, 85, 102, 111, 115, 3857, 3862, 3867, 3871, 79, 84, 32827, 34, 16418, 114, 59, 49152, 55349, 56596, 112, 102, 59, 24858, 99, 114, 59, 49152, 55349, 56492, 1536, 66, 69, 97, 99, 101, 102, 104, 105, 111, 114, 115, 117, 3902, 3907, 3911, 3936, 3955, 4007, 4010, 4013, 4246, 4265, 4276, 4286, 97, 114, 114, 59, 26896, 71, 32827, 174, 16558, 384, 99, 110, 114, 3918, 3923, 3926, 117, 116, 101, 59, 16724, 103, 59, 26603, 114, 256, 59, 116, 3932, 3933, 24992, 108, 59, 26902, 384, 97, 101, 121, 3943, 3948, 3953, 114, 111, 110, 59, 16728, 100, 105, 108, 59, 16726, 59, 17440, 256, 59, 118, 3960, 3961, 24860, 101, 114, 115, 101, 256, 69, 85, 3970, 3993, 256, 108, 113, 3975, 3982, 101, 109, 101, 110, 116, 59, 25099, 117, 105, 108, 105, 98, 114, 105, 117, 109, 59, 25035, 112, 69, 113, 117, 105, 108, 105, 98, 114, 105, 117, 109, 59, 26991, 114, 187, 3961, 111, 59, 17313, 103, 104, 116, 1024, 65, 67, 68, 70, 84, 85, 86, 97, 4033, 4075, 4083, 4130, 4136, 4187, 4231, 984, 256, 110, 114, 4038, 4050, 103, 108, 101, 66, 114, 97, 99, 107, 101, 116, 59, 26601, 114, 111, 119, 384, 59, 66, 76, 4060, 4061, 4065, 24978, 97, 114, 59, 25061, 101, 102, 116, 65, 114, 114, 111, 119, 59, 25028, 101, 105, 108, 105, 110, 103, 59, 25353, 111, 501, 4089, 0, 4101, 98, 108, 101, 66, 114, 97, 99, 107, 101, 116, 59, 26599, 110, 468, 4106, 0, 4116, 101, 101, 86, 101, 99, 116, 111, 114, 59, 26973, 101, 99, 116, 111, 114, 256, 59, 66, 4125, 4126, 25026, 97, 114, 59, 26965, 108, 111, 111, 114, 59, 25355, 256, 101, 114, 4141, 4163, 101, 384, 59, 65, 86, 4149, 4150, 4156, 25250, 114, 114, 111, 119, 59, 24998, 101, 99, 116, 111, 114, 59, 26971, 105, 97, 110, 103, 108, 101, 384, 59, 66, 69, 4176, 4177, 4181, 25267, 97, 114, 59, 27088, 113, 117, 97, 108, 59, 25269, 112, 384, 68, 84, 86, 4195, 4206, 4216, 111, 119, 110, 86, 101, 99, 116, 111, 114, 59, 26959, 101, 101, 86, 101, 99, 116, 111, 114, 59, 26972, 101, 99, 116, 111, 114, 256, 59, 66, 4226, 4227, 25022, 97, 114, 59, 26964, 101, 99, 116, 111, 114, 256, 59, 66, 4241, 4242, 25024, 97, 114, 59, 26963, 256, 112, 117, 4251, 4254, 102, 59, 24861, 110, 100, 73, 109, 112, 108, 105, 101, 115, 59, 26992, 105, 103, 104, 116, 97, 114, 114, 111, 119, 59, 25051, 256, 99, 104, 4281, 4284, 114, 59, 24859, 59, 25009, 108, 101, 68, 101, 108, 97, 121, 101, 100, 59, 27124, 1664, 72, 79, 97, 99, 102, 104, 105, 109, 111, 113, 115, 116, 117, 4324, 4337, 4343, 4349, 4377, 4382, 4433, 4438, 4449, 4455, 4533, 4539, 4543, 256, 67, 99, 4329, 4334, 72, 99, 121, 59, 17449, 121, 59, 17448, 70, 84, 99, 121, 59, 17452, 99, 117, 116, 101, 59, 16730, 640, 59, 97, 101, 105, 121, 4360, 4361, 4366, 4371, 4375, 27324, 114, 111, 110, 59, 16736, 100, 105, 108, 59, 16734, 114, 99, 59, 16732, 59, 17441, 114, 59, 49152, 55349, 56598, 111, 114, 116, 512, 68, 76, 82, 85, 4394, 4404, 4414, 4425, 111, 119, 110, 65, 114, 114, 111, 119, 187, 1054, 101, 102, 116, 65, 114, 114, 111, 119, 187, 2202, 105, 103, 104, 116, 65, 114, 114, 111, 119, 187, 4061, 112, 65, 114, 114, 111, 119, 59, 24977, 103, 109, 97, 59, 17315, 97, 108, 108, 67, 105, 114, 99, 108, 101, 59, 25112, 112, 102, 59, 49152, 55349, 56650, 626, 4461, 0, 0, 4464, 116, 59, 25114, 97, 114, 101, 512, 59, 73, 83, 85, 4475, 4476, 4489, 4527, 26017, 110, 116, 101, 114, 115, 101, 99, 116, 105, 111, 110, 59, 25235, 117, 256, 98, 112, 4495, 4510, 115, 101, 116, 256, 59, 69, 4503, 4504, 25231, 113, 117, 97, 108, 59, 25233, 101, 114, 115, 101, 116, 256, 59, 69, 4520, 4521, 25232, 113, 117, 97, 108, 59, 25234, 110, 105, 111, 110, 59, 25236, 99, 114, 59, 49152, 55349, 56494, 97, 114, 59, 25286, 512, 98, 99, 109, 112, 4552, 4571, 4617, 4619, 256, 59, 115, 4557, 4558, 25296, 101, 116, 256, 59, 69, 4557, 4565, 113, 117, 97, 108, 59, 25222, 256, 99, 104, 4576, 4613, 101, 101, 100, 115, 512, 59, 69, 83, 84, 4589, 4590, 4596, 4607, 25211, 113, 117, 97, 108, 59, 27312, 108, 97, 110, 116, 69, 113, 117, 97, 108, 59, 25213, 105, 108, 100, 101, 59, 25215, 84, 104, 225, 3980, 59, 25105, 384, 59, 101, 115, 4626, 4627, 4643, 25297, 114, 115, 101, 116, 256, 59, 69, 4636, 4637, 25219, 113, 117, 97, 108, 59, 25223, 101, 116, 187, 4627, 1408, 72, 82, 83, 97, 99, 102, 104, 105, 111, 114, 115, 4670, 4676, 4681, 4693, 4702, 4721, 4726, 4767, 4802, 4808, 4817, 79, 82, 78, 32827, 222, 16606, 65, 68, 69, 59, 24866, 256, 72, 99, 4686, 4690, 99, 121, 59, 17419, 121, 59, 17446, 256, 98, 117, 4698, 4700, 59, 16393, 59, 17316, 384, 97, 101, 121, 4709, 4714, 4719, 114, 111, 110, 59, 16740, 100, 105, 108, 59, 16738, 59, 17442, 114, 59, 49152, 55349, 56599, 256, 101, 105, 4731, 4745, 498, 4736, 0, 4743, 101, 102, 111, 114, 101, 59, 25140, 97, 59, 17304, 256, 99, 110, 4750, 4760, 107, 83, 112, 97, 99, 101, 59, 49152, 8287, 8202, 83, 112, 97, 99, 101, 59, 24585, 108, 100, 101, 512, 59, 69, 70, 84, 4779, 4780, 4786, 4796, 25148, 113, 117, 97, 108, 59, 25155, 117, 108, 108, 69, 113, 117, 97, 108, 59, 25157, 105, 108, 100, 101, 59, 25160, 112, 102, 59, 49152, 55349, 56651, 105, 112, 108, 101, 68, 111, 116, 59, 24795, 256, 99, 116, 4822, 4827, 114, 59, 49152, 55349, 56495, 114, 111, 107, 59, 16742, 2785, 4855, 4878, 4890, 4902, 0, 4908, 4913, 0, 0, 0, 0, 0, 4920, 4925, 4983, 4997, 0, 5119, 5124, 5130, 5136, 256, 99, 114, 4859, 4865, 117, 116, 101, 32827, 218, 16602, 114, 256, 59, 111, 4871, 4872, 24991, 99, 105, 114, 59, 26953, 114, 483, 4883, 0, 4886, 121, 59, 17422, 118, 101, 59, 16748, 256, 105, 121, 4894, 4899, 114, 99, 32827, 219, 16603, 59, 17443, 98, 108, 97, 99, 59, 16752, 114, 59, 49152, 55349, 56600, 114, 97, 118, 101, 32827, 217, 16601, 97, 99, 114, 59, 16746, 256, 100, 105, 4929, 4969, 101, 114, 256, 66, 80, 4936, 4957, 256, 97, 114, 4941, 4944, 114, 59, 16479, 97, 99, 256, 101, 107, 4951, 4953, 59, 25567, 101, 116, 59, 25525, 97, 114, 101, 110, 116, 104, 101, 115, 105, 115, 59, 25565, 111, 110, 256, 59, 80, 4976, 4977, 25283, 108, 117, 115, 59, 25230, 256, 103, 112, 4987, 4991, 111, 110, 59, 16754, 102, 59, 49152, 55349, 56652, 1024, 65, 68, 69, 84, 97, 100, 112, 115, 5013, 5038, 5048, 5060, 1000, 5074, 5079, 5107, 114, 114, 111, 119, 384, 59, 66, 68, 4432, 5024, 5028, 97, 114, 59, 26898, 111, 119, 110, 65, 114, 114, 111, 119, 59, 25029, 111, 119, 110, 65, 114, 114, 111, 119, 59, 24981, 113, 117, 105, 108, 105, 98, 114, 105, 117, 109, 59, 26990, 101, 101, 256, 59, 65, 5067, 5068, 25253, 114, 114, 111, 119, 59, 24997, 111, 119, 110, 225, 1011, 101, 114, 256, 76, 82, 5086, 5096, 101, 102, 116, 65, 114, 114, 111, 119, 59, 24982, 105, 103, 104, 116, 65, 114, 114, 111, 119, 59, 24983, 105, 256, 59, 108, 5113, 5114, 17362, 111, 110, 59, 17317, 105, 110, 103, 59, 16750, 99, 114, 59, 49152, 55349, 56496, 105, 108, 100, 101, 59, 16744, 109, 108, 32827, 220, 16604, 1152, 68, 98, 99, 100, 101, 102, 111, 115, 118, 5159, 5164, 5168, 5171, 5182, 5253, 5258, 5264, 5270, 97, 115, 104, 59, 25259, 97, 114, 59, 27371, 121, 59, 17426, 97, 115, 104, 256, 59, 108, 5179, 5180, 25257, 59, 27366, 256, 101, 114, 5187, 5189, 59, 25281, 384, 98, 116, 121, 5196, 5200, 5242, 97, 114, 59, 24598, 256, 59, 105, 5199, 5205, 99, 97, 108, 512, 66, 76, 83, 84, 5217, 5221, 5226, 5236, 97, 114, 59, 25123, 105, 110, 101, 59, 16508, 101, 112, 97, 114, 97, 116, 111, 114, 59, 26456, 105, 108, 100, 101, 59, 25152, 84, 104, 105, 110, 83, 112, 97, 99, 101, 59, 24586, 114, 59, 49152, 55349, 56601, 112, 102, 59, 49152, 55349, 56653, 99, 114, 59, 49152, 55349, 56497, 100, 97, 115, 104, 59, 25258, 640, 99, 101, 102, 111, 115, 5287, 5292, 5297, 5302, 5308, 105, 114, 99, 59, 16756, 100, 103, 101, 59, 25280, 114, 59, 49152, 55349, 56602, 112, 102, 59, 49152, 55349, 56654, 99, 114, 59, 49152, 55349, 56498, 512, 102, 105, 111, 115, 5323, 5328, 5330, 5336, 114, 59, 49152, 55349, 56603, 59, 17310, 112, 102, 59, 49152, 55349, 56655, 99, 114, 59, 49152, 55349, 56499, 1152, 65, 73, 85, 97, 99, 102, 111, 115, 117, 5361, 5365, 5369, 5373, 5380, 5391, 5396, 5402, 5408, 99, 121, 59, 17455, 99, 121, 59, 17415, 99, 121, 59, 17454, 99, 117, 116, 101, 32827, 221, 16605, 256, 105, 121, 5385, 5389, 114, 99, 59, 16758, 59, 17451, 114, 59, 49152, 55349, 56604, 112, 102, 59, 49152, 55349, 56656, 99, 114, 59, 49152, 55349, 56500, 109, 108, 59, 16760, 1024, 72, 97, 99, 100, 101, 102, 111, 115, 5429, 5433, 5439, 5451, 5455, 5469, 5472, 5476, 99, 121, 59, 17430, 99, 117, 116, 101, 59, 16761, 256, 97, 121, 5444, 5449, 114, 111, 110, 59, 16765, 59, 17431, 111, 116, 59, 16763, 498, 5460, 0, 5467, 111, 87, 105, 100, 116, 232, 2777, 97, 59, 17302, 114, 59, 24872, 112, 102, 59, 24868, 99, 114, 59, 49152, 55349, 56501, 3041, 5507, 5514, 5520, 0, 5552, 5558, 5567, 0, 0, 0, 0, 5574, 5595, 5611, 5727, 5741, 0, 5781, 5787, 5810, 5817, 0, 5822, 99, 117, 116, 101, 32827, 225, 16609, 114, 101, 118, 101, 59, 16643, 768, 59, 69, 100, 105, 117, 121, 5532, 5533, 5537, 5539, 5544, 5549, 25150, 59, 49152, 8766, 819, 59, 25151, 114, 99, 32827, 226, 16610, 116, 101, 32955, 180, 774, 59, 17456, 108, 105, 103, 32827, 230, 16614, 256, 59, 114, 178, 5562, 59, 49152, 55349, 56606, 114, 97, 118, 101, 32827, 224, 16608, 256, 101, 112, 5578, 5590, 256, 102, 112, 5583, 5588, 115, 121, 109, 59, 24885, 232, 5587, 104, 97, 59, 17329, 256, 97, 112, 5599, 99, 256, 99, 108, 5604, 5607, 114, 59, 16641, 103, 59, 27199, 612, 5616, 0, 0, 5642, 640, 59, 97, 100, 115, 118, 5626, 5627, 5631, 5633, 5639, 25127, 110, 100, 59, 27221, 59, 27228, 108, 111, 112, 101, 59, 27224, 59, 27226, 896, 59, 101, 108, 109, 114, 115, 122, 5656, 5657, 5659, 5662, 5695, 5711, 5721, 25120, 59, 27044, 101, 187, 5657, 115, 100, 256, 59, 97, 5669, 5670, 25121, 1121, 5680, 5682, 5684, 5686, 5688, 5690, 5692, 5694, 59, 27048, 59, 27049, 59, 27050, 59, 27051, 59, 27052, 59, 27053, 59, 27054, 59, 27055, 116, 256, 59, 118, 5701, 5702, 25119, 98, 256, 59, 100, 5708, 5709, 25278, 59, 27037, 256, 112, 116, 5716, 5719, 104, 59, 25122, 187, 185, 97, 114, 114, 59, 25468, 256, 103, 112, 5731, 5735, 111, 110, 59, 16645, 102, 59, 49152, 55349, 56658, 896, 59, 69, 97, 101, 105, 111, 112, 4801, 5755, 5757, 5762, 5764, 5767, 5770, 59, 27248, 99, 105, 114, 59, 27247, 59, 25162, 100, 59, 25163, 115, 59, 16423, 114, 111, 120, 256, 59, 101, 4801, 5778, 241, 5763, 105, 110, 103, 32827, 229, 16613, 384, 99, 116, 121, 5793, 5798, 5800, 114, 59, 49152, 55349, 56502, 59, 16426, 109, 112, 256, 59, 101, 4801, 5807, 241, 648, 105, 108, 100, 101, 32827, 227, 16611, 109, 108, 32827, 228, 16612, 256, 99, 105, 5826, 5832, 111, 110, 105, 110, 244, 626, 110, 116, 59, 27153, 2048, 78, 97, 98, 99, 100, 101, 102, 105, 107, 108, 110, 111, 112, 114, 115, 117, 5869, 5873, 5936, 5948, 5955, 5960, 6008, 6013, 6112, 6118, 6201, 6224, 5901, 6461, 6472, 6512, 111, 116, 59, 27373, 256, 99, 114, 5878, 5918, 107, 512, 99, 101, 112, 115, 5888, 5893, 5901, 5907, 111, 110, 103, 59, 25164, 112, 115, 105, 108, 111, 110, 59, 17398, 114, 105, 109, 101, 59, 24629, 105, 109, 256, 59, 101, 5914, 5915, 25149, 113, 59, 25293, 374, 5922, 5926, 101, 101, 59, 25277, 101, 100, 256, 59, 103, 5932, 5933, 25349, 101, 187, 5933, 114, 107, 256, 59, 116, 4956, 5943, 98, 114, 107, 59, 25526, 256, 111, 121, 5889, 5953, 59, 17457, 113, 117, 111, 59, 24606, 640, 99, 109, 112, 114, 116, 5971, 5979, 5985, 5988, 5992, 97, 117, 115, 256, 59, 101, 266, 265, 112, 116, 121, 118, 59, 27056, 115, 233, 5900, 110, 111, 245, 275, 384, 97, 104, 119, 5999, 6001, 6003, 59, 17330, 59, 24886, 101, 101, 110, 59, 25196, 114, 59, 49152, 55349, 56607, 103, 896, 99, 111, 115, 116, 117, 118, 119, 6029, 6045, 6067, 6081, 6101, 6107, 6110, 384, 97, 105, 117, 6036, 6038, 6042, 240, 1888, 114, 99, 59, 26095, 112, 187, 4977, 384, 100, 112, 116, 6052, 6056, 6061, 111, 116, 59, 27136, 108, 117, 115, 59, 27137, 105, 109, 101, 115, 59, 27138, 625, 6073, 0, 0, 6078, 99, 117, 112, 59, 27142, 97, 114, 59, 26117, 114, 105, 97, 110, 103, 108, 101, 256, 100, 117, 6093, 6098, 111, 119, 110, 59, 26045, 112, 59, 26035, 112, 108, 117, 115, 59, 27140, 101, 229, 5188, 229, 5293, 97, 114, 111, 119, 59, 26893, 384, 97, 107, 111, 6125, 6182, 6197, 256, 99, 110, 6130, 6179, 107, 384, 108, 115, 116, 6138, 1451, 6146, 111, 122, 101, 110, 103, 101, 59, 27115, 114, 105, 97, 110, 103, 108, 101, 512, 59, 100, 108, 114, 6162, 6163, 6168, 6173, 26036, 111, 119, 110, 59, 26046, 101, 102, 116, 59, 26050, 105, 103, 104, 116, 59, 26040, 107, 59, 25635, 433, 6187, 0, 6195, 434, 6191, 0, 6193, 59, 26002, 59, 26001, 52, 59, 26003, 99, 107, 59, 25992, 256, 101, 111, 6206, 6221, 256, 59, 113, 6211, 6214, 49152, 61, 8421, 117, 105, 118, 59, 49152, 8801, 8421, 116, 59, 25360, 512, 112, 116, 119, 120, 6233, 6238, 6247, 6252, 102, 59, 49152, 55349, 56659, 256, 59, 116, 5067, 6243, 111, 109, 187, 5068, 116, 105, 101, 59, 25288, 1536, 68, 72, 85, 86, 98, 100, 104, 109, 112, 116, 117, 118, 6277, 6294, 6314, 6331, 6359, 6363, 6380, 6399, 6405, 6410, 6416, 6433, 512, 76, 82, 108, 114, 6286, 6288, 6290, 6292, 59, 25943, 59, 25940, 59, 25942, 59, 25939, 640, 59, 68, 85, 100, 117, 6305, 6306, 6308, 6310, 6312, 25936, 59, 25958, 59, 25961, 59, 25956, 59, 25959, 512, 76, 82, 108, 114, 6323, 6325, 6327, 6329, 59, 25949, 59, 25946, 59, 25948, 59, 25945, 896, 59, 72, 76, 82, 104, 108, 114, 6346, 6347, 6349, 6351, 6353, 6355, 6357, 25937, 59, 25964, 59, 25955, 59, 25952, 59, 25963, 59, 25954, 59, 25951, 111, 120, 59, 27081, 512, 76, 82, 108, 114, 6372, 6374, 6376, 6378, 59, 25941, 59, 25938, 59, 25872, 59, 25868, 640, 59, 68, 85, 100, 117, 1725, 6391, 6393, 6395, 6397, 59, 25957, 59, 25960, 59, 25900, 59, 25908, 105, 110, 117, 115, 59, 25247, 108, 117, 115, 59, 25246, 105, 109, 101, 115, 59, 25248, 512, 76, 82, 108, 114, 6425, 6427, 6429, 6431, 59, 25947, 59, 25944, 59, 25880, 59, 25876, 896, 59, 72, 76, 82, 104, 108, 114, 6448, 6449, 6451, 6453, 6455, 6457, 6459, 25858, 59, 25962, 59, 25953, 59, 25950, 59, 25916, 59, 25892, 59, 25884, 256, 101, 118, 291, 6466, 98, 97, 114, 32827, 166, 16550, 512, 99, 101, 105, 111, 6481, 6486, 6490, 6496, 114, 59, 49152, 55349, 56503, 109, 105, 59, 24655, 109, 256, 59, 101, 5914, 5916, 108, 384, 59, 98, 104, 6504, 6505, 6507, 16476, 59, 27077, 115, 117, 98, 59, 26568, 364, 6516, 6526, 108, 256, 59, 101, 6521, 6522, 24610, 116, 187, 6522, 112, 384, 59, 69, 101, 303, 6533, 6535, 59, 27310, 256, 59, 113, 1756, 1755, 3297, 6567, 0, 6632, 6673, 6677, 6706, 0, 6711, 6736, 0, 0, 6836, 0, 0, 6849, 0, 0, 6945, 6958, 6989, 6994, 0, 7165, 0, 7180, 384, 99, 112, 114, 6573, 6578, 6621, 117, 116, 101, 59, 16647, 768, 59, 97, 98, 99, 100, 115, 6591, 6592, 6596, 6602, 6613, 6617, 25129, 110, 100, 59, 27204, 114, 99, 117, 112, 59, 27209, 256, 97, 117, 6607, 6610, 112, 59, 27211, 112, 59, 27207, 111, 116, 59, 27200, 59, 49152, 8745, 65024, 256, 101, 111, 6626, 6629, 116, 59, 24641, 238, 1683, 512, 97, 101, 105, 117, 6640, 6651, 6657, 6661, 496, 6645, 0, 6648, 115, 59, 27213, 111, 110, 59, 16653, 100, 105, 108, 32827, 231, 16615, 114, 99, 59, 16649, 112, 115, 256, 59, 115, 6668, 6669, 27212, 109, 59, 27216, 111, 116, 59, 16651, 384, 100, 109, 110, 6683, 6688, 6694, 105, 108, 32955, 184, 429, 112, 116, 121, 118, 59, 27058, 116, 33024, 162, 59, 101, 6701, 6702, 16546, 114, 228, 434, 114, 59, 49152, 55349, 56608, 384, 99, 101, 105, 6717, 6720, 6733, 121, 59, 17479, 99, 107, 256, 59, 109, 6727, 6728, 26387, 97, 114, 107, 187, 6728, 59, 17351, 114, 896, 59, 69, 99, 101, 102, 109, 115, 6751, 6752, 6754, 6763, 6820, 6826, 6830, 26059, 59, 27075, 384, 59, 101, 108, 6761, 6762, 6765, 17094, 113, 59, 25175, 101, 609, 6772, 0, 0, 6792, 114, 114, 111, 119, 256, 108, 114, 6780, 6785, 101, 102, 116, 59, 25018, 105, 103, 104, 116, 59, 25019, 640, 82, 83, 97, 99, 100, 6802, 6804, 6806, 6810, 6815, 187, 3911, 59, 25800, 115, 116, 59, 25243, 105, 114, 99, 59, 25242, 97, 115, 104, 59, 25245, 110, 105, 110, 116, 59, 27152, 105, 100, 59, 27375, 99, 105, 114, 59, 27074, 117, 98, 115, 256, 59, 117, 6843, 6844, 26211, 105, 116, 187, 6844, 748, 6855, 6868, 6906, 0, 6922, 111, 110, 256, 59, 101, 6861, 6862, 16442, 256, 59, 113, 199, 198, 621, 6873, 0, 0, 6882, 97, 256, 59, 116, 6878, 6879, 16428, 59, 16448, 384, 59, 102, 108, 6888, 6889, 6891, 25089, 238, 4448, 101, 256, 109, 120, 6897, 6902, 101, 110, 116, 187, 6889, 101, 243, 589, 487, 6910, 0, 6919, 256, 59, 100, 4795, 6914, 111, 116, 59, 27245, 110, 244, 582, 384, 102, 114, 121, 6928, 6932, 6935, 59, 49152, 55349, 56660, 111, 228, 596, 33024, 169, 59, 115, 341, 6941, 114, 59, 24855, 256, 97, 111, 6949, 6953, 114, 114, 59, 25013, 115, 115, 59, 26391, 256, 99, 117, 6962, 6967, 114, 59, 49152, 55349, 56504, 256, 98, 112, 6972, 6980, 256, 59, 101, 6977, 6978, 27343, 59, 27345, 256, 59, 101, 6985, 6986, 27344, 59, 27346, 100, 111, 116, 59, 25327, 896, 100, 101, 108, 112, 114, 118, 119, 7008, 7020, 7031, 7042, 7084, 7124, 7161, 97, 114, 114, 256, 108, 114, 7016, 7018, 59, 26936, 59, 26933, 624, 7026, 0, 0, 7029, 114, 59, 25310, 99, 59, 25311, 97, 114, 114, 256, 59, 112, 7039, 7040, 25014, 59, 26941, 768, 59, 98, 99, 100, 111, 115, 7055, 7056, 7062, 7073, 7077, 7080, 25130, 114, 99, 97, 112, 59, 27208, 256, 97, 117, 7067, 7070, 112, 59, 27206, 112, 59, 27210, 111, 116, 59, 25229, 114, 59, 27205, 59, 49152, 8746, 65024, 512, 97, 108, 114, 118, 7093, 7103, 7134, 7139, 114, 114, 256, 59, 109, 7100, 7101, 25015, 59, 26940, 121, 384, 101, 118, 119, 7111, 7124, 7128, 113, 624, 7118, 0, 0, 7122, 114, 101, 227, 7027, 117, 227, 7029, 101, 101, 59, 25294, 101, 100, 103, 101, 59, 25295, 101, 110, 32827, 164, 16548, 101, 97, 114, 114, 111, 119, 256, 108, 114, 7150, 7155, 101, 102, 116, 187, 7040, 105, 103, 104, 116, 187, 7101, 101, 228, 7133, 256, 99, 105, 7169, 7175, 111, 110, 105, 110, 244, 503, 110, 116, 59, 25137, 108, 99, 116, 121, 59, 25389, 2432, 65, 72, 97, 98, 99, 100, 101, 102, 104, 105, 106, 108, 111, 114, 115, 116, 117, 119, 122, 7224, 7227, 7231, 7261, 7273, 7285, 7306, 7326, 7340, 7351, 7419, 7423, 7437, 7547, 7569, 7595, 7611, 7622, 7629, 114, 242, 897, 97, 114, 59, 26981, 512, 103, 108, 114, 115, 7240, 7245, 7250, 7252, 103, 101, 114, 59, 24608, 101, 116, 104, 59, 24888, 242, 4403, 104, 256, 59, 118, 7258, 7259, 24592, 187, 2314, 363, 7265, 7271, 97, 114, 111, 119, 59, 26895, 97, 227, 789, 256, 97, 121, 7278, 7283, 114, 111, 110, 59, 16655, 59, 17460, 384, 59, 97, 111, 818, 7292, 7300, 256, 103, 114, 703, 7297, 114, 59, 25034, 116, 115, 101, 113, 59, 27255, 384, 103, 108, 109, 7313, 7316, 7320, 32827, 176, 16560, 116, 97, 59, 17332, 112, 116, 121, 118, 59, 27057, 256, 105, 114, 7331, 7336, 115, 104, 116, 59, 27007, 59, 49152, 55349, 56609, 97, 114, 256, 108, 114, 7347, 7349, 187, 2268, 187, 4126, 640, 97, 101, 103, 115, 118, 7362, 888, 7382, 7388, 7392, 109, 384, 59, 111, 115, 806, 7370, 7380, 110, 100, 256, 59, 115, 806, 7377, 117, 105, 116, 59, 26214, 97, 109, 109, 97, 59, 17373, 105, 110, 59, 25330, 384, 59, 105, 111, 7399, 7400, 7416, 16631, 100, 101, 33024, 247, 59, 111, 7399, 7408, 110, 116, 105, 109, 101, 115, 59, 25287, 110, 248, 7415, 99, 121, 59, 17490, 99, 623, 7430, 0, 0, 7434, 114, 110, 59, 25374, 111, 112, 59, 25357, 640, 108, 112, 116, 117, 119, 7448, 7453, 7458, 7497, 7509, 108, 97, 114, 59, 16420, 102, 59, 49152, 55349, 56661, 640, 59, 101, 109, 112, 115, 779, 7469, 7479, 7485, 7490, 113, 256, 59, 100, 850, 7475, 111, 116, 59, 25169, 105, 110, 117, 115, 59, 25144, 108, 117, 115, 59, 25108, 113, 117, 97, 114, 101, 59, 25249, 98, 108, 101, 98, 97, 114, 119, 101, 100, 103, 229, 250, 110, 384, 97, 100, 104, 4398, 7517, 7527, 111, 119, 110, 97, 114, 114, 111, 119, 243, 7299, 97, 114, 112, 111, 111, 110, 256, 108, 114, 7538, 7542, 101, 102, 244, 7348, 105, 103, 104, 244, 7350, 354, 7551, 7557, 107, 97, 114, 111, 247, 3906, 623, 7562, 0, 0, 7566, 114, 110, 59, 25375, 111, 112, 59, 25356, 384, 99, 111, 116, 7576, 7587, 7590, 256, 114, 121, 7581, 7585, 59, 49152, 55349, 56505, 59, 17493, 108, 59, 27126, 114, 111, 107, 59, 16657, 256, 100, 114, 7600, 7604, 111, 116, 59, 25329, 105, 256, 59, 102, 7610, 6166, 26047, 256, 97, 104, 7616, 7619, 114, 242, 1065, 97, 242, 4006, 97, 110, 103, 108, 101, 59, 27046, 256, 99, 105, 7634, 7637, 121, 59, 17503, 103, 114, 97, 114, 114, 59, 26623, 2304, 68, 97, 99, 100, 101, 102, 103, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 120, 7681, 7689, 7705, 7736, 1400, 7740, 7753, 7777, 7806, 7845, 7855, 7869, 7905, 7978, 7991, 8004, 8014, 8026, 256, 68, 111, 7686, 7476, 111, 244, 7305, 256, 99, 115, 7694, 7700, 117, 116, 101, 32827, 233, 16617, 116, 101, 114, 59, 27246, 512, 97, 105, 111, 121, 7714, 7719, 7729, 7734, 114, 111, 110, 59, 16667, 114, 256, 59, 99, 7725, 7726, 25174, 32827, 234, 16618, 108, 111, 110, 59, 25173, 59, 17485, 111, 116, 59, 16663, 256, 68, 114, 7745, 7749, 111, 116, 59, 25170, 59, 49152, 55349, 56610, 384, 59, 114, 115, 7760, 7761, 7767, 27290, 97, 118, 101, 32827, 232, 16616, 256, 59, 100, 7772, 7773, 27286, 111, 116, 59, 27288, 512, 59, 105, 108, 115, 7786, 7787, 7794, 7796, 27289, 110, 116, 101, 114, 115, 59, 25575, 59, 24851, 256, 59, 100, 7801, 7802, 27285, 111, 116, 59, 27287, 384, 97, 112, 115, 7813, 7817, 7831, 99, 114, 59, 16659, 116, 121, 384, 59, 115, 118, 7826, 7827, 7829, 25093, 101, 116, 187, 7827, 112, 256, 49, 59, 7837, 7844, 307, 7841, 7843, 59, 24580, 59, 24581, 24579, 256, 103, 115, 7850, 7852, 59, 16715, 112, 59, 24578, 256, 103, 112, 7860, 7864, 111, 110, 59, 16665, 102, 59, 49152, 55349, 56662, 384, 97, 108, 115, 7876, 7886, 7890, 114, 256, 59, 115, 7882, 7883, 25301, 108, 59, 27107, 117, 115, 59, 27249, 105, 384, 59, 108, 118, 7898, 7899, 7903, 17333, 111, 110, 187, 7899, 59, 17397, 512, 99, 115, 117, 118, 7914, 7923, 7947, 7971, 256, 105, 111, 7919, 7729, 114, 99, 187, 7726, 617, 7929, 0, 0, 7931, 237, 1352, 97, 110, 116, 256, 103, 108, 7938, 7942, 116, 114, 187, 7773, 101, 115, 115, 187, 7802, 384, 97, 101, 105, 7954, 7958, 7962, 108, 115, 59, 16445, 115, 116, 59, 25183, 118, 256, 59, 68, 565, 7968, 68, 59, 27256, 112, 97, 114, 115, 108, 59, 27109, 256, 68, 97, 7983, 7987, 111, 116, 59, 25171, 114, 114, 59, 26993, 384, 99, 100, 105, 7998, 8001, 7928, 114, 59, 24879, 111, 244, 850, 256, 97, 104, 8009, 8011, 59, 17335, 32827, 240, 16624, 256, 109, 114, 8019, 8023, 108, 32827, 235, 16619, 111, 59, 24748, 384, 99, 105, 112, 8033, 8036, 8039, 108, 59, 16417, 115, 244, 1390, 256, 101, 111, 8044, 8052, 99, 116, 97, 116, 105, 111, 238, 1369, 110, 101, 110, 116, 105, 97, 108, 229, 1401, 2529, 8082, 0, 8094, 0, 8097, 8103, 0, 0, 8134, 8140, 0, 8147, 0, 8166, 8170, 8192, 0, 8200, 8282, 108, 108, 105, 110, 103, 100, 111, 116, 115, 101, 241, 7748, 121, 59, 17476, 109, 97, 108, 101, 59, 26176, 384, 105, 108, 114, 8109, 8115, 8129, 108, 105, 103, 59, 32768, 64259, 617, 8121, 0, 0, 8125, 103, 59, 32768, 64256, 105, 103, 59, 32768, 64260, 59, 49152, 55349, 56611, 108, 105, 103, 59, 32768, 64257, 108, 105, 103, 59, 49152, 102, 106, 384, 97, 108, 116, 8153, 8156, 8161, 116, 59, 26221, 105, 103, 59, 32768, 64258, 110, 115, 59, 26033, 111, 102, 59, 16786, 496, 8174, 0, 8179, 102, 59, 49152, 55349, 56663, 256, 97, 107, 1471, 8183, 256, 59, 118, 8188, 8189, 25300, 59, 27353, 97, 114, 116, 105, 110, 116, 59, 27149, 256, 97, 111, 8204, 8277, 256, 99, 115, 8209, 8274, 945, 8218, 8240, 8248, 8261, 8264, 0, 8272, 946, 8226, 8229, 8231, 8234, 8236, 0, 8238, 32827, 189, 16573, 59, 24915, 32827, 188, 16572, 59, 24917, 59, 24921, 59, 24923, 435, 8244, 0, 8246, 59, 24916, 59, 24918, 692, 8254, 8257, 0, 0, 8259, 32827, 190, 16574, 59, 24919, 59, 24924, 53, 59, 24920, 438, 8268, 0, 8270, 59, 24922, 59, 24925, 56, 59, 24926, 108, 59, 24644, 119, 110, 59, 25378, 99, 114, 59, 49152, 55349, 56507, 2176, 69, 97, 98, 99, 100, 101, 102, 103, 105, 106, 108, 110, 111, 114, 115, 116, 118, 8322, 8329, 8351, 8357, 8368, 8372, 8432, 8437, 8442, 8447, 8451, 8466, 8504, 791, 8510, 8530, 8606, 256, 59, 108, 1613, 8327, 59, 27276, 384, 99, 109, 112, 8336, 8341, 8349, 117, 116, 101, 59, 16885, 109, 97, 256, 59, 100, 8348, 7386, 17331, 59, 27270, 114, 101, 118, 101, 59, 16671, 256, 105, 121, 8362, 8366, 114, 99, 59, 16669, 59, 17459, 111, 116, 59, 16673, 512, 59, 108, 113, 115, 1598, 1602, 8381, 8393, 384, 59, 113, 115, 1598, 1612, 8388, 108, 97, 110, 244, 1637, 512, 59, 99, 100, 108, 1637, 8402, 8405, 8421, 99, 59, 27305, 111, 116, 256, 59, 111, 8412, 8413, 27264, 256, 59, 108, 8418, 8419, 27266, 59, 27268, 256, 59, 101, 8426, 8429, 49152, 8923, 65024, 115, 59, 27284, 114, 59, 49152, 55349, 56612, 256, 59, 103, 1651, 1563, 109, 101, 108, 59, 24887, 99, 121, 59, 17491, 512, 59, 69, 97, 106, 1626, 8460, 8462, 8464, 59, 27282, 59, 27301, 59, 27300, 512, 69, 97, 101, 115, 8475, 8477, 8489, 8500, 59, 25193, 112, 256, 59, 112, 8483, 8484, 27274, 114, 111, 120, 187, 8484, 256, 59, 113, 8494, 8495, 27272, 256, 59, 113, 8494, 8475, 105, 109, 59, 25319, 112, 102, 59, 49152, 55349, 56664, 256, 99, 105, 8515, 8518, 114, 59, 24842, 109, 384, 59, 101, 108, 1643, 8526, 8528, 59, 27278, 59, 27280, 33536, 62, 59, 99, 100, 108, 113, 114, 1518, 8544, 8554, 8558, 8563, 8569, 256, 99, 105, 8549, 8551, 59, 27303, 114, 59, 27258, 111, 116, 59, 25303, 80, 97, 114, 59, 27029, 117, 101, 115, 116, 59, 27260, 640, 97, 100, 101, 108, 115, 8580, 8554, 8592, 1622, 8603, 496, 8585, 0, 8590, 112, 114, 111, 248, 8350, 114, 59, 27000, 113, 256, 108, 113, 1599, 8598, 108, 101, 115, 243, 8328, 105, 237, 1643, 256, 101, 110, 8611, 8621, 114, 116, 110, 101, 113, 113, 59, 49152, 8809, 65024, 197, 8618, 1280, 65, 97, 98, 99, 101, 102, 107, 111, 115, 121, 8644, 8647, 8689, 8693, 8698, 8728, 8733, 8751, 8808, 8829, 114, 242, 928, 512, 105, 108, 109, 114, 8656, 8660, 8663, 8667, 114, 115, 240, 5252, 102, 187, 8228, 105, 108, 244, 1705, 256, 100, 114, 8672, 8676, 99, 121, 59, 17482, 384, 59, 99, 119, 2292, 8683, 8687, 105, 114, 59, 26952, 59, 25005, 97, 114, 59, 24847, 105, 114, 99, 59, 16677, 384, 97, 108, 114, 8705, 8718, 8723, 114, 116, 115, 256, 59, 117, 8713, 8714, 26213, 105, 116, 187, 8714, 108, 105, 112, 59, 24614, 99, 111, 110, 59, 25273, 114, 59, 49152, 55349, 56613, 115, 256, 101, 119, 8739, 8745, 97, 114, 111, 119, 59, 26917, 97, 114, 111, 119, 59, 26918, 640, 97, 109, 111, 112, 114, 8762, 8766, 8771, 8798, 8803, 114, 114, 59, 25087, 116, 104, 116, 59, 25147, 107, 256, 108, 114, 8777, 8787, 101, 102, 116, 97, 114, 114, 111, 119, 59, 25001, 105, 103, 104, 116, 97, 114, 114, 111, 119, 59, 25002, 102, 59, 49152, 55349, 56665, 98, 97, 114, 59, 24597, 384, 99, 108, 116, 8815, 8820, 8824, 114, 59, 49152, 55349, 56509, 97, 115, 232, 8692, 114, 111, 107, 59, 16679, 256, 98, 112, 8834, 8839, 117, 108, 108, 59, 24643, 104, 101, 110, 187, 7259, 2785, 8867, 0, 8874, 0, 8888, 8901, 8910, 0, 8917, 8947, 0, 0, 8952, 8994, 9063, 9058, 9087, 0, 9094, 9130, 9140, 99, 117, 116, 101, 32827, 237, 16621, 384, 59, 105, 121, 1905, 8880, 8885, 114, 99, 32827, 238, 16622, 59, 17464, 256, 99, 120, 8892, 8895, 121, 59, 17461, 99, 108, 32827, 161, 16545, 256, 102, 114, 927, 8905, 59, 49152, 55349, 56614, 114, 97, 118, 101, 32827, 236, 16620, 512, 59, 105, 110, 111, 1854, 8925, 8937, 8942, 256, 105, 110, 8930, 8934, 110, 116, 59, 27148, 116, 59, 25133, 102, 105, 110, 59, 27100, 116, 97, 59, 24873, 108, 105, 103, 59, 16691, 384, 97, 111, 112, 8958, 8986, 8989, 384, 99, 103, 116, 8965, 8968, 8983, 114, 59, 16683, 384, 101, 108, 112, 1823, 8975, 8979, 105, 110, 229, 1934, 97, 114, 244, 1824, 104, 59, 16689, 102, 59, 25271, 101, 100, 59, 16821, 640, 59, 99, 102, 111, 116, 1268, 9004, 9009, 9021, 9025, 97, 114, 101, 59, 24837, 105, 110, 256, 59, 116, 9016, 9017, 25118, 105, 101, 59, 27101, 100, 111, 244, 8985, 640, 59, 99, 101, 108, 112, 1879, 9036, 9040, 9051, 9057, 97, 108, 59, 25274, 256, 103, 114, 9045, 9049, 101, 114, 243, 5475, 227, 9037, 97, 114, 104, 107, 59, 27159, 114, 111, 100, 59, 27196, 512, 99, 103, 112, 116, 9071, 9074, 9078, 9083, 121, 59, 17489, 111, 110, 59, 16687, 102, 59, 49152, 55349, 56666, 97, 59, 17337, 117, 101, 115, 116, 32827, 191, 16575, 256, 99, 105, 9098, 9103, 114, 59, 49152, 55349, 56510, 110, 640, 59, 69, 100, 115, 118, 1268, 9115, 9117, 9121, 1267, 59, 25337, 111, 116, 59, 25333, 256, 59, 118, 9126, 9127, 25332, 59, 25331, 256, 59, 105, 1911, 9134, 108, 100, 101, 59, 16681, 491, 9144, 0, 9148, 99, 121, 59, 17494, 108, 32827, 239, 16623, 768, 99, 102, 109, 111, 115, 117, 9164, 9175, 9180, 9185, 9191, 9205, 256, 105, 121, 9169, 9173, 114, 99, 59, 16693, 59, 17465, 114, 59, 49152, 55349, 56615, 97, 116, 104, 59, 16951, 112, 102, 59, 49152, 55349, 56667, 483, 9196, 0, 9201, 114, 59, 49152, 55349, 56511, 114, 99, 121, 59, 17496, 107, 99, 121, 59, 17492, 1024, 97, 99, 102, 103, 104, 106, 111, 115, 9227, 9238, 9250, 9255, 9261, 9265, 9269, 9275, 112, 112, 97, 256, 59, 118, 9235, 9236, 17338, 59, 17392, 256, 101, 121, 9243, 9248, 100, 105, 108, 59, 16695, 59, 17466, 114, 59, 49152, 55349, 56616, 114, 101, 101, 110, 59, 16696, 99, 121, 59, 17477, 99, 121, 59, 17500, 112, 102, 59, 49152, 55349, 56668, 99, 114, 59, 49152, 55349, 56512, 2944, 65, 66, 69, 72, 97, 98, 99, 100, 101, 102, 103, 104, 106, 108, 109, 110, 111, 112, 114, 115, 116, 117, 118, 9328, 9345, 9350, 9357, 9361, 9486, 9533, 9562, 9600, 9806, 9822, 9829, 9849, 9853, 9882, 9906, 9944, 10077, 10088, 10123, 10176, 10241, 10258, 384, 97, 114, 116, 9335, 9338, 9340, 114, 242, 2502, 242, 917, 97, 105, 108, 59, 26907, 97, 114, 114, 59, 26894, 256, 59, 103, 2452, 9355, 59, 27275, 97, 114, 59, 26978, 2403, 9381, 0, 9386, 0, 9393, 0, 0, 0, 0, 0, 9397, 9402, 0, 9414, 9416, 9421, 0, 9465, 117, 116, 101, 59, 16698, 109, 112, 116, 121, 118, 59, 27060, 114, 97, 238, 2124, 98, 100, 97, 59, 17339, 103, 384, 59, 100, 108, 2190, 9409, 9411, 59, 27025, 229, 2190, 59, 27269, 117, 111, 32827, 171, 16555, 114, 1024, 59, 98, 102, 104, 108, 112, 115, 116, 2201, 9438, 9446, 9449, 9451, 9454, 9457, 9461, 256, 59, 102, 2205, 9443, 115, 59, 26911, 115, 59, 26909, 235, 8786, 112, 59, 25003, 108, 59, 26937, 105, 109, 59, 26995, 108, 59, 24994, 384, 59, 97, 101, 9471, 9472, 9476, 27307, 105, 108, 59, 26905, 256, 59, 115, 9481, 9482, 27309, 59, 49152, 10925, 65024, 384, 97, 98, 114, 9493, 9497, 9501, 114, 114, 59, 26892, 114, 107, 59, 26482, 256, 97, 107, 9506, 9516, 99, 256, 101, 107, 9512, 9514, 59, 16507, 59, 16475, 256, 101, 115, 9521, 9523, 59, 27019, 108, 256, 100, 117, 9529, 9531, 59, 27023, 59, 27021, 512, 97, 101, 117, 121, 9542, 9547, 9558, 9560, 114, 111, 110, 59, 16702, 256, 100, 105, 9552, 9556, 105, 108, 59, 16700, 236, 2224, 226, 9513, 59, 17467, 512, 99, 113, 114, 115, 9571, 9574, 9581, 9597, 97, 59, 26934, 117, 111, 256, 59, 114, 3609, 5958, 256, 100, 117, 9586, 9591, 104, 97, 114, 59, 26983, 115, 104, 97, 114, 59, 26955, 104, 59, 25010, 640, 59, 102, 103, 113, 115, 9611, 9612, 2441, 9715, 9727, 25188, 116, 640, 97, 104, 108, 114, 116, 9624, 9636, 9655, 9666, 9704, 114, 114, 111, 119, 256, 59, 116, 2201, 9633, 97, 233, 9462, 97, 114, 112, 111, 111, 110, 256, 100, 117, 9647, 9652, 111, 119, 110, 187, 1114, 112, 187, 2406, 101, 102, 116, 97, 114, 114, 111, 119, 115, 59, 25031, 105, 103, 104, 116, 384, 97, 104, 115, 9677, 9686, 9694, 114, 114, 111, 119, 256, 59, 115, 2292, 2215, 97, 114, 112, 111, 111, 110, 243, 3992, 113, 117, 105, 103, 97, 114, 114, 111, 247, 8688, 104, 114, 101, 101, 116, 105, 109, 101, 115, 59, 25291, 384, 59, 113, 115, 9611, 2451, 9722, 108, 97, 110, 244, 2476, 640, 59, 99, 100, 103, 115, 2476, 9738, 9741, 9757, 9768, 99, 59, 27304, 111, 116, 256, 59, 111, 9748, 9749, 27263, 256, 59, 114, 9754, 9755, 27265, 59, 27267, 256, 59, 101, 9762, 9765, 49152, 8922, 65024, 115, 59, 27283, 640, 97, 100, 101, 103, 115, 9779, 9785, 9789, 9801, 9803, 112, 112, 114, 111, 248, 9414, 111, 116, 59, 25302, 113, 256, 103, 113, 9795, 9797, 244, 2441, 103, 116, 242, 9356, 244, 2459, 105, 237, 2482, 384, 105, 108, 114, 9813, 2273, 9818, 115, 104, 116, 59, 27004, 59, 49152, 55349, 56617, 256, 59, 69, 2460, 9827, 59, 27281, 353, 9833, 9846, 114, 256, 100, 117, 9650, 9838, 256, 59, 108, 2405, 9843, 59, 26986, 108, 107, 59, 25988, 99, 121, 59, 17497, 640, 59, 97, 99, 104, 116, 2632, 9864, 9867, 9873, 9878, 114, 242, 9665, 111, 114, 110, 101, 242, 7432, 97, 114, 100, 59, 26987, 114, 105, 59, 26106, 256, 105, 111, 9887, 9892, 100, 111, 116, 59, 16704, 117, 115, 116, 256, 59, 97, 9900, 9901, 25520, 99, 104, 101, 187, 9901, 512, 69, 97, 101, 115, 9915, 9917, 9929, 9940, 59, 25192, 112, 256, 59, 112, 9923, 9924, 27273, 114, 111, 120, 187, 9924, 256, 59, 113, 9934, 9935, 27271, 256, 59, 113, 9934, 9915, 105, 109, 59, 25318, 1024, 97, 98, 110, 111, 112, 116, 119, 122, 9961, 9972, 9975, 10010, 10031, 10049, 10055, 10064, 256, 110, 114, 9966, 9969, 103, 59, 26604, 114, 59, 25085, 114, 235, 2241, 103, 384, 108, 109, 114, 9983, 9997, 10004, 101, 102, 116, 256, 97, 114, 2534, 9991, 105, 103, 104, 116, 225, 2546, 97, 112, 115, 116, 111, 59, 26620, 105, 103, 104, 116, 225, 2557, 112, 97, 114, 114, 111, 119, 256, 108, 114, 10021, 10025, 101, 102, 244, 9453, 105, 103, 104, 116, 59, 25004, 384, 97, 102, 108, 10038, 10041, 10045, 114, 59, 27013, 59, 49152, 55349, 56669, 117, 115, 59, 27181, 105, 109, 101, 115, 59, 27188, 353, 10059, 10063, 115, 116, 59, 25111, 225, 4942, 384, 59, 101, 102, 10071, 10072, 6144, 26058, 110, 103, 101, 187, 10072, 97, 114, 256, 59, 108, 10084, 10085, 16424, 116, 59, 27027, 640, 97, 99, 104, 109, 116, 10099, 10102, 10108, 10117, 10119, 114, 242, 2216, 111, 114, 110, 101, 242, 7564, 97, 114, 256, 59, 100, 3992, 10115, 59, 26989, 59, 24590, 114, 105, 59, 25279, 768, 97, 99, 104, 105, 113, 116, 10136, 10141, 2624, 10146, 10158, 10171, 113, 117, 111, 59, 24633, 114, 59, 49152, 55349, 56513, 109, 384, 59, 101, 103, 2482, 10154, 10156, 59, 27277, 59, 27279, 256, 98, 117, 9514, 10163, 111, 256, 59, 114, 3615, 10169, 59, 24602, 114, 111, 107, 59, 16706, 33792, 60, 59, 99, 100, 104, 105, 108, 113, 114, 2091, 10194, 9785, 10204, 10208, 10213, 10218, 10224, 256, 99, 105, 10199, 10201, 59, 27302, 114, 59, 27257, 114, 101, 229, 9714, 109, 101, 115, 59, 25289, 97, 114, 114, 59, 26998, 117, 101, 115, 116, 59, 27259, 256, 80, 105, 10229, 10233, 97, 114, 59, 27030, 384, 59, 101, 102, 10240, 2349, 6171, 26051, 114, 256, 100, 117, 10247, 10253, 115, 104, 97, 114, 59, 26954, 104, 97, 114, 59, 26982, 256, 101, 110, 10263, 10273, 114, 116, 110, 101, 113, 113, 59, 49152, 8808, 65024, 197, 10270, 1792, 68, 97, 99, 100, 101, 102, 104, 105, 108, 110, 111, 112, 115, 117, 10304, 10309, 10370, 10382, 10387, 10400, 10405, 10408, 10458, 10466, 10468, 2691, 10483, 10498, 68, 111, 116, 59, 25146, 512, 99, 108, 112, 114, 10318, 10322, 10339, 10365, 114, 32827, 175, 16559, 256, 101, 116, 10327, 10329, 59, 26178, 256, 59, 101, 10334, 10335, 26400, 115, 101, 187, 10335, 256, 59, 115, 4155, 10344, 116, 111, 512, 59, 100, 108, 117, 4155, 10355, 10359, 10363, 111, 119, 238, 1164, 101, 102, 244, 2319, 240, 5073, 107, 101, 114, 59, 26030, 256, 111, 121, 10375, 10380, 109, 109, 97, 59, 27177, 59, 17468, 97, 115, 104, 59, 24596, 97, 115, 117, 114, 101, 100, 97, 110, 103, 108, 101, 187, 5670, 114, 59, 49152, 55349, 56618, 111, 59, 24871, 384, 99, 100, 110, 10415, 10420, 10441, 114, 111, 32827, 181, 16565, 512, 59, 97, 99, 100, 5220, 10429, 10432, 10436, 115, 244, 5799, 105, 114, 59, 27376, 111, 116, 32955, 183, 437, 117, 115, 384, 59, 98, 100, 10450, 6403, 10451, 25106, 256, 59, 117, 7484, 10456, 59, 27178, 355, 10462, 10465, 112, 59, 27355, 242, 8722, 240, 2689, 256, 100, 112, 10473, 10478, 101, 108, 115, 59, 25255, 102, 59, 49152, 55349, 56670, 256, 99, 116, 10488, 10493, 114, 59, 49152, 55349, 56514, 112, 111, 115, 187, 5533, 384, 59, 108, 109, 10505, 10506, 10509, 17340, 116, 105, 109, 97, 112, 59, 25272, 3072, 71, 76, 82, 86, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 108, 109, 111, 112, 114, 115, 116, 117, 118, 119, 10562, 10579, 10622, 10633, 10648, 10714, 10729, 10773, 10778, 10840, 10845, 10883, 10901, 10916, 10920, 11012, 11015, 11076, 11135, 11182, 11316, 11367, 11388, 11497, 256, 103, 116, 10567, 10571, 59, 49152, 8921, 824, 256, 59, 118, 10576, 3023, 49152, 8811, 8402, 384, 101, 108, 116, 10586, 10610, 10614, 102, 116, 256, 97, 114, 10593, 10599, 114, 114, 111, 119, 59, 25037, 105, 103, 104, 116, 97, 114, 114, 111, 119, 59, 25038, 59, 49152, 8920, 824, 256, 59, 118, 10619, 3143, 49152, 8810, 8402, 105, 103, 104, 116, 97, 114, 114, 111, 119, 59, 25039, 256, 68, 100, 10638, 10643, 97, 115, 104, 59, 25263, 97, 115, 104, 59, 25262, 640, 98, 99, 110, 112, 116, 10659, 10663, 10668, 10673, 10700, 108, 97, 187, 734, 117, 116, 101, 59, 16708, 103, 59, 49152, 8736, 8402, 640, 59, 69, 105, 111, 112, 3460, 10684, 10688, 10693, 10696, 59, 49152, 10864, 824, 100, 59, 49152, 8779, 824, 115, 59, 16713, 114, 111, 248, 3460, 117, 114, 256, 59, 97, 10707, 10708, 26222, 108, 256, 59, 115, 10707, 2872, 499, 10719, 0, 10723, 112, 32955, 160, 2871, 109, 112, 256, 59, 101, 3065, 3072, 640, 97, 101, 111, 117, 121, 10740, 10750, 10755, 10768, 10771, 496, 10745, 0, 10747, 59, 27203, 111, 110, 59, 16712, 100, 105, 108, 59, 16710, 110, 103, 256, 59, 100, 3454, 10762, 111, 116, 59, 49152, 10861, 824, 112, 59, 27202, 59, 17469, 97, 115, 104, 59, 24595, 896, 59, 65, 97, 100, 113, 115, 120, 2962, 10793, 10797, 10811, 10817, 10821, 10832, 114, 114, 59, 25047, 114, 256, 104, 114, 10803, 10806, 107, 59, 26916, 256, 59, 111, 5106, 5104, 111, 116, 59, 49152, 8784, 824, 117, 105, 246, 2915, 256, 101, 105, 10826, 10830, 97, 114, 59, 26920, 237, 2968, 105, 115, 116, 256, 59, 115, 2976, 2975, 114, 59, 49152, 55349, 56619, 512, 69, 101, 115, 116, 3013, 10854, 10873, 10876, 384, 59, 113, 115, 3004, 10861, 3041, 384, 59, 113, 115, 3004, 3013, 10868, 108, 97, 110, 244, 3042, 105, 237, 3050, 256, 59, 114, 2998, 10881, 187, 2999, 384, 65, 97, 112, 10890, 10893, 10897, 114, 242, 10609, 114, 114, 59, 25006, 97, 114, 59, 27378, 384, 59, 115, 118, 3981, 10908, 3980, 256, 59, 100, 10913, 10914, 25340, 59, 25338, 99, 121, 59, 17498, 896, 65, 69, 97, 100, 101, 115, 116, 10935, 10938, 10942, 10946, 10949, 10998, 11001, 114, 242, 10598, 59, 49152, 8806, 824, 114, 114, 59, 24986, 114, 59, 24613, 512, 59, 102, 113, 115, 3131, 10958, 10979, 10991, 116, 256, 97, 114, 10964, 10969, 114, 114, 111, 247, 10945, 105, 103, 104, 116, 97, 114, 114, 111, 247, 10896, 384, 59, 113, 115, 3131, 10938, 10986, 108, 97, 110, 244, 3157, 256, 59, 115, 3157, 10996, 187, 3126, 105, 237, 3165, 256, 59, 114, 3125, 11006, 105, 256, 59, 101, 3098, 3109, 105, 228, 3472, 256, 112, 116, 11020, 11025, 102, 59, 49152, 55349, 56671, 33152, 172, 59, 105, 110, 11033, 11034, 11062, 16556, 110, 512, 59, 69, 100, 118, 2953, 11044, 11048, 11054, 59, 49152, 8953, 824, 111, 116, 59, 49152, 8949, 824, 481, 2953, 11059, 11061, 59, 25335, 59, 25334, 105, 256, 59, 118, 3256, 11068, 481, 3256, 11073, 11075, 59, 25342, 59, 25341, 384, 97, 111, 114, 11083, 11107, 11113, 114, 512, 59, 97, 115, 116, 2939, 11093, 11098, 11103, 108, 108, 101, 236, 2939, 108, 59, 49152, 11005, 8421, 59, 49152, 8706, 824, 108, 105, 110, 116, 59, 27156, 384, 59, 99, 101, 3218, 11120, 11123, 117, 229, 3237, 256, 59, 99, 3224, 11128, 256, 59, 101, 3218, 11133, 241, 3224, 512, 65, 97, 105, 116, 11144, 11147, 11165, 11175, 114, 242, 10632, 114, 114, 384, 59, 99, 119, 11156, 11157, 11161, 24987, 59, 49152, 10547, 824, 59, 49152, 8605, 824, 103, 104, 116, 97, 114, 114, 111, 119, 187, 11157, 114, 105, 256, 59, 101, 3275, 3286, 896, 99, 104, 105, 109, 112, 113, 117, 11197, 11213, 11225, 11012, 2936, 11236, 11247, 512, 59, 99, 101, 114, 3378, 11206, 3383, 11209, 117, 229, 3397, 59, 49152, 55349, 56515, 111, 114, 116, 621, 11013, 0, 0, 11222, 97, 114, 225, 11094, 109, 256, 59, 101, 3438, 11231, 256, 59, 113, 3444, 3443, 115, 117, 256, 98, 112, 11243, 11245, 229, 3320, 229, 3339, 384, 98, 99, 112, 11254, 11281, 11289, 512, 59, 69, 101, 115, 11263, 11264, 3362, 11268, 25220, 59, 49152, 10949, 824, 101, 116, 256, 59, 101, 3355, 11275, 113, 256, 59, 113, 3363, 11264, 99, 256, 59, 101, 3378, 11287, 241, 3384, 512, 59, 69, 101, 115, 11298, 11299, 3423, 11303, 25221, 59, 49152, 10950, 824, 101, 116, 256, 59, 101, 3416, 11310, 113, 256, 59, 113, 3424, 11299, 512, 103, 105, 108, 114, 11325, 11327, 11333, 11335, 236, 3031, 108, 100, 101, 32827, 241, 16625, 231, 3139, 105, 97, 110, 103, 108, 101, 256, 108, 114, 11346, 11356, 101, 102, 116, 256, 59, 101, 3098, 11354, 241, 3110, 105, 103, 104, 116, 256, 59, 101, 3275, 11365, 241, 3287, 256, 59, 109, 11372, 11373, 17341, 384, 59, 101, 115, 11380, 11381, 11385, 16419, 114, 111, 59, 24854, 112, 59, 24583, 1152, 68, 72, 97, 100, 103, 105, 108, 114, 115, 11407, 11412, 11417, 11422, 11427, 11440, 11446, 11475, 11491, 97, 115, 104, 59, 25261, 97, 114, 114, 59, 26884, 112, 59, 49152, 8781, 8402, 97, 115, 104, 59, 25260, 256, 101, 116, 11432, 11436, 59, 49152, 8805, 8402, 59, 49152, 62, 8402, 110, 102, 105, 110, 59, 27102, 384, 65, 101, 116, 11453, 11457, 11461, 114, 114, 59, 26882, 59, 49152, 8804, 8402, 256, 59, 114, 11466, 11469, 49152, 60, 8402, 105, 101, 59, 49152, 8884, 8402, 256, 65, 116, 11480, 11484, 114, 114, 59, 26883, 114, 105, 101, 59, 49152, 8885, 8402, 105, 109, 59, 49152, 8764, 8402, 384, 65, 97, 110, 11504, 11508, 11522, 114, 114, 59, 25046, 114, 256, 104, 114, 11514, 11517, 107, 59, 26915, 256, 59, 111, 5095, 5093, 101, 97, 114, 59, 26919, 4691, 6805, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11565, 0, 11576, 11592, 11616, 11621, 11634, 11652, 6919, 0, 0, 11661, 11691, 0, 11720, 11726, 0, 11740, 11801, 11819, 11838, 11843, 256, 99, 115, 11569, 6807, 117, 116, 101, 32827, 243, 16627, 256, 105, 121, 11580, 11589, 114, 256, 59, 99, 6814, 11586, 32827, 244, 16628, 59, 17470, 640, 97, 98, 105, 111, 115, 6816, 11602, 11607, 456, 11610, 108, 97, 99, 59, 16721, 118, 59, 27192, 111, 108, 100, 59, 27068, 108, 105, 103, 59, 16723, 256, 99, 114, 11625, 11629, 105, 114, 59, 27071, 59, 49152, 55349, 56620, 879, 11641, 0, 0, 11644, 0, 11650, 110, 59, 17115, 97, 118, 101, 32827, 242, 16626, 59, 27073, 256, 98, 109, 11656, 3572, 97, 114, 59, 27061, 512, 97, 99, 105, 116, 11669, 11672, 11685, 11688, 114, 242, 6784, 256, 105, 114, 11677, 11680, 114, 59, 27070, 111, 115, 115, 59, 27067, 110, 229, 3666, 59, 27072, 384, 97, 101, 105, 11697, 11701, 11705, 99, 114, 59, 16717, 103, 97, 59, 17353, 384, 99, 100, 110, 11712, 11717, 461, 114, 111, 110, 59, 17343, 59, 27062, 112, 102, 59, 49152, 55349, 56672, 384, 97, 101, 108, 11732, 11735, 466, 114, 59, 27063, 114, 112, 59, 27065, 896, 59, 97, 100, 105, 111, 115, 118, 11754, 11755, 11758, 11784, 11789, 11792, 11798, 25128, 114, 242, 6790, 512, 59, 101, 102, 109, 11767, 11768, 11778, 11781, 27229, 114, 256, 59, 111, 11774, 11775, 24884, 102, 187, 11775, 32827, 170, 16554, 32827, 186, 16570, 103, 111, 102, 59, 25270, 114, 59, 27222, 108, 111, 112, 101, 59, 27223, 59, 27227, 384, 99, 108, 111, 11807, 11809, 11815, 242, 11777, 97, 115, 104, 32827, 248, 16632, 108, 59, 25240, 105, 364, 11823, 11828, 100, 101, 32827, 245, 16629, 101, 115, 256, 59, 97, 475, 11834, 115, 59, 27190, 109, 108, 32827, 246, 16630, 98, 97, 114, 59, 25405, 2785, 11870, 0, 11901, 0, 11904, 11933, 0, 11938, 11961, 0, 0, 11979, 3740, 0, 12051, 0, 0, 12075, 12220, 0, 12232, 114, 512, 59, 97, 115, 116, 1027, 11879, 11890, 3717, 33024, 182, 59, 108, 11885, 11886, 16566, 108, 101, 236, 1027, 617, 11896, 0, 0, 11899, 109, 59, 27379, 59, 27389, 121, 59, 17471, 114, 640, 99, 105, 109, 112, 116, 11915, 11919, 11923, 6245, 11927, 110, 116, 59, 16421, 111, 100, 59, 16430, 105, 108, 59, 24624, 101, 110, 107, 59, 24625, 114, 59, 49152, 55349, 56621, 384, 105, 109, 111, 11944, 11952, 11956, 256, 59, 118, 11949, 11950, 17350, 59, 17365, 109, 97, 244, 2678, 110, 101, 59, 26126, 384, 59, 116, 118, 11967, 11968, 11976, 17344, 99, 104, 102, 111, 114, 107, 187, 8189, 59, 17366, 256, 97, 117, 11983, 11999, 110, 256, 99, 107, 11989, 11997, 107, 256, 59, 104, 8692, 11995, 59, 24846, 246, 8692, 115, 1152, 59, 97, 98, 99, 100, 101, 109, 115, 116, 12019, 12020, 6408, 12025, 12029, 12036, 12038, 12042, 12046, 16427, 99, 105, 114, 59, 27171, 105, 114, 59, 27170, 256, 111, 117, 7488, 12034, 59, 27173, 59, 27250, 110, 32955, 177, 3741, 105, 109, 59, 27174, 119, 111, 59, 27175, 384, 105, 112, 117, 12057, 12064, 12069, 110, 116, 105, 110, 116, 59, 27157, 102, 59, 49152, 55349, 56673, 110, 100, 32827, 163, 16547, 1280, 59, 69, 97, 99, 101, 105, 110, 111, 115, 117, 3784, 12095, 12097, 12100, 12103, 12161, 12169, 12178, 12158, 12214, 59, 27315, 112, 59, 27319, 117, 229, 3801, 256, 59, 99, 3790, 12108, 768, 59, 97, 99, 101, 110, 115, 3784, 12121, 12127, 12134, 12136, 12158, 112, 112, 114, 111, 248, 12099, 117, 114, 108, 121, 101, 241, 3801, 241, 3790, 384, 97, 101, 115, 12143, 12150, 12154, 112, 112, 114, 111, 120, 59, 27321, 113, 113, 59, 27317, 105, 109, 59, 25320, 105, 237, 3807, 109, 101, 256, 59, 115, 12168, 3758, 24626, 384, 69, 97, 115, 12152, 12176, 12154, 240, 12149, 384, 100, 102, 112, 3820, 12185, 12207, 384, 97, 108, 115, 12192, 12197, 12202, 108, 97, 114, 59, 25390, 105, 110, 101, 59, 25362, 117, 114, 102, 59, 25363, 256, 59, 116, 3835, 12212, 239, 3835, 114, 101, 108, 59, 25264, 256, 99, 105, 12224, 12229, 114, 59, 49152, 55349, 56517, 59, 17352, 110, 99, 115, 112, 59, 24584, 768, 102, 105, 111, 112, 115, 117, 12250, 8930, 12255, 12261, 12267, 12273, 114, 59, 49152, 55349, 56622, 112, 102, 59, 49152, 55349, 56674, 114, 105, 109, 101, 59, 24663, 99, 114, 59, 49152, 55349, 56518, 384, 97, 101, 111, 12280, 12297, 12307, 116, 256, 101, 105, 12286, 12293, 114, 110, 105, 111, 110, 243, 1712, 110, 116, 59, 27158, 115, 116, 256, 59, 101, 12304, 12305, 16447, 241, 7961, 244, 3860, 2688, 65, 66, 72, 97, 98, 99, 100, 101, 102, 104, 105, 108, 109, 110, 111, 112, 114, 115, 116, 117, 120, 12352, 12369, 12373, 12377, 12512, 12558, 12587, 12615, 12642, 12658, 12686, 12806, 12821, 12836, 12841, 12888, 12910, 12914, 12944, 12976, 12983, 384, 97, 114, 116, 12359, 12362, 12364, 114, 242, 4275, 242, 989, 97, 105, 108, 59, 26908, 97, 114, 242, 7269, 97, 114, 59, 26980, 896, 99, 100, 101, 110, 113, 114, 116, 12392, 12405, 12408, 12415, 12431, 12436, 12492, 256, 101, 117, 12397, 12401, 59, 49152, 8765, 817, 116, 101, 59, 16725, 105, 227, 4462, 109, 112, 116, 121, 118, 59, 27059, 103, 512, 59, 100, 101, 108, 4049, 12425, 12427, 12429, 59, 27026, 59, 27045, 229, 4049, 117, 111, 32827, 187, 16571, 114, 1408, 59, 97, 98, 99, 102, 104, 108, 112, 115, 116, 119, 4060, 12460, 12463, 12471, 12473, 12476, 12478, 12480, 12483, 12487, 12490, 112, 59, 26997, 256, 59, 102, 4064, 12468, 115, 59, 26912, 59, 26931, 115, 59, 26910, 235, 8797, 240, 10030, 108, 59, 26949, 105, 109, 59, 26996, 108, 59, 24995, 59, 24989, 256, 97, 105, 12497, 12501, 105, 108, 59, 26906, 111, 256, 59, 110, 12507, 12508, 25142, 97, 108, 243, 3870, 384, 97, 98, 114, 12519, 12522, 12526, 114, 242, 6117, 114, 107, 59, 26483, 256, 97, 107, 12531, 12541, 99, 256, 101, 107, 12537, 12539, 59, 16509, 59, 16477, 256, 101, 115, 12546, 12548, 59, 27020, 108, 256, 100, 117, 12554, 12556, 59, 27022, 59, 27024, 512, 97, 101, 117, 121, 12567, 12572, 12583, 12585, 114, 111, 110, 59, 16729, 256, 100, 105, 12577, 12581, 105, 108, 59, 16727, 236, 4082, 226, 12538, 59, 17472, 512, 99, 108, 113, 115, 12596, 12599, 12605, 12612, 97, 59, 26935, 100, 104, 97, 114, 59, 26985, 117, 111, 256, 59, 114, 526, 525, 104, 59, 25011, 384, 97, 99, 103, 12622, 12639, 3908, 108, 512, 59, 105, 112, 115, 3960, 12632, 12635, 4252, 110, 229, 4283, 97, 114, 244, 4009, 116, 59, 26029, 384, 105, 108, 114, 12649, 4131, 12654, 115, 104, 116, 59, 27005, 59, 49152, 55349, 56623, 256, 97, 111, 12663, 12678, 114, 256, 100, 117, 12669, 12671, 187, 1147, 256, 59, 108, 4241, 12676, 59, 26988, 256, 59, 118, 12683, 12684, 17345, 59, 17393, 384, 103, 110, 115, 12693, 12793, 12796, 104, 116, 768, 97, 104, 108, 114, 115, 116, 12708, 12720, 12738, 12760, 12772, 12782, 114, 114, 111, 119, 256, 59, 116, 4060, 12717, 97, 233, 12488, 97, 114, 112, 111, 111, 110, 256, 100, 117, 12731, 12735, 111, 119, 238, 12670, 112, 187, 4242, 101, 102, 116, 256, 97, 104, 12746, 12752, 114, 114, 111, 119, 243, 4074, 97, 114, 112, 111, 111, 110, 243, 1361, 105, 103, 104, 116, 97, 114, 114, 111, 119, 115, 59, 25033, 113, 117, 105, 103, 97, 114, 114, 111, 247, 12491, 104, 114, 101, 101, 116, 105, 109, 101, 115, 59, 25292, 103, 59, 17114, 105, 110, 103, 100, 111, 116, 115, 101, 241, 7986, 384, 97, 104, 109, 12813, 12816, 12819, 114, 242, 4074, 97, 242, 1361, 59, 24591, 111, 117, 115, 116, 256, 59, 97, 12830, 12831, 25521, 99, 104, 101, 187, 12831, 109, 105, 100, 59, 27374, 512, 97, 98, 112, 116, 12850, 12861, 12864, 12882, 256, 110, 114, 12855, 12858, 103, 59, 26605, 114, 59, 25086, 114, 235, 4099, 384, 97, 102, 108, 12871, 12874, 12878, 114, 59, 27014, 59, 49152, 55349, 56675, 117, 115, 59, 27182, 105, 109, 101, 115, 59, 27189, 256, 97, 112, 12893, 12903, 114, 256, 59, 103, 12899, 12900, 16425, 116, 59, 27028, 111, 108, 105, 110, 116, 59, 27154, 97, 114, 242, 12771, 512, 97, 99, 104, 113, 12923, 12928, 4284, 12933, 113, 117, 111, 59, 24634, 114, 59, 49152, 55349, 56519, 256, 98, 117, 12539, 12938, 111, 256, 59, 114, 532, 531, 384, 104, 105, 114, 12951, 12955, 12960, 114, 101, 229, 12792, 109, 101, 115, 59, 25290, 105, 512, 59, 101, 102, 108, 12970, 4185, 6177, 12971, 26041, 116, 114, 105, 59, 27086, 108, 117, 104, 97, 114, 59, 26984, 59, 24862, 3425, 13013, 13019, 13023, 13100, 13112, 13169, 0, 13178, 13220, 0, 0, 13292, 13296, 0, 13352, 13384, 13402, 13485, 13489, 13514, 13553, 0, 13846, 0, 0, 13875, 99, 117, 116, 101, 59, 16731, 113, 117, 239, 10170, 1280, 59, 69, 97, 99, 101, 105, 110, 112, 115, 121, 4589, 13043, 13045, 13055, 13058, 13067, 13071, 13087, 13094, 13097, 59, 27316, 496, 13050, 0, 13052, 59, 27320, 111, 110, 59, 16737, 117, 229, 4606, 256, 59, 100, 4595, 13063, 105, 108, 59, 16735, 114, 99, 59, 16733, 384, 69, 97, 115, 13078, 13080, 13083, 59, 27318, 112, 59, 27322, 105, 109, 59, 25321, 111, 108, 105, 110, 116, 59, 27155, 105, 237, 4612, 59, 17473, 111, 116, 384, 59, 98, 101, 13108, 7495, 13109, 25285, 59, 27238, 896, 65, 97, 99, 109, 115, 116, 120, 13126, 13130, 13143, 13147, 13150, 13155, 13165, 114, 114, 59, 25048, 114, 256, 104, 114, 13136, 13138, 235, 8744, 256, 59, 111, 2614, 2612, 116, 32827, 167, 16551, 105, 59, 16443, 119, 97, 114, 59, 26921, 109, 256, 105, 110, 13161, 240, 110, 117, 243, 241, 116, 59, 26422, 114, 256, 59, 111, 13174, 8277, 49152, 55349, 56624, 512, 97, 99, 111, 121, 13186, 13190, 13201, 13216, 114, 112, 59, 26223, 256, 104, 121, 13195, 13199, 99, 121, 59, 17481, 59, 17480, 114, 116, 621, 13209, 0, 0, 13212, 105, 228, 5220, 97, 114, 97, 236, 11887, 32827, 173, 16557, 256, 103, 109, 13224, 13236, 109, 97, 384, 59, 102, 118, 13233, 13234, 13234, 17347, 59, 17346, 1024, 59, 100, 101, 103, 108, 110, 112, 114, 4779, 13253, 13257, 13262, 13270, 13278, 13281, 13286, 111, 116, 59, 27242, 256, 59, 113, 4785, 4784, 256, 59, 69, 13267, 13268, 27294, 59, 27296, 256, 59, 69, 13275, 13276, 27293, 59, 27295, 101, 59, 25158, 108, 117, 115, 59, 27172, 97, 114, 114, 59, 26994, 97, 114, 242, 4413, 512, 97, 101, 105, 116, 13304, 13320, 13327, 13335, 256, 108, 115, 13309, 13316, 108, 115, 101, 116, 109, 233, 13162, 104, 112, 59, 27187, 112, 97, 114, 115, 108, 59, 27108, 256, 100, 108, 5219, 13332, 101, 59, 25379, 256, 59, 101, 13340, 13341, 27306, 256, 59, 115, 13346, 13347, 27308, 59, 49152, 10924, 65024, 384, 102, 108, 112, 13358, 13363, 13378, 116, 99, 121, 59, 17484, 256, 59, 98, 13368, 13369, 16431, 256, 59, 97, 13374, 13375, 27076, 114, 59, 25407, 102, 59, 49152, 55349, 56676, 97, 256, 100, 114, 13389, 1026, 101, 115, 256, 59, 117, 13396, 13397, 26208, 105, 116, 187, 13397, 384, 99, 115, 117, 13408, 13433, 13471, 256, 97, 117, 13413, 13423, 112, 256, 59, 115, 4488, 13419, 59, 49152, 8851, 65024, 112, 256, 59, 115, 4532, 13429, 59, 49152, 8852, 65024, 117, 256, 98, 112, 13439, 13455, 384, 59, 101, 115, 4503, 4508, 13446, 101, 116, 256, 59, 101, 4503, 13453, 241, 4509, 384, 59, 101, 115, 4520, 4525, 13462, 101, 116, 256, 59, 101, 4520, 13469, 241, 4526, 384, 59, 97, 102, 4475, 13478, 1456, 114, 357, 13483, 1457, 187, 4476, 97, 114, 242, 4424, 512, 99, 101, 109, 116, 13497, 13502, 13506, 13509, 114, 59, 49152, 55349, 56520, 116, 109, 238, 241, 105, 236, 13333, 97, 114, 230, 4542, 256, 97, 114, 13518, 13525, 114, 256, 59, 102, 13524, 6079, 26118, 256, 97, 110, 13530, 13549, 105, 103, 104, 116, 256, 101, 112, 13539, 13546, 112, 115, 105, 108, 111, 238, 7904, 104, 233, 11951, 115, 187, 10322, 640, 98, 99, 109, 110, 112, 13563, 13662, 4617, 13707, 13710, 1152, 59, 69, 100, 101, 109, 110, 112, 114, 115, 13582, 13583, 13585, 13589, 13598, 13603, 13612, 13617, 13622, 25218, 59, 27333, 111, 116, 59, 27325, 256, 59, 100, 4570, 13594, 111, 116, 59, 27331, 117, 108, 116, 59, 27329, 256, 69, 101, 13608, 13610, 59, 27339, 59, 25226, 108, 117, 115, 59, 27327, 97, 114, 114, 59, 27001, 384, 101, 105, 117, 13629, 13650, 13653, 116, 384, 59, 101, 110, 13582, 13637, 13643, 113, 256, 59, 113, 4570, 13583, 101, 113, 256, 59, 113, 13611, 13608, 109, 59, 27335, 256, 98, 112, 13658, 13660, 59, 27349, 59, 27347, 99, 768, 59, 97, 99, 101, 110, 115, 4589, 13676, 13682, 13689, 13691, 13094, 112, 112, 114, 111, 248, 13050, 117, 114, 108, 121, 101, 241, 4606, 241, 4595, 384, 97, 101, 115, 13698, 13704, 13083, 112, 112, 114, 111, 248, 13082, 113, 241, 13079, 103, 59, 26218, 1664, 49, 50, 51, 59, 69, 100, 101, 104, 108, 109, 110, 112, 115, 13737, 13740, 13743, 4636, 13746, 13748, 13760, 13769, 13781, 13786, 13791, 13800, 13805, 32827, 185, 16569, 32827, 178, 16562, 32827, 179, 16563, 59, 27334, 256, 111, 115, 13753, 13756, 116, 59, 27326, 117, 98, 59, 27352, 256, 59, 100, 4642, 13765, 111, 116, 59, 27332, 115, 256, 111, 117, 13775, 13778, 108, 59, 26569, 98, 59, 27351, 97, 114, 114, 59, 27003, 117, 108, 116, 59, 27330, 256, 69, 101, 13796, 13798, 59, 27340, 59, 25227, 108, 117, 115, 59, 27328, 384, 101, 105, 117, 13812, 13833, 13836, 116, 384, 59, 101, 110, 4636, 13820, 13826, 113, 256, 59, 113, 4642, 13746, 101, 113, 256, 59, 113, 13799, 13796, 109, 59, 27336, 256, 98, 112, 13841, 13843, 59, 27348, 59, 27350, 384, 65, 97, 110, 13852, 13856, 13869, 114, 114, 59, 25049, 114, 256, 104, 114, 13862, 13864, 235, 8750, 256, 59, 111, 2603, 2601, 119, 97, 114, 59, 26922, 108, 105, 103, 32827, 223, 16607, 3041, 13905, 13917, 13920, 4814, 13939, 13945, 0, 13950, 14018, 0, 0, 0, 0, 0, 14043, 14083, 0, 14089, 14188, 0, 0, 0, 14215, 626, 13910, 0, 0, 13915, 103, 101, 116, 59, 25366, 59, 17348, 114, 235, 3679, 384, 97, 101, 121, 13926, 13931, 13936, 114, 111, 110, 59, 16741, 100, 105, 108, 59, 16739, 59, 17474, 108, 114, 101, 99, 59, 25365, 114, 59, 49152, 55349, 56625, 512, 101, 105, 107, 111, 13958, 13981, 14005, 14012, 498, 13963, 0, 13969, 101, 256, 52, 102, 4740, 4737, 97, 384, 59, 115, 118, 13976, 13977, 13979, 17336, 121, 109, 59, 17361, 256, 99, 110, 13986, 14002, 107, 256, 97, 115, 13992, 13998, 112, 112, 114, 111, 248, 4801, 105, 109, 187, 4780, 115, 240, 4766, 256, 97, 115, 14010, 13998, 240, 4801, 114, 110, 32827, 254, 16638, 492, 799, 14022, 8935, 101, 115, 33152, 215, 59, 98, 100, 14031, 14032, 14040, 16599, 256, 59, 97, 6415, 14037, 114, 59, 27185, 59, 27184, 384, 101, 112, 115, 14049, 14051, 14080, 225, 10829, 512, 59, 98, 99, 102, 1158, 14060, 14064, 14068, 111, 116, 59, 25398, 105, 114, 59, 27377, 256, 59, 111, 14073, 14076, 49152, 55349, 56677, 114, 107, 59, 27354, 225, 13154, 114, 105, 109, 101, 59, 24628, 384, 97, 105, 112, 14095, 14098, 14180, 100, 229, 4680, 896, 97, 100, 101, 109, 112, 115, 116, 14113, 14157, 14144, 14161, 14167, 14172, 14175, 110, 103, 108, 101, 640, 59, 100, 108, 113, 114, 14128, 14129, 14134, 14144, 14146, 26037, 111, 119, 110, 187, 7611, 101, 102, 116, 256, 59, 101, 10240, 14142, 241, 2350, 59, 25180, 105, 103, 104, 116, 256, 59, 101, 12970, 14155, 241, 4186, 111, 116, 59, 26092, 105, 110, 117, 115, 59, 27194, 108, 117, 115, 59, 27193, 98, 59, 27085, 105, 109, 101, 59, 27195, 101, 122, 105, 117, 109, 59, 25570, 384, 99, 104, 116, 14194, 14205, 14209, 256, 114, 121, 14199, 14203, 59, 49152, 55349, 56521, 59, 17478, 99, 121, 59, 17499, 114, 111, 107, 59, 16743, 256, 105, 111, 14219, 14222, 120, 244, 6007, 104, 101, 97, 100, 256, 108, 114, 14231, 14240, 101, 102, 116, 97, 114, 114, 111, 247, 2127, 105, 103, 104, 116, 97, 114, 114, 111, 119, 187, 3933, 2304, 65, 72, 97, 98, 99, 100, 102, 103, 104, 108, 109, 111, 112, 114, 115, 116, 117, 119, 14288, 14291, 14295, 14308, 14320, 14332, 14350, 14364, 14371, 14388, 14417, 14429, 14443, 14505, 14540, 14546, 14570, 14582, 114, 242, 1005, 97, 114, 59, 26979, 256, 99, 114, 14300, 14306, 117, 116, 101, 32827, 250, 16634, 242, 4432, 114, 483, 14314, 0, 14317, 121, 59, 17502, 118, 101, 59, 16749, 256, 105, 121, 14325, 14330, 114, 99, 32827, 251, 16635, 59, 17475, 384, 97, 98, 104, 14339, 14342, 14347, 114, 242, 5037, 108, 97, 99, 59, 16753, 97, 242, 5059, 256, 105, 114, 14355, 14360, 115, 104, 116, 59, 27006, 59, 49152, 55349, 56626, 114, 97, 118, 101, 32827, 249, 16633, 353, 14375, 14385, 114, 256, 108, 114, 14380, 14382, 187, 2391, 187, 4227, 108, 107, 59, 25984, 256, 99, 116, 14393, 14413, 623, 14399, 0, 0, 14410, 114, 110, 256, 59, 101, 14405, 14406, 25372, 114, 187, 14406, 111, 112, 59, 25359, 114, 105, 59, 26104, 256, 97, 108, 14422, 14426, 99, 114, 59, 16747, 32955, 168, 841, 256, 103, 112, 14434, 14438, 111, 110, 59, 16755, 102, 59, 49152, 55349, 56678, 768, 97, 100, 104, 108, 115, 117, 4427, 14456, 14461, 4978, 14481, 14496, 111, 119, 110, 225, 5043, 97, 114, 112, 111, 111, 110, 256, 108, 114, 14472, 14476, 101, 102, 244, 14381, 105, 103, 104, 244, 14383, 105, 384, 59, 104, 108, 14489, 14490, 14492, 17349, 187, 5114, 111, 110, 187, 14490, 112, 97, 114, 114, 111, 119, 115, 59, 25032, 384, 99, 105, 116, 14512, 14532, 14536, 623, 14518, 0, 0, 14529, 114, 110, 256, 59, 101, 14524, 14525, 25373, 114, 187, 14525, 111, 112, 59, 25358, 110, 103, 59, 16751, 114, 105, 59, 26105, 99, 114, 59, 49152, 55349, 56522, 384, 100, 105, 114, 14553, 14557, 14562, 111, 116, 59, 25328, 108, 100, 101, 59, 16745, 105, 256, 59, 102, 14128, 14568, 187, 6163, 256, 97, 109, 14575, 14578, 114, 242, 14504, 108, 32827, 252, 16636, 97, 110, 103, 108, 101, 59, 27047, 1920, 65, 66, 68, 97, 99, 100, 101, 102, 108, 110, 111, 112, 114, 115, 122, 14620, 14623, 14633, 14637, 14773, 14776, 14781, 14815, 14820, 14824, 14835, 14841, 14845, 14849, 14880, 114, 242, 1015, 97, 114, 256, 59, 118, 14630, 14631, 27368, 59, 27369, 97, 115, 232, 993, 256, 110, 114, 14642, 14647, 103, 114, 116, 59, 27036, 896, 101, 107, 110, 112, 114, 115, 116, 13539, 14662, 14667, 14674, 14685, 14692, 14742, 97, 112, 112, 225, 9237, 111, 116, 104, 105, 110, 231, 7830, 384, 104, 105, 114, 13547, 11976, 14681, 111, 112, 244, 12213, 256, 59, 104, 5047, 14690, 239, 12685, 256, 105, 117, 14697, 14701, 103, 109, 225, 13235, 256, 98, 112, 14706, 14724, 115, 101, 116, 110, 101, 113, 256, 59, 113, 14717, 14720, 49152, 8842, 65024, 59, 49152, 10955, 65024, 115, 101, 116, 110, 101, 113, 256, 59, 113, 14735, 14738, 49152, 8843, 65024, 59, 49152, 10956, 65024, 256, 104, 114, 14747, 14751, 101, 116, 225, 13980, 105, 97, 110, 103, 108, 101, 256, 108, 114, 14762, 14767, 101, 102, 116, 187, 2341, 105, 103, 104, 116, 187, 4177, 121, 59, 17458, 97, 115, 104, 187, 4150, 384, 101, 108, 114, 14788, 14802, 14807, 384, 59, 98, 101, 11754, 14795, 14799, 97, 114, 59, 25275, 113, 59, 25178, 108, 105, 112, 59, 25326, 256, 98, 116, 14812, 5224, 97, 242, 5225, 114, 59, 49152, 55349, 56627, 116, 114, 233, 14766, 115, 117, 256, 98, 112, 14831, 14833, 187, 3356, 187, 3417, 112, 102, 59, 49152, 55349, 56679, 114, 111, 240, 3835, 116, 114, 233, 14772, 256, 99, 117, 14854, 14859, 114, 59, 49152, 55349, 56523, 256, 98, 112, 14864, 14872, 110, 256, 69, 101, 14720, 14870, 187, 14718, 110, 256, 69, 101, 14738, 14878, 187, 14736, 105, 103, 122, 97, 103, 59, 27034, 896, 99, 101, 102, 111, 112, 114, 115, 14902, 14907, 14934, 14939, 14932, 14945, 14954, 105, 114, 99, 59, 16757, 256, 100, 105, 14912, 14929, 256, 98, 103, 14917, 14921, 97, 114, 59, 27231, 101, 256, 59, 113, 5626, 14927, 59, 25177, 101, 114, 112, 59, 24856, 114, 59, 49152, 55349, 56628, 112, 102, 59, 49152, 55349, 56680, 256, 59, 101, 5241, 14950, 97, 116, 232, 5241, 99, 114, 59, 49152, 55349, 56524, 2787, 6030, 14983, 0, 14987, 0, 14992, 15003, 0, 0, 15005, 15016, 15019, 15023, 0, 0, 15043, 15054, 0, 15064, 6108, 6111, 116, 114, 233, 6097, 114, 59, 49152, 55349, 56629, 256, 65, 97, 14996, 14999, 114, 242, 963, 114, 242, 2550, 59, 17342, 256, 65, 97, 15009, 15012, 114, 242, 952, 114, 242, 2539, 97, 240, 10003, 105, 115, 59, 25339, 384, 100, 112, 116, 6052, 15029, 15038, 256, 102, 108, 15034, 6057, 59, 49152, 55349, 56681, 105, 109, 229, 6066, 256, 65, 97, 15047, 15050, 114, 242, 974, 114, 242, 2561, 256, 99, 113, 15058, 6072, 114, 59, 49152, 55349, 56525, 256, 112, 116, 6102, 15068, 114, 233, 6100, 1024, 97, 99, 101, 102, 105, 111, 115, 117, 15088, 15101, 15112, 15116, 15121, 15125, 15131, 15137, 99, 256, 117, 121, 15094, 15099, 116, 101, 32827, 253, 16637, 59, 17487, 256, 105, 121, 15106, 15110, 114, 99, 59, 16759, 59, 17483, 110, 32827, 165, 16549, 114, 59, 49152, 55349, 56630, 99, 121, 59, 17495, 112, 102, 59, 49152, 55349, 56682, 99, 114, 59, 49152, 55349, 56526, 256, 99, 109, 15142, 15145, 121, 59, 17486, 108, 32827, 255, 16639, 1280, 97, 99, 100, 101, 102, 104, 105, 111, 115, 119, 15170, 15176, 15188, 15192, 15204, 15209, 15213, 15220, 15226, 15232, 99, 117, 116, 101, 59, 16762, 256, 97, 121, 15181, 15186, 114, 111, 110, 59, 16766, 59, 17463, 111, 116, 59, 16764, 256, 101, 116, 15197, 15201, 116, 114, 230, 5471, 97, 59, 17334, 114, 59, 49152, 55349, 56631, 99, 121, 59, 17462, 103, 114, 97, 114, 114, 59, 25053, 112, 102, 59, 49152, 55349, 56683, 99, 114, 59, 49152, 55349, 56527, 256, 106, 110, 15237, 15239, 59, 24589, 106, 59, 24588]);

    var xmlDecodeTree = new Uint16Array([512, 97, 103, 108, 113, 9, 21, 24, 27, 621, 15, 0, 0, 18, 112, 59, 16422, 111, 115, 59, 16423, 116, 59, 16446, 116, 59, 16444, 117, 111, 116, 59, 16418]);

    var _a;
    const decodeMap = new Map([
        [0, 65533],
        [128, 8364],
        [130, 8218],
        [131, 402],
        [132, 8222],
        [133, 8230],
        [134, 8224],
        [135, 8225],
        [136, 710],
        [137, 8240],
        [138, 352],
        [139, 8249],
        [140, 338],
        [142, 381],
        [145, 8216],
        [146, 8217],
        [147, 8220],
        [148, 8221],
        [149, 8226],
        [150, 8211],
        [151, 8212],
        [152, 732],
        [153, 8482],
        [154, 353],
        [155, 8250],
        [156, 339],
        [158, 382],
        [159, 376],
    ]);
    const fromCodePoint =
    (_a = String.fromCodePoint) !== null && _a !== void 0 ? _a : function (codePoint) {
        let output = "";
        if (codePoint > 0xffff) {
            codePoint -= 0x10000;
            output += String.fromCharCode(((codePoint >>> 10) & 0x3ff) | 0xd800);
            codePoint = 0xdc00 | (codePoint & 0x3ff);
        }
        output += String.fromCharCode(codePoint);
        return output;
    };
    function replaceCodePoint(codePoint) {
        var _a;
        if ((codePoint >= 0xd800 && codePoint <= 0xdfff) || codePoint > 0x10ffff) {
            return 0xfffd;
        }
        return (_a = decodeMap.get(codePoint)) !== null && _a !== void 0 ? _a : codePoint;
    }

    var CharCodes$1;
    (function (CharCodes) {
        CharCodes[CharCodes["NUM"] = 35] = "NUM";
        CharCodes[CharCodes["SEMI"] = 59] = "SEMI";
        CharCodes[CharCodes["ZERO"] = 48] = "ZERO";
        CharCodes[CharCodes["NINE"] = 57] = "NINE";
        CharCodes[CharCodes["LOWER_A"] = 97] = "LOWER_A";
        CharCodes[CharCodes["LOWER_F"] = 102] = "LOWER_F";
        CharCodes[CharCodes["LOWER_X"] = 120] = "LOWER_X";
        CharCodes[CharCodes["To_LOWER_BIT"] = 32] = "To_LOWER_BIT";
    })(CharCodes$1 || (CharCodes$1 = {}));
    var BinTrieFlags;
    (function (BinTrieFlags) {
        BinTrieFlags[BinTrieFlags["VALUE_LENGTH"] = 49152] = "VALUE_LENGTH";
        BinTrieFlags[BinTrieFlags["BRANCH_LENGTH"] = 16256] = "BRANCH_LENGTH";
        BinTrieFlags[BinTrieFlags["JUMP_TABLE"] = 127] = "JUMP_TABLE";
    })(BinTrieFlags || (BinTrieFlags = {}));
    function determineBranch(decodeTree, current, nodeIdx, char) {
        const branchCount = (current & BinTrieFlags.BRANCH_LENGTH) >> 7;
        const jumpOffset = current & BinTrieFlags.JUMP_TABLE;
        if (branchCount === 0) {
            return jumpOffset !== 0 && char === jumpOffset ? nodeIdx : -1;
        }
        if (jumpOffset) {
            const value = char - jumpOffset;
            return value < 0 || value >= branchCount
                ? -1
                : decodeTree[nodeIdx + value] - 1;
        }
        let lo = nodeIdx;
        let hi = lo + branchCount - 1;
        while (lo <= hi) {
            const mid = (lo + hi) >>> 1;
            const midVal = decodeTree[mid];
            if (midVal < char) {
                lo = mid + 1;
            }
            else if (midVal > char) {
                hi = mid - 1;
            }
            else {
                return decodeTree[mid + branchCount];
            }
        }
        return -1;
    }

    var CharCodes;
    (function (CharCodes) {
        CharCodes[CharCodes["Tab"] = 9] = "Tab";
        CharCodes[CharCodes["NewLine"] = 10] = "NewLine";
        CharCodes[CharCodes["FormFeed"] = 12] = "FormFeed";
        CharCodes[CharCodes["CarriageReturn"] = 13] = "CarriageReturn";
        CharCodes[CharCodes["Space"] = 32] = "Space";
        CharCodes[CharCodes["ExclamationMark"] = 33] = "ExclamationMark";
        CharCodes[CharCodes["Num"] = 35] = "Num";
        CharCodes[CharCodes["Amp"] = 38] = "Amp";
        CharCodes[CharCodes["SingleQuote"] = 39] = "SingleQuote";
        CharCodes[CharCodes["DoubleQuote"] = 34] = "DoubleQuote";
        CharCodes[CharCodes["Dash"] = 45] = "Dash";
        CharCodes[CharCodes["Slash"] = 47] = "Slash";
        CharCodes[CharCodes["Zero"] = 48] = "Zero";
        CharCodes[CharCodes["Nine"] = 57] = "Nine";
        CharCodes[CharCodes["Semi"] = 59] = "Semi";
        CharCodes[CharCodes["Lt"] = 60] = "Lt";
        CharCodes[CharCodes["Eq"] = 61] = "Eq";
        CharCodes[CharCodes["Gt"] = 62] = "Gt";
        CharCodes[CharCodes["Questionmark"] = 63] = "Questionmark";
        CharCodes[CharCodes["UpperA"] = 65] = "UpperA";
        CharCodes[CharCodes["LowerA"] = 97] = "LowerA";
        CharCodes[CharCodes["UpperF"] = 70] = "UpperF";
        CharCodes[CharCodes["LowerF"] = 102] = "LowerF";
        CharCodes[CharCodes["UpperZ"] = 90] = "UpperZ";
        CharCodes[CharCodes["LowerZ"] = 122] = "LowerZ";
        CharCodes[CharCodes["LowerX"] = 120] = "LowerX";
        CharCodes[CharCodes["OpeningSquareBracket"] = 91] = "OpeningSquareBracket";
    })(CharCodes || (CharCodes = {}));
    var State;
    (function (State) {
        State[State["Text"] = 1] = "Text";
        State[State["BeforeTagName"] = 2] = "BeforeTagName";
        State[State["InTagName"] = 3] = "InTagName";
        State[State["InSelfClosingTag"] = 4] = "InSelfClosingTag";
        State[State["BeforeClosingTagName"] = 5] = "BeforeClosingTagName";
        State[State["InClosingTagName"] = 6] = "InClosingTagName";
        State[State["AfterClosingTagName"] = 7] = "AfterClosingTagName";
        State[State["BeforeAttributeName"] = 8] = "BeforeAttributeName";
        State[State["InAttributeName"] = 9] = "InAttributeName";
        State[State["AfterAttributeName"] = 10] = "AfterAttributeName";
        State[State["BeforeAttributeValue"] = 11] = "BeforeAttributeValue";
        State[State["InAttributeValueDq"] = 12] = "InAttributeValueDq";
        State[State["InAttributeValueSq"] = 13] = "InAttributeValueSq";
        State[State["InAttributeValueNq"] = 14] = "InAttributeValueNq";
        State[State["BeforeDeclaration"] = 15] = "BeforeDeclaration";
        State[State["InDeclaration"] = 16] = "InDeclaration";
        State[State["InProcessingInstruction"] = 17] = "InProcessingInstruction";
        State[State["BeforeComment"] = 18] = "BeforeComment";
        State[State["CDATASequence"] = 19] = "CDATASequence";
        State[State["InSpecialComment"] = 20] = "InSpecialComment";
        State[State["InCommentLike"] = 21] = "InCommentLike";
        State[State["BeforeSpecialS"] = 22] = "BeforeSpecialS";
        State[State["SpecialStartSequence"] = 23] = "SpecialStartSequence";
        State[State["InSpecialTag"] = 24] = "InSpecialTag";
        State[State["BeforeEntity"] = 25] = "BeforeEntity";
        State[State["BeforeNumericEntity"] = 26] = "BeforeNumericEntity";
        State[State["InNamedEntity"] = 27] = "InNamedEntity";
        State[State["InNumericEntity"] = 28] = "InNumericEntity";
        State[State["InHexEntity"] = 29] = "InHexEntity";
    })(State || (State = {}));
    function isWhitespace(c) {
        return (c === CharCodes.Space ||
            c === CharCodes.NewLine ||
            c === CharCodes.Tab ||
            c === CharCodes.FormFeed ||
            c === CharCodes.CarriageReturn);
    }
    function isEndOfTagSection(c) {
        return c === CharCodes.Slash || c === CharCodes.Gt || isWhitespace(c);
    }
    function isNumber(c) {
        return c >= CharCodes.Zero && c <= CharCodes.Nine;
    }
    function isASCIIAlpha(c) {
        return ((c >= CharCodes.LowerA && c <= CharCodes.LowerZ) ||
            (c >= CharCodes.UpperA && c <= CharCodes.UpperZ));
    }
    function isHexDigit(c) {
        return ((c >= CharCodes.UpperA && c <= CharCodes.UpperF) ||
            (c >= CharCodes.LowerA && c <= CharCodes.LowerF));
    }
    var QuoteType;
    (function (QuoteType) {
        QuoteType[QuoteType["NoValue"] = 0] = "NoValue";
        QuoteType[QuoteType["Unquoted"] = 1] = "Unquoted";
        QuoteType[QuoteType["Single"] = 2] = "Single";
        QuoteType[QuoteType["Double"] = 3] = "Double";
    })(QuoteType || (QuoteType = {}));
    const Sequences = {
        Cdata: new Uint8Array([0x43, 0x44, 0x41, 0x54, 0x41, 0x5b]),
        CdataEnd: new Uint8Array([0x5d, 0x5d, 0x3e]),
        CommentEnd: new Uint8Array([0x2d, 0x2d, 0x3e]),
        ScriptEnd: new Uint8Array([0x3c, 0x2f, 0x73, 0x63, 0x72, 0x69, 0x70, 0x74]),
        StyleEnd: new Uint8Array([0x3c, 0x2f, 0x73, 0x74, 0x79, 0x6c, 0x65]),
        TitleEnd: new Uint8Array([0x3c, 0x2f, 0x74, 0x69, 0x74, 0x6c, 0x65]),
    };
    class Tokenizer {
        constructor({ xmlMode = false, decodeEntities = true, }, cbs) {
            this.cbs = cbs;
            this.state = State.Text;
            this.buffer = "";
            this.sectionStart = 0;
            this.index = 0;
            this.baseState = State.Text;
            this.isSpecial = false;
            this.running = true;
            this.offset = 0;
            this.sequenceIndex = 0;
            this.trieIndex = 0;
            this.trieCurrent = 0;
            this.entityResult = 0;
            this.entityExcess = 0;
            this.xmlMode = xmlMode;
            this.decodeEntities = decodeEntities;
            this.entityTrie = xmlMode ? xmlDecodeTree : htmlDecodeTree;
        }
        reset() {
            this.state = State.Text;
            this.buffer = "";
            this.sectionStart = 0;
            this.index = 0;
            this.baseState = State.Text;
            this.currentSequence = undefined;
            this.running = true;
            this.offset = 0;
        }
        write(chunk) {
            this.offset += this.buffer.length;
            this.buffer = chunk;
            this.parse();
        }
        end() {
            if (this.running)
                this.finish();
        }
        pause() {
            this.running = false;
        }
        resume() {
            this.running = true;
            if (this.index < this.buffer.length + this.offset) {
                this.parse();
            }
        }
        getIndex() {
            return this.index;
        }
        getSectionStart() {
            return this.sectionStart;
        }
        stateText(c) {
            if (c === CharCodes.Lt ||
                (!this.decodeEntities && this.fastForwardTo(CharCodes.Lt))) {
                if (this.index > this.sectionStart) {
                    this.cbs.ontext(this.sectionStart, this.index);
                }
                this.state = State.BeforeTagName;
                this.sectionStart = this.index;
            }
            else if (this.decodeEntities && c === CharCodes.Amp) {
                this.state = State.BeforeEntity;
            }
        }
        stateSpecialStartSequence(c) {
            const isEnd = this.sequenceIndex === this.currentSequence.length;
            const isMatch = isEnd
                ?
                    isEndOfTagSection(c)
                :
                    (c | 0x20) === this.currentSequence[this.sequenceIndex];
            if (!isMatch) {
                this.isSpecial = false;
            }
            else if (!isEnd) {
                this.sequenceIndex++;
                return;
            }
            this.sequenceIndex = 0;
            this.state = State.InTagName;
            this.stateInTagName(c);
        }
        stateInSpecialTag(c) {
            if (this.sequenceIndex === this.currentSequence.length) {
                if (c === CharCodes.Gt || isWhitespace(c)) {
                    const endOfText = this.index - this.currentSequence.length;
                    if (this.sectionStart < endOfText) {
                        const actualIndex = this.index;
                        this.index = endOfText;
                        this.cbs.ontext(this.sectionStart, endOfText);
                        this.index = actualIndex;
                    }
                    this.isSpecial = false;
                    this.sectionStart = endOfText + 2;
                    this.stateInClosingTagName(c);
                    return;
                }
                this.sequenceIndex = 0;
            }
            if ((c | 0x20) === this.currentSequence[this.sequenceIndex]) {
                this.sequenceIndex += 1;
            }
            else if (this.sequenceIndex === 0) {
                if (this.currentSequence === Sequences.TitleEnd) {
                    if (this.decodeEntities && c === CharCodes.Amp) {
                        this.state = State.BeforeEntity;
                    }
                }
                else if (this.fastForwardTo(CharCodes.Lt)) {
                    this.sequenceIndex = 1;
                }
            }
            else {
                this.sequenceIndex = Number(c === CharCodes.Lt);
            }
        }
        stateCDATASequence(c) {
            if (c === Sequences.Cdata[this.sequenceIndex]) {
                if (++this.sequenceIndex === Sequences.Cdata.length) {
                    this.state = State.InCommentLike;
                    this.currentSequence = Sequences.CdataEnd;
                    this.sequenceIndex = 0;
                    this.sectionStart = this.index + 1;
                }
            }
            else {
                this.sequenceIndex = 0;
                this.state = State.InDeclaration;
                this.stateInDeclaration(c);
            }
        }
        fastForwardTo(c) {
            while (++this.index < this.buffer.length + this.offset) {
                if (this.buffer.charCodeAt(this.index - this.offset) === c) {
                    return true;
                }
            }
            this.index = this.buffer.length + this.offset - 1;
            return false;
        }
        stateInCommentLike(c) {
            if (c === this.currentSequence[this.sequenceIndex]) {
                if (++this.sequenceIndex === this.currentSequence.length) {
                    if (this.currentSequence === Sequences.CdataEnd) {
                        this.cbs.oncdata(this.sectionStart, this.index, 2);
                    }
                    else {
                        this.cbs.oncomment(this.sectionStart, this.index, 2);
                    }
                    this.sequenceIndex = 0;
                    this.sectionStart = this.index + 1;
                    this.state = State.Text;
                }
            }
            else if (this.sequenceIndex === 0) {
                if (this.fastForwardTo(this.currentSequence[0])) {
                    this.sequenceIndex = 1;
                }
            }
            else if (c !== this.currentSequence[this.sequenceIndex - 1]) {
                this.sequenceIndex = 0;
            }
        }
        isTagStartChar(c) {
            return this.xmlMode ? !isEndOfTagSection(c) : isASCIIAlpha(c);
        }
        startSpecial(sequence, offset) {
            this.isSpecial = true;
            this.currentSequence = sequence;
            this.sequenceIndex = offset;
            this.state = State.SpecialStartSequence;
        }
        stateBeforeTagName(c) {
            if (c === CharCodes.ExclamationMark) {
                this.state = State.BeforeDeclaration;
                this.sectionStart = this.index + 1;
            }
            else if (c === CharCodes.Questionmark) {
                this.state = State.InProcessingInstruction;
                this.sectionStart = this.index + 1;
            }
            else if (this.isTagStartChar(c)) {
                const lower = c | 0x20;
                this.sectionStart = this.index;
                if (!this.xmlMode && lower === Sequences.TitleEnd[2]) {
                    this.startSpecial(Sequences.TitleEnd, 3);
                }
                else {
                    this.state =
                        !this.xmlMode && lower === Sequences.ScriptEnd[2]
                            ? State.BeforeSpecialS
                            : State.InTagName;
                }
            }
            else if (c === CharCodes.Slash) {
                this.state = State.BeforeClosingTagName;
            }
            else {
                this.state = State.Text;
                this.stateText(c);
            }
        }
        stateInTagName(c) {
            if (isEndOfTagSection(c)) {
                this.cbs.onopentagname(this.sectionStart, this.index);
                this.sectionStart = -1;
                this.state = State.BeforeAttributeName;
                this.stateBeforeAttributeName(c);
            }
        }
        stateBeforeClosingTagName(c) {
            if (isWhitespace(c)) ;
            else if (c === CharCodes.Gt) {
                this.state = State.Text;
            }
            else {
                this.state = this.isTagStartChar(c)
                    ? State.InClosingTagName
                    : State.InSpecialComment;
                this.sectionStart = this.index;
            }
        }
        stateInClosingTagName(c) {
            if (c === CharCodes.Gt || isWhitespace(c)) {
                this.cbs.onclosetag(this.sectionStart, this.index);
                this.sectionStart = -1;
                this.state = State.AfterClosingTagName;
                this.stateAfterClosingTagName(c);
            }
        }
        stateAfterClosingTagName(c) {
            if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
                this.state = State.Text;
                this.sectionStart = this.index + 1;
            }
        }
        stateBeforeAttributeName(c) {
            if (c === CharCodes.Gt) {
                this.cbs.onopentagend(this.index);
                if (this.isSpecial) {
                    this.state = State.InSpecialTag;
                    this.sequenceIndex = 0;
                }
                else {
                    this.state = State.Text;
                }
                this.baseState = this.state;
                this.sectionStart = this.index + 1;
            }
            else if (c === CharCodes.Slash) {
                this.state = State.InSelfClosingTag;
            }
            else if (!isWhitespace(c)) {
                this.state = State.InAttributeName;
                this.sectionStart = this.index;
            }
        }
        stateInSelfClosingTag(c) {
            if (c === CharCodes.Gt) {
                this.cbs.onselfclosingtag(this.index);
                this.state = State.Text;
                this.baseState = State.Text;
                this.sectionStart = this.index + 1;
                this.isSpecial = false;
            }
            else if (!isWhitespace(c)) {
                this.state = State.BeforeAttributeName;
                this.stateBeforeAttributeName(c);
            }
        }
        stateInAttributeName(c) {
            if (c === CharCodes.Eq || isEndOfTagSection(c)) {
                this.cbs.onattribname(this.sectionStart, this.index);
                this.sectionStart = -1;
                this.state = State.AfterAttributeName;
                this.stateAfterAttributeName(c);
            }
        }
        stateAfterAttributeName(c) {
            if (c === CharCodes.Eq) {
                this.state = State.BeforeAttributeValue;
            }
            else if (c === CharCodes.Slash || c === CharCodes.Gt) {
                this.cbs.onattribend(QuoteType.NoValue, this.index);
                this.state = State.BeforeAttributeName;
                this.stateBeforeAttributeName(c);
            }
            else if (!isWhitespace(c)) {
                this.cbs.onattribend(QuoteType.NoValue, this.index);
                this.state = State.InAttributeName;
                this.sectionStart = this.index;
            }
        }
        stateBeforeAttributeValue(c) {
            if (c === CharCodes.DoubleQuote) {
                this.state = State.InAttributeValueDq;
                this.sectionStart = this.index + 1;
            }
            else if (c === CharCodes.SingleQuote) {
                this.state = State.InAttributeValueSq;
                this.sectionStart = this.index + 1;
            }
            else if (!isWhitespace(c)) {
                this.sectionStart = this.index;
                this.state = State.InAttributeValueNq;
                this.stateInAttributeValueNoQuotes(c);
            }
        }
        handleInAttributeValue(c, quote) {
            if (c === quote ||
                (!this.decodeEntities && this.fastForwardTo(quote))) {
                this.cbs.onattribdata(this.sectionStart, this.index);
                this.sectionStart = -1;
                this.cbs.onattribend(quote === CharCodes.DoubleQuote
                    ? QuoteType.Double
                    : QuoteType.Single, this.index);
                this.state = State.BeforeAttributeName;
            }
            else if (this.decodeEntities && c === CharCodes.Amp) {
                this.baseState = this.state;
                this.state = State.BeforeEntity;
            }
        }
        stateInAttributeValueDoubleQuotes(c) {
            this.handleInAttributeValue(c, CharCodes.DoubleQuote);
        }
        stateInAttributeValueSingleQuotes(c) {
            this.handleInAttributeValue(c, CharCodes.SingleQuote);
        }
        stateInAttributeValueNoQuotes(c) {
            if (isWhitespace(c) || c === CharCodes.Gt) {
                this.cbs.onattribdata(this.sectionStart, this.index);
                this.sectionStart = -1;
                this.cbs.onattribend(QuoteType.Unquoted, this.index);
                this.state = State.BeforeAttributeName;
                this.stateBeforeAttributeName(c);
            }
            else if (this.decodeEntities && c === CharCodes.Amp) {
                this.baseState = this.state;
                this.state = State.BeforeEntity;
            }
        }
        stateBeforeDeclaration(c) {
            if (c === CharCodes.OpeningSquareBracket) {
                this.state = State.CDATASequence;
                this.sequenceIndex = 0;
            }
            else {
                this.state =
                    c === CharCodes.Dash
                        ? State.BeforeComment
                        : State.InDeclaration;
            }
        }
        stateInDeclaration(c) {
            if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
                this.cbs.ondeclaration(this.sectionStart, this.index);
                this.state = State.Text;
                this.sectionStart = this.index + 1;
            }
        }
        stateInProcessingInstruction(c) {
            if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
                this.cbs.onprocessinginstruction(this.sectionStart, this.index);
                this.state = State.Text;
                this.sectionStart = this.index + 1;
            }
        }
        stateBeforeComment(c) {
            if (c === CharCodes.Dash) {
                this.state = State.InCommentLike;
                this.currentSequence = Sequences.CommentEnd;
                this.sequenceIndex = 2;
                this.sectionStart = this.index + 1;
            }
            else {
                this.state = State.InDeclaration;
            }
        }
        stateInSpecialComment(c) {
            if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
                this.cbs.oncomment(this.sectionStart, this.index, 0);
                this.state = State.Text;
                this.sectionStart = this.index + 1;
            }
        }
        stateBeforeSpecialS(c) {
            const lower = c | 0x20;
            if (lower === Sequences.ScriptEnd[3]) {
                this.startSpecial(Sequences.ScriptEnd, 4);
            }
            else if (lower === Sequences.StyleEnd[3]) {
                this.startSpecial(Sequences.StyleEnd, 4);
            }
            else {
                this.state = State.InTagName;
                this.stateInTagName(c);
            }
        }
        stateBeforeEntity(c) {
            this.entityExcess = 1;
            this.entityResult = 0;
            if (c === CharCodes.Num) {
                this.state = State.BeforeNumericEntity;
            }
            else if (c === CharCodes.Amp) ;
            else {
                this.trieIndex = 0;
                this.trieCurrent = this.entityTrie[0];
                this.state = State.InNamedEntity;
                this.stateInNamedEntity(c);
            }
        }
        stateInNamedEntity(c) {
            this.entityExcess += 1;
            this.trieIndex = determineBranch(this.entityTrie, this.trieCurrent, this.trieIndex + 1, c);
            if (this.trieIndex < 0) {
                this.emitNamedEntity();
                this.index--;
                return;
            }
            this.trieCurrent = this.entityTrie[this.trieIndex];
            const masked = this.trieCurrent & BinTrieFlags.VALUE_LENGTH;
            if (masked) {
                const valueLength = (masked >> 14) - 1;
                if (!this.allowLegacyEntity() && c !== CharCodes.Semi) {
                    this.trieIndex += valueLength;
                }
                else {
                    const entityStart = this.index - this.entityExcess + 1;
                    if (entityStart > this.sectionStart) {
                        this.emitPartial(this.sectionStart, entityStart);
                    }
                    this.entityResult = this.trieIndex;
                    this.trieIndex += valueLength;
                    this.entityExcess = 0;
                    this.sectionStart = this.index + 1;
                    if (valueLength === 0) {
                        this.emitNamedEntity();
                    }
                }
            }
        }
        emitNamedEntity() {
            this.state = this.baseState;
            if (this.entityResult === 0) {
                return;
            }
            const valueLength = (this.entityTrie[this.entityResult] & BinTrieFlags.VALUE_LENGTH) >>
                14;
            switch (valueLength) {
                case 1:
                    this.emitCodePoint(this.entityTrie[this.entityResult] &
                        ~BinTrieFlags.VALUE_LENGTH);
                    break;
                case 2:
                    this.emitCodePoint(this.entityTrie[this.entityResult + 1]);
                    break;
                case 3: {
                    this.emitCodePoint(this.entityTrie[this.entityResult + 1]);
                    this.emitCodePoint(this.entityTrie[this.entityResult + 2]);
                }
            }
        }
        stateBeforeNumericEntity(c) {
            if ((c | 0x20) === CharCodes.LowerX) {
                this.entityExcess++;
                this.state = State.InHexEntity;
            }
            else {
                this.state = State.InNumericEntity;
                this.stateInNumericEntity(c);
            }
        }
        emitNumericEntity(strict) {
            const entityStart = this.index - this.entityExcess - 1;
            const numberStart = entityStart + 2 + Number(this.state === State.InHexEntity);
            if (numberStart !== this.index) {
                if (entityStart > this.sectionStart) {
                    this.emitPartial(this.sectionStart, entityStart);
                }
                this.sectionStart = this.index + Number(strict);
                this.emitCodePoint(replaceCodePoint(this.entityResult));
            }
            this.state = this.baseState;
        }
        stateInNumericEntity(c) {
            if (c === CharCodes.Semi) {
                this.emitNumericEntity(true);
            }
            else if (isNumber(c)) {
                this.entityResult = this.entityResult * 10 + (c - CharCodes.Zero);
                this.entityExcess++;
            }
            else {
                if (this.allowLegacyEntity()) {
                    this.emitNumericEntity(false);
                }
                else {
                    this.state = this.baseState;
                }
                this.index--;
            }
        }
        stateInHexEntity(c) {
            if (c === CharCodes.Semi) {
                this.emitNumericEntity(true);
            }
            else if (isNumber(c)) {
                this.entityResult = this.entityResult * 16 + (c - CharCodes.Zero);
                this.entityExcess++;
            }
            else if (isHexDigit(c)) {
                this.entityResult =
                    this.entityResult * 16 + ((c | 0x20) - CharCodes.LowerA + 10);
                this.entityExcess++;
            }
            else {
                if (this.allowLegacyEntity()) {
                    this.emitNumericEntity(false);
                }
                else {
                    this.state = this.baseState;
                }
                this.index--;
            }
        }
        allowLegacyEntity() {
            return (!this.xmlMode &&
                (this.baseState === State.Text ||
                    this.baseState === State.InSpecialTag));
        }
        cleanup() {
            if (this.running && this.sectionStart !== this.index) {
                if (this.state === State.Text ||
                    (this.state === State.InSpecialTag && this.sequenceIndex === 0)) {
                    this.cbs.ontext(this.sectionStart, this.index);
                    this.sectionStart = this.index;
                }
                else if (this.state === State.InAttributeValueDq ||
                    this.state === State.InAttributeValueSq ||
                    this.state === State.InAttributeValueNq) {
                    this.cbs.onattribdata(this.sectionStart, this.index);
                    this.sectionStart = this.index;
                }
            }
        }
        shouldContinue() {
            return this.index < this.buffer.length + this.offset && this.running;
        }
        parse() {
            while (this.shouldContinue()) {
                const c = this.buffer.charCodeAt(this.index - this.offset);
                if (this.state === State.Text) {
                    this.stateText(c);
                }
                else if (this.state === State.SpecialStartSequence) {
                    this.stateSpecialStartSequence(c);
                }
                else if (this.state === State.InSpecialTag) {
                    this.stateInSpecialTag(c);
                }
                else if (this.state === State.CDATASequence) {
                    this.stateCDATASequence(c);
                }
                else if (this.state === State.InAttributeValueDq) {
                    this.stateInAttributeValueDoubleQuotes(c);
                }
                else if (this.state === State.InAttributeName) {
                    this.stateInAttributeName(c);
                }
                else if (this.state === State.InCommentLike) {
                    this.stateInCommentLike(c);
                }
                else if (this.state === State.InSpecialComment) {
                    this.stateInSpecialComment(c);
                }
                else if (this.state === State.BeforeAttributeName) {
                    this.stateBeforeAttributeName(c);
                }
                else if (this.state === State.InTagName) {
                    this.stateInTagName(c);
                }
                else if (this.state === State.InClosingTagName) {
                    this.stateInClosingTagName(c);
                }
                else if (this.state === State.BeforeTagName) {
                    this.stateBeforeTagName(c);
                }
                else if (this.state === State.AfterAttributeName) {
                    this.stateAfterAttributeName(c);
                }
                else if (this.state === State.InAttributeValueSq) {
                    this.stateInAttributeValueSingleQuotes(c);
                }
                else if (this.state === State.BeforeAttributeValue) {
                    this.stateBeforeAttributeValue(c);
                }
                else if (this.state === State.BeforeClosingTagName) {
                    this.stateBeforeClosingTagName(c);
                }
                else if (this.state === State.AfterClosingTagName) {
                    this.stateAfterClosingTagName(c);
                }
                else if (this.state === State.BeforeSpecialS) {
                    this.stateBeforeSpecialS(c);
                }
                else if (this.state === State.InAttributeValueNq) {
                    this.stateInAttributeValueNoQuotes(c);
                }
                else if (this.state === State.InSelfClosingTag) {
                    this.stateInSelfClosingTag(c);
                }
                else if (this.state === State.InDeclaration) {
                    this.stateInDeclaration(c);
                }
                else if (this.state === State.BeforeDeclaration) {
                    this.stateBeforeDeclaration(c);
                }
                else if (this.state === State.BeforeComment) {
                    this.stateBeforeComment(c);
                }
                else if (this.state === State.InProcessingInstruction) {
                    this.stateInProcessingInstruction(c);
                }
                else if (this.state === State.InNamedEntity) {
                    this.stateInNamedEntity(c);
                }
                else if (this.state === State.BeforeEntity) {
                    this.stateBeforeEntity(c);
                }
                else if (this.state === State.InHexEntity) {
                    this.stateInHexEntity(c);
                }
                else if (this.state === State.InNumericEntity) {
                    this.stateInNumericEntity(c);
                }
                else {
                    this.stateBeforeNumericEntity(c);
                }
                this.index++;
            }
            this.cleanup();
        }
        finish() {
            if (this.state === State.InNamedEntity) {
                this.emitNamedEntity();
            }
            if (this.sectionStart < this.index) {
                this.handleTrailingData();
            }
            this.cbs.onend();
        }
        handleTrailingData() {
            const endIndex = this.buffer.length + this.offset;
            if (this.state === State.InCommentLike) {
                if (this.currentSequence === Sequences.CdataEnd) {
                    this.cbs.oncdata(this.sectionStart, endIndex, 0);
                }
                else {
                    this.cbs.oncomment(this.sectionStart, endIndex, 0);
                }
            }
            else if (this.state === State.InNumericEntity &&
                this.allowLegacyEntity()) {
                this.emitNumericEntity(false);
            }
            else if (this.state === State.InHexEntity &&
                this.allowLegacyEntity()) {
                this.emitNumericEntity(false);
            }
            else if (this.state === State.InTagName ||
                this.state === State.BeforeAttributeName ||
                this.state === State.BeforeAttributeValue ||
                this.state === State.AfterAttributeName ||
                this.state === State.InAttributeName ||
                this.state === State.InAttributeValueSq ||
                this.state === State.InAttributeValueDq ||
                this.state === State.InAttributeValueNq ||
                this.state === State.InClosingTagName) ;
            else {
                this.cbs.ontext(this.sectionStart, endIndex);
            }
        }
        emitPartial(start, endIndex) {
            if (this.baseState !== State.Text &&
                this.baseState !== State.InSpecialTag) {
                this.cbs.onattribdata(start, endIndex);
            }
            else {
                this.cbs.ontext(start, endIndex);
            }
        }
        emitCodePoint(cp) {
            if (this.baseState !== State.Text &&
                this.baseState !== State.InSpecialTag) {
                this.cbs.onattribentity(cp);
            }
            else {
                this.cbs.ontextentity(cp);
            }
        }
    }

    const formTags = new Set([
        "input",
        "option",
        "optgroup",
        "select",
        "button",
        "datalist",
        "textarea",
    ]);
    const pTag = new Set(["p"]);
    const tableSectionTags = new Set(["thead", "tbody"]);
    const ddtTags = new Set(["dd", "dt"]);
    const rtpTags = new Set(["rt", "rp"]);
    const openImpliesClose = new Map([
        ["tr", new Set(["tr", "th", "td"])],
        ["th", new Set(["th"])],
        ["td", new Set(["thead", "th", "td"])],
        ["body", new Set(["head", "link", "script"])],
        ["li", new Set(["li"])],
        ["p", pTag],
        ["h1", pTag],
        ["h2", pTag],
        ["h3", pTag],
        ["h4", pTag],
        ["h5", pTag],
        ["h6", pTag],
        ["select", formTags],
        ["input", formTags],
        ["output", formTags],
        ["button", formTags],
        ["datalist", formTags],
        ["textarea", formTags],
        ["option", new Set(["option"])],
        ["optgroup", new Set(["optgroup", "option"])],
        ["dd", ddtTags],
        ["dt", ddtTags],
        ["address", pTag],
        ["article", pTag],
        ["aside", pTag],
        ["blockquote", pTag],
        ["details", pTag],
        ["div", pTag],
        ["dl", pTag],
        ["fieldset", pTag],
        ["figcaption", pTag],
        ["figure", pTag],
        ["footer", pTag],
        ["form", pTag],
        ["header", pTag],
        ["hr", pTag],
        ["main", pTag],
        ["nav", pTag],
        ["ol", pTag],
        ["pre", pTag],
        ["section", pTag],
        ["table", pTag],
        ["ul", pTag],
        ["rt", rtpTags],
        ["rp", rtpTags],
        ["tbody", tableSectionTags],
        ["tfoot", tableSectionTags],
    ]);
    const voidElements = new Set([
        "area",
        "base",
        "basefont",
        "br",
        "col",
        "command",
        "embed",
        "frame",
        "hr",
        "img",
        "input",
        "isindex",
        "keygen",
        "link",
        "meta",
        "param",
        "source",
        "track",
        "wbr",
    ]);
    const foreignContextElements = new Set(["math", "svg"]);
    const htmlIntegrationElements = new Set([
        "mi",
        "mo",
        "mn",
        "ms",
        "mtext",
        "annotation-xml",
        "foreignobject",
        "desc",
        "title",
    ]);
    const reNameEnd = /\s|\//;
    class Parser {
        constructor(cbs, options = {}) {
            var _a, _b, _c, _d, _e;
            this.options = options;
            this.startIndex = 0;
            this.endIndex = 0;
            this.openTagStart = 0;
            this.tagname = "";
            this.attribname = "";
            this.attribvalue = "";
            this.attribs = null;
            this.stack = [];
            this.foreignContext = [];
            this.buffers = [];
            this.bufferOffset = 0;
            this.writeIndex = 0;
            this.ended = false;
            this.cbs = cbs !== null && cbs !== void 0 ? cbs : {};
            this.lowerCaseTagNames = (_a = options.lowerCaseTags) !== null && _a !== void 0 ? _a : !options.xmlMode;
            this.lowerCaseAttributeNames =
                (_b = options.lowerCaseAttributeNames) !== null && _b !== void 0 ? _b : !options.xmlMode;
            this.tokenizer = new ((_c = options.Tokenizer) !== null && _c !== void 0 ? _c : Tokenizer)(this.options, this);
            (_e = (_d = this.cbs).onparserinit) === null || _e === void 0 ? void 0 : _e.call(_d, this);
        }
        ontext(start, endIndex) {
            var _a, _b;
            const data = this.getSlice(start, endIndex);
            this.endIndex = endIndex - 1;
            (_b = (_a = this.cbs).ontext) === null || _b === void 0 ? void 0 : _b.call(_a, data);
            this.startIndex = endIndex;
        }
        ontextentity(cp) {
            var _a, _b;
            const idx = this.tokenizer.getSectionStart();
            this.endIndex = idx - 1;
            (_b = (_a = this.cbs).ontext) === null || _b === void 0 ? void 0 : _b.call(_a, fromCodePoint(cp));
            this.startIndex = idx;
        }
        isVoidElement(name) {
            return !this.options.xmlMode && voidElements.has(name);
        }
        onopentagname(start, endIndex) {
            this.endIndex = endIndex;
            let name = this.getSlice(start, endIndex);
            if (this.lowerCaseTagNames) {
                name = name.toLowerCase();
            }
            this.emitOpenTag(name);
        }
        emitOpenTag(name) {
            var _a, _b, _c, _d;
            this.openTagStart = this.startIndex;
            this.tagname = name;
            const impliesClose = !this.options.xmlMode && openImpliesClose.get(name);
            if (impliesClose) {
                while (this.stack.length > 0 &&
                    impliesClose.has(this.stack[this.stack.length - 1])) {
                    const el = this.stack.pop();
                    (_b = (_a = this.cbs).onclosetag) === null || _b === void 0 ? void 0 : _b.call(_a, el, true);
                }
            }
            if (!this.isVoidElement(name)) {
                this.stack.push(name);
                if (foreignContextElements.has(name)) {
                    this.foreignContext.push(true);
                }
                else if (htmlIntegrationElements.has(name)) {
                    this.foreignContext.push(false);
                }
            }
            (_d = (_c = this.cbs).onopentagname) === null || _d === void 0 ? void 0 : _d.call(_c, name);
            if (this.cbs.onopentag)
                this.attribs = {};
        }
        endOpenTag(isImplied) {
            var _a, _b;
            this.startIndex = this.openTagStart;
            if (this.attribs) {
                (_b = (_a = this.cbs).onopentag) === null || _b === void 0 ? void 0 : _b.call(_a, this.tagname, this.attribs, isImplied);
                this.attribs = null;
            }
            if (this.cbs.onclosetag && this.isVoidElement(this.tagname)) {
                this.cbs.onclosetag(this.tagname, true);
            }
            this.tagname = "";
        }
        onopentagend(endIndex) {
            this.endIndex = endIndex;
            this.endOpenTag(false);
            this.startIndex = endIndex + 1;
        }
        onclosetag(start, endIndex) {
            var _a, _b, _c, _d, _e, _f;
            this.endIndex = endIndex;
            let name = this.getSlice(start, endIndex);
            if (this.lowerCaseTagNames) {
                name = name.toLowerCase();
            }
            if (foreignContextElements.has(name) ||
                htmlIntegrationElements.has(name)) {
                this.foreignContext.pop();
            }
            if (!this.isVoidElement(name)) {
                const pos = this.stack.lastIndexOf(name);
                if (pos !== -1) {
                    if (this.cbs.onclosetag) {
                        let count = this.stack.length - pos;
                        while (count--) {
                            this.cbs.onclosetag(this.stack.pop(), count !== 0);
                        }
                    }
                    else
                        this.stack.length = pos;
                }
                else if (!this.options.xmlMode && name === "p") {
                    this.emitOpenTag("p");
                    this.closeCurrentTag(true);
                }
            }
            else if (!this.options.xmlMode && name === "br") {
                (_b = (_a = this.cbs).onopentagname) === null || _b === void 0 ? void 0 : _b.call(_a, "br");
                (_d = (_c = this.cbs).onopentag) === null || _d === void 0 ? void 0 : _d.call(_c, "br", {}, true);
                (_f = (_e = this.cbs).onclosetag) === null || _f === void 0 ? void 0 : _f.call(_e, "br", false);
            }
            this.startIndex = endIndex + 1;
        }
        onselfclosingtag(endIndex) {
            this.endIndex = endIndex;
            if (this.options.xmlMode ||
                this.options.recognizeSelfClosing ||
                this.foreignContext[this.foreignContext.length - 1]) {
                this.closeCurrentTag(false);
                this.startIndex = endIndex + 1;
            }
            else {
                this.onopentagend(endIndex);
            }
        }
        closeCurrentTag(isOpenImplied) {
            var _a, _b;
            const name = this.tagname;
            this.endOpenTag(isOpenImplied);
            if (this.stack[this.stack.length - 1] === name) {
                (_b = (_a = this.cbs).onclosetag) === null || _b === void 0 ? void 0 : _b.call(_a, name, !isOpenImplied);
                this.stack.pop();
            }
        }
        onattribname(start, endIndex) {
            this.startIndex = start;
            const name = this.getSlice(start, endIndex);
            this.attribname = this.lowerCaseAttributeNames
                ? name.toLowerCase()
                : name;
        }
        onattribdata(start, endIndex) {
            this.attribvalue += this.getSlice(start, endIndex);
        }
        onattribentity(cp) {
            this.attribvalue += fromCodePoint(cp);
        }
        onattribend(quote, endIndex) {
            var _a, _b;
            this.endIndex = endIndex;
            (_b = (_a = this.cbs).onattribute) === null || _b === void 0 ? void 0 : _b.call(_a, this.attribname, this.attribvalue, quote === QuoteType.Double
                ? '"'
                : quote === QuoteType.Single
                    ? "'"
                    : quote === QuoteType.NoValue
                        ? undefined
                        : null);
            if (this.attribs &&
                !Object.prototype.hasOwnProperty.call(this.attribs, this.attribname)) {
                this.attribs[this.attribname] = this.attribvalue;
            }
            this.attribvalue = "";
        }
        getInstructionName(value) {
            const idx = value.search(reNameEnd);
            let name = idx < 0 ? value : value.substr(0, idx);
            if (this.lowerCaseTagNames) {
                name = name.toLowerCase();
            }
            return name;
        }
        ondeclaration(start, endIndex) {
            this.endIndex = endIndex;
            const value = this.getSlice(start, endIndex);
            if (this.cbs.onprocessinginstruction) {
                const name = this.getInstructionName(value);
                this.cbs.onprocessinginstruction(`!${name}`, `!${value}`);
            }
            this.startIndex = endIndex + 1;
        }
        onprocessinginstruction(start, endIndex) {
            this.endIndex = endIndex;
            const value = this.getSlice(start, endIndex);
            if (this.cbs.onprocessinginstruction) {
                const name = this.getInstructionName(value);
                this.cbs.onprocessinginstruction(`?${name}`, `?${value}`);
            }
            this.startIndex = endIndex + 1;
        }
        oncomment(start, endIndex, offset) {
            var _a, _b, _c, _d;
            this.endIndex = endIndex;
            (_b = (_a = this.cbs).oncomment) === null || _b === void 0 ? void 0 : _b.call(_a, this.getSlice(start, endIndex - offset));
            (_d = (_c = this.cbs).oncommentend) === null || _d === void 0 ? void 0 : _d.call(_c);
            this.startIndex = endIndex + 1;
        }
        oncdata(start, endIndex, offset) {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
            this.endIndex = endIndex;
            const value = this.getSlice(start, endIndex - offset);
            if (this.options.xmlMode || this.options.recognizeCDATA) {
                (_b = (_a = this.cbs).oncdatastart) === null || _b === void 0 ? void 0 : _b.call(_a);
                (_d = (_c = this.cbs).ontext) === null || _d === void 0 ? void 0 : _d.call(_c, value);
                (_f = (_e = this.cbs).oncdataend) === null || _f === void 0 ? void 0 : _f.call(_e);
            }
            else {
                (_h = (_g = this.cbs).oncomment) === null || _h === void 0 ? void 0 : _h.call(_g, `[CDATA[${value}]]`);
                (_k = (_j = this.cbs).oncommentend) === null || _k === void 0 ? void 0 : _k.call(_j);
            }
            this.startIndex = endIndex + 1;
        }
        onend() {
            var _a, _b;
            if (this.cbs.onclosetag) {
                this.endIndex = this.startIndex;
                for (let i = this.stack.length; i > 0; this.cbs.onclosetag(this.stack[--i], true))
                    ;
            }
            (_b = (_a = this.cbs).onend) === null || _b === void 0 ? void 0 : _b.call(_a);
        }
        reset() {
            var _a, _b, _c, _d;
            (_b = (_a = this.cbs).onreset) === null || _b === void 0 ? void 0 : _b.call(_a);
            this.tokenizer.reset();
            this.tagname = "";
            this.attribname = "";
            this.attribs = null;
            this.stack.length = 0;
            this.startIndex = 0;
            this.endIndex = 0;
            (_d = (_c = this.cbs).onparserinit) === null || _d === void 0 ? void 0 : _d.call(_c, this);
            this.buffers.length = 0;
            this.bufferOffset = 0;
            this.writeIndex = 0;
            this.ended = false;
        }
        parseComplete(data) {
            this.reset();
            this.end(data);
        }
        getSlice(start, end) {
            while (start - this.bufferOffset >= this.buffers[0].length) {
                this.shiftBuffer();
            }
            let str = this.buffers[0].slice(start - this.bufferOffset, end - this.bufferOffset);
            while (end - this.bufferOffset > this.buffers[0].length) {
                this.shiftBuffer();
                str += this.buffers[0].slice(0, end - this.bufferOffset);
            }
            return str;
        }
        shiftBuffer() {
            this.bufferOffset += this.buffers[0].length;
            this.writeIndex--;
            this.buffers.shift();
        }
        write(chunk) {
            var _a, _b;
            if (this.ended) {
                (_b = (_a = this.cbs).onerror) === null || _b === void 0 ? void 0 : _b.call(_a, new Error(".write() after done!"));
                return;
            }
            this.buffers.push(chunk);
            if (this.tokenizer.running) {
                this.tokenizer.write(chunk);
                this.writeIndex++;
            }
        }
        end(chunk) {
            var _a, _b;
            if (this.ended) {
                (_b = (_a = this.cbs).onerror) === null || _b === void 0 ? void 0 : _b.call(_a, Error(".end() after done!"));
                return;
            }
            if (chunk)
                this.write(chunk);
            this.ended = true;
            this.tokenizer.end();
        }
        pause() {
            this.tokenizer.pause();
        }
        resume() {
            this.tokenizer.resume();
            while (this.tokenizer.running &&
                this.writeIndex < this.buffers.length) {
                this.tokenizer.write(this.buffers[this.writeIndex++]);
            }
            if (this.ended)
                this.tokenizer.end();
        }
        parseChunk(chunk) {
            this.write(chunk);
        }
        done(chunk) {
            this.end(chunk);
        }
    }

    var ElementType;
    (function (ElementType) {
        ElementType["Root"] = "root";
        ElementType["Text"] = "text";
        ElementType["Directive"] = "directive";
        ElementType["Comment"] = "comment";
        ElementType["Script"] = "script";
        ElementType["Style"] = "style";
        ElementType["Tag"] = "tag";
        ElementType["CDATA"] = "cdata";
        ElementType["Doctype"] = "doctype";
    })(ElementType || (ElementType = {}));
    ElementType.Root;
    ElementType.Text;
    ElementType.Directive;
    ElementType.Comment;
    ElementType.Script;
    ElementType.Style;
    ElementType.Tag;
    ElementType.CDATA;
    ElementType.Doctype;

    var EntityLevel;
    (function (EntityLevel) {
        EntityLevel[EntityLevel["XML"] = 0] = "XML";
        EntityLevel[EntityLevel["HTML"] = 1] = "HTML";
    })(EntityLevel || (EntityLevel = {}));
    var DecodingMode;
    (function (DecodingMode) {
        DecodingMode[DecodingMode["Legacy"] = 0] = "Legacy";
        DecodingMode[DecodingMode["Strict"] = 1] = "Strict";
    })(DecodingMode || (DecodingMode = {}));
    var EncodingMode;
    (function (EncodingMode) {
        EncodingMode[EncodingMode["UTF8"] = 0] = "UTF8";
        EncodingMode[EncodingMode["ASCII"] = 1] = "ASCII";
        EncodingMode[EncodingMode["Extensive"] = 2] = "Extensive";
        EncodingMode[EncodingMode["Attribute"] = 3] = "Attribute";
        EncodingMode[EncodingMode["Text"] = 4] = "Text";
    })(EncodingMode || (EncodingMode = {}));

    new Map([
        "altGlyph",
        "altGlyphDef",
        "altGlyphItem",
        "animateColor",
        "animateMotion",
        "animateTransform",
        "clipPath",
        "feBlend",
        "feColorMatrix",
        "feComponentTransfer",
        "feComposite",
        "feConvolveMatrix",
        "feDiffuseLighting",
        "feDisplacementMap",
        "feDistantLight",
        "feDropShadow",
        "feFlood",
        "feFuncA",
        "feFuncB",
        "feFuncG",
        "feFuncR",
        "feGaussianBlur",
        "feImage",
        "feMerge",
        "feMergeNode",
        "feMorphology",
        "feOffset",
        "fePointLight",
        "feSpecularLighting",
        "feSpotLight",
        "feTile",
        "feTurbulence",
        "foreignObject",
        "glyphRef",
        "linearGradient",
        "radialGradient",
        "textPath",
    ].map((val) => [val.toLowerCase(), val]));
    new Map([
        "definitionURL",
        "attributeName",
        "attributeType",
        "baseFrequency",
        "baseProfile",
        "calcMode",
        "clipPathUnits",
        "diffuseConstant",
        "edgeMode",
        "filterUnits",
        "glyphRef",
        "gradientTransform",
        "gradientUnits",
        "kernelMatrix",
        "kernelUnitLength",
        "keyPoints",
        "keySplines",
        "keyTimes",
        "lengthAdjust",
        "limitingConeAngle",
        "markerHeight",
        "markerUnits",
        "markerWidth",
        "maskContentUnits",
        "maskUnits",
        "numOctaves",
        "pathLength",
        "patternContentUnits",
        "patternTransform",
        "patternUnits",
        "pointsAtX",
        "pointsAtY",
        "pointsAtZ",
        "preserveAlpha",
        "preserveAspectRatio",
        "primitiveUnits",
        "refX",
        "refY",
        "repeatCount",
        "repeatDur",
        "requiredExtensions",
        "requiredFeatures",
        "specularConstant",
        "specularExponent",
        "spreadMethod",
        "startOffset",
        "stdDeviation",
        "stitchTiles",
        "surfaceScale",
        "systemLanguage",
        "tableValues",
        "targetX",
        "targetY",
        "textLength",
        "viewBox",
        "viewTarget",
        "xChannelSelector",
        "yChannelSelector",
        "zoomAndPan",
    ].map((val) => [val.toLowerCase(), val]));

    var DocumentPosition;
    (function (DocumentPosition) {
        DocumentPosition[DocumentPosition["DISCONNECTED"] = 1] = "DISCONNECTED";
        DocumentPosition[DocumentPosition["PRECEDING"] = 2] = "PRECEDING";
        DocumentPosition[DocumentPosition["FOLLOWING"] = 4] = "FOLLOWING";
        DocumentPosition[DocumentPosition["CONTAINS"] = 8] = "CONTAINS";
        DocumentPosition[DocumentPosition["CONTAINED_BY"] = 16] = "CONTAINED_BY";
    })(DocumentPosition || (DocumentPosition = {}));

    const DEFAULT_USER_AGENT = 'Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)';
    const session = new soup3.Session();
    session.timeout = 5;
    const decoder = new TextDecoder();
    const debug$2 = logger('link-parser');
    const getDocument = async (url) => {
        const defaultResult = {
            title: '',
            description: '',
            imageUrl: '',
        };
        try {
            const message = soup3.Message.new('GET', url);
            message.request_headers.append('User-Agent', DEFAULT_USER_AGENT);
            const response = await session.send_and_read_async(message, glib2.PRIORITY_DEFAULT, null);
            if (response == null) {
                debug$2(`no response from ${url}`);
                return defaultResult;
            }
            const bytes = response.get_data();
            if (bytes == null) {
                debug$2(`no data from ${url}`);
                return defaultResult;
            }
            const data = decoder.decode(bytes);
            let titleMatch = false;
            let titleTag = '';
            let title = '', description = '', imageUrl = '';
            const p = new Parser({
                onopentag(name, attribs) {
                    if (name === 'meta') {
                        if (!title &&
                            (attribs['property'] === 'og:title' ||
                                attribs['property'] === 'twitter:title' ||
                                attribs['property'] === 'title' ||
                                attribs['name'] === 'og:title' ||
                                attribs['name'] === 'twitter:title' ||
                                attribs['name'] === 'title')) {
                            title = attribs['content'];
                        }
                        else if (!description &&
                            (attribs['property'] === 'og:description' ||
                                attribs['property'] === 'twitter:description' ||
                                attribs['property'] === 'description' ||
                                attribs['name'] === 'og:description' ||
                                attribs['name'] === 'twitter:description' ||
                                attribs['name'] === 'description')) {
                            description = attribs['content'];
                        }
                        else if (!imageUrl &&
                            (attribs['property'] === 'og:image' ||
                                attribs['property'] === 'twitter:image' ||
                                attribs['property'] === 'image' ||
                                attribs['name'] === 'og:image' ||
                                attribs['name'] === 'twitter:image' ||
                                attribs['name'] === 'image')) {
                            imageUrl = attribs['content'];
                            if (imageUrl.startsWith('/')) {
                                const uri = glib2.uri_parse(url, glib2.UriFlags.NONE);
                                imageUrl = `${uri.get_scheme()}://${uri.get_host()}${imageUrl}`;
                            }
                        }
                    }
                    if (name === 'title') {
                        titleMatch = true;
                    }
                },
                ontext(data) {
                    if (titleMatch && !title) {
                        titleTag += data;
                    }
                },
                onclosetag(name) {
                    if (name === 'title') {
                        titleMatch = false;
                    }
                },
            }, {
                decodeEntities: true,
                lowerCaseTags: true,
                lowerCaseAttributeNames: true,
            });
            p.write(data);
            p.end();
            title = title || titleTag;
            return {
                title,
                description,
                imageUrl,
            };
        }
        catch (err) {
            debug$2(`failed to parse link ${url}. err: ${err}`);
        }
        return defaultResult;
    };
    const getImage = async (imageUrl) => {
        if (imageUrl && imageUrl.startsWith('http')) {
            try {
                const checksum = glib2.compute_checksum_for_string(glib2.ChecksumType.MD5, imageUrl, imageUrl.length);
                const cachedImage = gio2.File.new_for_path(`${getCachePath()}/${checksum}.png`);
                if (cachedImage.query_exists(null)) {
                    return [checksum, cachedImage];
                }
                const message = soup3.Message.new('GET', imageUrl);
                message.request_headers.append('User-Agent', DEFAULT_USER_AGENT);
                const response = await session.send_and_read_async(message, glib2.PRIORITY_DEFAULT, null);
                if (!response) {
                    debug$2('no response while fetching the image');
                    return [null, null];
                }
                const data = response.get_data();
                if (!data || data.length == 0) {
                    debug$2('empty response while fetching the image');
                    return [null, null];
                }
                cachedImage.replace_contents(data, null, false, gio2.FileCreateFlags.REPLACE_DESTINATION, null);
                return [checksum, cachedImage];
            }
            catch (err) {
                debug$2(`failed to load image: ${imageUrl}. err: ${err}`);
            }
        }
        return [null, null];
    };

    const opacity$1 = (hex, opacity) => {
      if (typeof hex !== 'string' || !/^#([A-Fa-f0-9]{3}$|[A-Fa-f0-9]{6}$|[A-Fa-f0-9]{8}$)/.test(hex)) throw new Error('Invalid hexadecimal color value')
      if (typeof opacity !== 'number' || opacity > 1 || opacity < 0) throw new Error('Opacity should be float between 0 - 1')
      let color = hex.substring(1);
      if (color.length === 8) color = color.substring(0, color.length - 2);
      if (color.length === 3) color = color[0] + color[0] + color[1] + color[1] + color[2] + color[2];
      color += Math.round(opacity * 255).toString(16).padStart(2, '0');
      return `#${color}`.toUpperCase()
    };
    var lib$1 = opacity$1;

    const opacity = lib$1;
    const convert = (color) => {
      if (typeof color !== 'string') throw new Error('Invalid rgb(a) color value')
      if (/^#([A-Fa-f0-9]{3}$|[A-Fa-f0-9]{6}$|[A-Fa-f0-9]{8}$)$/.test(color)) return color
      const rgb = /rgb\((\d{1,3}), ?(\d{1,3}), ?(\d{1,3})\)/.exec(color);
      const rgba = /rgba\((\d{1,3}), ?(\d{1,3}), ?(\d{1,3}), ?(1|(0(?:\.\d{1,2})?))\)/.exec(color);
      if (rgb !== null) {
        let hexadecimal = '#';
        if (rgb[1].length > 1) hexadecimal += Number(rgb[1]).toString(16);
        else hexadecimal += '0' + Number(rgb[1]).toString(16);
        if (rgb[2].length > 1) hexadecimal += Number(rgb[2]).toString(16);
        else hexadecimal += '0' + Number(rgb[2]).toString(16);
        if (rgb[3].length > 1) hexadecimal += Number(rgb[3]).toString(16);
        else hexadecimal += '0' + Number(rgb[3]).toString(16);
        return hexadecimal.toUpperCase()
      } else if (rgba !== null) {
        let hexadecimal = '#';
        if (rgba[1].length > 1) hexadecimal += Number(rgba[1]).toString(16);
        else hexadecimal += '0' + Number(rgba[1]).toString(16);
        if (rgba[2].length > 1) hexadecimal += Number(rgba[2]).toString(16);
        else hexadecimal += '0' + Number(rgba[2]).toString(16);
        if (rgba[3].length > 1) hexadecimal += Number(rgba[3]).toString(16);
        else hexadecimal += '0' + Number(rgba[3]).toString(16);
        hexadecimal = opacity(hexadecimal, Number(rgba[4]));
        return hexadecimal.toUpperCase()
      } else throw new Error('Invalid rgb(a) color value')
    };
    var lib = convert;

    var deepFreezeEs6 = {exports: {}};
    function deepFreeze(obj) {
        if (obj instanceof Map) {
            obj.clear = obj.delete = obj.set = function () {
                throw new Error('map is read-only');
            };
        } else if (obj instanceof Set) {
            obj.add = obj.clear = obj.delete = function () {
                throw new Error('set is read-only');
            };
        }
        Object.freeze(obj);
        Object.getOwnPropertyNames(obj).forEach(function (name) {
            var prop = obj[name];
            if (typeof prop == 'object' && !Object.isFrozen(prop)) {
                deepFreeze(prop);
            }
        });
        return obj;
    }
    deepFreezeEs6.exports = deepFreeze;
    deepFreezeEs6.exports.default = deepFreeze;
    class Response {
      constructor(mode) {
        if (mode.data === undefined) mode.data = {};
        this.data = mode.data;
        this.isMatchIgnored = false;
      }
      ignoreMatch() {
        this.isMatchIgnored = true;
      }
    }
    function escapeHTML(value) {
      return value
        .replace(/&/g, '&amp;')
        .replace(/</g, '&lt;')
        .replace(/>/g, '&gt;')
        .replace(/"/g, '&quot;')
        .replace(/'/g, '&#x27;');
    }
    function inherit$1(original, ...objects) {
      const result = Object.create(null);
      for (const key in original) {
        result[key] = original[key];
      }
      objects.forEach(function(obj) {
        for (const key in obj) {
          result[key] = obj[key];
        }
      });
      return  (result);
    }
    const SPAN_CLOSE = '</span>';
    const emitsWrappingTags = (node) => {
      return !!node.scope || (node.sublanguage && node.language);
    };
    const scopeToCSSClass = (name, { prefix }) => {
      if (name.includes(".")) {
        const pieces = name.split(".");
        return [
          `${prefix}${pieces.shift()}`,
          ...(pieces.map((x, i) => `${x}${"_".repeat(i + 1)}`))
        ].join(" ");
      }
      return `${prefix}${name}`;
    };
    class HTMLRenderer {
      constructor(parseTree, options) {
        this.buffer = "";
        this.classPrefix = options.classPrefix;
        parseTree.walk(this);
      }
      addText(text) {
        this.buffer += escapeHTML(text);
      }
      openNode(node) {
        if (!emitsWrappingTags(node)) return;
        let className = "";
        if (node.sublanguage) {
          className = `language-${node.language}`;
        } else {
          className = scopeToCSSClass(node.scope, { prefix: this.classPrefix });
        }
        this.span(className);
      }
      closeNode(node) {
        if (!emitsWrappingTags(node)) return;
        this.buffer += SPAN_CLOSE;
      }
      value() {
        return this.buffer;
      }
      span(className) {
        this.buffer += `<span class="${className}">`;
      }
    }
    const newNode = (opts = {}) => {
      const result = { children: [] };
      Object.assign(result, opts);
      return result;
    };
    class TokenTree {
      constructor() {
        this.rootNode = newNode();
        this.stack = [this.rootNode];
      }
      get top() {
        return this.stack[this.stack.length - 1];
      }
      get root() { return this.rootNode; }
      add(node) {
        this.top.children.push(node);
      }
      openNode(scope) {
        const node = newNode({ scope });
        this.add(node);
        this.stack.push(node);
      }
      closeNode() {
        if (this.stack.length > 1) {
          return this.stack.pop();
        }
        return undefined;
      }
      closeAllNodes() {
        while (this.closeNode());
      }
      toJSON() {
        return JSON.stringify(this.rootNode, null, 4);
      }
      walk(builder) {
        return this.constructor._walk(builder, this.rootNode);
      }
      static _walk(builder, node) {
        if (typeof node === "string") {
          builder.addText(node);
        } else if (node.children) {
          builder.openNode(node);
          node.children.forEach((child) => this._walk(builder, child));
          builder.closeNode(node);
        }
        return builder;
      }
      static _collapse(node) {
        if (typeof node === "string") return;
        if (!node.children) return;
        if (node.children.every(el => typeof el === "string")) {
          node.children = [node.children.join("")];
        } else {
          node.children.forEach((child) => {
            TokenTree._collapse(child);
          });
        }
      }
    }
    class TokenTreeEmitter extends TokenTree {
      constructor(options) {
        super();
        this.options = options;
      }
      addKeyword(text, scope) {
        if (text === "") { return; }
        this.openNode(scope);
        this.addText(text);
        this.closeNode();
      }
      addText(text) {
        if (text === "") { return; }
        this.add(text);
      }
      addSublanguage(emitter, name) {
        const node = emitter.root;
        node.sublanguage = true;
        node.language = name;
        this.add(node);
      }
      toHTML() {
        const renderer = new HTMLRenderer(this, this.options);
        return renderer.value();
      }
      finalize() {
        return true;
      }
    }
    function source$1(re) {
      if (!re) return null;
      if (typeof re === "string") return re;
      return re.source;
    }
    function lookahead$1(re) {
      return concat$1('(?=', re, ')');
    }
    function anyNumberOfTimes(re) {
      return concat$1('(?:', re, ')*');
    }
    function optional(re) {
      return concat$1('(?:', re, ')?');
    }
    function concat$1(...args) {
      const joined = args.map((x) => source$1(x)).join("");
      return joined;
    }
    function stripOptionsFromArgs$1(args) {
      const opts = args[args.length - 1];
      if (typeof opts === 'object' && opts.constructor === Object) {
        args.splice(args.length - 1, 1);
        return opts;
      } else {
        return {};
      }
    }
    function either$1(...args) {
      const opts = stripOptionsFromArgs$1(args);
      const joined = '('
        + (opts.capture ? "" : "?:")
        + args.map((x) => source$1(x)).join("|") + ")";
      return joined;
    }
    function countMatchGroups(re) {
      return (new RegExp(re.toString() + '|')).exec('').length - 1;
    }
    function startsWith(re, lexeme) {
      const match = re && re.exec(lexeme);
      return match && match.index === 0;
    }
    const BACKREF_RE = /\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./;
    function _rewriteBackreferences(regexps, { joinWith }) {
      let numCaptures = 0;
      return regexps.map((regex) => {
        numCaptures += 1;
        const offset = numCaptures;
        let re = source$1(regex);
        let out = '';
        while (re.length > 0) {
          const match = BACKREF_RE.exec(re);
          if (!match) {
            out += re;
            break;
          }
          out += re.substring(0, match.index);
          re = re.substring(match.index + match[0].length);
          if (match[0][0] === '\\' && match[1]) {
            out += '\\' + String(Number(match[1]) + offset);
          } else {
            out += match[0];
            if (match[0] === '(') {
              numCaptures++;
            }
          }
        }
        return out;
      }).map(re => `(${re})`).join(joinWith);
    }
    const MATCH_NOTHING_RE = /\b\B/;
    const IDENT_RE$2 = '[a-zA-Z]\\w*';
    const UNDERSCORE_IDENT_RE = '[a-zA-Z_]\\w*';
    const NUMBER_RE = '\\b\\d+(\\.\\d+)?';
    const C_NUMBER_RE = '(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)';
    const BINARY_NUMBER_RE = '\\b(0b[01]+)';
    const RE_STARTERS_RE = '!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~';
    const SHEBANG = (opts = {}) => {
      const beginShebang = /^#![ ]*\//;
      if (opts.binary) {
        opts.begin = concat$1(
          beginShebang,
          /.*\b/,
          opts.binary,
          /\b.*/);
      }
      return inherit$1({
        scope: 'meta',
        begin: beginShebang,
        end: /$/,
        relevance: 0,
        "on:begin": (m, resp) => {
          if (m.index !== 0) resp.ignoreMatch();
        }
      }, opts);
    };
    const BACKSLASH_ESCAPE = {
      begin: '\\\\[\\s\\S]', relevance: 0
    };
    const APOS_STRING_MODE = {
      scope: 'string',
      begin: '\'',
      end: '\'',
      illegal: '\\n',
      contains: [BACKSLASH_ESCAPE]
    };
    const QUOTE_STRING_MODE = {
      scope: 'string',
      begin: '"',
      end: '"',
      illegal: '\\n',
      contains: [BACKSLASH_ESCAPE]
    };
    const PHRASAL_WORDS_MODE = {
      begin: /\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/
    };
    const COMMENT = function(begin, end, modeOptions = {}) {
      const mode = inherit$1(
        {
          scope: 'comment',
          begin,
          end,
          contains: []
        },
        modeOptions
      );
      mode.contains.push({
        scope: 'doctag',
        begin: '[ ]*(?=(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):)',
        end: /(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):/,
        excludeBegin: true,
        relevance: 0
      });
      const ENGLISH_WORD = either$1(
        "I",
        "a",
        "is",
        "so",
        "us",
        "to",
        "at",
        "if",
        "in",
        "it",
        "on",
        /[A-Za-z]+['](d|ve|re|ll|t|s|n)/,
        /[A-Za-z]+[-][a-z]+/,
        /[A-Za-z][a-z]{2,}/
      );
      mode.contains.push(
        {
          begin: concat$1(
            /[ ]+/,
            '(',
            ENGLISH_WORD,
            /[.]?[:]?([.][ ]|[ ])/,
            '){3}')
        }
      );
      return mode;
    };
    const C_LINE_COMMENT_MODE = COMMENT('//', '$');
    const C_BLOCK_COMMENT_MODE = COMMENT('/\\*', '\\*/');
    const HASH_COMMENT_MODE = COMMENT('#', '$');
    const NUMBER_MODE = {
      scope: 'number',
      begin: NUMBER_RE,
      relevance: 0
    };
    const C_NUMBER_MODE = {
      scope: 'number',
      begin: C_NUMBER_RE,
      relevance: 0
    };
    const BINARY_NUMBER_MODE = {
      scope: 'number',
      begin: BINARY_NUMBER_RE,
      relevance: 0
    };
    const REGEXP_MODE = {
      begin: /(?=\/[^/\n]*\/)/,
      contains: [{
        scope: 'regexp',
        begin: /\//,
        end: /\/[gimuy]*/,
        illegal: /\n/,
        contains: [
          BACKSLASH_ESCAPE,
          {
            begin: /\[/,
            end: /\]/,
            relevance: 0,
            contains: [BACKSLASH_ESCAPE]
          }
        ]
      }]
    };
    const TITLE_MODE = {
      scope: 'title',
      begin: IDENT_RE$2,
      relevance: 0
    };
    const UNDERSCORE_TITLE_MODE = {
      scope: 'title',
      begin: UNDERSCORE_IDENT_RE,
      relevance: 0
    };
    const METHOD_GUARD = {
      begin: '\\.\\s*' + UNDERSCORE_IDENT_RE,
      relevance: 0
    };
    const END_SAME_AS_BEGIN = function(mode) {
      return Object.assign(mode,
        {
          'on:begin': (m, resp) => { resp.data._beginMatch = m[1]; },
          'on:end': (m, resp) => { if (resp.data._beginMatch !== m[1]) resp.ignoreMatch(); }
        });
    };
    var MODES = Object.freeze({
        __proto__: null,
        MATCH_NOTHING_RE: MATCH_NOTHING_RE,
        IDENT_RE: IDENT_RE$2,
        UNDERSCORE_IDENT_RE: UNDERSCORE_IDENT_RE,
        NUMBER_RE: NUMBER_RE,
        C_NUMBER_RE: C_NUMBER_RE,
        BINARY_NUMBER_RE: BINARY_NUMBER_RE,
        RE_STARTERS_RE: RE_STARTERS_RE,
        SHEBANG: SHEBANG,
        BACKSLASH_ESCAPE: BACKSLASH_ESCAPE,
        APOS_STRING_MODE: APOS_STRING_MODE,
        QUOTE_STRING_MODE: QUOTE_STRING_MODE,
        PHRASAL_WORDS_MODE: PHRASAL_WORDS_MODE,
        COMMENT: COMMENT,
        C_LINE_COMMENT_MODE: C_LINE_COMMENT_MODE,
        C_BLOCK_COMMENT_MODE: C_BLOCK_COMMENT_MODE,
        HASH_COMMENT_MODE: HASH_COMMENT_MODE,
        NUMBER_MODE: NUMBER_MODE,
        C_NUMBER_MODE: C_NUMBER_MODE,
        BINARY_NUMBER_MODE: BINARY_NUMBER_MODE,
        REGEXP_MODE: REGEXP_MODE,
        TITLE_MODE: TITLE_MODE,
        UNDERSCORE_TITLE_MODE: UNDERSCORE_TITLE_MODE,
        METHOD_GUARD: METHOD_GUARD,
        END_SAME_AS_BEGIN: END_SAME_AS_BEGIN
    });
    function skipIfHasPrecedingDot(match, response) {
      const before = match.input[match.index - 1];
      if (before === ".") {
        response.ignoreMatch();
      }
    }
    function scopeClassName(mode, _parent) {
      if (mode.className !== undefined) {
        mode.scope = mode.className;
        delete mode.className;
      }
    }
    function beginKeywords(mode, parent) {
      if (!parent) return;
      if (!mode.beginKeywords) return;
      mode.begin = '\\b(' + mode.beginKeywords.split(' ').join('|') + ')(?!\\.)(?=\\b|\\s)';
      mode.__beforeBegin = skipIfHasPrecedingDot;
      mode.keywords = mode.keywords || mode.beginKeywords;
      delete mode.beginKeywords;
      if (mode.relevance === undefined) mode.relevance = 0;
    }
    function compileIllegal(mode, _parent) {
      if (!Array.isArray(mode.illegal)) return;
      mode.illegal = either$1(...mode.illegal);
    }
    function compileMatch(mode, _parent) {
      if (!mode.match) return;
      if (mode.begin || mode.end) throw new Error("begin & end are not supported with match");
      mode.begin = mode.match;
      delete mode.match;
    }
    function compileRelevance(mode, _parent) {
      if (mode.relevance === undefined) mode.relevance = 1;
    }
    const beforeMatchExt = (mode, parent) => {
      if (!mode.beforeMatch) return;
      if (mode.starts) throw new Error("beforeMatch cannot be used with starts");
      const originalMode = Object.assign({}, mode);
      Object.keys(mode).forEach((key) => { delete mode[key]; });
      mode.keywords = originalMode.keywords;
      mode.begin = concat$1(originalMode.beforeMatch, lookahead$1(originalMode.begin));
      mode.starts = {
        relevance: 0,
        contains: [
          Object.assign(originalMode, { endsParent: true })
        ]
      };
      mode.relevance = 0;
      delete originalMode.beforeMatch;
    };
    const COMMON_KEYWORDS = [
      'of',
      'and',
      'for',
      'in',
      'not',
      'or',
      'if',
      'then',
      'parent',
      'list',
      'value'
    ];
    const DEFAULT_KEYWORD_SCOPE = "keyword";
    function compileKeywords(rawKeywords, caseInsensitive, scopeName = DEFAULT_KEYWORD_SCOPE) {
      const compiledKeywords = Object.create(null);
      if (typeof rawKeywords === 'string') {
        compileList(scopeName, rawKeywords.split(" "));
      } else if (Array.isArray(rawKeywords)) {
        compileList(scopeName, rawKeywords);
      } else {
        Object.keys(rawKeywords).forEach(function(scopeName) {
          Object.assign(
            compiledKeywords,
            compileKeywords(rawKeywords[scopeName], caseInsensitive, scopeName)
          );
        });
      }
      return compiledKeywords;
      function compileList(scopeName, keywordList) {
        if (caseInsensitive) {
          keywordList = keywordList.map(x => x.toLowerCase());
        }
        keywordList.forEach(function(keyword) {
          const pair = keyword.split('|');
          compiledKeywords[pair[0]] = [scopeName, scoreForKeyword(pair[0], pair[1])];
        });
      }
    }
    function scoreForKeyword(keyword, providedScore) {
      if (providedScore) {
        return Number(providedScore);
      }
      return commonKeyword(keyword) ? 0 : 1;
    }
    function commonKeyword(keyword) {
      return COMMON_KEYWORDS.includes(keyword.toLowerCase());
    }
    const seenDeprecations = {};
    const error = (message) => {
      console.error(message);
    };
    const warn = (message, ...args) => {
      console.log(`WARN: ${message}`, ...args);
    };
    const deprecated = (version, message) => {
      if (seenDeprecations[`${version}/${message}`]) return;
      console.log(`Deprecated as of ${version}. ${message}`);
      seenDeprecations[`${version}/${message}`] = true;
    };
    const MultiClassError = new Error();
    function remapScopeNames(mode, regexes, { key }) {
      let offset = 0;
      const scopeNames = mode[key];
      const emit = {};
      const positions = {};
      for (let i = 1; i <= regexes.length; i++) {
        positions[i + offset] = scopeNames[i];
        emit[i + offset] = true;
        offset += countMatchGroups(regexes[i - 1]);
      }
      mode[key] = positions;
      mode[key]._emit = emit;
      mode[key]._multi = true;
    }
    function beginMultiClass(mode) {
      if (!Array.isArray(mode.begin)) return;
      if (mode.skip || mode.excludeBegin || mode.returnBegin) {
        error("skip, excludeBegin, returnBegin not compatible with beginScope: {}");
        throw MultiClassError;
      }
      if (typeof mode.beginScope !== "object" || mode.beginScope === null) {
        error("beginScope must be object");
        throw MultiClassError;
      }
      remapScopeNames(mode, mode.begin, { key: "beginScope" });
      mode.begin = _rewriteBackreferences(mode.begin, { joinWith: "" });
    }
    function endMultiClass(mode) {
      if (!Array.isArray(mode.end)) return;
      if (mode.skip || mode.excludeEnd || mode.returnEnd) {
        error("skip, excludeEnd, returnEnd not compatible with endScope: {}");
        throw MultiClassError;
      }
      if (typeof mode.endScope !== "object" || mode.endScope === null) {
        error("endScope must be object");
        throw MultiClassError;
      }
      remapScopeNames(mode, mode.end, { key: "endScope" });
      mode.end = _rewriteBackreferences(mode.end, { joinWith: "" });
    }
    function scopeSugar(mode) {
      if (mode.scope && typeof mode.scope === "object" && mode.scope !== null) {
        mode.beginScope = mode.scope;
        delete mode.scope;
      }
    }
    function MultiClass(mode) {
      scopeSugar(mode);
      if (typeof mode.beginScope === "string") {
        mode.beginScope = { _wrap: mode.beginScope };
      }
      if (typeof mode.endScope === "string") {
        mode.endScope = { _wrap: mode.endScope };
      }
      beginMultiClass(mode);
      endMultiClass(mode);
    }
    function compileLanguage(language) {
      function langRe(value, global) {
        return new RegExp(
          source$1(value),
          'm'
          + (language.case_insensitive ? 'i' : '')
          + (language.unicodeRegex ? 'u' : '')
          + (global ? 'g' : '')
        );
      }
      class MultiRegex {
        constructor() {
          this.matchIndexes = {};
          this.regexes = [];
          this.matchAt = 1;
          this.position = 0;
        }
        addRule(re, opts) {
          opts.position = this.position++;
          this.matchIndexes[this.matchAt] = opts;
          this.regexes.push([opts, re]);
          this.matchAt += countMatchGroups(re) + 1;
        }
        compile() {
          if (this.regexes.length === 0) {
            this.exec = () => null;
          }
          const terminators = this.regexes.map(el => el[1]);
          this.matcherRe = langRe(_rewriteBackreferences(terminators, { joinWith: '|' }), true);
          this.lastIndex = 0;
        }
        exec(s) {
          this.matcherRe.lastIndex = this.lastIndex;
          const match = this.matcherRe.exec(s);
          if (!match) { return null; }
          const i = match.findIndex((el, i) => i > 0 && el !== undefined);
          const matchData = this.matchIndexes[i];
          match.splice(0, i);
          return Object.assign(match, matchData);
        }
      }
      class ResumableMultiRegex {
        constructor() {
          this.rules = [];
          this.multiRegexes = [];
          this.count = 0;
          this.lastIndex = 0;
          this.regexIndex = 0;
        }
        getMatcher(index) {
          if (this.multiRegexes[index]) return this.multiRegexes[index];
          const matcher = new MultiRegex();
          this.rules.slice(index).forEach(([re, opts]) => matcher.addRule(re, opts));
          matcher.compile();
          this.multiRegexes[index] = matcher;
          return matcher;
        }
        resumingScanAtSamePosition() {
          return this.regexIndex !== 0;
        }
        considerAll() {
          this.regexIndex = 0;
        }
        addRule(re, opts) {
          this.rules.push([re, opts]);
          if (opts.type === "begin") this.count++;
        }
        exec(s) {
          const m = this.getMatcher(this.regexIndex);
          m.lastIndex = this.lastIndex;
          let result = m.exec(s);
          if (this.resumingScanAtSamePosition()) {
            if (result && result.index === this.lastIndex) ; else {
              const m2 = this.getMatcher(0);
              m2.lastIndex = this.lastIndex + 1;
              result = m2.exec(s);
            }
          }
          if (result) {
            this.regexIndex += result.position + 1;
            if (this.regexIndex === this.count) {
              this.considerAll();
            }
          }
          return result;
        }
      }
      function buildModeRegex(mode) {
        const mm = new ResumableMultiRegex();
        mode.contains.forEach(term => mm.addRule(term.begin, { rule: term, type: "begin" }));
        if (mode.terminatorEnd) {
          mm.addRule(mode.terminatorEnd, { type: "end" });
        }
        if (mode.illegal) {
          mm.addRule(mode.illegal, { type: "illegal" });
        }
        return mm;
      }
      function compileMode(mode, parent) {
        const cmode =  (mode);
        if (mode.isCompiled) return cmode;
        [
          scopeClassName,
          compileMatch,
          MultiClass,
          beforeMatchExt
        ].forEach(ext => ext(mode, parent));
        language.compilerExtensions.forEach(ext => ext(mode, parent));
        mode.__beforeBegin = null;
        [
          beginKeywords,
          compileIllegal,
          compileRelevance
        ].forEach(ext => ext(mode, parent));
        mode.isCompiled = true;
        let keywordPattern = null;
        if (typeof mode.keywords === "object" && mode.keywords.$pattern) {
          mode.keywords = Object.assign({}, mode.keywords);
          keywordPattern = mode.keywords.$pattern;
          delete mode.keywords.$pattern;
        }
        keywordPattern = keywordPattern || /\w+/;
        if (mode.keywords) {
          mode.keywords = compileKeywords(mode.keywords, language.case_insensitive);
        }
        cmode.keywordPatternRe = langRe(keywordPattern, true);
        if (parent) {
          if (!mode.begin) mode.begin = /\B|\b/;
          cmode.beginRe = langRe(cmode.begin);
          if (!mode.end && !mode.endsWithParent) mode.end = /\B|\b/;
          if (mode.end) cmode.endRe = langRe(cmode.end);
          cmode.terminatorEnd = source$1(cmode.end) || '';
          if (mode.endsWithParent && parent.terminatorEnd) {
            cmode.terminatorEnd += (mode.end ? '|' : '') + parent.terminatorEnd;
          }
        }
        if (mode.illegal) cmode.illegalRe = langRe( (mode.illegal));
        if (!mode.contains) mode.contains = [];
        mode.contains = [].concat(...mode.contains.map(function(c) {
          return expandOrCloneMode(c === 'self' ? mode : c);
        }));
        mode.contains.forEach(function(c) { compileMode( (c), cmode); });
        if (mode.starts) {
          compileMode(mode.starts, parent);
        }
        cmode.matcher = buildModeRegex(cmode);
        return cmode;
      }
      if (!language.compilerExtensions) language.compilerExtensions = [];
      if (language.contains && language.contains.includes('self')) {
        throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.");
      }
      language.classNameAliases = inherit$1(language.classNameAliases || {});
      return compileMode( (language));
    }
    function dependencyOnParent(mode) {
      if (!mode) return false;
      return mode.endsWithParent || dependencyOnParent(mode.starts);
    }
    function expandOrCloneMode(mode) {
      if (mode.variants && !mode.cachedVariants) {
        mode.cachedVariants = mode.variants.map(function(variant) {
          return inherit$1(mode, { variants: null }, variant);
        });
      }
      if (mode.cachedVariants) {
        return mode.cachedVariants;
      }
      if (dependencyOnParent(mode)) {
        return inherit$1(mode, { starts: mode.starts ? inherit$1(mode.starts) : null });
      }
      if (Object.isFrozen(mode)) {
        return inherit$1(mode);
      }
      return mode;
    }
    var version = "11.6.0";
    class HTMLInjectionError extends Error {
      constructor(reason, html) {
        super(reason);
        this.name = "HTMLInjectionError";
        this.html = html;
      }
    }
    const escape = escapeHTML;
    const inherit = inherit$1;
    const NO_MATCH = Symbol("nomatch");
    const MAX_KEYWORD_HITS = 7;
    const HLJS = function(hljs) {
      const languages = Object.create(null);
      const aliases = Object.create(null);
      const plugins = [];
      let SAFE_MODE = true;
      const LANGUAGE_NOT_FOUND = "Could not find the language '{}', did you forget to load/include a language module?";
      const PLAINTEXT_LANGUAGE = { disableAutodetect: true, name: 'Plain text', contains: [] };
      let options = {
        ignoreUnescapedHTML: false,
        throwUnescapedHTML: false,
        noHighlightRe: /^(no-?highlight)$/i,
        languageDetectRe: /\blang(?:uage)?-([\w-]+)\b/i,
        classPrefix: 'hljs-',
        cssSelector: 'pre code',
        languages: null,
        __emitter: TokenTreeEmitter
      };
      function shouldNotHighlight(languageName) {
        return options.noHighlightRe.test(languageName);
      }
      function blockLanguage(block) {
        let classes = block.className + ' ';
        classes += block.parentNode ? block.parentNode.className : '';
        const match = options.languageDetectRe.exec(classes);
        if (match) {
          const language = getLanguage(match[1]);
          if (!language) {
            warn(LANGUAGE_NOT_FOUND.replace("{}", match[1]));
            warn("Falling back to no-highlight mode for this block.", block);
          }
          return language ? match[1] : 'no-highlight';
        }
        return classes
          .split(/\s+/)
          .find((_class) => shouldNotHighlight(_class) || getLanguage(_class));
      }
      function highlight(codeOrLanguageName, optionsOrCode, ignoreIllegals) {
        let code = "";
        let languageName = "";
        if (typeof optionsOrCode === "object") {
          code = codeOrLanguageName;
          ignoreIllegals = optionsOrCode.ignoreIllegals;
          languageName = optionsOrCode.language;
        } else {
          deprecated("10.7.0", "highlight(lang, code, ...args) has been deprecated.");
          deprecated("10.7.0", "Please use highlight(code, options) instead.\nhttps://github.com/highlightjs/highlight.js/issues/2277");
          languageName = codeOrLanguageName;
          code = optionsOrCode;
        }
        if (ignoreIllegals === undefined) { ignoreIllegals = true; }
        const context = {
          code,
          language: languageName
        };
        fire("before:highlight", context);
        const result = context.result
          ? context.result
          : _highlight(context.language, context.code, ignoreIllegals);
        result.code = context.code;
        fire("after:highlight", result);
        return result;
      }
      function _highlight(languageName, codeToHighlight, ignoreIllegals, continuation) {
        const keywordHits = Object.create(null);
        function keywordData(mode, matchText) {
          return mode.keywords[matchText];
        }
        function processKeywords() {
          if (!top.keywords) {
            emitter.addText(modeBuffer);
            return;
          }
          let lastIndex = 0;
          top.keywordPatternRe.lastIndex = 0;
          let match = top.keywordPatternRe.exec(modeBuffer);
          let buf = "";
          while (match) {
            buf += modeBuffer.substring(lastIndex, match.index);
            const word = language.case_insensitive ? match[0].toLowerCase() : match[0];
            const data = keywordData(top, word);
            if (data) {
              const [kind, keywordRelevance] = data;
              emitter.addText(buf);
              buf = "";
              keywordHits[word] = (keywordHits[word] || 0) + 1;
              if (keywordHits[word] <= MAX_KEYWORD_HITS) relevance += keywordRelevance;
              if (kind.startsWith("_")) {
                buf += match[0];
              } else {
                const cssClass = language.classNameAliases[kind] || kind;
                emitter.addKeyword(match[0], cssClass);
              }
            } else {
              buf += match[0];
            }
            lastIndex = top.keywordPatternRe.lastIndex;
            match = top.keywordPatternRe.exec(modeBuffer);
          }
          buf += modeBuffer.substring(lastIndex);
          emitter.addText(buf);
        }
        function processSubLanguage() {
          if (modeBuffer === "") return;
          let result = null;
          if (typeof top.subLanguage === 'string') {
            if (!languages[top.subLanguage]) {
              emitter.addText(modeBuffer);
              return;
            }
            result = _highlight(top.subLanguage, modeBuffer, true, continuations[top.subLanguage]);
            continuations[top.subLanguage] =  (result._top);
          } else {
            result = highlightAuto(modeBuffer, top.subLanguage.length ? top.subLanguage : null);
          }
          if (top.relevance > 0) {
            relevance += result.relevance;
          }
          emitter.addSublanguage(result._emitter, result.language);
        }
        function processBuffer() {
          if (top.subLanguage != null) {
            processSubLanguage();
          } else {
            processKeywords();
          }
          modeBuffer = '';
        }
        function emitMultiClass(scope, match) {
          let i = 1;
          const max = match.length - 1;
          while (i <= max) {
            if (!scope._emit[i]) { i++; continue; }
            const klass = language.classNameAliases[scope[i]] || scope[i];
            const text = match[i];
            if (klass) {
              emitter.addKeyword(text, klass);
            } else {
              modeBuffer = text;
              processKeywords();
              modeBuffer = "";
            }
            i++;
          }
        }
        function startNewMode(mode, match) {
          if (mode.scope && typeof mode.scope === "string") {
            emitter.openNode(language.classNameAliases[mode.scope] || mode.scope);
          }
          if (mode.beginScope) {
            if (mode.beginScope._wrap) {
              emitter.addKeyword(modeBuffer, language.classNameAliases[mode.beginScope._wrap] || mode.beginScope._wrap);
              modeBuffer = "";
            } else if (mode.beginScope._multi) {
              emitMultiClass(mode.beginScope, match);
              modeBuffer = "";
            }
          }
          top = Object.create(mode, { parent: { value: top } });
          return top;
        }
        function endOfMode(mode, match, matchPlusRemainder) {
          let matched = startsWith(mode.endRe, matchPlusRemainder);
          if (matched) {
            if (mode["on:end"]) {
              const resp = new Response(mode);
              mode["on:end"](match, resp);
              if (resp.isMatchIgnored) matched = false;
            }
            if (matched) {
              while (mode.endsParent && mode.parent) {
                mode = mode.parent;
              }
              return mode;
            }
          }
          if (mode.endsWithParent) {
            return endOfMode(mode.parent, match, matchPlusRemainder);
          }
        }
        function doIgnore(lexeme) {
          if (top.matcher.regexIndex === 0) {
            modeBuffer += lexeme[0];
            return 1;
          } else {
            resumeScanAtSamePosition = true;
            return 0;
          }
        }
        function doBeginMatch(match) {
          const lexeme = match[0];
          const newMode = match.rule;
          const resp = new Response(newMode);
          const beforeCallbacks = [newMode.__beforeBegin, newMode["on:begin"]];
          for (const cb of beforeCallbacks) {
            if (!cb) continue;
            cb(match, resp);
            if (resp.isMatchIgnored) return doIgnore(lexeme);
          }
          if (newMode.skip) {
            modeBuffer += lexeme;
          } else {
            if (newMode.excludeBegin) {
              modeBuffer += lexeme;
            }
            processBuffer();
            if (!newMode.returnBegin && !newMode.excludeBegin) {
              modeBuffer = lexeme;
            }
          }
          startNewMode(newMode, match);
          return newMode.returnBegin ? 0 : lexeme.length;
        }
        function doEndMatch(match) {
          const lexeme = match[0];
          const matchPlusRemainder = codeToHighlight.substring(match.index);
          const endMode = endOfMode(top, match, matchPlusRemainder);
          if (!endMode) { return NO_MATCH; }
          const origin = top;
          if (top.endScope && top.endScope._wrap) {
            processBuffer();
            emitter.addKeyword(lexeme, top.endScope._wrap);
          } else if (top.endScope && top.endScope._multi) {
            processBuffer();
            emitMultiClass(top.endScope, match);
          } else if (origin.skip) {
            modeBuffer += lexeme;
          } else {
            if (!(origin.returnEnd || origin.excludeEnd)) {
              modeBuffer += lexeme;
            }
            processBuffer();
            if (origin.excludeEnd) {
              modeBuffer = lexeme;
            }
          }
          do {
            if (top.scope) {
              emitter.closeNode();
            }
            if (!top.skip && !top.subLanguage) {
              relevance += top.relevance;
            }
            top = top.parent;
          } while (top !== endMode.parent);
          if (endMode.starts) {
            startNewMode(endMode.starts, match);
          }
          return origin.returnEnd ? 0 : lexeme.length;
        }
        function processContinuations() {
          const list = [];
          for (let current = top; current !== language; current = current.parent) {
            if (current.scope) {
              list.unshift(current.scope);
            }
          }
          list.forEach(item => emitter.openNode(item));
        }
        let lastMatch = {};
        function processLexeme(textBeforeMatch, match) {
          const lexeme = match && match[0];
          modeBuffer += textBeforeMatch;
          if (lexeme == null) {
            processBuffer();
            return 0;
          }
          if (lastMatch.type === "begin" && match.type === "end" && lastMatch.index === match.index && lexeme === "") {
            modeBuffer += codeToHighlight.slice(match.index, match.index + 1);
            if (!SAFE_MODE) {
              const err = new Error(`0 width match regex (${languageName})`);
              err.languageName = languageName;
              err.badRule = lastMatch.rule;
              throw err;
            }
            return 1;
          }
          lastMatch = match;
          if (match.type === "begin") {
            return doBeginMatch(match);
          } else if (match.type === "illegal" && !ignoreIllegals) {
            const err = new Error('Illegal lexeme "' + lexeme + '" for mode "' + (top.scope || '<unnamed>') + '"');
            err.mode = top;
            throw err;
          } else if (match.type === "end") {
            const processed = doEndMatch(match);
            if (processed !== NO_MATCH) {
              return processed;
            }
          }
          if (match.type === "illegal" && lexeme === "") {
            return 1;
          }
          if (iterations > 100000 && iterations > match.index * 3) {
            const err = new Error('potential infinite loop, way more iterations than matches');
            throw err;
          }
          modeBuffer += lexeme;
          return lexeme.length;
        }
        const language = getLanguage(languageName);
        if (!language) {
          error(LANGUAGE_NOT_FOUND.replace("{}", languageName));
          throw new Error('Unknown language: "' + languageName + '"');
        }
        const md = compileLanguage(language);
        let result = '';
        let top = continuation || md;
        const continuations = {};
        const emitter = new options.__emitter(options);
        processContinuations();
        let modeBuffer = '';
        let relevance = 0;
        let index = 0;
        let iterations = 0;
        let resumeScanAtSamePosition = false;
        try {
          top.matcher.considerAll();
          for (;;) {
            iterations++;
            if (resumeScanAtSamePosition) {
              resumeScanAtSamePosition = false;
            } else {
              top.matcher.considerAll();
            }
            top.matcher.lastIndex = index;
            const match = top.matcher.exec(codeToHighlight);
            if (!match) break;
            const beforeMatch = codeToHighlight.substring(index, match.index);
            const processedCount = processLexeme(beforeMatch, match);
            index = match.index + processedCount;
          }
          processLexeme(codeToHighlight.substring(index));
          emitter.closeAllNodes();
          emitter.finalize();
          result = emitter.toHTML();
          return {
            language: languageName,
            value: result,
            relevance: relevance,
            illegal: false,
            _emitter: emitter,
            _top: top
          };
        } catch (err) {
          if (err.message && err.message.includes('Illegal')) {
            return {
              language: languageName,
              value: escape(codeToHighlight),
              illegal: true,
              relevance: 0,
              _illegalBy: {
                message: err.message,
                index: index,
                context: codeToHighlight.slice(index - 100, index + 100),
                mode: err.mode,
                resultSoFar: result
              },
              _emitter: emitter
            };
          } else if (SAFE_MODE) {
            return {
              language: languageName,
              value: escape(codeToHighlight),
              illegal: false,
              relevance: 0,
              errorRaised: err,
              _emitter: emitter,
              _top: top
            };
          } else {
            throw err;
          }
        }
      }
      function justTextHighlightResult(code) {
        const result = {
          value: escape(code),
          illegal: false,
          relevance: 0,
          _top: PLAINTEXT_LANGUAGE,
          _emitter: new options.__emitter(options)
        };
        result._emitter.addText(code);
        return result;
      }
      function highlightAuto(code, languageSubset) {
        languageSubset = languageSubset || options.languages || Object.keys(languages);
        const plaintext = justTextHighlightResult(code);
        const results = languageSubset.filter(getLanguage).filter(autoDetection).map(name =>
          _highlight(name, code, false)
        );
        results.unshift(plaintext);
        const sorted = results.sort((a, b) => {
          if (a.relevance !== b.relevance) return b.relevance - a.relevance;
          if (a.language && b.language) {
            if (getLanguage(a.language).supersetOf === b.language) {
              return 1;
            } else if (getLanguage(b.language).supersetOf === a.language) {
              return -1;
            }
          }
          return 0;
        });
        const [best, secondBest] = sorted;
        const result = best;
        result.secondBest = secondBest;
        return result;
      }
      function updateClassName(element, currentLang, resultLang) {
        const language = (currentLang && aliases[currentLang]) || resultLang;
        element.classList.add("hljs");
        element.classList.add(`language-${language}`);
      }
      function highlightElement(element) {
        let node = null;
        const language = blockLanguage(element);
        if (shouldNotHighlight(language)) return;
        fire("before:highlightElement",
          { el: element, language: language });
        if (element.children.length > 0) {
          if (!options.ignoreUnescapedHTML) {
            console.warn("One of your code blocks includes unescaped HTML. This is a potentially serious security risk.");
            console.warn("https://github.com/highlightjs/highlight.js/wiki/security");
            console.warn("The element with unescaped HTML:");
            console.warn(element);
          }
          if (options.throwUnescapedHTML) {
            const err = new HTMLInjectionError(
              "One of your code blocks includes unescaped HTML.",
              element.innerHTML
            );
            throw err;
          }
        }
        node = element;
        const text = node.textContent;
        const result = language ? highlight(text, { language, ignoreIllegals: true }) : highlightAuto(text);
        element.innerHTML = result.value;
        updateClassName(element, language, result.language);
        element.result = {
          language: result.language,
          re: result.relevance,
          relevance: result.relevance
        };
        if (result.secondBest) {
          element.secondBest = {
            language: result.secondBest.language,
            relevance: result.secondBest.relevance
          };
        }
        fire("after:highlightElement", { el: element, result, text });
      }
      function configure(userOptions) {
        options = inherit(options, userOptions);
      }
      const initHighlighting = () => {
        highlightAll();
        deprecated("10.6.0", "initHighlighting() deprecated.  Use highlightAll() now.");
      };
      function initHighlightingOnLoad() {
        highlightAll();
        deprecated("10.6.0", "initHighlightingOnLoad() deprecated.  Use highlightAll() now.");
      }
      let wantsHighlight = false;
      function highlightAll() {
        if (document.readyState === "loading") {
          wantsHighlight = true;
          return;
        }
        const blocks = document.querySelectorAll(options.cssSelector);
        blocks.forEach(highlightElement);
      }
      function boot() {
        if (wantsHighlight) highlightAll();
      }
      if (typeof window !== 'undefined' && window.addEventListener) {
        window.addEventListener('DOMContentLoaded', boot, false);
      }
      function registerLanguage(languageName, languageDefinition) {
        let lang = null;
        try {
          lang = languageDefinition(hljs);
        } catch (error$1) {
          error("Language definition for '{}' could not be registered.".replace("{}", languageName));
          if (!SAFE_MODE) { throw error$1; } else { error(error$1); }
          lang = PLAINTEXT_LANGUAGE;
        }
        if (!lang.name) lang.name = languageName;
        languages[languageName] = lang;
        lang.rawDefinition = languageDefinition.bind(null, hljs);
        if (lang.aliases) {
          registerAliases(lang.aliases, { languageName });
        }
      }
      function unregisterLanguage(languageName) {
        delete languages[languageName];
        for (const alias of Object.keys(aliases)) {
          if (aliases[alias] === languageName) {
            delete aliases[alias];
          }
        }
      }
      function listLanguages() {
        return Object.keys(languages);
      }
      function getLanguage(name) {
        name = (name || '').toLowerCase();
        return languages[name] || languages[aliases[name]];
      }
      function registerAliases(aliasList, { languageName }) {
        if (typeof aliasList === 'string') {
          aliasList = [aliasList];
        }
        aliasList.forEach(alias => { aliases[alias.toLowerCase()] = languageName; });
      }
      function autoDetection(name) {
        const lang = getLanguage(name);
        return lang && !lang.disableAutodetect;
      }
      function upgradePluginAPI(plugin) {
        if (plugin["before:highlightBlock"] && !plugin["before:highlightElement"]) {
          plugin["before:highlightElement"] = (data) => {
            plugin["before:highlightBlock"](
              Object.assign({ block: data.el }, data)
            );
          };
        }
        if (plugin["after:highlightBlock"] && !plugin["after:highlightElement"]) {
          plugin["after:highlightElement"] = (data) => {
            plugin["after:highlightBlock"](
              Object.assign({ block: data.el }, data)
            );
          };
        }
      }
      function addPlugin(plugin) {
        upgradePluginAPI(plugin);
        plugins.push(plugin);
      }
      function fire(event, args) {
        const cb = event;
        plugins.forEach(function(plugin) {
          if (plugin[cb]) {
            plugin[cb](args);
          }
        });
      }
      function deprecateHighlightBlock(el) {
        deprecated("10.7.0", "highlightBlock will be removed entirely in v12.0");
        deprecated("10.7.0", "Please use highlightElement now.");
        return highlightElement(el);
      }
      Object.assign(hljs, {
        highlight,
        highlightAuto,
        highlightAll,
        highlightElement,
        highlightBlock: deprecateHighlightBlock,
        configure,
        initHighlighting,
        initHighlightingOnLoad,
        registerLanguage,
        unregisterLanguage,
        listLanguages,
        getLanguage,
        registerAliases,
        autoDetection,
        inherit,
        addPlugin
      });
      hljs.debugMode = function() { SAFE_MODE = false; };
      hljs.safeMode = function() { SAFE_MODE = true; };
      hljs.versionString = version;
      hljs.regex = {
        concat: concat$1,
        lookahead: lookahead$1,
        either: either$1,
        optional: optional,
        anyNumberOfTimes: anyNumberOfTimes
      };
      for (const key in MODES) {
        if (typeof MODES[key] === "object") {
          deepFreezeEs6.exports(MODES[key]);
        }
      }
      Object.assign(hljs, MODES);
      return hljs;
    };
    var highlight = HLJS({});
    var core = highlight;
    highlight.HighlightJS = highlight;
    highlight.default = highlight;

    function bash(hljs) {
      const regex = hljs.regex;
      const VAR = {};
      const BRACED_VAR = {
        begin: /\$\{/,
        end: /\}/,
        contains: [
          "self",
          {
            begin: /:-/,
            contains: [ VAR ]
          }
        ]
      };
      Object.assign(VAR, {
        className: 'variable',
        variants: [
          { begin: regex.concat(/\$[\w\d#@][\w\d_]*/,
            `(?![\\w\\d])(?![$])`) },
          BRACED_VAR
        ]
      });
      const SUBST = {
        className: 'subst',
        begin: /\$\(/,
        end: /\)/,
        contains: [ hljs.BACKSLASH_ESCAPE ]
      };
      const HERE_DOC = {
        begin: /<<-?\s*(?=\w+)/,
        starts: { contains: [
          hljs.END_SAME_AS_BEGIN({
            begin: /(\w+)/,
            end: /(\w+)/,
            className: 'string'
          })
        ] }
      };
      const QUOTE_STRING = {
        className: 'string',
        begin: /"/,
        end: /"/,
        contains: [
          hljs.BACKSLASH_ESCAPE,
          VAR,
          SUBST
        ]
      };
      SUBST.contains.push(QUOTE_STRING);
      const ESCAPED_QUOTE = {
        className: '',
        begin: /\\"/
      };
      const APOS_STRING = {
        className: 'string',
        begin: /'/,
        end: /'/
      };
      const ARITHMETIC = {
        begin: /\$\(\(/,
        end: /\)\)/,
        contains: [
          {
            begin: /\d+#[0-9a-f]+/,
            className: "number"
          },
          hljs.NUMBER_MODE,
          VAR
        ]
      };
      const SH_LIKE_SHELLS = [
        "fish",
        "bash",
        "zsh",
        "sh",
        "csh",
        "ksh",
        "tcsh",
        "dash",
        "scsh",
      ];
      const KNOWN_SHEBANG = hljs.SHEBANG({
        binary: `(${SH_LIKE_SHELLS.join("|")})`,
        relevance: 10
      });
      const FUNCTION = {
        className: 'function',
        begin: /\w[\w\d_]*\s*\(\s*\)\s*\{/,
        returnBegin: true,
        contains: [ hljs.inherit(hljs.TITLE_MODE, { begin: /\w[\w\d_]*/ }) ],
        relevance: 0
      };
      const KEYWORDS = [
        "if",
        "then",
        "else",
        "elif",
        "fi",
        "for",
        "while",
        "in",
        "do",
        "done",
        "case",
        "esac",
        "function"
      ];
      const LITERALS = [
        "true",
        "false"
      ];
      const PATH_MODE = { match: /(\/[a-z._-]+)+/ };
      const SHELL_BUILT_INS = [
        "break",
        "cd",
        "continue",
        "eval",
        "exec",
        "exit",
        "export",
        "getopts",
        "hash",
        "pwd",
        "readonly",
        "return",
        "shift",
        "test",
        "times",
        "trap",
        "umask",
        "unset"
      ];
      const BASH_BUILT_INS = [
        "alias",
        "bind",
        "builtin",
        "caller",
        "command",
        "declare",
        "echo",
        "enable",
        "help",
        "let",
        "local",
        "logout",
        "mapfile",
        "printf",
        "read",
        "readarray",
        "source",
        "type",
        "typeset",
        "ulimit",
        "unalias"
      ];
      const ZSH_BUILT_INS = [
        "autoload",
        "bg",
        "bindkey",
        "bye",
        "cap",
        "chdir",
        "clone",
        "comparguments",
        "compcall",
        "compctl",
        "compdescribe",
        "compfiles",
        "compgroups",
        "compquote",
        "comptags",
        "comptry",
        "compvalues",
        "dirs",
        "disable",
        "disown",
        "echotc",
        "echoti",
        "emulate",
        "fc",
        "fg",
        "float",
        "functions",
        "getcap",
        "getln",
        "history",
        "integer",
        "jobs",
        "kill",
        "limit",
        "log",
        "noglob",
        "popd",
        "print",
        "pushd",
        "pushln",
        "rehash",
        "sched",
        "setcap",
        "setopt",
        "stat",
        "suspend",
        "ttyctl",
        "unfunction",
        "unhash",
        "unlimit",
        "unsetopt",
        "vared",
        "wait",
        "whence",
        "where",
        "which",
        "zcompile",
        "zformat",
        "zftp",
        "zle",
        "zmodload",
        "zparseopts",
        "zprof",
        "zpty",
        "zregexparse",
        "zsocket",
        "zstyle",
        "ztcp"
      ];
      const GNU_CORE_UTILS = [
        "chcon",
        "chgrp",
        "chown",
        "chmod",
        "cp",
        "dd",
        "df",
        "dir",
        "dircolors",
        "ln",
        "ls",
        "mkdir",
        "mkfifo",
        "mknod",
        "mktemp",
        "mv",
        "realpath",
        "rm",
        "rmdir",
        "shred",
        "sync",
        "touch",
        "truncate",
        "vdir",
        "b2sum",
        "base32",
        "base64",
        "cat",
        "cksum",
        "comm",
        "csplit",
        "cut",
        "expand",
        "fmt",
        "fold",
        "head",
        "join",
        "md5sum",
        "nl",
        "numfmt",
        "od",
        "paste",
        "ptx",
        "pr",
        "sha1sum",
        "sha224sum",
        "sha256sum",
        "sha384sum",
        "sha512sum",
        "shuf",
        "sort",
        "split",
        "sum",
        "tac",
        "tail",
        "tr",
        "tsort",
        "unexpand",
        "uniq",
        "wc",
        "arch",
        "basename",
        "chroot",
        "date",
        "dirname",
        "du",
        "echo",
        "env",
        "expr",
        "factor",
        "groups",
        "hostid",
        "id",
        "link",
        "logname",
        "nice",
        "nohup",
        "nproc",
        "pathchk",
        "pinky",
        "printenv",
        "printf",
        "pwd",
        "readlink",
        "runcon",
        "seq",
        "sleep",
        "stat",
        "stdbuf",
        "stty",
        "tee",
        "test",
        "timeout",
        "tty",
        "uname",
        "unlink",
        "uptime",
        "users",
        "who",
        "whoami",
        "yes"
      ];
      return {
        name: 'Bash',
        aliases: [ 'sh' ],
        keywords: {
          $pattern: /\b[a-z][a-z0-9._-]+\b/,
          keyword: KEYWORDS,
          literal: LITERALS,
          built_in: [
            ...SHELL_BUILT_INS,
            ...BASH_BUILT_INS,
            "set",
            "shopt",
            ...ZSH_BUILT_INS,
            ...GNU_CORE_UTILS
          ]
        },
        contains: [
          KNOWN_SHEBANG,
          hljs.SHEBANG(),
          FUNCTION,
          ARITHMETIC,
          hljs.HASH_COMMENT_MODE,
          HERE_DOC,
          PATH_MODE,
          QUOTE_STRING,
          ESCAPED_QUOTE,
          APOS_STRING,
          VAR
        ]
      };
    }

    function c(hljs) {
      const regex = hljs.regex;
      const C_LINE_COMMENT_MODE = hljs.COMMENT('//', '$', { contains: [ { begin: /\\\n/ } ] });
      const DECLTYPE_AUTO_RE = 'decltype\\(auto\\)';
      const NAMESPACE_RE = '[a-zA-Z_]\\w*::';
      const TEMPLATE_ARGUMENT_RE = '<[^<>]+>';
      const FUNCTION_TYPE_RE = '('
        + DECLTYPE_AUTO_RE + '|'
        + regex.optional(NAMESPACE_RE)
        + '[a-zA-Z_]\\w*' + regex.optional(TEMPLATE_ARGUMENT_RE)
      + ')';
      const TYPES = {
        className: 'type',
        variants: [
          { begin: '\\b[a-z\\d_]*_t\\b' },
          { match: /\batomic_[a-z]{3,6}\b/ }
        ]
      };
      const CHARACTER_ESCAPES = '\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)';
      const STRINGS = {
        className: 'string',
        variants: [
          {
            begin: '(u8?|U|L)?"',
            end: '"',
            illegal: '\\n',
            contains: [ hljs.BACKSLASH_ESCAPE ]
          },
          {
            begin: '(u8?|U|L)?\'(' + CHARACTER_ESCAPES + "|.)",
            end: '\'',
            illegal: '.'
          },
          hljs.END_SAME_AS_BEGIN({
            begin: /(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,
            end: /\)([^()\\ ]{0,16})"/
          })
        ]
      };
      const NUMBERS = {
        className: 'number',
        variants: [
          { begin: '\\b(0b[01\']+)' },
          { begin: '(-?)\\b([\\d\']+(\\.[\\d\']*)?|\\.[\\d\']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)' },
          { begin: '(-?)(\\b0[xX][a-fA-F0-9\']+|(\\b[\\d\']+(\\.[\\d\']*)?|\\.[\\d\']+)([eE][-+]?[\\d\']+)?)' }
        ],
        relevance: 0
      };
      const PREPROCESSOR = {
        className: 'meta',
        begin: /#\s*[a-z]+\b/,
        end: /$/,
        keywords: { keyword:
            'if else elif endif define undef warning error line '
            + 'pragma _Pragma ifdef ifndef include' },
        contains: [
          {
            begin: /\\\n/,
            relevance: 0
          },
          hljs.inherit(STRINGS, { className: 'string' }),
          {
            className: 'string',
            begin: /<.*?>/
          },
          C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      };
      const TITLE_MODE = {
        className: 'title',
        begin: regex.optional(NAMESPACE_RE) + hljs.IDENT_RE,
        relevance: 0
      };
      const FUNCTION_TITLE = regex.optional(NAMESPACE_RE) + hljs.IDENT_RE + '\\s*\\(';
      const C_KEYWORDS = [
        "asm",
        "auto",
        "break",
        "case",
        "continue",
        "default",
        "do",
        "else",
        "enum",
        "extern",
        "for",
        "fortran",
        "goto",
        "if",
        "inline",
        "register",
        "restrict",
        "return",
        "sizeof",
        "struct",
        "switch",
        "typedef",
        "union",
        "volatile",
        "while",
        "_Alignas",
        "_Alignof",
        "_Atomic",
        "_Generic",
        "_Noreturn",
        "_Static_assert",
        "_Thread_local",
        "alignas",
        "alignof",
        "noreturn",
        "static_assert",
        "thread_local",
        "_Pragma"
      ];
      const C_TYPES = [
        "float",
        "double",
        "signed",
        "unsigned",
        "int",
        "short",
        "long",
        "char",
        "void",
        "_Bool",
        "_Complex",
        "_Imaginary",
        "_Decimal32",
        "_Decimal64",
        "_Decimal128",
        "const",
        "static",
        "complex",
        "bool",
        "imaginary"
      ];
      const KEYWORDS = {
        keyword: C_KEYWORDS,
        type: C_TYPES,
        literal: 'true false NULL',
        built_in: 'std string wstring cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream '
          + 'auto_ptr deque list queue stack vector map set pair bitset multiset multimap unordered_set '
          + 'unordered_map unordered_multiset unordered_multimap priority_queue make_pair array shared_ptr abort terminate abs acos '
          + 'asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp '
          + 'fscanf future isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper '
          + 'isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow '
          + 'printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp '
          + 'strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan '
          + 'vfprintf vprintf vsprintf endl initializer_list unique_ptr',
      };
      const EXPRESSION_CONTAINS = [
        PREPROCESSOR,
        TYPES,
        C_LINE_COMMENT_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        NUMBERS,
        STRINGS
      ];
      const EXPRESSION_CONTEXT = {
        variants: [
          {
            begin: /=/,
            end: /;/
          },
          {
            begin: /\(/,
            end: /\)/
          },
          {
            beginKeywords: 'new throw return else',
            end: /;/
          }
        ],
        keywords: KEYWORDS,
        contains: EXPRESSION_CONTAINS.concat([
          {
            begin: /\(/,
            end: /\)/,
            keywords: KEYWORDS,
            contains: EXPRESSION_CONTAINS.concat([ 'self' ]),
            relevance: 0
          }
        ]),
        relevance: 0
      };
      const FUNCTION_DECLARATION = {
        begin: '(' + FUNCTION_TYPE_RE + '[\\*&\\s]+)+' + FUNCTION_TITLE,
        returnBegin: true,
        end: /[{;=]/,
        excludeEnd: true,
        keywords: KEYWORDS,
        illegal: /[^\w\s\*&:<>.]/,
        contains: [
          {
            begin: DECLTYPE_AUTO_RE,
            keywords: KEYWORDS,
            relevance: 0
          },
          {
            begin: FUNCTION_TITLE,
            returnBegin: true,
            contains: [ hljs.inherit(TITLE_MODE, { className: "title.function" }) ],
            relevance: 0
          },
          {
            relevance: 0,
            match: /,/
          },
          {
            className: 'params',
            begin: /\(/,
            end: /\)/,
            keywords: KEYWORDS,
            relevance: 0,
            contains: [
              C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              STRINGS,
              NUMBERS,
              TYPES,
              {
                begin: /\(/,
                end: /\)/,
                keywords: KEYWORDS,
                relevance: 0,
                contains: [
                  'self',
                  C_LINE_COMMENT_MODE,
                  hljs.C_BLOCK_COMMENT_MODE,
                  STRINGS,
                  NUMBERS,
                  TYPES
                ]
              }
            ]
          },
          TYPES,
          C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          PREPROCESSOR
        ]
      };
      return {
        name: "C",
        aliases: [ 'h' ],
        keywords: KEYWORDS,
        disableAutodetect: true,
        illegal: '</',
        contains: [].concat(
          EXPRESSION_CONTEXT,
          FUNCTION_DECLARATION,
          EXPRESSION_CONTAINS,
          [
            PREPROCESSOR,
            {
              begin: hljs.IDENT_RE + '::',
              keywords: KEYWORDS
            },
            {
              className: 'class',
              beginKeywords: 'enum class struct union',
              end: /[{;:<>=]/,
              contains: [
                { beginKeywords: "final class struct" },
                hljs.TITLE_MODE
              ]
            }
          ]),
        exports: {
          preprocessor: PREPROCESSOR,
          strings: STRINGS,
          keywords: KEYWORDS
        }
      };
    }

    function cpp(hljs) {
      const regex = hljs.regex;
      const C_LINE_COMMENT_MODE = hljs.COMMENT('//', '$', { contains: [ { begin: /\\\n/ } ] });
      const DECLTYPE_AUTO_RE = 'decltype\\(auto\\)';
      const NAMESPACE_RE = '[a-zA-Z_]\\w*::';
      const TEMPLATE_ARGUMENT_RE = '<[^<>]+>';
      const FUNCTION_TYPE_RE = '(?!struct)('
        + DECLTYPE_AUTO_RE + '|'
        + regex.optional(NAMESPACE_RE)
        + '[a-zA-Z_]\\w*' + regex.optional(TEMPLATE_ARGUMENT_RE)
      + ')';
      const CPP_PRIMITIVE_TYPES = {
        className: 'type',
        begin: '\\b[a-z\\d_]*_t\\b'
      };
      const CHARACTER_ESCAPES = '\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)';
      const STRINGS = {
        className: 'string',
        variants: [
          {
            begin: '(u8?|U|L)?"',
            end: '"',
            illegal: '\\n',
            contains: [ hljs.BACKSLASH_ESCAPE ]
          },
          {
            begin: '(u8?|U|L)?\'(' + CHARACTER_ESCAPES + '|.)',
            end: '\'',
            illegal: '.'
          },
          hljs.END_SAME_AS_BEGIN({
            begin: /(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,
            end: /\)([^()\\ ]{0,16})"/
          })
        ]
      };
      const NUMBERS = {
        className: 'number',
        variants: [
          { begin: '\\b(0b[01\']+)' },
          { begin: '(-?)\\b([\\d\']+(\\.[\\d\']*)?|\\.[\\d\']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)' },
          { begin: '(-?)(\\b0[xX][a-fA-F0-9\']+|(\\b[\\d\']+(\\.[\\d\']*)?|\\.[\\d\']+)([eE][-+]?[\\d\']+)?)' }
        ],
        relevance: 0
      };
      const PREPROCESSOR = {
        className: 'meta',
        begin: /#\s*[a-z]+\b/,
        end: /$/,
        keywords: { keyword:
            'if else elif endif define undef warning error line '
            + 'pragma _Pragma ifdef ifndef include' },
        contains: [
          {
            begin: /\\\n/,
            relevance: 0
          },
          hljs.inherit(STRINGS, { className: 'string' }),
          {
            className: 'string',
            begin: /<.*?>/
          },
          C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      };
      const TITLE_MODE = {
        className: 'title',
        begin: regex.optional(NAMESPACE_RE) + hljs.IDENT_RE,
        relevance: 0
      };
      const FUNCTION_TITLE = regex.optional(NAMESPACE_RE) + hljs.IDENT_RE + '\\s*\\(';
      const RESERVED_KEYWORDS = [
        'alignas',
        'alignof',
        'and',
        'and_eq',
        'asm',
        'atomic_cancel',
        'atomic_commit',
        'atomic_noexcept',
        'auto',
        'bitand',
        'bitor',
        'break',
        'case',
        'catch',
        'class',
        'co_await',
        'co_return',
        'co_yield',
        'compl',
        'concept',
        'const_cast|10',
        'consteval',
        'constexpr',
        'constinit',
        'continue',
        'decltype',
        'default',
        'delete',
        'do',
        'dynamic_cast|10',
        'else',
        'enum',
        'explicit',
        'export',
        'extern',
        'false',
        'final',
        'for',
        'friend',
        'goto',
        'if',
        'import',
        'inline',
        'module',
        'mutable',
        'namespace',
        'new',
        'noexcept',
        'not',
        'not_eq',
        'nullptr',
        'operator',
        'or',
        'or_eq',
        'override',
        'private',
        'protected',
        'public',
        'reflexpr',
        'register',
        'reinterpret_cast|10',
        'requires',
        'return',
        'sizeof',
        'static_assert',
        'static_cast|10',
        'struct',
        'switch',
        'synchronized',
        'template',
        'this',
        'thread_local',
        'throw',
        'transaction_safe',
        'transaction_safe_dynamic',
        'true',
        'try',
        'typedef',
        'typeid',
        'typename',
        'union',
        'using',
        'virtual',
        'volatile',
        'while',
        'xor',
        'xor_eq'
      ];
      const RESERVED_TYPES = [
        'bool',
        'char',
        'char16_t',
        'char32_t',
        'char8_t',
        'double',
        'float',
        'int',
        'long',
        'short',
        'void',
        'wchar_t',
        'unsigned',
        'signed',
        'const',
        'static'
      ];
      const TYPE_HINTS = [
        'any',
        'auto_ptr',
        'barrier',
        'binary_semaphore',
        'bitset',
        'complex',
        'condition_variable',
        'condition_variable_any',
        'counting_semaphore',
        'deque',
        'false_type',
        'future',
        'imaginary',
        'initializer_list',
        'istringstream',
        'jthread',
        'latch',
        'lock_guard',
        'multimap',
        'multiset',
        'mutex',
        'optional',
        'ostringstream',
        'packaged_task',
        'pair',
        'promise',
        'priority_queue',
        'queue',
        'recursive_mutex',
        'recursive_timed_mutex',
        'scoped_lock',
        'set',
        'shared_future',
        'shared_lock',
        'shared_mutex',
        'shared_timed_mutex',
        'shared_ptr',
        'stack',
        'string_view',
        'stringstream',
        'timed_mutex',
        'thread',
        'true_type',
        'tuple',
        'unique_lock',
        'unique_ptr',
        'unordered_map',
        'unordered_multimap',
        'unordered_multiset',
        'unordered_set',
        'variant',
        'vector',
        'weak_ptr',
        'wstring',
        'wstring_view'
      ];
      const FUNCTION_HINTS = [
        'abort',
        'abs',
        'acos',
        'apply',
        'as_const',
        'asin',
        'atan',
        'atan2',
        'calloc',
        'ceil',
        'cerr',
        'cin',
        'clog',
        'cos',
        'cosh',
        'cout',
        'declval',
        'endl',
        'exchange',
        'exit',
        'exp',
        'fabs',
        'floor',
        'fmod',
        'forward',
        'fprintf',
        'fputs',
        'free',
        'frexp',
        'fscanf',
        'future',
        'invoke',
        'isalnum',
        'isalpha',
        'iscntrl',
        'isdigit',
        'isgraph',
        'islower',
        'isprint',
        'ispunct',
        'isspace',
        'isupper',
        'isxdigit',
        'labs',
        'launder',
        'ldexp',
        'log',
        'log10',
        'make_pair',
        'make_shared',
        'make_shared_for_overwrite',
        'make_tuple',
        'make_unique',
        'malloc',
        'memchr',
        'memcmp',
        'memcpy',
        'memset',
        'modf',
        'move',
        'pow',
        'printf',
        'putchar',
        'puts',
        'realloc',
        'scanf',
        'sin',
        'sinh',
        'snprintf',
        'sprintf',
        'sqrt',
        'sscanf',
        'std',
        'stderr',
        'stdin',
        'stdout',
        'strcat',
        'strchr',
        'strcmp',
        'strcpy',
        'strcspn',
        'strlen',
        'strncat',
        'strncmp',
        'strncpy',
        'strpbrk',
        'strrchr',
        'strspn',
        'strstr',
        'swap',
        'tan',
        'tanh',
        'terminate',
        'to_underlying',
        'tolower',
        'toupper',
        'vfprintf',
        'visit',
        'vprintf',
        'vsprintf'
      ];
      const LITERALS = [
        'NULL',
        'false',
        'nullopt',
        'nullptr',
        'true'
      ];
      const BUILT_IN = [ '_Pragma' ];
      const CPP_KEYWORDS = {
        type: RESERVED_TYPES,
        keyword: RESERVED_KEYWORDS,
        literal: LITERALS,
        built_in: BUILT_IN,
        _type_hints: TYPE_HINTS
      };
      const FUNCTION_DISPATCH = {
        className: 'function.dispatch',
        relevance: 0,
        keywords: {
          _hint: FUNCTION_HINTS },
        begin: regex.concat(
          /\b/,
          /(?!decltype)/,
          /(?!if)/,
          /(?!for)/,
          /(?!switch)/,
          /(?!while)/,
          hljs.IDENT_RE,
          regex.lookahead(/(<[^<>]+>|)\s*\(/))
      };
      const EXPRESSION_CONTAINS = [
        FUNCTION_DISPATCH,
        PREPROCESSOR,
        CPP_PRIMITIVE_TYPES,
        C_LINE_COMMENT_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        NUMBERS,
        STRINGS
      ];
      const EXPRESSION_CONTEXT = {
        variants: [
          {
            begin: /=/,
            end: /;/
          },
          {
            begin: /\(/,
            end: /\)/
          },
          {
            beginKeywords: 'new throw return else',
            end: /;/
          }
        ],
        keywords: CPP_KEYWORDS,
        contains: EXPRESSION_CONTAINS.concat([
          {
            begin: /\(/,
            end: /\)/,
            keywords: CPP_KEYWORDS,
            contains: EXPRESSION_CONTAINS.concat([ 'self' ]),
            relevance: 0
          }
        ]),
        relevance: 0
      };
      const FUNCTION_DECLARATION = {
        className: 'function',
        begin: '(' + FUNCTION_TYPE_RE + '[\\*&\\s]+)+' + FUNCTION_TITLE,
        returnBegin: true,
        end: /[{;=]/,
        excludeEnd: true,
        keywords: CPP_KEYWORDS,
        illegal: /[^\w\s\*&:<>.]/,
        contains: [
          {
            begin: DECLTYPE_AUTO_RE,
            keywords: CPP_KEYWORDS,
            relevance: 0
          },
          {
            begin: FUNCTION_TITLE,
            returnBegin: true,
            contains: [ TITLE_MODE ],
            relevance: 0
          },
          {
            begin: /::/,
            relevance: 0
          },
          {
            begin: /:/,
            endsWithParent: true,
            contains: [
              STRINGS,
              NUMBERS
            ]
          },
          {
            relevance: 0,
            match: /,/
          },
          {
            className: 'params',
            begin: /\(/,
            end: /\)/,
            keywords: CPP_KEYWORDS,
            relevance: 0,
            contains: [
              C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              STRINGS,
              NUMBERS,
              CPP_PRIMITIVE_TYPES,
              {
                begin: /\(/,
                end: /\)/,
                keywords: CPP_KEYWORDS,
                relevance: 0,
                contains: [
                  'self',
                  C_LINE_COMMENT_MODE,
                  hljs.C_BLOCK_COMMENT_MODE,
                  STRINGS,
                  NUMBERS,
                  CPP_PRIMITIVE_TYPES
                ]
              }
            ]
          },
          CPP_PRIMITIVE_TYPES,
          C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          PREPROCESSOR
        ]
      };
      return {
        name: 'C++',
        aliases: [
          'cc',
          'c++',
          'h++',
          'hpp',
          'hh',
          'hxx',
          'cxx'
        ],
        keywords: CPP_KEYWORDS,
        illegal: '</',
        classNameAliases: { 'function.dispatch': 'built_in' },
        contains: [].concat(
          EXPRESSION_CONTEXT,
          FUNCTION_DECLARATION,
          FUNCTION_DISPATCH,
          EXPRESSION_CONTAINS,
          [
            PREPROCESSOR,
            {
              begin: '\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function)\\s*<(?!<)',
              end: '>',
              keywords: CPP_KEYWORDS,
              contains: [
                'self',
                CPP_PRIMITIVE_TYPES
              ]
            },
            {
              begin: hljs.IDENT_RE + '::',
              keywords: CPP_KEYWORDS
            },
            {
              match: [
                /\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,
                /\s+/,
                /\w+/
              ],
              className: {
                1: 'keyword',
                3: 'title.class'
              }
            }
          ])
      };
    }

    function csharp(hljs) {
      const BUILT_IN_KEYWORDS = [
        'bool',
        'byte',
        'char',
        'decimal',
        'delegate',
        'double',
        'dynamic',
        'enum',
        'float',
        'int',
        'long',
        'nint',
        'nuint',
        'object',
        'sbyte',
        'short',
        'string',
        'ulong',
        'uint',
        'ushort'
      ];
      const FUNCTION_MODIFIERS = [
        'public',
        'private',
        'protected',
        'static',
        'internal',
        'protected',
        'abstract',
        'async',
        'extern',
        'override',
        'unsafe',
        'virtual',
        'new',
        'sealed',
        'partial'
      ];
      const LITERAL_KEYWORDS = [
        'default',
        'false',
        'null',
        'true'
      ];
      const NORMAL_KEYWORDS = [
        'abstract',
        'as',
        'base',
        'break',
        'case',
        'catch',
        'class',
        'const',
        'continue',
        'do',
        'else',
        'event',
        'explicit',
        'extern',
        'finally',
        'fixed',
        'for',
        'foreach',
        'goto',
        'if',
        'implicit',
        'in',
        'interface',
        'internal',
        'is',
        'lock',
        'namespace',
        'new',
        'operator',
        'out',
        'override',
        'params',
        'private',
        'protected',
        'public',
        'readonly',
        'record',
        'ref',
        'return',
        'scoped',
        'sealed',
        'sizeof',
        'stackalloc',
        'static',
        'struct',
        'switch',
        'this',
        'throw',
        'try',
        'typeof',
        'unchecked',
        'unsafe',
        'using',
        'virtual',
        'void',
        'volatile',
        'while'
      ];
      const CONTEXTUAL_KEYWORDS = [
        'add',
        'alias',
        'and',
        'ascending',
        'async',
        'await',
        'by',
        'descending',
        'equals',
        'from',
        'get',
        'global',
        'group',
        'init',
        'into',
        'join',
        'let',
        'nameof',
        'not',
        'notnull',
        'on',
        'or',
        'orderby',
        'partial',
        'remove',
        'select',
        'set',
        'unmanaged',
        'value|0',
        'var',
        'when',
        'where',
        'with',
        'yield'
      ];
      const KEYWORDS = {
        keyword: NORMAL_KEYWORDS.concat(CONTEXTUAL_KEYWORDS),
        built_in: BUILT_IN_KEYWORDS,
        literal: LITERAL_KEYWORDS
      };
      const TITLE_MODE = hljs.inherit(hljs.TITLE_MODE, { begin: '[a-zA-Z](\\.?\\w)*' });
      const NUMBERS = {
        className: 'number',
        variants: [
          { begin: '\\b(0b[01\']+)' },
          { begin: '(-?)\\b([\\d\']+(\\.[\\d\']*)?|\\.[\\d\']+)(u|U|l|L|ul|UL|f|F|b|B)' },
          { begin: '(-?)(\\b0[xX][a-fA-F0-9\']+|(\\b[\\d\']+(\\.[\\d\']*)?|\\.[\\d\']+)([eE][-+]?[\\d\']+)?)' }
        ],
        relevance: 0
      };
      const VERBATIM_STRING = {
        className: 'string',
        begin: '@"',
        end: '"',
        contains: [ { begin: '""' } ]
      };
      const VERBATIM_STRING_NO_LF = hljs.inherit(VERBATIM_STRING, { illegal: /\n/ });
      const SUBST = {
        className: 'subst',
        begin: /\{/,
        end: /\}/,
        keywords: KEYWORDS
      };
      const SUBST_NO_LF = hljs.inherit(SUBST, { illegal: /\n/ });
      const INTERPOLATED_STRING = {
        className: 'string',
        begin: /\$"/,
        end: '"',
        illegal: /\n/,
        contains: [
          { begin: /\{\{/ },
          { begin: /\}\}/ },
          hljs.BACKSLASH_ESCAPE,
          SUBST_NO_LF
        ]
      };
      const INTERPOLATED_VERBATIM_STRING = {
        className: 'string',
        begin: /\$@"/,
        end: '"',
        contains: [
          { begin: /\{\{/ },
          { begin: /\}\}/ },
          { begin: '""' },
          SUBST
        ]
      };
      const INTERPOLATED_VERBATIM_STRING_NO_LF = hljs.inherit(INTERPOLATED_VERBATIM_STRING, {
        illegal: /\n/,
        contains: [
          { begin: /\{\{/ },
          { begin: /\}\}/ },
          { begin: '""' },
          SUBST_NO_LF
        ]
      });
      SUBST.contains = [
        INTERPOLATED_VERBATIM_STRING,
        INTERPOLATED_STRING,
        VERBATIM_STRING,
        hljs.APOS_STRING_MODE,
        hljs.QUOTE_STRING_MODE,
        NUMBERS,
        hljs.C_BLOCK_COMMENT_MODE
      ];
      SUBST_NO_LF.contains = [
        INTERPOLATED_VERBATIM_STRING_NO_LF,
        INTERPOLATED_STRING,
        VERBATIM_STRING_NO_LF,
        hljs.APOS_STRING_MODE,
        hljs.QUOTE_STRING_MODE,
        NUMBERS,
        hljs.inherit(hljs.C_BLOCK_COMMENT_MODE, { illegal: /\n/ })
      ];
      const STRING = { variants: [
        INTERPOLATED_VERBATIM_STRING,
        INTERPOLATED_STRING,
        VERBATIM_STRING,
        hljs.APOS_STRING_MODE,
        hljs.QUOTE_STRING_MODE
      ] };
      const GENERIC_MODIFIER = {
        begin: "<",
        end: ">",
        contains: [
          { beginKeywords: "in out" },
          TITLE_MODE
        ]
      };
      const TYPE_IDENT_RE = hljs.IDENT_RE + '(<' + hljs.IDENT_RE + '(\\s*,\\s*' + hljs.IDENT_RE + ')*>)?(\\[\\])?';
      const AT_IDENTIFIER = {
        begin: "@" + hljs.IDENT_RE,
        relevance: 0
      };
      return {
        name: 'C#',
        aliases: [
          'cs',
          'c#'
        ],
        keywords: KEYWORDS,
        illegal: /::/,
        contains: [
          hljs.COMMENT(
            '///',
            '$',
            {
              returnBegin: true,
              contains: [
                {
                  className: 'doctag',
                  variants: [
                    {
                      begin: '///',
                      relevance: 0
                    },
                    { begin: '<!--|-->' },
                    {
                      begin: '</?',
                      end: '>'
                    }
                  ]
                }
              ]
            }
          ),
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          {
            className: 'meta',
            begin: '#',
            end: '$',
            keywords: { keyword: 'if else elif endif define undef warning error line region endregion pragma checksum' }
          },
          STRING,
          NUMBERS,
          {
            beginKeywords: 'class interface',
            relevance: 0,
            end: /[{;=]/,
            illegal: /[^\s:,]/,
            contains: [
              { beginKeywords: "where class" },
              TITLE_MODE,
              GENERIC_MODIFIER,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          {
            beginKeywords: 'namespace',
            relevance: 0,
            end: /[{;=]/,
            illegal: /[^\s:]/,
            contains: [
              TITLE_MODE,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          {
            beginKeywords: 'record',
            relevance: 0,
            end: /[{;=]/,
            illegal: /[^\s:]/,
            contains: [
              TITLE_MODE,
              GENERIC_MODIFIER,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          {
            className: 'meta',
            begin: '^\\s*\\[(?=[\\w])',
            excludeBegin: true,
            end: '\\]',
            excludeEnd: true,
            contains: [
              {
                className: 'string',
                begin: /"/,
                end: /"/
              }
            ]
          },
          {
            beginKeywords: 'new return throw await else',
            relevance: 0
          },
          {
            className: 'function',
            begin: '(' + TYPE_IDENT_RE + '\\s+)+' + hljs.IDENT_RE + '\\s*(<[^=]+>\\s*)?\\(',
            returnBegin: true,
            end: /\s*[{;=]/,
            excludeEnd: true,
            keywords: KEYWORDS,
            contains: [
              {
                beginKeywords: FUNCTION_MODIFIERS.join(" "),
                relevance: 0
              },
              {
                begin: hljs.IDENT_RE + '\\s*(<[^=]+>\\s*)?\\(',
                returnBegin: true,
                contains: [
                  hljs.TITLE_MODE,
                  GENERIC_MODIFIER
                ],
                relevance: 0
              },
              { match: /\(\)/ },
              {
                className: 'params',
                begin: /\(/,
                end: /\)/,
                excludeBegin: true,
                excludeEnd: true,
                keywords: KEYWORDS,
                relevance: 0,
                contains: [
                  STRING,
                  NUMBERS,
                  hljs.C_BLOCK_COMMENT_MODE
                ]
              },
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          AT_IDENTIFIER
        ]
      };
    }

    function dart(hljs) {
      const SUBST = {
        className: 'subst',
        variants: [ { begin: '\\$[A-Za-z0-9_]+' } ]
      };
      const BRACED_SUBST = {
        className: 'subst',
        variants: [
          {
            begin: /\$\{/,
            end: /\}/
          }
        ],
        keywords: 'true false null this is new super'
      };
      const STRING = {
        className: 'string',
        variants: [
          {
            begin: 'r\'\'\'',
            end: '\'\'\''
          },
          {
            begin: 'r"""',
            end: '"""'
          },
          {
            begin: 'r\'',
            end: '\'',
            illegal: '\\n'
          },
          {
            begin: 'r"',
            end: '"',
            illegal: '\\n'
          },
          {
            begin: '\'\'\'',
            end: '\'\'\'',
            contains: [
              hljs.BACKSLASH_ESCAPE,
              SUBST,
              BRACED_SUBST
            ]
          },
          {
            begin: '"""',
            end: '"""',
            contains: [
              hljs.BACKSLASH_ESCAPE,
              SUBST,
              BRACED_SUBST
            ]
          },
          {
            begin: '\'',
            end: '\'',
            illegal: '\\n',
            contains: [
              hljs.BACKSLASH_ESCAPE,
              SUBST,
              BRACED_SUBST
            ]
          },
          {
            begin: '"',
            end: '"',
            illegal: '\\n',
            contains: [
              hljs.BACKSLASH_ESCAPE,
              SUBST,
              BRACED_SUBST
            ]
          }
        ]
      };
      BRACED_SUBST.contains = [
        hljs.C_NUMBER_MODE,
        STRING
      ];
      const BUILT_IN_TYPES = [
        'Comparable',
        'DateTime',
        'Duration',
        'Function',
        'Iterable',
        'Iterator',
        'List',
        'Map',
        'Match',
        'Object',
        'Pattern',
        'RegExp',
        'Set',
        'Stopwatch',
        'String',
        'StringBuffer',
        'StringSink',
        'Symbol',
        'Type',
        'Uri',
        'bool',
        'double',
        'int',
        'num',
        'Element',
        'ElementList'
      ];
      const NULLABLE_BUILT_IN_TYPES = BUILT_IN_TYPES.map((e) => `${e}?`);
      const BASIC_KEYWORDS = [
        "abstract",
        "as",
        "assert",
        "async",
        "await",
        "break",
        "case",
        "catch",
        "class",
        "const",
        "continue",
        "covariant",
        "default",
        "deferred",
        "do",
        "dynamic",
        "else",
        "enum",
        "export",
        "extends",
        "extension",
        "external",
        "factory",
        "false",
        "final",
        "finally",
        "for",
        "Function",
        "get",
        "hide",
        "if",
        "implements",
        "import",
        "in",
        "inferface",
        "is",
        "late",
        "library",
        "mixin",
        "new",
        "null",
        "on",
        "operator",
        "part",
        "required",
        "rethrow",
        "return",
        "set",
        "show",
        "static",
        "super",
        "switch",
        "sync",
        "this",
        "throw",
        "true",
        "try",
        "typedef",
        "var",
        "void",
        "while",
        "with",
        "yield"
      ];
      const KEYWORDS = {
        keyword: BASIC_KEYWORDS,
        built_in:
          BUILT_IN_TYPES
            .concat(NULLABLE_BUILT_IN_TYPES)
            .concat([
              'Never',
              'Null',
              'dynamic',
              'print',
              'document',
              'querySelector',
              'querySelectorAll',
              'window'
            ]),
        $pattern: /[A-Za-z][A-Za-z0-9_]*\??/
      };
      return {
        name: 'Dart',
        keywords: KEYWORDS,
        contains: [
          STRING,
          hljs.COMMENT(
            /\/\*\*(?!\/)/,
            /\*\//,
            {
              subLanguage: 'markdown',
              relevance: 0
            }
          ),
          hljs.COMMENT(
            /\/{3,} ?/,
            /$/, { contains: [
              {
                subLanguage: 'markdown',
                begin: '.',
                end: '$',
                relevance: 0
              }
            ] }
          ),
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          {
            className: 'class',
            beginKeywords: 'class interface',
            end: /\{/,
            excludeEnd: true,
            contains: [
              { beginKeywords: 'extends implements' },
              hljs.UNDERSCORE_TITLE_MODE
            ]
          },
          hljs.C_NUMBER_MODE,
          {
            className: 'meta',
            begin: '@[A-Za-z]+'
          },
          { begin: '=>'
          }
        ]
      };
    }

    function go(hljs) {
      const LITERALS = [
        "true",
        "false",
        "iota",
        "nil"
      ];
      const BUILT_INS = [
        "append",
        "cap",
        "close",
        "complex",
        "copy",
        "imag",
        "len",
        "make",
        "new",
        "panic",
        "print",
        "println",
        "real",
        "recover",
        "delete"
      ];
      const TYPES = [
        "bool",
        "byte",
        "complex64",
        "complex128",
        "error",
        "float32",
        "float64",
        "int8",
        "int16",
        "int32",
        "int64",
        "string",
        "uint8",
        "uint16",
        "uint32",
        "uint64",
        "int",
        "uint",
        "uintptr",
        "rune"
      ];
      const KWS = [
        "break",
        "case",
        "chan",
        "const",
        "continue",
        "default",
        "defer",
        "else",
        "fallthrough",
        "for",
        "func",
        "go",
        "goto",
        "if",
        "import",
        "interface",
        "map",
        "package",
        "range",
        "return",
        "select",
        "struct",
        "switch",
        "type",
        "var",
      ];
      const KEYWORDS = {
        keyword: KWS,
        type: TYPES,
        literal: LITERALS,
        built_in: BUILT_INS
      };
      return {
        name: 'Go',
        aliases: [ 'golang' ],
        keywords: KEYWORDS,
        illegal: '</',
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          {
            className: 'string',
            variants: [
              hljs.QUOTE_STRING_MODE,
              hljs.APOS_STRING_MODE,
              {
                begin: '`',
                end: '`'
              }
            ]
          },
          {
            className: 'number',
            variants: [
              {
                begin: hljs.C_NUMBER_RE + '[i]',
                relevance: 1
              },
              hljs.C_NUMBER_MODE
            ]
          },
          { begin: /:=/
          },
          {
            className: 'function',
            beginKeywords: 'func',
            end: '\\s*(\\{|$)',
            excludeEnd: true,
            contains: [
              hljs.TITLE_MODE,
              {
                className: 'params',
                begin: /\(/,
                end: /\)/,
                endsParent: true,
                keywords: KEYWORDS,
                illegal: /["']/
              }
            ]
          }
        ]
      };
    }

    function variants(variants, obj = {}) {
      obj.variants = variants;
      return obj;
    }
    function groovy(hljs) {
      const regex = hljs.regex;
      const IDENT_RE = '[A-Za-z0-9_$]+';
      const COMMENT = variants([
        hljs.C_LINE_COMMENT_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        hljs.COMMENT(
          '/\\*\\*',
          '\\*/',
          {
            relevance: 0,
            contains: [
              {
                begin: /\w+@/,
                relevance: 0
              },
              {
                className: 'doctag',
                begin: '@[A-Za-z]+'
              }
            ]
          }
        )
      ]);
      const REGEXP = {
        className: 'regexp',
        begin: /~?\/[^\/\n]+\//,
        contains: [ hljs.BACKSLASH_ESCAPE ]
      };
      const NUMBER = variants([
        hljs.BINARY_NUMBER_MODE,
        hljs.C_NUMBER_MODE
      ]);
      const STRING = variants([
        {
          begin: /"""/,
          end: /"""/
        },
        {
          begin: /'''/,
          end: /'''/
        },
        {
          begin: "\\$/",
          end: "/\\$",
          relevance: 10
        },
        hljs.APOS_STRING_MODE,
        hljs.QUOTE_STRING_MODE
      ],
      { className: "string" }
      );
      const CLASS_DEFINITION = {
        match: [
          /(class|interface|trait|enum|extends|implements)/,
          /\s+/,
          hljs.UNDERSCORE_IDENT_RE
        ],
        scope: {
          1: "keyword",
          3: "title.class",
        }
      };
      const TYPES = [
        "byte",
        "short",
        "char",
        "int",
        "long",
        "boolean",
        "float",
        "double",
        "void"
      ];
      const KEYWORDS = [
        "def",
        "as",
        "in",
        "assert",
        "trait",
        "abstract",
        "static",
        "volatile",
        "transient",
        "public",
        "private",
        "protected",
        "synchronized",
        "final",
        "class",
        "interface",
        "enum",
        "if",
        "else",
        "for",
        "while",
        "switch",
        "case",
        "break",
        "default",
        "continue",
        "throw",
        "throws",
        "try",
        "catch",
        "finally",
        "implements",
        "extends",
        "new",
        "import",
        "package",
        "return",
        "instanceof"
      ];
      return {
        name: 'Groovy',
        keywords: {
          "variable.language": 'this super',
          literal: 'true false null',
          type: TYPES,
          keyword: KEYWORDS
        },
        contains: [
          hljs.SHEBANG({
            binary: "groovy",
            relevance: 10
          }),
          COMMENT,
          STRING,
          REGEXP,
          NUMBER,
          CLASS_DEFINITION,
          {
            className: 'meta',
            begin: '@[A-Za-z]+',
            relevance: 0
          },
          {
            className: 'attr',
            begin: IDENT_RE + '[ \t]*:',
            relevance: 0
          },
          {
            begin: /\?/,
            end: /:/,
            relevance: 0,
            contains: [
              COMMENT,
              STRING,
              REGEXP,
              NUMBER,
              'self'
            ]
          },
          {
            className: 'symbol',
            begin: '^[ \t]*' + regex.lookahead(IDENT_RE + ':'),
            excludeBegin: true,
            end: IDENT_RE + ':',
            relevance: 0
          }
        ],
        illegal: /#|<\//
      };
    }

    function haskell(hljs) {
      const COMMENT = { variants: [
        hljs.COMMENT('--', '$'),
        hljs.COMMENT(
          /\{-/,
          /-\}/,
          { contains: [ 'self' ] }
        )
      ] };
      const PRAGMA = {
        className: 'meta',
        begin: /\{-#/,
        end: /#-\}/
      };
      const PREPROCESSOR = {
        className: 'meta',
        begin: '^#',
        end: '$'
      };
      const CONSTRUCTOR = {
        className: 'type',
        begin: '\\b[A-Z][\\w\']*',
        relevance: 0
      };
      const LIST = {
        begin: '\\(',
        end: '\\)',
        illegal: '"',
        contains: [
          PRAGMA,
          PREPROCESSOR,
          {
            className: 'type',
            begin: '\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?'
          },
          hljs.inherit(hljs.TITLE_MODE, { begin: '[_a-z][\\w\']*' }),
          COMMENT
        ]
      };
      const RECORD = {
        begin: /\{/,
        end: /\}/,
        contains: LIST.contains
      };
      const decimalDigits = '([0-9]_*)+';
      const hexDigits = '([0-9a-fA-F]_*)+';
      const binaryDigits = '([01]_*)+';
      const octalDigits = '([0-7]_*)+';
      const NUMBER = {
        className: 'number',
        relevance: 0,
        variants: [
          { match: `\\b(${decimalDigits})(\\.(${decimalDigits}))?` + `([eE][+-]?(${decimalDigits}))?\\b` },
          { match: `\\b0[xX]_*(${hexDigits})(\\.(${hexDigits}))?` + `([pP][+-]?(${decimalDigits}))?\\b` },
          { match: `\\b0[oO](${octalDigits})\\b` },
          { match: `\\b0[bB](${binaryDigits})\\b` }
        ]
      };
      return {
        name: 'Haskell',
        aliases: [ 'hs' ],
        keywords:
          'let in if then else case of where do module import hiding '
          + 'qualified type data newtype deriving class instance as default '
          + 'infix infixl infixr foreign export ccall stdcall cplusplus '
          + 'jvm dotnet safe unsafe family forall mdo proc rec',
        contains: [
          {
            beginKeywords: 'module',
            end: 'where',
            keywords: 'module where',
            contains: [
              LIST,
              COMMENT
            ],
            illegal: '\\W\\.|;'
          },
          {
            begin: '\\bimport\\b',
            end: '$',
            keywords: 'import qualified as hiding',
            contains: [
              LIST,
              COMMENT
            ],
            illegal: '\\W\\.|;'
          },
          {
            className: 'class',
            begin: '^(\\s*)?(class|instance)\\b',
            end: 'where',
            keywords: 'class family instance where',
            contains: [
              CONSTRUCTOR,
              LIST,
              COMMENT
            ]
          },
          {
            className: 'class',
            begin: '\\b(data|(new)?type)\\b',
            end: '$',
            keywords: 'data family type newtype deriving',
            contains: [
              PRAGMA,
              CONSTRUCTOR,
              LIST,
              RECORD,
              COMMENT
            ]
          },
          {
            beginKeywords: 'default',
            end: '$',
            contains: [
              CONSTRUCTOR,
              LIST,
              COMMENT
            ]
          },
          {
            beginKeywords: 'infix infixl infixr',
            end: '$',
            contains: [
              hljs.C_NUMBER_MODE,
              COMMENT
            ]
          },
          {
            begin: '\\bforeign\\b',
            end: '$',
            keywords: 'foreign import export ccall stdcall cplusplus jvm '
                      + 'dotnet safe unsafe',
            contains: [
              CONSTRUCTOR,
              hljs.QUOTE_STRING_MODE,
              COMMENT
            ]
          },
          {
            className: 'meta',
            begin: '#!\\/usr\\/bin\\/env\ runhaskell',
            end: '$'
          },
          PRAGMA,
          PREPROCESSOR,
          hljs.QUOTE_STRING_MODE,
          NUMBER,
          CONSTRUCTOR,
          hljs.inherit(hljs.TITLE_MODE, { begin: '^[_a-z][\\w\']*' }),
          COMMENT,
          {
            begin: '->|<-' }
        ]
      };
    }

    var decimalDigits$1 = '[0-9](_*[0-9])*';
    var frac$1 = `\\.(${decimalDigits$1})`;
    var hexDigits$1 = '[0-9a-fA-F](_*[0-9a-fA-F])*';
    var NUMERIC$1 = {
      className: 'number',
      variants: [
        { begin: `(\\b(${decimalDigits$1})((${frac$1})|\\.)?|(${frac$1}))` +
          `[eE][+-]?(${decimalDigits$1})[fFdD]?\\b` },
        { begin: `\\b(${decimalDigits$1})((${frac$1})[fFdD]?\\b|\\.([fFdD]\\b)?)` },
        { begin: `(${frac$1})[fFdD]?\\b` },
        { begin: `\\b(${decimalDigits$1})[fFdD]\\b` },
        { begin: `\\b0[xX]((${hexDigits$1})\\.?|(${hexDigits$1})?\\.(${hexDigits$1}))` +
          `[pP][+-]?(${decimalDigits$1})[fFdD]?\\b` },
        { begin: '\\b(0|[1-9](_*[0-9])*)[lL]?\\b' },
        { begin: `\\b0[xX](${hexDigits$1})[lL]?\\b` },
        { begin: '\\b0(_*[0-7])*[lL]?\\b' },
        { begin: '\\b0[bB][01](_*[01])*[lL]?\\b' },
      ],
      relevance: 0
    };
    function recurRegex(re, substitution, depth) {
      if (depth === -1) return "";
      return re.replace(substitution, _ => {
        return recurRegex(re, substitution, depth - 1);
      });
    }
    function java(hljs) {
      const regex = hljs.regex;
      const JAVA_IDENT_RE = '[\u00C0-\u02B8a-zA-Z_$][\u00C0-\u02B8a-zA-Z_$0-9]*';
      const GENERIC_IDENT_RE = JAVA_IDENT_RE
        + recurRegex('(?:<' + JAVA_IDENT_RE + '~~~(?:\\s*,\\s*' + JAVA_IDENT_RE + '~~~)*>)?', /~~~/g, 2);
      const MAIN_KEYWORDS = [
        'synchronized',
        'abstract',
        'private',
        'var',
        'static',
        'if',
        'const ',
        'for',
        'while',
        'strictfp',
        'finally',
        'protected',
        'import',
        'native',
        'final',
        'void',
        'enum',
        'else',
        'break',
        'transient',
        'catch',
        'instanceof',
        'volatile',
        'case',
        'assert',
        'package',
        'default',
        'public',
        'try',
        'switch',
        'continue',
        'throws',
        'protected',
        'public',
        'private',
        'module',
        'requires',
        'exports',
        'do',
        'sealed'
      ];
      const BUILT_INS = [
        'super',
        'this'
      ];
      const LITERALS = [
        'false',
        'true',
        'null'
      ];
      const TYPES = [
        'char',
        'boolean',
        'long',
        'float',
        'int',
        'byte',
        'short',
        'double'
      ];
      const KEYWORDS = {
        keyword: MAIN_KEYWORDS,
        literal: LITERALS,
        type: TYPES,
        built_in: BUILT_INS
      };
      const ANNOTATION = {
        className: 'meta',
        begin: '@' + JAVA_IDENT_RE,
        contains: [
          {
            begin: /\(/,
            end: /\)/,
            contains: [ "self" ]
          }
        ]
      };
      const PARAMS = {
        className: 'params',
        begin: /\(/,
        end: /\)/,
        keywords: KEYWORDS,
        relevance: 0,
        contains: [ hljs.C_BLOCK_COMMENT_MODE ],
        endsParent: true
      };
      return {
        name: 'Java',
        aliases: [ 'jsp' ],
        keywords: KEYWORDS,
        illegal: /<\/|#/,
        contains: [
          hljs.COMMENT(
            '/\\*\\*',
            '\\*/',
            {
              relevance: 0,
              contains: [
                {
                  begin: /\w+@/,
                  relevance: 0
                },
                {
                  className: 'doctag',
                  begin: '@[A-Za-z]+'
                }
              ]
            }
          ),
          {
            begin: /import java\.[a-z]+\./,
            keywords: "import",
            relevance: 2
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          {
            begin: /"""/,
            end: /"""/,
            className: "string",
            contains: [ hljs.BACKSLASH_ESCAPE ]
          },
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          {
            match: [
              /\b(?:class|interface|enum|extends|implements|new)/,
              /\s+/,
              JAVA_IDENT_RE
            ],
            className: {
              1: "keyword",
              3: "title.class"
            }
          },
          {
            match: /non-sealed/,
            scope: "keyword"
          },
          {
            begin: [
              regex.concat(/(?!else)/, JAVA_IDENT_RE),
              /\s+/,
              JAVA_IDENT_RE,
              /\s+/,
              /=(?!=)/
            ],
            className: {
              1: "type",
              3: "variable",
              5: "operator"
            }
          },
          {
            begin: [
              /record/,
              /\s+/,
              JAVA_IDENT_RE
            ],
            className: {
              1: "keyword",
              3: "title.class"
            },
            contains: [
              PARAMS,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          {
            beginKeywords: 'new throw return else',
            relevance: 0
          },
          {
            begin: [
              '(?:' + GENERIC_IDENT_RE + '\\s+)',
              hljs.UNDERSCORE_IDENT_RE,
              /\s*(?=\()/
            ],
            className: { 2: "title.function" },
            keywords: KEYWORDS,
            contains: [
              {
                className: 'params',
                begin: /\(/,
                end: /\)/,
                keywords: KEYWORDS,
                relevance: 0,
                contains: [
                  ANNOTATION,
                  hljs.APOS_STRING_MODE,
                  hljs.QUOTE_STRING_MODE,
                  NUMERIC$1,
                  hljs.C_BLOCK_COMMENT_MODE
                ]
              },
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          NUMERIC$1,
          ANNOTATION
        ]
      };
    }

    const IDENT_RE$1 = '[A-Za-z$_][0-9A-Za-z$_]*';
    const KEYWORDS$1 = [
      "as",
      "in",
      "of",
      "if",
      "for",
      "while",
      "finally",
      "var",
      "new",
      "function",
      "do",
      "return",
      "void",
      "else",
      "break",
      "catch",
      "instanceof",
      "with",
      "throw",
      "case",
      "default",
      "try",
      "switch",
      "continue",
      "typeof",
      "delete",
      "let",
      "yield",
      "const",
      "class",
      "debugger",
      "async",
      "await",
      "static",
      "import",
      "from",
      "export",
      "extends"
    ];
    const LITERALS$1 = [
      "true",
      "false",
      "null",
      "undefined",
      "NaN",
      "Infinity"
    ];
    const TYPES$1 = [
      "Object",
      "Function",
      "Boolean",
      "Symbol",
      "Math",
      "Date",
      "Number",
      "BigInt",
      "String",
      "RegExp",
      "Array",
      "Float32Array",
      "Float64Array",
      "Int8Array",
      "Uint8Array",
      "Uint8ClampedArray",
      "Int16Array",
      "Int32Array",
      "Uint16Array",
      "Uint32Array",
      "BigInt64Array",
      "BigUint64Array",
      "Set",
      "Map",
      "WeakSet",
      "WeakMap",
      "ArrayBuffer",
      "SharedArrayBuffer",
      "Atomics",
      "DataView",
      "JSON",
      "Promise",
      "Generator",
      "GeneratorFunction",
      "AsyncFunction",
      "Reflect",
      "Proxy",
      "Intl",
      "WebAssembly"
    ];
    const ERROR_TYPES$1 = [
      "Error",
      "EvalError",
      "InternalError",
      "RangeError",
      "ReferenceError",
      "SyntaxError",
      "TypeError",
      "URIError"
    ];
    const BUILT_IN_GLOBALS$1 = [
      "setInterval",
      "setTimeout",
      "clearInterval",
      "clearTimeout",
      "require",
      "exports",
      "eval",
      "isFinite",
      "isNaN",
      "parseFloat",
      "parseInt",
      "decodeURI",
      "decodeURIComponent",
      "encodeURI",
      "encodeURIComponent",
      "escape",
      "unescape"
    ];
    const BUILT_IN_VARIABLES$1 = [
      "arguments",
      "this",
      "super",
      "console",
      "window",
      "document",
      "localStorage",
      "module",
      "global"
    ];
    const BUILT_INS$1 = [].concat(
      BUILT_IN_GLOBALS$1,
      TYPES$1,
      ERROR_TYPES$1
    );
    function javascript$1(hljs) {
      const regex = hljs.regex;
      const hasClosingTag = (match, { after }) => {
        const tag = "</" + match[0].slice(1);
        const pos = match.input.indexOf(tag, after);
        return pos !== -1;
      };
      const IDENT_RE$1$1 = IDENT_RE$1;
      const FRAGMENT = {
        begin: '<>',
        end: '</>'
      };
      const XML_SELF_CLOSING = /<[A-Za-z0-9\\._:-]+\s*\/>/;
      const XML_TAG = {
        begin: /<[A-Za-z0-9\\._:-]+/,
        end: /\/[A-Za-z0-9\\._:-]+>|\/>/,
        isTrulyOpeningTag: (match, response) => {
          const afterMatchIndex = match[0].length + match.index;
          const nextChar = match.input[afterMatchIndex];
          if (
            nextChar === "<" ||
            nextChar === ",") {
            response.ignoreMatch();
            return;
          }
          if (nextChar === ">") {
            if (!hasClosingTag(match, { after: afterMatchIndex })) {
              response.ignoreMatch();
            }
          }
          let m;
          const afterMatch = match.input.substring(afterMatchIndex);
          if ((m = afterMatch.match(/^\s+extends\s+/))) {
            if (m.index === 0) {
              response.ignoreMatch();
              return;
            }
          }
        }
      };
      const KEYWORDS$1$1 = {
        $pattern: IDENT_RE$1,
        keyword: KEYWORDS$1,
        literal: LITERALS$1,
        built_in: BUILT_INS$1,
        "variable.language": BUILT_IN_VARIABLES$1
      };
      const decimalDigits = '[0-9](_?[0-9])*';
      const frac = `\\.(${decimalDigits})`;
      const decimalInteger = `0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*`;
      const NUMBER = {
        className: 'number',
        variants: [
          { begin: `(\\b(${decimalInteger})((${frac})|\\.)?|(${frac}))` +
            `[eE][+-]?(${decimalDigits})\\b` },
          { begin: `\\b(${decimalInteger})\\b((${frac})\\b|\\.)?|(${frac})\\b` },
          { begin: `\\b(0|[1-9](_?[0-9])*)n\\b` },
          { begin: "\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b" },
          { begin: "\\b0[bB][0-1](_?[0-1])*n?\\b" },
          { begin: "\\b0[oO][0-7](_?[0-7])*n?\\b" },
          { begin: "\\b0[0-7]+n?\\b" },
        ],
        relevance: 0
      };
      const SUBST = {
        className: 'subst',
        begin: '\\$\\{',
        end: '\\}',
        keywords: KEYWORDS$1$1,
        contains: []
      };
      const HTML_TEMPLATE = {
        begin: 'html`',
        end: '',
        starts: {
          end: '`',
          returnEnd: false,
          contains: [
            hljs.BACKSLASH_ESCAPE,
            SUBST
          ],
          subLanguage: 'xml'
        }
      };
      const CSS_TEMPLATE = {
        begin: 'css`',
        end: '',
        starts: {
          end: '`',
          returnEnd: false,
          contains: [
            hljs.BACKSLASH_ESCAPE,
            SUBST
          ],
          subLanguage: 'css'
        }
      };
      const TEMPLATE_STRING = {
        className: 'string',
        begin: '`',
        end: '`',
        contains: [
          hljs.BACKSLASH_ESCAPE,
          SUBST
        ]
      };
      const JSDOC_COMMENT = hljs.COMMENT(
        /\/\*\*(?!\/)/,
        '\\*/',
        {
          relevance: 0,
          contains: [
            {
              begin: '(?=@[A-Za-z]+)',
              relevance: 0,
              contains: [
                {
                  className: 'doctag',
                  begin: '@[A-Za-z]+'
                },
                {
                  className: 'type',
                  begin: '\\{',
                  end: '\\}',
                  excludeEnd: true,
                  excludeBegin: true,
                  relevance: 0
                },
                {
                  className: 'variable',
                  begin: IDENT_RE$1$1 + '(?=\\s*(-)|$)',
                  endsParent: true,
                  relevance: 0
                },
                {
                  begin: /(?=[^\n])\s/,
                  relevance: 0
                }
              ]
            }
          ]
        }
      );
      const COMMENT = {
        className: "comment",
        variants: [
          JSDOC_COMMENT,
          hljs.C_BLOCK_COMMENT_MODE,
          hljs.C_LINE_COMMENT_MODE
        ]
      };
      const SUBST_INTERNALS = [
        hljs.APOS_STRING_MODE,
        hljs.QUOTE_STRING_MODE,
        HTML_TEMPLATE,
        CSS_TEMPLATE,
        TEMPLATE_STRING,
        NUMBER,
      ];
      SUBST.contains = SUBST_INTERNALS
        .concat({
          begin: /\{/,
          end: /\}/,
          keywords: KEYWORDS$1$1,
          contains: [
            "self"
          ].concat(SUBST_INTERNALS)
        });
      const SUBST_AND_COMMENTS = [].concat(COMMENT, SUBST.contains);
      const PARAMS_CONTAINS = SUBST_AND_COMMENTS.concat([
        {
          begin: /\(/,
          end: /\)/,
          keywords: KEYWORDS$1$1,
          contains: ["self"].concat(SUBST_AND_COMMENTS)
        }
      ]);
      const PARAMS = {
        className: 'params',
        begin: /\(/,
        end: /\)/,
        excludeBegin: true,
        excludeEnd: true,
        keywords: KEYWORDS$1$1,
        contains: PARAMS_CONTAINS
      };
      const CLASS_OR_EXTENDS = {
        variants: [
          {
            match: [
              /class/,
              /\s+/,
              IDENT_RE$1$1,
              /\s+/,
              /extends/,
              /\s+/,
              regex.concat(IDENT_RE$1$1, "(", regex.concat(/\./, IDENT_RE$1$1), ")*")
            ],
            scope: {
              1: "keyword",
              3: "title.class",
              5: "keyword",
              7: "title.class.inherited"
            }
          },
          {
            match: [
              /class/,
              /\s+/,
              IDENT_RE$1$1
            ],
            scope: {
              1: "keyword",
              3: "title.class"
            }
          },
        ]
      };
      const CLASS_REFERENCE = {
        relevance: 0,
        match:
        regex.either(
          /\bJSON/,
          /\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,
          /\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,
          /\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/,
        ),
        className: "title.class",
        keywords: {
          _: [
            ...TYPES$1,
            ...ERROR_TYPES$1
          ]
        }
      };
      const USE_STRICT = {
        label: "use_strict",
        className: 'meta',
        relevance: 10,
        begin: /^\s*['"]use (strict|asm)['"]/
      };
      const FUNCTION_DEFINITION = {
        variants: [
          {
            match: [
              /function/,
              /\s+/,
              IDENT_RE$1$1,
              /(?=\s*\()/
            ]
          },
          {
            match: [
              /function/,
              /\s*(?=\()/
            ]
          }
        ],
        className: {
          1: "keyword",
          3: "title.function"
        },
        label: "func.def",
        contains: [ PARAMS ],
        illegal: /%/
      };
      const UPPER_CASE_CONSTANT = {
        relevance: 0,
        match: /\b[A-Z][A-Z_0-9]+\b/,
        className: "variable.constant"
      };
      function noneOf(list) {
        return regex.concat("(?!", list.join("|"), ")");
      }
      const FUNCTION_CALL = {
        match: regex.concat(
          /\b/,
          noneOf([
            ...BUILT_IN_GLOBALS$1,
            "super"
          ]),
          IDENT_RE$1$1, regex.lookahead(/\(/)),
        className: "title.function",
        relevance: 0
      };
      const PROPERTY_ACCESS = {
        begin: regex.concat(/\./, regex.lookahead(
          regex.concat(IDENT_RE$1$1, /(?![0-9A-Za-z$_(])/)
        )),
        end: IDENT_RE$1$1,
        excludeBegin: true,
        keywords: "prototype",
        className: "property",
        relevance: 0
      };
      const GETTER_OR_SETTER = {
        match: [
          /get|set/,
          /\s+/,
          IDENT_RE$1$1,
          /(?=\()/
        ],
        className: {
          1: "keyword",
          3: "title.function"
        },
        contains: [
          {
            begin: /\(\)/
          },
          PARAMS
        ]
      };
      const FUNC_LEAD_IN_RE = '(\\(' +
        '[^()]*(\\(' +
        '[^()]*(\\(' +
        '[^()]*' +
        '\\)[^()]*)*' +
        '\\)[^()]*)*' +
        '\\)|' + hljs.UNDERSCORE_IDENT_RE + ')\\s*=>';
      const FUNCTION_VARIABLE = {
        match: [
          /const|var|let/, /\s+/,
          IDENT_RE$1$1, /\s*/,
          /=\s*/,
          /(async\s*)?/,
          regex.lookahead(FUNC_LEAD_IN_RE)
        ],
        keywords: "async",
        className: {
          1: "keyword",
          3: "title.function"
        },
        contains: [
          PARAMS
        ]
      };
      return {
        name: 'Javascript',
        aliases: ['js', 'jsx', 'mjs', 'cjs'],
        keywords: KEYWORDS$1$1,
        exports: { PARAMS_CONTAINS, CLASS_REFERENCE },
        illegal: /#(?![$_A-z])/,
        contains: [
          hljs.SHEBANG({
            label: "shebang",
            binary: "node",
            relevance: 5
          }),
          USE_STRICT,
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          HTML_TEMPLATE,
          CSS_TEMPLATE,
          TEMPLATE_STRING,
          COMMENT,
          NUMBER,
          CLASS_REFERENCE,
          {
            className: 'attr',
            begin: IDENT_RE$1$1 + regex.lookahead(':'),
            relevance: 0
          },
          FUNCTION_VARIABLE,
          {
            begin: '(' + hljs.RE_STARTERS_RE + '|\\b(case|return|throw)\\b)\\s*',
            keywords: 'return throw case',
            relevance: 0,
            contains: [
              COMMENT,
              hljs.REGEXP_MODE,
              {
                className: 'function',
                begin: FUNC_LEAD_IN_RE,
                returnBegin: true,
                end: '\\s*=>',
                contains: [
                  {
                    className: 'params',
                    variants: [
                      {
                        begin: hljs.UNDERSCORE_IDENT_RE,
                        relevance: 0
                      },
                      {
                        className: null,
                        begin: /\(\s*\)/,
                        skip: true
                      },
                      {
                        begin: /\(/,
                        end: /\)/,
                        excludeBegin: true,
                        excludeEnd: true,
                        keywords: KEYWORDS$1$1,
                        contains: PARAMS_CONTAINS
                      }
                    ]
                  }
                ]
              },
              {
                begin: /,/,
                relevance: 0
              },
              {
                match: /\s+/,
                relevance: 0
              },
              {
                variants: [
                  { begin: FRAGMENT.begin, end: FRAGMENT.end },
                  { match: XML_SELF_CLOSING },
                  {
                    begin: XML_TAG.begin,
                    'on:begin': XML_TAG.isTrulyOpeningTag,
                    end: XML_TAG.end
                  }
                ],
                subLanguage: 'xml',
                contains: [
                  {
                    begin: XML_TAG.begin,
                    end: XML_TAG.end,
                    skip: true,
                    contains: ['self']
                  }
                ]
              }
            ],
          },
          FUNCTION_DEFINITION,
          {
            beginKeywords: "while if switch catch for"
          },
          {
            begin: '\\b(?!function)' + hljs.UNDERSCORE_IDENT_RE +
              '\\(' +
              '[^()]*(\\(' +
                '[^()]*(\\(' +
                  '[^()]*' +
                '\\)[^()]*)*' +
              '\\)[^()]*)*' +
              '\\)\\s*\\{',
            returnBegin:true,
            label: "func.def",
            contains: [
              PARAMS,
              hljs.inherit(hljs.TITLE_MODE, { begin: IDENT_RE$1$1, className: "title.function" })
            ]
          },
          {
            match: /\.\.\./,
            relevance: 0
          },
          PROPERTY_ACCESS,
          {
            match: '\\$' + IDENT_RE$1$1,
            relevance: 0
          },
          {
            match: [ /\bconstructor(?=\s*\()/ ],
            className: { 1: "title.function" },
            contains: [ PARAMS ]
          },
          FUNCTION_CALL,
          UPPER_CASE_CONSTANT,
          CLASS_OR_EXTENDS,
          GETTER_OR_SETTER,
          {
            match: /\$[(.]/
          }
        ]
      };
    }

    function julia(hljs) {
      const VARIABLE_NAME_RE = '[A-Za-z_\\u00A1-\\uFFFF][A-Za-z_0-9\\u00A1-\\uFFFF]*';
      const KEYWORD_LIST = [
        'baremodule',
        'begin',
        'break',
        'catch',
        'ccall',
        'const',
        'continue',
        'do',
        'else',
        'elseif',
        'end',
        'export',
        'false',
        'finally',
        'for',
        'function',
        'global',
        'if',
        'import',
        'in',
        'isa',
        'let',
        'local',
        'macro',
        'module',
        'quote',
        'return',
        'true',
        'try',
        'using',
        'where',
        'while',
      ];
      const LITERAL_LIST = [
        'ARGS',
        'C_NULL',
        'DEPOT_PATH',
        'ENDIAN_BOM',
        'ENV',
        'Inf',
        'Inf16',
        'Inf32',
        'Inf64',
        'InsertionSort',
        'LOAD_PATH',
        'MergeSort',
        'NaN',
        'NaN16',
        'NaN32',
        'NaN64',
        'PROGRAM_FILE',
        'QuickSort',
        'RoundDown',
        'RoundFromZero',
        'RoundNearest',
        'RoundNearestTiesAway',
        'RoundNearestTiesUp',
        'RoundToZero',
        'RoundUp',
        'VERSION|0',
        'devnull',
        'false',
        'im',
        'missing',
        'nothing',
        'pi',
        'stderr',
        'stdin',
        'stdout',
        'true',
        'undef',
        'π',
        'ℯ',
      ];
      const BUILT_IN_LIST = [
        'AbstractArray',
        'AbstractChannel',
        'AbstractChar',
        'AbstractDict',
        'AbstractDisplay',
        'AbstractFloat',
        'AbstractIrrational',
        'AbstractMatrix',
        'AbstractRange',
        'AbstractSet',
        'AbstractString',
        'AbstractUnitRange',
        'AbstractVecOrMat',
        'AbstractVector',
        'Any',
        'ArgumentError',
        'Array',
        'AssertionError',
        'BigFloat',
        'BigInt',
        'BitArray',
        'BitMatrix',
        'BitSet',
        'BitVector',
        'Bool',
        'BoundsError',
        'CapturedException',
        'CartesianIndex',
        'CartesianIndices',
        'Cchar',
        'Cdouble',
        'Cfloat',
        'Channel',
        'Char',
        'Cint',
        'Cintmax_t',
        'Clong',
        'Clonglong',
        'Cmd',
        'Colon',
        'Complex',
        'ComplexF16',
        'ComplexF32',
        'ComplexF64',
        'CompositeException',
        'Condition',
        'Cptrdiff_t',
        'Cshort',
        'Csize_t',
        'Cssize_t',
        'Cstring',
        'Cuchar',
        'Cuint',
        'Cuintmax_t',
        'Culong',
        'Culonglong',
        'Cushort',
        'Cvoid',
        'Cwchar_t',
        'Cwstring',
        'DataType',
        'DenseArray',
        'DenseMatrix',
        'DenseVecOrMat',
        'DenseVector',
        'Dict',
        'DimensionMismatch',
        'Dims',
        'DivideError',
        'DomainError',
        'EOFError',
        'Enum',
        'ErrorException',
        'Exception',
        'ExponentialBackOff',
        'Expr',
        'Float16',
        'Float32',
        'Float64',
        'Function',
        'GlobalRef',
        'HTML',
        'IO',
        'IOBuffer',
        'IOContext',
        'IOStream',
        'IdDict',
        'IndexCartesian',
        'IndexLinear',
        'IndexStyle',
        'InexactError',
        'InitError',
        'Int',
        'Int128',
        'Int16',
        'Int32',
        'Int64',
        'Int8',
        'Integer',
        'InterruptException',
        'InvalidStateException',
        'Irrational',
        'KeyError',
        'LinRange',
        'LineNumberNode',
        'LinearIndices',
        'LoadError',
        'MIME',
        'Matrix',
        'Method',
        'MethodError',
        'Missing',
        'MissingException',
        'Module',
        'NTuple',
        'NamedTuple',
        'Nothing',
        'Number',
        'OrdinalRange',
        'OutOfMemoryError',
        'OverflowError',
        'Pair',
        'PartialQuickSort',
        'PermutedDimsArray',
        'Pipe',
        'ProcessFailedException',
        'Ptr',
        'QuoteNode',
        'Rational',
        'RawFD',
        'ReadOnlyMemoryError',
        'Real',
        'ReentrantLock',
        'Ref',
        'Regex',
        'RegexMatch',
        'RoundingMode',
        'SegmentationFault',
        'Set',
        'Signed',
        'Some',
        'StackOverflowError',
        'StepRange',
        'StepRangeLen',
        'StridedArray',
        'StridedMatrix',
        'StridedVecOrMat',
        'StridedVector',
        'String',
        'StringIndexError',
        'SubArray',
        'SubString',
        'SubstitutionString',
        'Symbol',
        'SystemError',
        'Task',
        'TaskFailedException',
        'Text',
        'TextDisplay',
        'Timer',
        'Tuple',
        'Type',
        'TypeError',
        'TypeVar',
        'UInt',
        'UInt128',
        'UInt16',
        'UInt32',
        'UInt64',
        'UInt8',
        'UndefInitializer',
        'UndefKeywordError',
        'UndefRefError',
        'UndefVarError',
        'Union',
        'UnionAll',
        'UnitRange',
        'Unsigned',
        'Val',
        'Vararg',
        'VecElement',
        'VecOrMat',
        'Vector',
        'VersionNumber',
        'WeakKeyDict',
        'WeakRef',
      ];
      const KEYWORDS = {
        $pattern: VARIABLE_NAME_RE,
        keyword: KEYWORD_LIST,
        literal: LITERAL_LIST,
        built_in: BUILT_IN_LIST,
      };
      const DEFAULT = {
        keywords: KEYWORDS,
        illegal: /<\//
      };
      const NUMBER = {
        className: 'number',
        begin: /(\b0x[\d_]*(\.[\d_]*)?|0x\.\d[\d_]*)p[-+]?\d+|\b0[box][a-fA-F0-9][a-fA-F0-9_]*|(\b\d[\d_]*(\.[\d_]*)?|\.\d[\d_]*)([eEfF][-+]?\d+)?/,
        relevance: 0
      };
      const CHAR = {
        className: 'string',
        begin: /'(.|\\[xXuU][a-zA-Z0-9]+)'/
      };
      const INTERPOLATION = {
        className: 'subst',
        begin: /\$\(/,
        end: /\)/,
        keywords: KEYWORDS
      };
      const INTERPOLATED_VARIABLE = {
        className: 'variable',
        begin: '\\$' + VARIABLE_NAME_RE
      };
      const STRING = {
        className: 'string',
        contains: [
          hljs.BACKSLASH_ESCAPE,
          INTERPOLATION,
          INTERPOLATED_VARIABLE
        ],
        variants: [
          {
            begin: /\w*"""/,
            end: /"""\w*/,
            relevance: 10
          },
          {
            begin: /\w*"/,
            end: /"\w*/
          }
        ]
      };
      const COMMAND = {
        className: 'string',
        contains: [
          hljs.BACKSLASH_ESCAPE,
          INTERPOLATION,
          INTERPOLATED_VARIABLE
        ],
        begin: '`',
        end: '`'
      };
      const MACROCALL = {
        className: 'meta',
        begin: '@' + VARIABLE_NAME_RE
      };
      const COMMENT = {
        className: 'comment',
        variants: [
          {
            begin: '#=',
            end: '=#',
            relevance: 10
          },
          {
            begin: '#',
            end: '$'
          }
        ]
      };
      DEFAULT.name = 'Julia';
      DEFAULT.contains = [
        NUMBER,
        CHAR,
        STRING,
        COMMAND,
        MACROCALL,
        COMMENT,
        hljs.HASH_COMMENT_MODE,
        {
          className: 'keyword',
          begin:
            '\\b(((abstract|primitive)\\s+)type|(mutable\\s+)?struct)\\b'
        },
        { begin: /<:/ }
      ];
      INTERPOLATION.contains = DEFAULT.contains;
      return DEFAULT;
    }

    var decimalDigits = '[0-9](_*[0-9])*';
    var frac = `\\.(${decimalDigits})`;
    var hexDigits = '[0-9a-fA-F](_*[0-9a-fA-F])*';
    var NUMERIC = {
      className: 'number',
      variants: [
        { begin: `(\\b(${decimalDigits})((${frac})|\\.)?|(${frac}))` +
          `[eE][+-]?(${decimalDigits})[fFdD]?\\b` },
        { begin: `\\b(${decimalDigits})((${frac})[fFdD]?\\b|\\.([fFdD]\\b)?)` },
        { begin: `(${frac})[fFdD]?\\b` },
        { begin: `\\b(${decimalDigits})[fFdD]\\b` },
        { begin: `\\b0[xX]((${hexDigits})\\.?|(${hexDigits})?\\.(${hexDigits}))` +
          `[pP][+-]?(${decimalDigits})[fFdD]?\\b` },
        { begin: '\\b(0|[1-9](_*[0-9])*)[lL]?\\b' },
        { begin: `\\b0[xX](${hexDigits})[lL]?\\b` },
        { begin: '\\b0(_*[0-7])*[lL]?\\b' },
        { begin: '\\b0[bB][01](_*[01])*[lL]?\\b' },
      ],
      relevance: 0
    };
    function kotlin(hljs) {
      const KEYWORDS = {
        keyword:
          'abstract as val var vararg get set class object open private protected public noinline '
          + 'crossinline dynamic final enum if else do while for when throw try catch finally '
          + 'import package is in fun override companion reified inline lateinit init '
          + 'interface annotation data sealed internal infix operator out by constructor super '
          + 'tailrec where const inner suspend typealias external expect actual',
        built_in:
          'Byte Short Char Int Long Boolean Float Double Void Unit Nothing',
        literal:
          'true false null'
      };
      const KEYWORDS_WITH_LABEL = {
        className: 'keyword',
        begin: /\b(break|continue|return|this)\b/,
        starts: { contains: [
          {
            className: 'symbol',
            begin: /@\w+/
          }
        ] }
      };
      const LABEL = {
        className: 'symbol',
        begin: hljs.UNDERSCORE_IDENT_RE + '@'
      };
      const SUBST = {
        className: 'subst',
        begin: /\$\{/,
        end: /\}/,
        contains: [ hljs.C_NUMBER_MODE ]
      };
      const VARIABLE = {
        className: 'variable',
        begin: '\\$' + hljs.UNDERSCORE_IDENT_RE
      };
      const STRING = {
        className: 'string',
        variants: [
          {
            begin: '"""',
            end: '"""(?=[^"])',
            contains: [
              VARIABLE,
              SUBST
            ]
          },
          {
            begin: '\'',
            end: '\'',
            illegal: /\n/,
            contains: [ hljs.BACKSLASH_ESCAPE ]
          },
          {
            begin: '"',
            end: '"',
            illegal: /\n/,
            contains: [
              hljs.BACKSLASH_ESCAPE,
              VARIABLE,
              SUBST
            ]
          }
        ]
      };
      SUBST.contains.push(STRING);
      const ANNOTATION_USE_SITE = {
        className: 'meta',
        begin: '@(?:file|property|field|get|set|receiver|param|setparam|delegate)\\s*:(?:\\s*' + hljs.UNDERSCORE_IDENT_RE + ')?'
      };
      const ANNOTATION = {
        className: 'meta',
        begin: '@' + hljs.UNDERSCORE_IDENT_RE,
        contains: [
          {
            begin: /\(/,
            end: /\)/,
            contains: [
              hljs.inherit(STRING, { className: 'string' }),
              "self"
            ]
          }
        ]
      };
      const KOTLIN_NUMBER_MODE = NUMERIC;
      const KOTLIN_NESTED_COMMENT = hljs.COMMENT(
        '/\\*', '\\*/',
        { contains: [ hljs.C_BLOCK_COMMENT_MODE ] }
      );
      const KOTLIN_PAREN_TYPE = { variants: [
        {
          className: 'type',
          begin: hljs.UNDERSCORE_IDENT_RE
        },
        {
          begin: /\(/,
          end: /\)/,
          contains: []
        }
      ] };
      const KOTLIN_PAREN_TYPE2 = KOTLIN_PAREN_TYPE;
      KOTLIN_PAREN_TYPE2.variants[1].contains = [ KOTLIN_PAREN_TYPE ];
      KOTLIN_PAREN_TYPE.variants[1].contains = [ KOTLIN_PAREN_TYPE2 ];
      return {
        name: 'Kotlin',
        aliases: [
          'kt',
          'kts'
        ],
        keywords: KEYWORDS,
        contains: [
          hljs.COMMENT(
            '/\\*\\*',
            '\\*/',
            {
              relevance: 0,
              contains: [
                {
                  className: 'doctag',
                  begin: '@[A-Za-z]+'
                }
              ]
            }
          ),
          hljs.C_LINE_COMMENT_MODE,
          KOTLIN_NESTED_COMMENT,
          KEYWORDS_WITH_LABEL,
          LABEL,
          ANNOTATION_USE_SITE,
          ANNOTATION,
          {
            className: 'function',
            beginKeywords: 'fun',
            end: '[(]|$',
            returnBegin: true,
            excludeEnd: true,
            keywords: KEYWORDS,
            relevance: 5,
            contains: [
              {
                begin: hljs.UNDERSCORE_IDENT_RE + '\\s*\\(',
                returnBegin: true,
                relevance: 0,
                contains: [ hljs.UNDERSCORE_TITLE_MODE ]
              },
              {
                className: 'type',
                begin: /</,
                end: />/,
                keywords: 'reified',
                relevance: 0
              },
              {
                className: 'params',
                begin: /\(/,
                end: /\)/,
                endsParent: true,
                keywords: KEYWORDS,
                relevance: 0,
                contains: [
                  {
                    begin: /:/,
                    end: /[=,\/]/,
                    endsWithParent: true,
                    contains: [
                      KOTLIN_PAREN_TYPE,
                      hljs.C_LINE_COMMENT_MODE,
                      KOTLIN_NESTED_COMMENT
                    ],
                    relevance: 0
                  },
                  hljs.C_LINE_COMMENT_MODE,
                  KOTLIN_NESTED_COMMENT,
                  ANNOTATION_USE_SITE,
                  ANNOTATION,
                  STRING,
                  hljs.C_NUMBER_MODE
                ]
              },
              KOTLIN_NESTED_COMMENT
            ]
          },
          {
            begin: [
              /class|interface|trait/,
              /\s+/,
              hljs.UNDERSCORE_IDENT_RE
            ],
            beginScope: {
              3: "title.class"
            },
            keywords: 'class interface trait',
            end: /[:\{(]|$/,
            excludeEnd: true,
            illegal: 'extends implements',
            contains: [
              { beginKeywords: 'public protected internal private constructor' },
              hljs.UNDERSCORE_TITLE_MODE,
              {
                className: 'type',
                begin: /</,
                end: />/,
                excludeBegin: true,
                excludeEnd: true,
                relevance: 0
              },
              {
                className: 'type',
                begin: /[,:]\s*/,
                end: /[<\(,){\s]|$/,
                excludeBegin: true,
                returnEnd: true
              },
              ANNOTATION_USE_SITE,
              ANNOTATION
            ]
          },
          STRING,
          {
            className: 'meta',
            begin: "^#!/usr/bin/env",
            end: '$',
            illegal: '\n'
          },
          KOTLIN_NUMBER_MODE
        ]
      };
    }

    function lua(hljs) {
      const OPENING_LONG_BRACKET = '\\[=*\\[';
      const CLOSING_LONG_BRACKET = '\\]=*\\]';
      const LONG_BRACKETS = {
        begin: OPENING_LONG_BRACKET,
        end: CLOSING_LONG_BRACKET,
        contains: [ 'self' ]
      };
      const COMMENTS = [
        hljs.COMMENT('--(?!' + OPENING_LONG_BRACKET + ')', '$'),
        hljs.COMMENT(
          '--' + OPENING_LONG_BRACKET,
          CLOSING_LONG_BRACKET,
          {
            contains: [ LONG_BRACKETS ],
            relevance: 10
          }
        )
      ];
      return {
        name: 'Lua',
        keywords: {
          $pattern: hljs.UNDERSCORE_IDENT_RE,
          literal: "true false nil",
          keyword: "and break do else elseif end for goto if in local not or repeat return then until while",
          built_in:
            '_G _ENV _VERSION __index __newindex __mode __call __metatable __tostring __len '
            + '__gc __add __sub __mul __div __mod __pow __concat __unm __eq __lt __le assert '
            + 'collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring '
            + 'module next pairs pcall print rawequal rawget rawset require select setfenv '
            + 'setmetatable tonumber tostring type unpack xpcall arg self '
            + 'coroutine resume yield status wrap create running debug getupvalue '
            + 'debug sethook getmetatable gethook setmetatable setlocal traceback setfenv getinfo setupvalue getlocal getregistry getfenv '
            + 'io lines write close flush open output type read stderr stdin input stdout popen tmpfile '
            + 'math log max acos huge ldexp pi cos tanh pow deg tan cosh sinh random randomseed frexp ceil floor rad abs sqrt modf asin min mod fmod log10 atan2 exp sin atan '
            + 'os exit setlocale date getenv difftime remove time clock tmpname rename execute package preload loadlib loaded loaders cpath config path seeall '
            + 'string sub upper len gfind rep find match char dump gmatch reverse byte format gsub lower '
            + 'table setn insert getn foreachi maxn foreach concat sort remove'
        },
        contains: COMMENTS.concat([
          {
            className: 'function',
            beginKeywords: 'function',
            end: '\\)',
            contains: [
              hljs.inherit(hljs.TITLE_MODE, { begin: '([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*' }),
              {
                className: 'params',
                begin: '\\(',
                endsWithParent: true,
                contains: COMMENTS
              }
            ].concat(COMMENTS)
          },
          hljs.C_NUMBER_MODE,
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          {
            className: 'string',
            begin: OPENING_LONG_BRACKET,
            end: CLOSING_LONG_BRACKET,
            contains: [ LONG_BRACKETS ],
            relevance: 5
          }
        ])
      };
    }

    function markdown(hljs) {
      const regex = hljs.regex;
      const INLINE_HTML = {
        begin: /<\/?[A-Za-z_]/,
        end: '>',
        subLanguage: 'xml',
        relevance: 0
      };
      const HORIZONTAL_RULE = {
        begin: '^[-\\*]{3,}',
        end: '$'
      };
      const CODE = {
        className: 'code',
        variants: [
          { begin: '(`{3,})[^`](.|\\n)*?\\1`*[ ]*' },
          { begin: '(~{3,})[^~](.|\\n)*?\\1~*[ ]*' },
          {
            begin: '```',
            end: '```+[ ]*$'
          },
          {
            begin: '~~~',
            end: '~~~+[ ]*$'
          },
          { begin: '`.+?`' },
          {
            begin: '(?=^( {4}|\\t))',
            contains: [
              {
                begin: '^( {4}|\\t)',
                end: '(\\n)$'
              }
            ],
            relevance: 0
          }
        ]
      };
      const LIST = {
        className: 'bullet',
        begin: '^[ \t]*([*+-]|(\\d+\\.))(?=\\s+)',
        end: '\\s+',
        excludeEnd: true
      };
      const LINK_REFERENCE = {
        begin: /^\[[^\n]+\]:/,
        returnBegin: true,
        contains: [
          {
            className: 'symbol',
            begin: /\[/,
            end: /\]/,
            excludeBegin: true,
            excludeEnd: true
          },
          {
            className: 'link',
            begin: /:\s*/,
            end: /$/,
            excludeBegin: true
          }
        ]
      };
      const URL_SCHEME = /[A-Za-z][A-Za-z0-9+.-]*/;
      const LINK = {
        variants: [
          {
            begin: /\[.+?\]\[.*?\]/,
            relevance: 0
          },
          {
            begin: /\[.+?\]\(((data|javascript|mailto):|(?:http|ftp)s?:\/\/).*?\)/,
            relevance: 2
          },
          {
            begin: regex.concat(/\[.+?\]\(/, URL_SCHEME, /:\/\/.*?\)/),
            relevance: 2
          },
          {
            begin: /\[.+?\]\([./?&#].*?\)/,
            relevance: 1
          },
          {
            begin: /\[.*?\]\(.*?\)/,
            relevance: 0
          }
        ],
        returnBegin: true,
        contains: [
          {
            match: /\[(?=\])/ },
          {
            className: 'string',
            relevance: 0,
            begin: '\\[',
            end: '\\]',
            excludeBegin: true,
            returnEnd: true
          },
          {
            className: 'link',
            relevance: 0,
            begin: '\\]\\(',
            end: '\\)',
            excludeBegin: true,
            excludeEnd: true
          },
          {
            className: 'symbol',
            relevance: 0,
            begin: '\\]\\[',
            end: '\\]',
            excludeBegin: true,
            excludeEnd: true
          }
        ]
      };
      const BOLD = {
        className: 'strong',
        contains: [],
        variants: [
          {
            begin: /_{2}/,
            end: /_{2}/
          },
          {
            begin: /\*{2}/,
            end: /\*{2}/
          }
        ]
      };
      const ITALIC = {
        className: 'emphasis',
        contains: [],
        variants: [
          {
            begin: /\*(?!\*)/,
            end: /\*/
          },
          {
            begin: /_(?!_)/,
            end: /_/,
            relevance: 0
          }
        ]
      };
      const BOLD_WITHOUT_ITALIC = hljs.inherit(BOLD, { contains: [] });
      const ITALIC_WITHOUT_BOLD = hljs.inherit(ITALIC, { contains: [] });
      BOLD.contains.push(ITALIC_WITHOUT_BOLD);
      ITALIC.contains.push(BOLD_WITHOUT_ITALIC);
      let CONTAINABLE = [
        INLINE_HTML,
        LINK
      ];
      [
        BOLD,
        ITALIC,
        BOLD_WITHOUT_ITALIC,
        ITALIC_WITHOUT_BOLD
      ].forEach(m => {
        m.contains = m.contains.concat(CONTAINABLE);
      });
      CONTAINABLE = CONTAINABLE.concat(BOLD, ITALIC);
      const HEADER = {
        className: 'section',
        variants: [
          {
            begin: '^#{1,6}',
            end: '$',
            contains: CONTAINABLE
          },
          {
            begin: '(?=^.+?\\n[=-]{2,}$)',
            contains: [
              { begin: '^[=-]*$' },
              {
                begin: '^',
                end: "\\n",
                contains: CONTAINABLE
              }
            ]
          }
        ]
      };
      const BLOCKQUOTE = {
        className: 'quote',
        begin: '^>\\s+',
        contains: CONTAINABLE,
        end: '$'
      };
      return {
        name: 'Markdown',
        aliases: [
          'md',
          'mkdown',
          'mkd'
        ],
        contains: [
          HEADER,
          INLINE_HTML,
          LIST,
          BOLD,
          ITALIC,
          BLOCKQUOTE,
          CODE,
          HORIZONTAL_RULE,
          LINK,
          LINK_REFERENCE
        ]
      };
    }

    function perl(hljs) {
      const regex = hljs.regex;
      const KEYWORDS = [
        'abs',
        'accept',
        'alarm',
        'and',
        'atan2',
        'bind',
        'binmode',
        'bless',
        'break',
        'caller',
        'chdir',
        'chmod',
        'chomp',
        'chop',
        'chown',
        'chr',
        'chroot',
        'close',
        'closedir',
        'connect',
        'continue',
        'cos',
        'crypt',
        'dbmclose',
        'dbmopen',
        'defined',
        'delete',
        'die',
        'do',
        'dump',
        'each',
        'else',
        'elsif',
        'endgrent',
        'endhostent',
        'endnetent',
        'endprotoent',
        'endpwent',
        'endservent',
        'eof',
        'eval',
        'exec',
        'exists',
        'exit',
        'exp',
        'fcntl',
        'fileno',
        'flock',
        'for',
        'foreach',
        'fork',
        'format',
        'formline',
        'getc',
        'getgrent',
        'getgrgid',
        'getgrnam',
        'gethostbyaddr',
        'gethostbyname',
        'gethostent',
        'getlogin',
        'getnetbyaddr',
        'getnetbyname',
        'getnetent',
        'getpeername',
        'getpgrp',
        'getpriority',
        'getprotobyname',
        'getprotobynumber',
        'getprotoent',
        'getpwent',
        'getpwnam',
        'getpwuid',
        'getservbyname',
        'getservbyport',
        'getservent',
        'getsockname',
        'getsockopt',
        'given',
        'glob',
        'gmtime',
        'goto',
        'grep',
        'gt',
        'hex',
        'if',
        'index',
        'int',
        'ioctl',
        'join',
        'keys',
        'kill',
        'last',
        'lc',
        'lcfirst',
        'length',
        'link',
        'listen',
        'local',
        'localtime',
        'log',
        'lstat',
        'lt',
        'ma',
        'map',
        'mkdir',
        'msgctl',
        'msgget',
        'msgrcv',
        'msgsnd',
        'my',
        'ne',
        'next',
        'no',
        'not',
        'oct',
        'open',
        'opendir',
        'or',
        'ord',
        'our',
        'pack',
        'package',
        'pipe',
        'pop',
        'pos',
        'print',
        'printf',
        'prototype',
        'push',
        'q|0',
        'qq',
        'quotemeta',
        'qw',
        'qx',
        'rand',
        'read',
        'readdir',
        'readline',
        'readlink',
        'readpipe',
        'recv',
        'redo',
        'ref',
        'rename',
        'require',
        'reset',
        'return',
        'reverse',
        'rewinddir',
        'rindex',
        'rmdir',
        'say',
        'scalar',
        'seek',
        'seekdir',
        'select',
        'semctl',
        'semget',
        'semop',
        'send',
        'setgrent',
        'sethostent',
        'setnetent',
        'setpgrp',
        'setpriority',
        'setprotoent',
        'setpwent',
        'setservent',
        'setsockopt',
        'shift',
        'shmctl',
        'shmget',
        'shmread',
        'shmwrite',
        'shutdown',
        'sin',
        'sleep',
        'socket',
        'socketpair',
        'sort',
        'splice',
        'split',
        'sprintf',
        'sqrt',
        'srand',
        'stat',
        'state',
        'study',
        'sub',
        'substr',
        'symlink',
        'syscall',
        'sysopen',
        'sysread',
        'sysseek',
        'system',
        'syswrite',
        'tell',
        'telldir',
        'tie',
        'tied',
        'time',
        'times',
        'tr',
        'truncate',
        'uc',
        'ucfirst',
        'umask',
        'undef',
        'unless',
        'unlink',
        'unpack',
        'unshift',
        'untie',
        'until',
        'use',
        'utime',
        'values',
        'vec',
        'wait',
        'waitpid',
        'wantarray',
        'warn',
        'when',
        'while',
        'write',
        'x|0',
        'xor',
        'y|0'
      ];
      const REGEX_MODIFIERS = /[dualxmsipngr]{0,12}/;
      const PERL_KEYWORDS = {
        $pattern: /[\w.]+/,
        keyword: KEYWORDS.join(" ")
      };
      const SUBST = {
        className: 'subst',
        begin: '[$@]\\{',
        end: '\\}',
        keywords: PERL_KEYWORDS
      };
      const METHOD = {
        begin: /->\{/,
        end: /\}/
      };
      const VAR = { variants: [
        { begin: /\$\d/ },
        { begin: regex.concat(
          /[$%@](\^\w\b|#\w+(::\w+)*|\{\w+\}|\w+(::\w*)*)/,
          `(?![A-Za-z])(?![@$%])`
        ) },
        {
          begin: /[$%@][^\s\w{]/,
          relevance: 0
        }
      ] };
      const STRING_CONTAINS = [
        hljs.BACKSLASH_ESCAPE,
        SUBST,
        VAR
      ];
      const REGEX_DELIMS = [
        /!/,
        /\//,
        /\|/,
        /\?/,
        /'/,
        /"/,
        /#/
      ];
      const PAIRED_DOUBLE_RE = (prefix, open, close = '\\1') => {
        const middle = (close === '\\1')
          ? close
          : regex.concat(close, open);
        return regex.concat(
          regex.concat("(?:", prefix, ")"),
          open,
          /(?:\\.|[^\\\/])*?/,
          middle,
          /(?:\\.|[^\\\/])*?/,
          close,
          REGEX_MODIFIERS
        );
      };
      const PAIRED_RE = (prefix, open, close) => {
        return regex.concat(
          regex.concat("(?:", prefix, ")"),
          open,
          /(?:\\.|[^\\\/])*?/,
          close,
          REGEX_MODIFIERS
        );
      };
      const PERL_DEFAULT_CONTAINS = [
        VAR,
        hljs.HASH_COMMENT_MODE,
        hljs.COMMENT(
          /^=\w/,
          /=cut/,
          { endsWithParent: true }
        ),
        METHOD,
        {
          className: 'string',
          contains: STRING_CONTAINS,
          variants: [
            {
              begin: 'q[qwxr]?\\s*\\(',
              end: '\\)',
              relevance: 5
            },
            {
              begin: 'q[qwxr]?\\s*\\[',
              end: '\\]',
              relevance: 5
            },
            {
              begin: 'q[qwxr]?\\s*\\{',
              end: '\\}',
              relevance: 5
            },
            {
              begin: 'q[qwxr]?\\s*\\|',
              end: '\\|',
              relevance: 5
            },
            {
              begin: 'q[qwxr]?\\s*<',
              end: '>',
              relevance: 5
            },
            {
              begin: 'qw\\s+q',
              end: 'q',
              relevance: 5
            },
            {
              begin: '\'',
              end: '\'',
              contains: [ hljs.BACKSLASH_ESCAPE ]
            },
            {
              begin: '"',
              end: '"'
            },
            {
              begin: '`',
              end: '`',
              contains: [ hljs.BACKSLASH_ESCAPE ]
            },
            {
              begin: /\{\w+\}/,
              relevance: 0
            },
            {
              begin: '-?\\w+\\s*=>',
              relevance: 0
            }
          ]
        },
        {
          className: 'number',
          begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
          relevance: 0
        },
        {
          begin: '(\\/\\/|' + hljs.RE_STARTERS_RE + '|\\b(split|return|print|reverse|grep)\\b)\\s*',
          keywords: 'split return print reverse grep',
          relevance: 0,
          contains: [
            hljs.HASH_COMMENT_MODE,
            {
              className: 'regexp',
              variants: [
                { begin: PAIRED_DOUBLE_RE("s|tr|y", regex.either(...REGEX_DELIMS, { capture: true })) },
                { begin: PAIRED_DOUBLE_RE("s|tr|y", "\\(", "\\)") },
                { begin: PAIRED_DOUBLE_RE("s|tr|y", "\\[", "\\]") },
                { begin: PAIRED_DOUBLE_RE("s|tr|y", "\\{", "\\}") }
              ],
              relevance: 2
            },
            {
              className: 'regexp',
              variants: [
                {
                  begin: /(m|qr)\/\//,
                  relevance: 0
                },
                { begin: PAIRED_RE("(?:m|qr)?", /\//, /\//) },
                { begin: PAIRED_RE("m|qr", regex.either(...REGEX_DELIMS, { capture: true }), /\1/) },
                { begin: PAIRED_RE("m|qr", /\(/, /\)/) },
                { begin: PAIRED_RE("m|qr", /\[/, /\]/) },
                { begin: PAIRED_RE("m|qr", /\{/, /\}/) }
              ]
            }
          ]
        },
        {
          className: 'function',
          beginKeywords: 'sub',
          end: '(\\s*\\(.*?\\))?[;{]',
          excludeEnd: true,
          relevance: 5,
          contains: [ hljs.TITLE_MODE ]
        },
        {
          begin: '-\\w\\b',
          relevance: 0
        },
        {
          begin: "^__DATA__$",
          end: "^__END__$",
          subLanguage: 'mojolicious',
          contains: [
            {
              begin: "^@@.*",
              end: "$",
              className: "comment"
            }
          ]
        }
      ];
      SUBST.contains = PERL_DEFAULT_CONTAINS;
      METHOD.contains = PERL_DEFAULT_CONTAINS;
      return {
        name: 'Perl',
        aliases: [
          'pl',
          'pm'
        ],
        keywords: PERL_KEYWORDS,
        contains: PERL_DEFAULT_CONTAINS
      };
    }

    function php(hljs) {
      const regex = hljs.regex;
      const NOT_PERL_ETC = /(?![A-Za-z0-9])(?![$])/;
      const IDENT_RE = regex.concat(
        /[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/,
        NOT_PERL_ETC);
      const PASCAL_CASE_CLASS_NAME_RE = regex.concat(
        /(\\?[A-Z][a-z0-9_\x7f-\xff]+|\\?[A-Z]+(?=[A-Z][a-z0-9_\x7f-\xff])){1,}/,
        NOT_PERL_ETC);
      const VARIABLE = {
        scope: 'variable',
        match: '\\$+' + IDENT_RE,
      };
      const PREPROCESSOR = {
        scope: 'meta',
        variants: [
          { begin: /<\?php/, relevance: 10 },
          { begin: /<\?=/ },
          { begin: /<\?/, relevance: 0.1 },
          { begin: /\?>/ }
        ]
      };
      const SUBST = {
        scope: 'subst',
        variants: [
          { begin: /\$\w+/ },
          {
            begin: /\{\$/,
            end: /\}/
          }
        ]
      };
      const SINGLE_QUOTED = hljs.inherit(hljs.APOS_STRING_MODE, { illegal: null, });
      const DOUBLE_QUOTED = hljs.inherit(hljs.QUOTE_STRING_MODE, {
        illegal: null,
        contains: hljs.QUOTE_STRING_MODE.contains.concat(SUBST),
      });
      const HEREDOC = hljs.END_SAME_AS_BEGIN({
        begin: /<<<[ \t]*(\w+)\n/,
        end: /[ \t]*(\w+)\b/,
        contains: hljs.QUOTE_STRING_MODE.contains.concat(SUBST),
      });
      const WHITESPACE = '[ \t\n]';
      const STRING = {
        scope: 'string',
        variants: [
          DOUBLE_QUOTED,
          SINGLE_QUOTED,
          HEREDOC
        ]
      };
      const NUMBER = {
        scope: 'number',
        variants: [
          { begin: `\\b0[bB][01]+(?:_[01]+)*\\b` },
          { begin: `\\b0[oO][0-7]+(?:_[0-7]+)*\\b` },
          { begin: `\\b0[xX][\\da-fA-F]+(?:_[\\da-fA-F]+)*\\b` },
          { begin: `(?:\\b\\d+(?:_\\d+)*(\\.(?:\\d+(?:_\\d+)*))?|\\B\\.\\d+)(?:[eE][+-]?\\d+)?` }
        ],
        relevance: 0
      };
      const LITERALS = [
        "false",
        "null",
        "true"
      ];
      const KWS = [
        "__CLASS__",
        "__DIR__",
        "__FILE__",
        "__FUNCTION__",
        "__COMPILER_HALT_OFFSET__",
        "__LINE__",
        "__METHOD__",
        "__NAMESPACE__",
        "__TRAIT__",
        "die",
        "echo",
        "exit",
        "include",
        "include_once",
        "print",
        "require",
        "require_once",
        "array",
        "abstract",
        "and",
        "as",
        "binary",
        "bool",
        "boolean",
        "break",
        "callable",
        "case",
        "catch",
        "class",
        "clone",
        "const",
        "continue",
        "declare",
        "default",
        "do",
        "double",
        "else",
        "elseif",
        "empty",
        "enddeclare",
        "endfor",
        "endforeach",
        "endif",
        "endswitch",
        "endwhile",
        "enum",
        "eval",
        "extends",
        "final",
        "finally",
        "float",
        "for",
        "foreach",
        "from",
        "global",
        "goto",
        "if",
        "implements",
        "instanceof",
        "insteadof",
        "int",
        "integer",
        "interface",
        "isset",
        "iterable",
        "list",
        "match|0",
        "mixed",
        "new",
        "never",
        "object",
        "or",
        "private",
        "protected",
        "public",
        "readonly",
        "real",
        "return",
        "string",
        "switch",
        "throw",
        "trait",
        "try",
        "unset",
        "use",
        "var",
        "void",
        "while",
        "xor",
        "yield"
      ];
      const BUILT_INS = [
        "Error|0",
        "AppendIterator",
        "ArgumentCountError",
        "ArithmeticError",
        "ArrayIterator",
        "ArrayObject",
        "AssertionError",
        "BadFunctionCallException",
        "BadMethodCallException",
        "CachingIterator",
        "CallbackFilterIterator",
        "CompileError",
        "Countable",
        "DirectoryIterator",
        "DivisionByZeroError",
        "DomainException",
        "EmptyIterator",
        "ErrorException",
        "Exception",
        "FilesystemIterator",
        "FilterIterator",
        "GlobIterator",
        "InfiniteIterator",
        "InvalidArgumentException",
        "IteratorIterator",
        "LengthException",
        "LimitIterator",
        "LogicException",
        "MultipleIterator",
        "NoRewindIterator",
        "OutOfBoundsException",
        "OutOfRangeException",
        "OuterIterator",
        "OverflowException",
        "ParentIterator",
        "ParseError",
        "RangeException",
        "RecursiveArrayIterator",
        "RecursiveCachingIterator",
        "RecursiveCallbackFilterIterator",
        "RecursiveDirectoryIterator",
        "RecursiveFilterIterator",
        "RecursiveIterator",
        "RecursiveIteratorIterator",
        "RecursiveRegexIterator",
        "RecursiveTreeIterator",
        "RegexIterator",
        "RuntimeException",
        "SeekableIterator",
        "SplDoublyLinkedList",
        "SplFileInfo",
        "SplFileObject",
        "SplFixedArray",
        "SplHeap",
        "SplMaxHeap",
        "SplMinHeap",
        "SplObjectStorage",
        "SplObserver",
        "SplPriorityQueue",
        "SplQueue",
        "SplStack",
        "SplSubject",
        "SplTempFileObject",
        "TypeError",
        "UnderflowException",
        "UnexpectedValueException",
        "UnhandledMatchError",
        "ArrayAccess",
        "BackedEnum",
        "Closure",
        "Fiber",
        "Generator",
        "Iterator",
        "IteratorAggregate",
        "Serializable",
        "Stringable",
        "Throwable",
        "Traversable",
        "UnitEnum",
        "WeakReference",
        "WeakMap",
        "Directory",
        "__PHP_Incomplete_Class",
        "parent",
        "php_user_filter",
        "self",
        "static",
        "stdClass"
      ];
      const dualCase = (items) => {
        const result = [];
        items.forEach(item => {
          result.push(item);
          if (item.toLowerCase() === item) {
            result.push(item.toUpperCase());
          } else {
            result.push(item.toLowerCase());
          }
        });
        return result;
      };
      const KEYWORDS = {
        keyword: KWS,
        literal: dualCase(LITERALS),
        built_in: BUILT_INS,
      };
      const normalizeKeywords = (items) => {
        return items.map(item => {
          return item.replace(/\|\d+$/, "");
        });
      };
      const CONSTRUCTOR_CALL = { variants: [
        {
          match: [
            /new/,
            regex.concat(WHITESPACE, "+"),
            regex.concat("(?!", normalizeKeywords(BUILT_INS).join("\\b|"), "\\b)"),
            PASCAL_CASE_CLASS_NAME_RE,
          ],
          scope: {
            1: "keyword",
            4: "title.class",
          },
        }
      ] };
      const CONSTANT_REFERENCE = regex.concat(IDENT_RE, "\\b(?!\\()");
      const LEFT_AND_RIGHT_SIDE_OF_DOUBLE_COLON = { variants: [
        {
          match: [
            regex.concat(
              /::/,
              regex.lookahead(/(?!class\b)/)
            ),
            CONSTANT_REFERENCE,
          ],
          scope: { 2: "variable.constant", },
        },
        {
          match: [
            /::/,
            /class/,
          ],
          scope: { 2: "variable.language", },
        },
        {
          match: [
            PASCAL_CASE_CLASS_NAME_RE,
            regex.concat(
              /::/,
              regex.lookahead(/(?!class\b)/)
            ),
            CONSTANT_REFERENCE,
          ],
          scope: {
            1: "title.class",
            3: "variable.constant",
          },
        },
        {
          match: [
            PASCAL_CASE_CLASS_NAME_RE,
            regex.concat(
              "::",
              regex.lookahead(/(?!class\b)/)
            ),
          ],
          scope: { 1: "title.class", },
        },
        {
          match: [
            PASCAL_CASE_CLASS_NAME_RE,
            /::/,
            /class/,
          ],
          scope: {
            1: "title.class",
            3: "variable.language",
          },
        }
      ] };
      const NAMED_ARGUMENT = {
        scope: 'attr',
        match: regex.concat(IDENT_RE, regex.lookahead(':'), regex.lookahead(/(?!::)/)),
      };
      const PARAMS_MODE = {
        relevance: 0,
        begin: /\(/,
        end: /\)/,
        keywords: KEYWORDS,
        contains: [
          NAMED_ARGUMENT,
          VARIABLE,
          LEFT_AND_RIGHT_SIDE_OF_DOUBLE_COLON,
          hljs.C_BLOCK_COMMENT_MODE,
          STRING,
          NUMBER,
          CONSTRUCTOR_CALL,
        ],
      };
      const FUNCTION_INVOKE = {
        relevance: 0,
        match: [
          /\b/,
          regex.concat("(?!fn\\b|function\\b|", normalizeKeywords(KWS).join("\\b|"), "|", normalizeKeywords(BUILT_INS).join("\\b|"), "\\b)"),
          IDENT_RE,
          regex.concat(WHITESPACE, "*"),
          regex.lookahead(/(?=\()/)
        ],
        scope: { 3: "title.function.invoke", },
        contains: [ PARAMS_MODE ]
      };
      PARAMS_MODE.contains.push(FUNCTION_INVOKE);
      const ATTRIBUTE_CONTAINS = [
        NAMED_ARGUMENT,
        LEFT_AND_RIGHT_SIDE_OF_DOUBLE_COLON,
        hljs.C_BLOCK_COMMENT_MODE,
        STRING,
        NUMBER,
        CONSTRUCTOR_CALL,
      ];
      const ATTRIBUTES = {
        begin: regex.concat(/#\[\s*/, PASCAL_CASE_CLASS_NAME_RE),
        beginScope: "meta",
        end: /]/,
        endScope: "meta",
        keywords: {
          literal: LITERALS,
          keyword: [
            'new',
            'array',
          ]
        },
        contains: [
          {
            begin: /\[/,
            end: /]/,
            keywords: {
              literal: LITERALS,
              keyword: [
                'new',
                'array',
              ]
            },
            contains: [
              'self',
              ...ATTRIBUTE_CONTAINS,
            ]
          },
          ...ATTRIBUTE_CONTAINS,
          {
            scope: 'meta',
            match: PASCAL_CASE_CLASS_NAME_RE
          }
        ]
      };
      return {
        case_insensitive: false,
        keywords: KEYWORDS,
        contains: [
          ATTRIBUTES,
          hljs.HASH_COMMENT_MODE,
          hljs.COMMENT('//', '$'),
          hljs.COMMENT(
            '/\\*',
            '\\*/',
            { contains: [
              {
                scope: 'doctag',
                match: '@[A-Za-z]+'
              }
            ] }
          ),
          {
            match: /__halt_compiler\(\);/,
            keywords: '__halt_compiler',
            starts: {
              scope: "comment",
              end: hljs.MATCH_NOTHING_RE,
              contains: [
                {
                  match: /\?>/,
                  scope: "meta",
                  endsParent: true
                }
              ]
            }
          },
          PREPROCESSOR,
          {
            scope: 'variable.language',
            match: /\$this\b/
          },
          VARIABLE,
          FUNCTION_INVOKE,
          LEFT_AND_RIGHT_SIDE_OF_DOUBLE_COLON,
          {
            match: [
              /const/,
              /\s/,
              IDENT_RE,
            ],
            scope: {
              1: "keyword",
              3: "variable.constant",
            },
          },
          CONSTRUCTOR_CALL,
          {
            scope: 'function',
            relevance: 0,
            beginKeywords: 'fn function',
            end: /[;{]/,
            excludeEnd: true,
            illegal: '[$%\\[]',
            contains: [
              { beginKeywords: 'use', },
              hljs.UNDERSCORE_TITLE_MODE,
              {
                begin: '=>',
                endsParent: true
              },
              {
                scope: 'params',
                begin: '\\(',
                end: '\\)',
                excludeBegin: true,
                excludeEnd: true,
                keywords: KEYWORDS,
                contains: [
                  'self',
                  VARIABLE,
                  LEFT_AND_RIGHT_SIDE_OF_DOUBLE_COLON,
                  hljs.C_BLOCK_COMMENT_MODE,
                  STRING,
                  NUMBER
                ]
              },
            ]
          },
          {
            scope: 'class',
            variants: [
              {
                beginKeywords: "enum",
                illegal: /[($"]/
              },
              {
                beginKeywords: "class interface trait",
                illegal: /[:($"]/
              }
            ],
            relevance: 0,
            end: /\{/,
            excludeEnd: true,
            contains: [
              { beginKeywords: 'extends implements' },
              hljs.UNDERSCORE_TITLE_MODE
            ]
          },
          {
            beginKeywords: 'namespace',
            relevance: 0,
            end: ';',
            illegal: /[.']/,
            contains: [ hljs.inherit(hljs.UNDERSCORE_TITLE_MODE, { scope: "title.class" }) ]
          },
          {
            beginKeywords: 'use',
            relevance: 0,
            end: ';',
            contains: [
              {
                match: /\b(as|const|function)\b/,
                scope: "keyword"
              },
              hljs.UNDERSCORE_TITLE_MODE
            ]
          },
          STRING,
          NUMBER,
        ]
      };
    }

    function python(hljs) {
      const regex = hljs.regex;
      const IDENT_RE = /[\p{XID_Start}_]\p{XID_Continue}*/u;
      const RESERVED_WORDS = [
        'and',
        'as',
        'assert',
        'async',
        'await',
        'break',
        'case',
        'class',
        'continue',
        'def',
        'del',
        'elif',
        'else',
        'except',
        'finally',
        'for',
        'from',
        'global',
        'if',
        'import',
        'in',
        'is',
        'lambda',
        'match',
        'nonlocal|10',
        'not',
        'or',
        'pass',
        'raise',
        'return',
        'try',
        'while',
        'with',
        'yield'
      ];
      const BUILT_INS = [
        '__import__',
        'abs',
        'all',
        'any',
        'ascii',
        'bin',
        'bool',
        'breakpoint',
        'bytearray',
        'bytes',
        'callable',
        'chr',
        'classmethod',
        'compile',
        'complex',
        'delattr',
        'dict',
        'dir',
        'divmod',
        'enumerate',
        'eval',
        'exec',
        'filter',
        'float',
        'format',
        'frozenset',
        'getattr',
        'globals',
        'hasattr',
        'hash',
        'help',
        'hex',
        'id',
        'input',
        'int',
        'isinstance',
        'issubclass',
        'iter',
        'len',
        'list',
        'locals',
        'map',
        'max',
        'memoryview',
        'min',
        'next',
        'object',
        'oct',
        'open',
        'ord',
        'pow',
        'print',
        'property',
        'range',
        'repr',
        'reversed',
        'round',
        'set',
        'setattr',
        'slice',
        'sorted',
        'staticmethod',
        'str',
        'sum',
        'super',
        'tuple',
        'type',
        'vars',
        'zip'
      ];
      const LITERALS = [
        '__debug__',
        'Ellipsis',
        'False',
        'None',
        'NotImplemented',
        'True'
      ];
      const TYPES = [
        "Any",
        "Callable",
        "Coroutine",
        "Dict",
        "List",
        "Literal",
        "Generic",
        "Optional",
        "Sequence",
        "Set",
        "Tuple",
        "Type",
        "Union"
      ];
      const KEYWORDS = {
        $pattern: /[A-Za-z]\w+|__\w+__/,
        keyword: RESERVED_WORDS,
        built_in: BUILT_INS,
        literal: LITERALS,
        type: TYPES
      };
      const PROMPT = {
        className: 'meta',
        begin: /^(>>>|\.\.\.) /
      };
      const SUBST = {
        className: 'subst',
        begin: /\{/,
        end: /\}/,
        keywords: KEYWORDS,
        illegal: /#/
      };
      const LITERAL_BRACKET = {
        begin: /\{\{/,
        relevance: 0
      };
      const STRING = {
        className: 'string',
        contains: [ hljs.BACKSLASH_ESCAPE ],
        variants: [
          {
            begin: /([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,
            end: /'''/,
            contains: [
              hljs.BACKSLASH_ESCAPE,
              PROMPT
            ],
            relevance: 10
          },
          {
            begin: /([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,
            end: /"""/,
            contains: [
              hljs.BACKSLASH_ESCAPE,
              PROMPT
            ],
            relevance: 10
          },
          {
            begin: /([fF][rR]|[rR][fF]|[fF])'''/,
            end: /'''/,
            contains: [
              hljs.BACKSLASH_ESCAPE,
              PROMPT,
              LITERAL_BRACKET,
              SUBST
            ]
          },
          {
            begin: /([fF][rR]|[rR][fF]|[fF])"""/,
            end: /"""/,
            contains: [
              hljs.BACKSLASH_ESCAPE,
              PROMPT,
              LITERAL_BRACKET,
              SUBST
            ]
          },
          {
            begin: /([uU]|[rR])'/,
            end: /'/,
            relevance: 10
          },
          {
            begin: /([uU]|[rR])"/,
            end: /"/,
            relevance: 10
          },
          {
            begin: /([bB]|[bB][rR]|[rR][bB])'/,
            end: /'/
          },
          {
            begin: /([bB]|[bB][rR]|[rR][bB])"/,
            end: /"/
          },
          {
            begin: /([fF][rR]|[rR][fF]|[fF])'/,
            end: /'/,
            contains: [
              hljs.BACKSLASH_ESCAPE,
              LITERAL_BRACKET,
              SUBST
            ]
          },
          {
            begin: /([fF][rR]|[rR][fF]|[fF])"/,
            end: /"/,
            contains: [
              hljs.BACKSLASH_ESCAPE,
              LITERAL_BRACKET,
              SUBST
            ]
          },
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE
        ]
      };
      const digitpart = '[0-9](_?[0-9])*';
      const pointfloat = `(\\b(${digitpart}))?\\.(${digitpart})|\\b(${digitpart})\\.`;
      const lookahead = `\\b|${RESERVED_WORDS.join('|')}`;
      const NUMBER = {
        className: 'number',
        relevance: 0,
        variants: [
          {
            begin: `(\\b(${digitpart})|(${pointfloat}))[eE][+-]?(${digitpart})[jJ]?(?=${lookahead})`
          },
          {
            begin: `(${pointfloat})[jJ]?`
          },
          {
            begin: `\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?(?=${lookahead})`
          },
          {
            begin: `\\b0[bB](_?[01])+[lL]?(?=${lookahead})`
          },
          {
            begin: `\\b0[oO](_?[0-7])+[lL]?(?=${lookahead})`
          },
          {
            begin: `\\b0[xX](_?[0-9a-fA-F])+[lL]?(?=${lookahead})`
          },
          {
            begin: `\\b(${digitpart})[jJ](?=${lookahead})`
          }
        ]
      };
      const COMMENT_TYPE = {
        className: "comment",
        begin: regex.lookahead(/# type:/),
        end: /$/,
        keywords: KEYWORDS,
        contains: [
          {
            begin: /# type:/
          },
          {
            begin: /#/,
            end: /\b\B/,
            endsWithParent: true
          }
        ]
      };
      const PARAMS = {
        className: 'params',
        variants: [
          {
            className: "",
            begin: /\(\s*\)/,
            skip: true
          },
          {
            begin: /\(/,
            end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            keywords: KEYWORDS,
            contains: [
              'self',
              PROMPT,
              NUMBER,
              STRING,
              hljs.HASH_COMMENT_MODE
            ]
          }
        ]
      };
      SUBST.contains = [
        STRING,
        NUMBER,
        PROMPT
      ];
      return {
        name: 'Python',
        aliases: [
          'py',
          'gyp',
          'ipython'
        ],
        unicodeRegex: true,
        keywords: KEYWORDS,
        illegal: /(<\/|->|\?)|=>/,
        contains: [
          PROMPT,
          NUMBER,
          {
            begin: /\bself\b/
          },
          {
            beginKeywords: "if",
            relevance: 0
          },
          STRING,
          COMMENT_TYPE,
          hljs.HASH_COMMENT_MODE,
          {
            match: [
              /\bdef/, /\s+/,
              IDENT_RE,
            ],
            scope: {
              1: "keyword",
              3: "title.function"
            },
            contains: [ PARAMS ]
          },
          {
            variants: [
              {
                match: [
                  /\bclass/, /\s+/,
                  IDENT_RE, /\s*/,
                  /\(\s*/, IDENT_RE,/\s*\)/
                ],
              },
              {
                match: [
                  /\bclass/, /\s+/,
                  IDENT_RE
                ],
              }
            ],
            scope: {
              1: "keyword",
              3: "title.class",
              6: "title.class.inherited",
            }
          },
          {
            className: 'meta',
            begin: /^[\t ]*@/,
            end: /(?=#)|$/,
            contains: [
              NUMBER,
              PARAMS,
              STRING
            ]
          }
        ]
      };
    }

    function ruby(hljs) {
      const regex = hljs.regex;
      const RUBY_METHOD_RE = '([a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?)';
      const CLASS_NAME_RE = regex.either(
        /\b([A-Z]+[a-z0-9]+)+/,
        /\b([A-Z]+[a-z0-9]+)+[A-Z]+/,
      )
      ;
      const CLASS_NAME_WITH_NAMESPACE_RE = regex.concat(CLASS_NAME_RE, /(::\w+)*/);
      const RUBY_KEYWORDS = {
        "variable.constant": [
          "__FILE__",
          "__LINE__"
        ],
        "variable.language": [
          "self",
          "super",
        ],
        keyword: [
          "alias",
          "and",
          "attr_accessor",
          "attr_reader",
          "attr_writer",
          "begin",
          "BEGIN",
          "break",
          "case",
          "class",
          "defined",
          "do",
          "else",
          "elsif",
          "end",
          "END",
          "ensure",
          "for",
          "if",
          "in",
          "include",
          "module",
          "next",
          "not",
          "or",
          "redo",
          "require",
          "rescue",
          "retry",
          "return",
          "then",
          "undef",
          "unless",
          "until",
          "when",
          "while",
          "yield",
        ],
        built_in: [
          "proc",
          "lambda"
        ],
        literal: [
          "true",
          "false",
          "nil"
        ]
      };
      const YARDOCTAG = {
        className: 'doctag',
        begin: '@[A-Za-z]+'
      };
      const IRB_OBJECT = {
        begin: '#<',
        end: '>'
      };
      const COMMENT_MODES = [
        hljs.COMMENT(
          '#',
          '$',
          { contains: [ YARDOCTAG ] }
        ),
        hljs.COMMENT(
          '^=begin',
          '^=end',
          {
            contains: [ YARDOCTAG ],
            relevance: 10
          }
        ),
        hljs.COMMENT('^__END__', hljs.MATCH_NOTHING_RE)
      ];
      const SUBST = {
        className: 'subst',
        begin: /#\{/,
        end: /\}/,
        keywords: RUBY_KEYWORDS
      };
      const STRING = {
        className: 'string',
        contains: [
          hljs.BACKSLASH_ESCAPE,
          SUBST
        ],
        variants: [
          {
            begin: /'/,
            end: /'/
          },
          {
            begin: /"/,
            end: /"/
          },
          {
            begin: /`/,
            end: /`/
          },
          {
            begin: /%[qQwWx]?\(/,
            end: /\)/
          },
          {
            begin: /%[qQwWx]?\[/,
            end: /\]/
          },
          {
            begin: /%[qQwWx]?\{/,
            end: /\}/
          },
          {
            begin: /%[qQwWx]?</,
            end: />/
          },
          {
            begin: /%[qQwWx]?\//,
            end: /\//
          },
          {
            begin: /%[qQwWx]?%/,
            end: /%/
          },
          {
            begin: /%[qQwWx]?-/,
            end: /-/
          },
          {
            begin: /%[qQwWx]?\|/,
            end: /\|/
          },
          { begin: /\B\?(\\\d{1,3})/ },
          { begin: /\B\?(\\x[A-Fa-f0-9]{1,2})/ },
          { begin: /\B\?(\\u\{?[A-Fa-f0-9]{1,6}\}?)/ },
          { begin: /\B\?(\\M-\\C-|\\M-\\c|\\c\\M-|\\M-|\\C-\\M-)[\x20-\x7e]/ },
          { begin: /\B\?\\(c|C-)[\x20-\x7e]/ },
          { begin: /\B\?\\?\S/ },
          {
            begin: regex.concat(
              /<<[-~]?'?/,
              regex.lookahead(/(\w+)(?=\W)[^\n]*\n(?:[^\n]*\n)*?\s*\1\b/)
            ),
            contains: [
              hljs.END_SAME_AS_BEGIN({
                begin: /(\w+)/,
                end: /(\w+)/,
                contains: [
                  hljs.BACKSLASH_ESCAPE,
                  SUBST
                ]
              })
            ]
          }
        ]
      };
      const decimal = '[1-9](_?[0-9])*|0';
      const digits = '[0-9](_?[0-9])*';
      const NUMBER = {
        className: 'number',
        relevance: 0,
        variants: [
          { begin: `\\b(${decimal})(\\.(${digits}))?([eE][+-]?(${digits})|r)?i?\\b` },
          { begin: "\\b0[dD][0-9](_?[0-9])*r?i?\\b" },
          { begin: "\\b0[bB][0-1](_?[0-1])*r?i?\\b" },
          { begin: "\\b0[oO][0-7](_?[0-7])*r?i?\\b" },
          { begin: "\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*r?i?\\b" },
          { begin: "\\b0(_?[0-7])+r?i?\\b" }
        ]
      };
      const PARAMS = {
        variants: [
          {
            match: /\(\)/,
          },
          {
            className: 'params',
            begin: /\(/,
            end: /(?=\))/,
            excludeBegin: true,
            endsParent: true,
            keywords: RUBY_KEYWORDS,
          }
        ]
      };
      const CLASS_DEFINITION = {
        variants: [
          {
            match: [
              /class\s+/,
              CLASS_NAME_WITH_NAMESPACE_RE,
              /\s+<\s+/,
              CLASS_NAME_WITH_NAMESPACE_RE
            ]
          },
          {
            match: [
              /class\s+/,
              CLASS_NAME_WITH_NAMESPACE_RE
            ]
          }
        ],
        scope: {
          2: "title.class",
          4: "title.class.inherited"
        },
        keywords: RUBY_KEYWORDS
      };
      const UPPER_CASE_CONSTANT = {
        relevance: 0,
        match: /\b[A-Z][A-Z_0-9]+\b/,
        className: "variable.constant"
      };
      const METHOD_DEFINITION = {
        match: [
          /def/, /\s+/,
          RUBY_METHOD_RE
        ],
        scope: {
          1: "keyword",
          3: "title.function"
        },
        contains: [
          PARAMS
        ]
      };
      const OBJECT_CREATION = {
        relevance: 0,
        match: [
          CLASS_NAME_WITH_NAMESPACE_RE,
          /\.new[ (]/
        ],
        scope: {
          1: "title.class"
        }
      };
      const RUBY_DEFAULT_CONTAINS = [
        STRING,
        CLASS_DEFINITION,
        OBJECT_CREATION,
        UPPER_CASE_CONSTANT,
        METHOD_DEFINITION,
        {
          begin: hljs.IDENT_RE + '::' },
        {
          className: 'symbol',
          begin: hljs.UNDERSCORE_IDENT_RE + '(!|\\?)?:',
          relevance: 0
        },
        {
          className: 'symbol',
          begin: ':(?!\\s)',
          contains: [
            STRING,
            { begin: RUBY_METHOD_RE }
          ],
          relevance: 0
        },
        NUMBER,
        {
          className: "variable",
          begin: '(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])' + `(?![A-Za-z])(?![@$?'])`
        },
        {
          className: 'params',
          begin: /\|/,
          end: /\|/,
          excludeBegin: true,
          excludeEnd: true,
          relevance: 0,
          keywords: RUBY_KEYWORDS
        },
        {
          begin: '(' + hljs.RE_STARTERS_RE + '|unless)\\s*',
          keywords: 'unless',
          contains: [
            {
              className: 'regexp',
              contains: [
                hljs.BACKSLASH_ESCAPE,
                SUBST
              ],
              illegal: /\n/,
              variants: [
                {
                  begin: '/',
                  end: '/[a-z]*'
                },
                {
                  begin: /%r\{/,
                  end: /\}[a-z]*/
                },
                {
                  begin: '%r\\(',
                  end: '\\)[a-z]*'
                },
                {
                  begin: '%r!',
                  end: '![a-z]*'
                },
                {
                  begin: '%r\\[',
                  end: '\\][a-z]*'
                }
              ]
            }
          ].concat(IRB_OBJECT, COMMENT_MODES),
          relevance: 0
        }
      ].concat(IRB_OBJECT, COMMENT_MODES);
      SUBST.contains = RUBY_DEFAULT_CONTAINS;
      PARAMS.contains = RUBY_DEFAULT_CONTAINS;
      const SIMPLE_PROMPT = "[>?]>";
      const DEFAULT_PROMPT = "[\\w#]+\\(\\w+\\):\\d+:\\d+[>*]";
      const RVM_PROMPT = "(\\w+-)?\\d+\\.\\d+\\.\\d+(p\\d+)?[^\\d][^>]+>";
      const IRB_DEFAULT = [
        {
          begin: /^\s*=>/,
          starts: {
            end: '$',
            contains: RUBY_DEFAULT_CONTAINS
          }
        },
        {
          className: 'meta.prompt',
          begin: '^(' + SIMPLE_PROMPT + "|" + DEFAULT_PROMPT + '|' + RVM_PROMPT + ')(?=[ ])',
          starts: {
            end: '$',
            keywords: RUBY_KEYWORDS,
            contains: RUBY_DEFAULT_CONTAINS
          }
        }
      ];
      COMMENT_MODES.unshift(IRB_OBJECT);
      return {
        name: 'Ruby',
        aliases: [
          'rb',
          'gemspec',
          'podspec',
          'thor',
          'irb'
        ],
        keywords: RUBY_KEYWORDS,
        illegal: /\/\*/,
        contains: [ hljs.SHEBANG({ binary: "ruby" }) ]
          .concat(IRB_DEFAULT)
          .concat(COMMENT_MODES)
          .concat(RUBY_DEFAULT_CONTAINS)
      };
    }

    function rust(hljs) {
      const regex = hljs.regex;
      const FUNCTION_INVOKE = {
        className: "title.function.invoke",
        relevance: 0,
        begin: regex.concat(
          /\b/,
          /(?!let\b)/,
          hljs.IDENT_RE,
          regex.lookahead(/\s*\(/))
      };
      const NUMBER_SUFFIX = '([ui](8|16|32|64|128|size)|f(32|64))\?';
      const KEYWORDS = [
        "abstract",
        "as",
        "async",
        "await",
        "become",
        "box",
        "break",
        "const",
        "continue",
        "crate",
        "do",
        "dyn",
        "else",
        "enum",
        "extern",
        "false",
        "final",
        "fn",
        "for",
        "if",
        "impl",
        "in",
        "let",
        "loop",
        "macro",
        "match",
        "mod",
        "move",
        "mut",
        "override",
        "priv",
        "pub",
        "ref",
        "return",
        "self",
        "Self",
        "static",
        "struct",
        "super",
        "trait",
        "true",
        "try",
        "type",
        "typeof",
        "unsafe",
        "unsized",
        "use",
        "virtual",
        "where",
        "while",
        "yield"
      ];
      const LITERALS = [
        "true",
        "false",
        "Some",
        "None",
        "Ok",
        "Err"
      ];
      const BUILTINS = [
        'drop ',
        "Copy",
        "Send",
        "Sized",
        "Sync",
        "Drop",
        "Fn",
        "FnMut",
        "FnOnce",
        "ToOwned",
        "Clone",
        "Debug",
        "PartialEq",
        "PartialOrd",
        "Eq",
        "Ord",
        "AsRef",
        "AsMut",
        "Into",
        "From",
        "Default",
        "Iterator",
        "Extend",
        "IntoIterator",
        "DoubleEndedIterator",
        "ExactSizeIterator",
        "SliceConcatExt",
        "ToString",
        "assert!",
        "assert_eq!",
        "bitflags!",
        "bytes!",
        "cfg!",
        "col!",
        "concat!",
        "concat_idents!",
        "debug_assert!",
        "debug_assert_eq!",
        "env!",
        "panic!",
        "file!",
        "format!",
        "format_args!",
        "include_bytes!",
        "include_str!",
        "line!",
        "local_data_key!",
        "module_path!",
        "option_env!",
        "print!",
        "println!",
        "select!",
        "stringify!",
        "try!",
        "unimplemented!",
        "unreachable!",
        "vec!",
        "write!",
        "writeln!",
        "macro_rules!",
        "assert_ne!",
        "debug_assert_ne!"
      ];
      const TYPES = [
        "i8",
        "i16",
        "i32",
        "i64",
        "i128",
        "isize",
        "u8",
        "u16",
        "u32",
        "u64",
        "u128",
        "usize",
        "f32",
        "f64",
        "str",
        "char",
        "bool",
        "Box",
        "Option",
        "Result",
        "String",
        "Vec"
      ];
      return {
        name: 'Rust',
        aliases: [ 'rs' ],
        keywords: {
          $pattern: hljs.IDENT_RE + '!?',
          type: TYPES,
          keyword: KEYWORDS,
          literal: LITERALS,
          built_in: BUILTINS
        },
        illegal: '</',
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.COMMENT('/\\*', '\\*/', { contains: [ 'self' ] }),
          hljs.inherit(hljs.QUOTE_STRING_MODE, {
            begin: /b?"/,
            illegal: null
          }),
          {
            className: 'string',
            variants: [
              { begin: /b?r(#*)"(.|\n)*?"\1(?!#)/ },
              { begin: /b?'\\?(x\w{2}|u\w{4}|U\w{8}|.)'/ }
            ]
          },
          {
            className: 'symbol',
            begin: /'[a-zA-Z_][a-zA-Z0-9_]*/
          },
          {
            className: 'number',
            variants: [
              { begin: '\\b0b([01_]+)' + NUMBER_SUFFIX },
              { begin: '\\b0o([0-7_]+)' + NUMBER_SUFFIX },
              { begin: '\\b0x([A-Fa-f0-9_]+)' + NUMBER_SUFFIX },
              { begin: '\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)'
                       + NUMBER_SUFFIX }
            ],
            relevance: 0
          },
          {
            begin: [
              /fn/,
              /\s+/,
              hljs.UNDERSCORE_IDENT_RE
            ],
            className: {
              1: "keyword",
              3: "title.function"
            }
          },
          {
            className: 'meta',
            begin: '#!?\\[',
            end: '\\]',
            contains: [
              {
                className: 'string',
                begin: /"/,
                end: /"/
              }
            ]
          },
          {
            begin: [
              /let/,
              /\s+/,
              /(?:mut\s+)?/,
              hljs.UNDERSCORE_IDENT_RE
            ],
            className: {
              1: "keyword",
              3: "keyword",
              4: "variable"
            }
          },
          {
            begin: [
              /for/,
              /\s+/,
              hljs.UNDERSCORE_IDENT_RE,
              /\s+/,
              /in/
            ],
            className: {
              1: "keyword",
              3: "variable",
              5: "keyword"
            }
          },
          {
            begin: [
              /type/,
              /\s+/,
              hljs.UNDERSCORE_IDENT_RE
            ],
            className: {
              1: "keyword",
              3: "title.class"
            }
          },
          {
            begin: [
              /(?:trait|enum|struct|union|impl|for)/,
              /\s+/,
              hljs.UNDERSCORE_IDENT_RE
            ],
            className: {
              1: "keyword",
              3: "title.class"
            }
          },
          {
            begin: hljs.IDENT_RE + '::',
            keywords: {
              keyword: "Self",
              built_in: BUILTINS,
              type: TYPES
            }
          },
          {
            className: "punctuation",
            begin: '->'
          },
          FUNCTION_INVOKE
        ]
      };
    }

    function scala(hljs) {
      const regex = hljs.regex;
      const ANNOTATION = {
        className: 'meta',
        begin: '@[A-Za-z]+'
      };
      const SUBST = {
        className: 'subst',
        variants: [
          { begin: '\\$[A-Za-z0-9_]+' },
          {
            begin: /\$\{/,
            end: /\}/
          }
        ]
      };
      const STRING = {
        className: 'string',
        variants: [
          {
            begin: '"""',
            end: '"""'
          },
          {
            begin: '"',
            end: '"',
            illegal: '\\n',
            contains: [ hljs.BACKSLASH_ESCAPE ]
          },
          {
            begin: '[a-z]+"',
            end: '"',
            illegal: '\\n',
            contains: [
              hljs.BACKSLASH_ESCAPE,
              SUBST
            ]
          },
          {
            className: 'string',
            begin: '[a-z]+"""',
            end: '"""',
            contains: [ SUBST ],
            relevance: 10
          }
        ]
      };
      const TYPE = {
        className: 'type',
        begin: '\\b[A-Z][A-Za-z0-9_]*',
        relevance: 0
      };
      const NAME = {
        className: 'title',
        begin: /[^0-9\n\t "'(),.`{}\[\]:;][^\n\t "'(),.`{}\[\]:;]+|[^0-9\n\t "'(),.`{}\[\]:;=]/,
        relevance: 0
      };
      const CLASS = {
        className: 'class',
        beginKeywords: 'class object trait type',
        end: /[:={\[\n;]/,
        excludeEnd: true,
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          {
            beginKeywords: 'extends with',
            relevance: 10
          },
          {
            begin: /\[/,
            end: /\]/,
            excludeBegin: true,
            excludeEnd: true,
            relevance: 0,
            contains: [ TYPE ]
          },
          {
            className: 'params',
            begin: /\(/,
            end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            relevance: 0,
            contains: [ TYPE ]
          },
          NAME
        ]
      };
      const METHOD = {
        className: 'function',
        beginKeywords: 'def',
        end: regex.lookahead(/[:={\[(\n;]/),
        contains: [ NAME ]
      };
      const EXTENSION = {
        begin: [
          /^\s*/,
          'extension',
          /\s+(?=[[(])/,
        ],
        beginScope: { 2: "keyword", }
      };
      const END = {
        begin: [
          /^\s*/,
          /end/,
          /\s+/,
          /(extension\b)?/,
        ],
        beginScope: {
          2: "keyword",
          4: "keyword",
        }
      };
      const INLINE_MODES = [
        { match: /\.inline\b/ },
        {
          begin: /\binline(?=\s)/,
          keywords: 'inline'
        }
      ];
      const USING_PARAM_CLAUSE = {
        begin: [
          /\(\s*/,
          /using/,
          /\s+(?!\))/,
        ],
        beginScope: { 2: "keyword", }
      };
      return {
        name: 'Scala',
        keywords: {
          literal: 'true false null',
          keyword: 'type yield lazy override def with val var sealed abstract private trait object if then forSome for while do throw finally protected extends import final return else break new catch super class case package default try this match continue throws implicit export enum given transparent'
        },
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          STRING,
          TYPE,
          METHOD,
          CLASS,
          hljs.C_NUMBER_MODE,
          EXTENSION,
          END,
          ...INLINE_MODES,
          USING_PARAM_CLAUSE,
          ANNOTATION
        ]
      };
    }

    function shell(hljs) {
      return {
        name: 'Shell Session',
        aliases: [
          'console',
          'shellsession'
        ],
        contains: [
          {
            className: 'meta.prompt',
            begin: /^\s{0,3}[/~\w\d[\]()@-]*[>%$#][ ]?/,
            starts: {
              end: /[^\\](?=\s*$)/,
              subLanguage: 'bash'
            }
          }
        ]
      };
    }

    function sql(hljs) {
      const regex = hljs.regex;
      const COMMENT_MODE = hljs.COMMENT('--', '$');
      const STRING = {
        className: 'string',
        variants: [
          {
            begin: /'/,
            end: /'/,
            contains: [ { begin: /''/ } ]
          }
        ]
      };
      const QUOTED_IDENTIFIER = {
        begin: /"/,
        end: /"/,
        contains: [ { begin: /""/ } ]
      };
      const LITERALS = [
        "true",
        "false",
        "unknown"
      ];
      const MULTI_WORD_TYPES = [
        "double precision",
        "large object",
        "with timezone",
        "without timezone"
      ];
      const TYPES = [
        'bigint',
        'binary',
        'blob',
        'boolean',
        'char',
        'character',
        'clob',
        'date',
        'dec',
        'decfloat',
        'decimal',
        'float',
        'int',
        'integer',
        'interval',
        'nchar',
        'nclob',
        'national',
        'numeric',
        'real',
        'row',
        'smallint',
        'time',
        'timestamp',
        'varchar',
        'varying',
        'varbinary'
      ];
      const NON_RESERVED_WORDS = [
        "add",
        "asc",
        "collation",
        "desc",
        "final",
        "first",
        "last",
        "view"
      ];
      const RESERVED_WORDS = [
        "abs",
        "acos",
        "all",
        "allocate",
        "alter",
        "and",
        "any",
        "are",
        "array",
        "array_agg",
        "array_max_cardinality",
        "as",
        "asensitive",
        "asin",
        "asymmetric",
        "at",
        "atan",
        "atomic",
        "authorization",
        "avg",
        "begin",
        "begin_frame",
        "begin_partition",
        "between",
        "bigint",
        "binary",
        "blob",
        "boolean",
        "both",
        "by",
        "call",
        "called",
        "cardinality",
        "cascaded",
        "case",
        "cast",
        "ceil",
        "ceiling",
        "char",
        "char_length",
        "character",
        "character_length",
        "check",
        "classifier",
        "clob",
        "close",
        "coalesce",
        "collate",
        "collect",
        "column",
        "commit",
        "condition",
        "connect",
        "constraint",
        "contains",
        "convert",
        "copy",
        "corr",
        "corresponding",
        "cos",
        "cosh",
        "count",
        "covar_pop",
        "covar_samp",
        "create",
        "cross",
        "cube",
        "cume_dist",
        "current",
        "current_catalog",
        "current_date",
        "current_default_transform_group",
        "current_path",
        "current_role",
        "current_row",
        "current_schema",
        "current_time",
        "current_timestamp",
        "current_path",
        "current_role",
        "current_transform_group_for_type",
        "current_user",
        "cursor",
        "cycle",
        "date",
        "day",
        "deallocate",
        "dec",
        "decimal",
        "decfloat",
        "declare",
        "default",
        "define",
        "delete",
        "dense_rank",
        "deref",
        "describe",
        "deterministic",
        "disconnect",
        "distinct",
        "double",
        "drop",
        "dynamic",
        "each",
        "element",
        "else",
        "empty",
        "end",
        "end_frame",
        "end_partition",
        "end-exec",
        "equals",
        "escape",
        "every",
        "except",
        "exec",
        "execute",
        "exists",
        "exp",
        "external",
        "extract",
        "false",
        "fetch",
        "filter",
        "first_value",
        "float",
        "floor",
        "for",
        "foreign",
        "frame_row",
        "free",
        "from",
        "full",
        "function",
        "fusion",
        "get",
        "global",
        "grant",
        "group",
        "grouping",
        "groups",
        "having",
        "hold",
        "hour",
        "identity",
        "in",
        "indicator",
        "initial",
        "inner",
        "inout",
        "insensitive",
        "insert",
        "int",
        "integer",
        "intersect",
        "intersection",
        "interval",
        "into",
        "is",
        "join",
        "json_array",
        "json_arrayagg",
        "json_exists",
        "json_object",
        "json_objectagg",
        "json_query",
        "json_table",
        "json_table_primitive",
        "json_value",
        "lag",
        "language",
        "large",
        "last_value",
        "lateral",
        "lead",
        "leading",
        "left",
        "like",
        "like_regex",
        "listagg",
        "ln",
        "local",
        "localtime",
        "localtimestamp",
        "log",
        "log10",
        "lower",
        "match",
        "match_number",
        "match_recognize",
        "matches",
        "max",
        "member",
        "merge",
        "method",
        "min",
        "minute",
        "mod",
        "modifies",
        "module",
        "month",
        "multiset",
        "national",
        "natural",
        "nchar",
        "nclob",
        "new",
        "no",
        "none",
        "normalize",
        "not",
        "nth_value",
        "ntile",
        "null",
        "nullif",
        "numeric",
        "octet_length",
        "occurrences_regex",
        "of",
        "offset",
        "old",
        "omit",
        "on",
        "one",
        "only",
        "open",
        "or",
        "order",
        "out",
        "outer",
        "over",
        "overlaps",
        "overlay",
        "parameter",
        "partition",
        "pattern",
        "per",
        "percent",
        "percent_rank",
        "percentile_cont",
        "percentile_disc",
        "period",
        "portion",
        "position",
        "position_regex",
        "power",
        "precedes",
        "precision",
        "prepare",
        "primary",
        "procedure",
        "ptf",
        "range",
        "rank",
        "reads",
        "real",
        "recursive",
        "ref",
        "references",
        "referencing",
        "regr_avgx",
        "regr_avgy",
        "regr_count",
        "regr_intercept",
        "regr_r2",
        "regr_slope",
        "regr_sxx",
        "regr_sxy",
        "regr_syy",
        "release",
        "result",
        "return",
        "returns",
        "revoke",
        "right",
        "rollback",
        "rollup",
        "row",
        "row_number",
        "rows",
        "running",
        "savepoint",
        "scope",
        "scroll",
        "search",
        "second",
        "seek",
        "select",
        "sensitive",
        "session_user",
        "set",
        "show",
        "similar",
        "sin",
        "sinh",
        "skip",
        "smallint",
        "some",
        "specific",
        "specifictype",
        "sql",
        "sqlexception",
        "sqlstate",
        "sqlwarning",
        "sqrt",
        "start",
        "static",
        "stddev_pop",
        "stddev_samp",
        "submultiset",
        "subset",
        "substring",
        "substring_regex",
        "succeeds",
        "sum",
        "symmetric",
        "system",
        "system_time",
        "system_user",
        "table",
        "tablesample",
        "tan",
        "tanh",
        "then",
        "time",
        "timestamp",
        "timezone_hour",
        "timezone_minute",
        "to",
        "trailing",
        "translate",
        "translate_regex",
        "translation",
        "treat",
        "trigger",
        "trim",
        "trim_array",
        "true",
        "truncate",
        "uescape",
        "union",
        "unique",
        "unknown",
        "unnest",
        "update",
        "upper",
        "user",
        "using",
        "value",
        "values",
        "value_of",
        "var_pop",
        "var_samp",
        "varbinary",
        "varchar",
        "varying",
        "versioning",
        "when",
        "whenever",
        "where",
        "width_bucket",
        "window",
        "with",
        "within",
        "without",
        "year",
      ];
      const RESERVED_FUNCTIONS = [
        "abs",
        "acos",
        "array_agg",
        "asin",
        "atan",
        "avg",
        "cast",
        "ceil",
        "ceiling",
        "coalesce",
        "corr",
        "cos",
        "cosh",
        "count",
        "covar_pop",
        "covar_samp",
        "cume_dist",
        "dense_rank",
        "deref",
        "element",
        "exp",
        "extract",
        "first_value",
        "floor",
        "json_array",
        "json_arrayagg",
        "json_exists",
        "json_object",
        "json_objectagg",
        "json_query",
        "json_table",
        "json_table_primitive",
        "json_value",
        "lag",
        "last_value",
        "lead",
        "listagg",
        "ln",
        "log",
        "log10",
        "lower",
        "max",
        "min",
        "mod",
        "nth_value",
        "ntile",
        "nullif",
        "percent_rank",
        "percentile_cont",
        "percentile_disc",
        "position",
        "position_regex",
        "power",
        "rank",
        "regr_avgx",
        "regr_avgy",
        "regr_count",
        "regr_intercept",
        "regr_r2",
        "regr_slope",
        "regr_sxx",
        "regr_sxy",
        "regr_syy",
        "row_number",
        "sin",
        "sinh",
        "sqrt",
        "stddev_pop",
        "stddev_samp",
        "substring",
        "substring_regex",
        "sum",
        "tan",
        "tanh",
        "translate",
        "translate_regex",
        "treat",
        "trim",
        "trim_array",
        "unnest",
        "upper",
        "value_of",
        "var_pop",
        "var_samp",
        "width_bucket",
      ];
      const POSSIBLE_WITHOUT_PARENS = [
        "current_catalog",
        "current_date",
        "current_default_transform_group",
        "current_path",
        "current_role",
        "current_schema",
        "current_transform_group_for_type",
        "current_user",
        "session_user",
        "system_time",
        "system_user",
        "current_time",
        "localtime",
        "current_timestamp",
        "localtimestamp"
      ];
      const COMBOS = [
        "create table",
        "insert into",
        "primary key",
        "foreign key",
        "not null",
        "alter table",
        "add constraint",
        "grouping sets",
        "on overflow",
        "character set",
        "respect nulls",
        "ignore nulls",
        "nulls first",
        "nulls last",
        "depth first",
        "breadth first"
      ];
      const FUNCTIONS = RESERVED_FUNCTIONS;
      const KEYWORDS = [
        ...RESERVED_WORDS,
        ...NON_RESERVED_WORDS
      ].filter((keyword) => {
        return !RESERVED_FUNCTIONS.includes(keyword);
      });
      const VARIABLE = {
        className: "variable",
        begin: /@[a-z0-9]+/,
      };
      const OPERATOR = {
        className: "operator",
        begin: /[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?/,
        relevance: 0,
      };
      const FUNCTION_CALL = {
        begin: regex.concat(/\b/, regex.either(...FUNCTIONS), /\s*\(/),
        relevance: 0,
        keywords: { built_in: FUNCTIONS }
      };
      function reduceRelevancy(list, {
        exceptions, when
      } = {}) {
        const qualifyFn = when;
        exceptions = exceptions || [];
        return list.map((item) => {
          if (item.match(/\|\d+$/) || exceptions.includes(item)) {
            return item;
          } else if (qualifyFn(item)) {
            return `${item}|0`;
          } else {
            return item;
          }
        });
      }
      return {
        name: 'SQL',
        case_insensitive: true,
        illegal: /[{}]|<\//,
        keywords: {
          $pattern: /\b[\w\.]+/,
          keyword:
            reduceRelevancy(KEYWORDS, { when: (x) => x.length < 3 }),
          literal: LITERALS,
          type: TYPES,
          built_in: POSSIBLE_WITHOUT_PARENS
        },
        contains: [
          {
            begin: regex.either(...COMBOS),
            relevance: 0,
            keywords: {
              $pattern: /[\w\.]+/,
              keyword: KEYWORDS.concat(COMBOS),
              literal: LITERALS,
              type: TYPES
            },
          },
          {
            className: "type",
            begin: regex.either(...MULTI_WORD_TYPES)
          },
          FUNCTION_CALL,
          VARIABLE,
          STRING,
          QUOTED_IDENTIFIER,
          hljs.C_NUMBER_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          COMMENT_MODE,
          OPERATOR
        ]
      };
    }

    function source(re) {
      if (!re) return null;
      if (typeof re === "string") return re;
      return re.source;
    }
    function lookahead(re) {
      return concat('(?=', re, ')');
    }
    function concat(...args) {
      const joined = args.map((x) => source(x)).join("");
      return joined;
    }
    function stripOptionsFromArgs(args) {
      const opts = args[args.length - 1];
      if (typeof opts === 'object' && opts.constructor === Object) {
        args.splice(args.length - 1, 1);
        return opts;
      } else {
        return {};
      }
    }
    function either(...args) {
      const opts = stripOptionsFromArgs(args);
      const joined = '('
        + (opts.capture ? "" : "?:")
        + args.map((x) => source(x)).join("|") + ")";
      return joined;
    }
    const keywordWrapper = keyword => concat(
      /\b/,
      keyword,
      /\w$/.test(keyword) ? /\b/ : /\B/
    );
    const dotKeywords = [
      'Protocol',
      'Type'
    ].map(keywordWrapper);
    const optionalDotKeywords = [
      'init',
      'self'
    ].map(keywordWrapper);
    const keywordTypes = [
      'Any',
      'Self'
    ];
    const keywords = [
      'actor',
      'any',
      'associatedtype',
      'async',
      'await',
      /as\?/,
      /as!/,
      'as',
      'break',
      'case',
      'catch',
      'class',
      'continue',
      'convenience',
      'default',
      'defer',
      'deinit',
      'didSet',
      'distributed',
      'do',
      'dynamic',
      'else',
      'enum',
      'extension',
      'fallthrough',
      /fileprivate\(set\)/,
      'fileprivate',
      'final',
      'for',
      'func',
      'get',
      'guard',
      'if',
      'import',
      'indirect',
      'infix',
      /init\?/,
      /init!/,
      'inout',
      /internal\(set\)/,
      'internal',
      'in',
      'is',
      'isolated',
      'nonisolated',
      'lazy',
      'let',
      'mutating',
      'nonmutating',
      /open\(set\)/,
      'open',
      'operator',
      'optional',
      'override',
      'postfix',
      'precedencegroup',
      'prefix',
      /private\(set\)/,
      'private',
      'protocol',
      /public\(set\)/,
      'public',
      'repeat',
      'required',
      'rethrows',
      'return',
      'set',
      'some',
      'static',
      'struct',
      'subscript',
      'super',
      'switch',
      'throws',
      'throw',
      /try\?/,
      /try!/,
      'try',
      'typealias',
      /unowned\(safe\)/,
      /unowned\(unsafe\)/,
      'unowned',
      'var',
      'weak',
      'where',
      'while',
      'willSet'
    ];
    const literals = [
      'false',
      'nil',
      'true'
    ];
    const precedencegroupKeywords = [
      'assignment',
      'associativity',
      'higherThan',
      'left',
      'lowerThan',
      'none',
      'right'
    ];
    const numberSignKeywords = [
      '#colorLiteral',
      '#column',
      '#dsohandle',
      '#else',
      '#elseif',
      '#endif',
      '#error',
      '#file',
      '#fileID',
      '#fileLiteral',
      '#filePath',
      '#function',
      '#if',
      '#imageLiteral',
      '#keyPath',
      '#line',
      '#selector',
      '#sourceLocation',
      '#warn_unqualified_access',
      '#warning'
    ];
    const builtIns = [
      'abs',
      'all',
      'any',
      'assert',
      'assertionFailure',
      'debugPrint',
      'dump',
      'fatalError',
      'getVaList',
      'isKnownUniquelyReferenced',
      'max',
      'min',
      'numericCast',
      'pointwiseMax',
      'pointwiseMin',
      'precondition',
      'preconditionFailure',
      'print',
      'readLine',
      'repeatElement',
      'sequence',
      'stride',
      'swap',
      'swift_unboxFromSwiftValueWithType',
      'transcode',
      'type',
      'unsafeBitCast',
      'unsafeDowncast',
      'withExtendedLifetime',
      'withUnsafeMutablePointer',
      'withUnsafePointer',
      'withVaList',
      'withoutActuallyEscaping',
      'zip'
    ];
    const operatorHead = either(
      /[/=\-+!*%<>&|^~?]/,
      /[\u00A1-\u00A7]/,
      /[\u00A9\u00AB]/,
      /[\u00AC\u00AE]/,
      /[\u00B0\u00B1]/,
      /[\u00B6\u00BB\u00BF\u00D7\u00F7]/,
      /[\u2016-\u2017]/,
      /[\u2020-\u2027]/,
      /[\u2030-\u203E]/,
      /[\u2041-\u2053]/,
      /[\u2055-\u205E]/,
      /[\u2190-\u23FF]/,
      /[\u2500-\u2775]/,
      /[\u2794-\u2BFF]/,
      /[\u2E00-\u2E7F]/,
      /[\u3001-\u3003]/,
      /[\u3008-\u3020]/,
      /[\u3030]/
    );
    const operatorCharacter = either(
      operatorHead,
      /[\u0300-\u036F]/,
      /[\u1DC0-\u1DFF]/,
      /[\u20D0-\u20FF]/,
      /[\uFE00-\uFE0F]/,
      /[\uFE20-\uFE2F]/
    );
    const operator = concat(operatorHead, operatorCharacter, '*');
    const identifierHead = either(
      /[a-zA-Z_]/,
      /[\u00A8\u00AA\u00AD\u00AF\u00B2-\u00B5\u00B7-\u00BA]/,
      /[\u00BC-\u00BE\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF]/,
      /[\u0100-\u02FF\u0370-\u167F\u1681-\u180D\u180F-\u1DBF]/,
      /[\u1E00-\u1FFF]/,
      /[\u200B-\u200D\u202A-\u202E\u203F-\u2040\u2054\u2060-\u206F]/,
      /[\u2070-\u20CF\u2100-\u218F\u2460-\u24FF\u2776-\u2793]/,
      /[\u2C00-\u2DFF\u2E80-\u2FFF]/,
      /[\u3004-\u3007\u3021-\u302F\u3031-\u303F\u3040-\uD7FF]/,
      /[\uF900-\uFD3D\uFD40-\uFDCF\uFDF0-\uFE1F\uFE30-\uFE44]/,
      /[\uFE47-\uFEFE\uFF00-\uFFFD]/
    );
    const identifierCharacter = either(
      identifierHead,
      /\d/,
      /[\u0300-\u036F\u1DC0-\u1DFF\u20D0-\u20FF\uFE20-\uFE2F]/
    );
    const identifier = concat(identifierHead, identifierCharacter, '*');
    const typeIdentifier = concat(/[A-Z]/, identifierCharacter, '*');
    const keywordAttributes = [
      'autoclosure',
      concat(/convention\(/, either('swift', 'block', 'c'), /\)/),
      'discardableResult',
      'dynamicCallable',
      'dynamicMemberLookup',
      'escaping',
      'frozen',
      'GKInspectable',
      'IBAction',
      'IBDesignable',
      'IBInspectable',
      'IBOutlet',
      'IBSegueAction',
      'inlinable',
      'main',
      'nonobjc',
      'NSApplicationMain',
      'NSCopying',
      'NSManaged',
      concat(/objc\(/, identifier, /\)/),
      'objc',
      'objcMembers',
      'propertyWrapper',
      'requires_stored_property_inits',
      'resultBuilder',
      'testable',
      'UIApplicationMain',
      'unknown',
      'usableFromInline'
    ];
    const availabilityKeywords = [
      'iOS',
      'iOSApplicationExtension',
      'macOS',
      'macOSApplicationExtension',
      'macCatalyst',
      'macCatalystApplicationExtension',
      'watchOS',
      'watchOSApplicationExtension',
      'tvOS',
      'tvOSApplicationExtension',
      'swift'
    ];
    function swift(hljs) {
      const WHITESPACE = {
        match: /\s+/,
        relevance: 0
      };
      const BLOCK_COMMENT = hljs.COMMENT(
        '/\\*',
        '\\*/',
        { contains: [ 'self' ] }
      );
      const COMMENTS = [
        hljs.C_LINE_COMMENT_MODE,
        BLOCK_COMMENT
      ];
      const DOT_KEYWORD = {
        match: [
          /\./,
          either(...dotKeywords, ...optionalDotKeywords)
        ],
        className: { 2: "keyword" }
      };
      const KEYWORD_GUARD = {
        match: concat(/\./, either(...keywords)),
        relevance: 0
      };
      const PLAIN_KEYWORDS = keywords
        .filter(kw => typeof kw === 'string')
        .concat([ "_|0" ]);
      const REGEX_KEYWORDS = keywords
        .filter(kw => typeof kw !== 'string')
        .concat(keywordTypes)
        .map(keywordWrapper);
      const KEYWORD = { variants: [
        {
          className: 'keyword',
          match: either(...REGEX_KEYWORDS, ...optionalDotKeywords)
        }
      ] };
      const KEYWORDS = {
        $pattern: either(
          /\b\w+/,
          /#\w+/
        ),
        keyword: PLAIN_KEYWORDS
          .concat(numberSignKeywords),
        literal: literals
      };
      const KEYWORD_MODES = [
        DOT_KEYWORD,
        KEYWORD_GUARD,
        KEYWORD
      ];
      const BUILT_IN_GUARD = {
        match: concat(/\./, either(...builtIns)),
        relevance: 0
      };
      const BUILT_IN = {
        className: 'built_in',
        match: concat(/\b/, either(...builtIns), /(?=\()/)
      };
      const BUILT_INS = [
        BUILT_IN_GUARD,
        BUILT_IN
      ];
      const OPERATOR_GUARD = {
        match: /->/,
        relevance: 0
      };
      const OPERATOR = {
        className: 'operator',
        relevance: 0,
        variants: [
          { match: operator },
          {
            match: `\\.(\\.|${operatorCharacter})+` }
        ]
      };
      const OPERATORS = [
        OPERATOR_GUARD,
        OPERATOR
      ];
      const decimalDigits = '([0-9]_*)+';
      const hexDigits = '([0-9a-fA-F]_*)+';
      const NUMBER = {
        className: 'number',
        relevance: 0,
        variants: [
          { match: `\\b(${decimalDigits})(\\.(${decimalDigits}))?` + `([eE][+-]?(${decimalDigits}))?\\b` },
          { match: `\\b0x(${hexDigits})(\\.(${hexDigits}))?` + `([pP][+-]?(${decimalDigits}))?\\b` },
          { match: /\b0o([0-7]_*)+\b/ },
          { match: /\b0b([01]_*)+\b/ }
        ]
      };
      const ESCAPED_CHARACTER = (rawDelimiter = "") => ({
        className: 'subst',
        variants: [
          { match: concat(/\\/, rawDelimiter, /[0\\tnr"']/) },
          { match: concat(/\\/, rawDelimiter, /u\{[0-9a-fA-F]{1,8}\}/) }
        ]
      });
      const ESCAPED_NEWLINE = (rawDelimiter = "") => ({
        className: 'subst',
        match: concat(/\\/, rawDelimiter, /[\t ]*(?:[\r\n]|\r\n)/)
      });
      const INTERPOLATION = (rawDelimiter = "") => ({
        className: 'subst',
        label: "interpol",
        begin: concat(/\\/, rawDelimiter, /\(/),
        end: /\)/
      });
      const MULTILINE_STRING = (rawDelimiter = "") => ({
        begin: concat(rawDelimiter, /"""/),
        end: concat(/"""/, rawDelimiter),
        contains: [
          ESCAPED_CHARACTER(rawDelimiter),
          ESCAPED_NEWLINE(rawDelimiter),
          INTERPOLATION(rawDelimiter)
        ]
      });
      const SINGLE_LINE_STRING = (rawDelimiter = "") => ({
        begin: concat(rawDelimiter, /"/),
        end: concat(/"/, rawDelimiter),
        contains: [
          ESCAPED_CHARACTER(rawDelimiter),
          INTERPOLATION(rawDelimiter)
        ]
      });
      const STRING = {
        className: 'string',
        variants: [
          MULTILINE_STRING(),
          MULTILINE_STRING("#"),
          MULTILINE_STRING("##"),
          MULTILINE_STRING("###"),
          SINGLE_LINE_STRING(),
          SINGLE_LINE_STRING("#"),
          SINGLE_LINE_STRING("##"),
          SINGLE_LINE_STRING("###")
        ]
      };
      const QUOTED_IDENTIFIER = { match: concat(/`/, identifier, /`/) };
      const IMPLICIT_PARAMETER = {
        className: 'variable',
        match: /\$\d+/
      };
      const PROPERTY_WRAPPER_PROJECTION = {
        className: 'variable',
        match: `\\$${identifierCharacter}+`
      };
      const IDENTIFIERS = [
        QUOTED_IDENTIFIER,
        IMPLICIT_PARAMETER,
        PROPERTY_WRAPPER_PROJECTION
      ];
      const AVAILABLE_ATTRIBUTE = {
        match: /(@|#(un)?)available/,
        className: "keyword",
        starts: { contains: [
          {
            begin: /\(/,
            end: /\)/,
            keywords: availabilityKeywords,
            contains: [
              ...OPERATORS,
              NUMBER,
              STRING
            ]
          }
        ] }
      };
      const KEYWORD_ATTRIBUTE = {
        className: 'keyword',
        match: concat(/@/, either(...keywordAttributes))
      };
      const USER_DEFINED_ATTRIBUTE = {
        className: 'meta',
        match: concat(/@/, identifier)
      };
      const ATTRIBUTES = [
        AVAILABLE_ATTRIBUTE,
        KEYWORD_ATTRIBUTE,
        USER_DEFINED_ATTRIBUTE
      ];
      const TYPE = {
        match: lookahead(/\b[A-Z]/),
        relevance: 0,
        contains: [
          {
            className: 'type',
            match: concat(/(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)/, identifierCharacter, '+')
          },
          {
            className: 'type',
            match: typeIdentifier,
            relevance: 0
          },
          {
            match: /[?!]+/,
            relevance: 0
          },
          {
            match: /\.\.\./,
            relevance: 0
          },
          {
            match: concat(/\s+&\s+/, lookahead(typeIdentifier)),
            relevance: 0
          }
        ]
      };
      const GENERIC_ARGUMENTS = {
        begin: /</,
        end: />/,
        keywords: KEYWORDS,
        contains: [
          ...COMMENTS,
          ...KEYWORD_MODES,
          ...ATTRIBUTES,
          OPERATOR_GUARD,
          TYPE
        ]
      };
      TYPE.contains.push(GENERIC_ARGUMENTS);
      const TUPLE_ELEMENT_NAME = {
        match: concat(identifier, /\s*:/),
        keywords: "_|0",
        relevance: 0
      };
      const TUPLE = {
        begin: /\(/,
        end: /\)/,
        relevance: 0,
        keywords: KEYWORDS,
        contains: [
          'self',
          TUPLE_ELEMENT_NAME,
          ...COMMENTS,
          ...KEYWORD_MODES,
          ...BUILT_INS,
          ...OPERATORS,
          NUMBER,
          STRING,
          ...IDENTIFIERS,
          ...ATTRIBUTES,
          TYPE
        ]
      };
      const GENERIC_PARAMETERS = {
        begin: /</,
        end: />/,
        contains: [
          ...COMMENTS,
          TYPE
        ]
      };
      const FUNCTION_PARAMETER_NAME = {
        begin: either(
          lookahead(concat(identifier, /\s*:/)),
          lookahead(concat(identifier, /\s+/, identifier, /\s*:/))
        ),
        end: /:/,
        relevance: 0,
        contains: [
          {
            className: 'keyword',
            match: /\b_\b/
          },
          {
            className: 'params',
            match: identifier
          }
        ]
      };
      const FUNCTION_PARAMETERS = {
        begin: /\(/,
        end: /\)/,
        keywords: KEYWORDS,
        contains: [
          FUNCTION_PARAMETER_NAME,
          ...COMMENTS,
          ...KEYWORD_MODES,
          ...OPERATORS,
          NUMBER,
          STRING,
          ...ATTRIBUTES,
          TYPE,
          TUPLE
        ],
        endsParent: true,
        illegal: /["']/
      };
      const FUNCTION = {
        match: [
          /func/,
          /\s+/,
          either(QUOTED_IDENTIFIER.match, identifier, operator)
        ],
        className: {
          1: "keyword",
          3: "title.function"
        },
        contains: [
          GENERIC_PARAMETERS,
          FUNCTION_PARAMETERS,
          WHITESPACE
        ],
        illegal: [
          /\[/,
          /%/
        ]
      };
      const INIT_SUBSCRIPT = {
        match: [
          /\b(?:subscript|init[?!]?)/,
          /\s*(?=[<(])/,
        ],
        className: { 1: "keyword" },
        contains: [
          GENERIC_PARAMETERS,
          FUNCTION_PARAMETERS,
          WHITESPACE
        ],
        illegal: /\[|%/
      };
      const OPERATOR_DECLARATION = {
        match: [
          /operator/,
          /\s+/,
          operator
        ],
        className: {
          1: "keyword",
          3: "title"
        }
      };
      const PRECEDENCEGROUP = {
        begin: [
          /precedencegroup/,
          /\s+/,
          typeIdentifier
        ],
        className: {
          1: "keyword",
          3: "title"
        },
        contains: [ TYPE ],
        keywords: [
          ...precedencegroupKeywords,
          ...literals
        ],
        end: /}/
      };
      for (const variant of STRING.variants) {
        const interpolation = variant.contains.find(mode => mode.label === "interpol");
        interpolation.keywords = KEYWORDS;
        const submodes = [
          ...KEYWORD_MODES,
          ...BUILT_INS,
          ...OPERATORS,
          NUMBER,
          STRING,
          ...IDENTIFIERS
        ];
        interpolation.contains = [
          ...submodes,
          {
            begin: /\(/,
            end: /\)/,
            contains: [
              'self',
              ...submodes
            ]
          }
        ];
      }
      return {
        name: 'Swift',
        keywords: KEYWORDS,
        contains: [
          ...COMMENTS,
          FUNCTION,
          INIT_SUBSCRIPT,
          {
            beginKeywords: 'struct protocol class extension enum actor',
            end: '\\{',
            excludeEnd: true,
            keywords: KEYWORDS,
            contains: [
              hljs.inherit(hljs.TITLE_MODE, {
                className: "title.class",
                begin: /[A-Za-z$_][\u00C0-\u02B80-9A-Za-z$_]*/
              }),
              ...KEYWORD_MODES
            ]
          },
          OPERATOR_DECLARATION,
          PRECEDENCEGROUP,
          {
            beginKeywords: 'import',
            end: /$/,
            contains: [ ...COMMENTS ],
            relevance: 0
          },
          ...KEYWORD_MODES,
          ...BUILT_INS,
          ...OPERATORS,
          NUMBER,
          STRING,
          ...IDENTIFIERS,
          ...ATTRIBUTES,
          TYPE,
          TUPLE
        ]
      };
    }

    const IDENT_RE = '[A-Za-z$_][0-9A-Za-z$_]*';
    const KEYWORDS = [
      "as",
      "in",
      "of",
      "if",
      "for",
      "while",
      "finally",
      "var",
      "new",
      "function",
      "do",
      "return",
      "void",
      "else",
      "break",
      "catch",
      "instanceof",
      "with",
      "throw",
      "case",
      "default",
      "try",
      "switch",
      "continue",
      "typeof",
      "delete",
      "let",
      "yield",
      "const",
      "class",
      "debugger",
      "async",
      "await",
      "static",
      "import",
      "from",
      "export",
      "extends"
    ];
    const LITERALS = [
      "true",
      "false",
      "null",
      "undefined",
      "NaN",
      "Infinity"
    ];
    const TYPES = [
      "Object",
      "Function",
      "Boolean",
      "Symbol",
      "Math",
      "Date",
      "Number",
      "BigInt",
      "String",
      "RegExp",
      "Array",
      "Float32Array",
      "Float64Array",
      "Int8Array",
      "Uint8Array",
      "Uint8ClampedArray",
      "Int16Array",
      "Int32Array",
      "Uint16Array",
      "Uint32Array",
      "BigInt64Array",
      "BigUint64Array",
      "Set",
      "Map",
      "WeakSet",
      "WeakMap",
      "ArrayBuffer",
      "SharedArrayBuffer",
      "Atomics",
      "DataView",
      "JSON",
      "Promise",
      "Generator",
      "GeneratorFunction",
      "AsyncFunction",
      "Reflect",
      "Proxy",
      "Intl",
      "WebAssembly"
    ];
    const ERROR_TYPES = [
      "Error",
      "EvalError",
      "InternalError",
      "RangeError",
      "ReferenceError",
      "SyntaxError",
      "TypeError",
      "URIError"
    ];
    const BUILT_IN_GLOBALS = [
      "setInterval",
      "setTimeout",
      "clearInterval",
      "clearTimeout",
      "require",
      "exports",
      "eval",
      "isFinite",
      "isNaN",
      "parseFloat",
      "parseInt",
      "decodeURI",
      "decodeURIComponent",
      "encodeURI",
      "encodeURIComponent",
      "escape",
      "unescape"
    ];
    const BUILT_IN_VARIABLES = [
      "arguments",
      "this",
      "super",
      "console",
      "window",
      "document",
      "localStorage",
      "module",
      "global"
    ];
    const BUILT_INS = [].concat(
      BUILT_IN_GLOBALS,
      TYPES,
      ERROR_TYPES
    );
    function javascript(hljs) {
      const regex = hljs.regex;
      const hasClosingTag = (match, { after }) => {
        const tag = "</" + match[0].slice(1);
        const pos = match.input.indexOf(tag, after);
        return pos !== -1;
      };
      const IDENT_RE$1 = IDENT_RE;
      const FRAGMENT = {
        begin: '<>',
        end: '</>'
      };
      const XML_SELF_CLOSING = /<[A-Za-z0-9\\._:-]+\s*\/>/;
      const XML_TAG = {
        begin: /<[A-Za-z0-9\\._:-]+/,
        end: /\/[A-Za-z0-9\\._:-]+>|\/>/,
        isTrulyOpeningTag: (match, response) => {
          const afterMatchIndex = match[0].length + match.index;
          const nextChar = match.input[afterMatchIndex];
          if (
            nextChar === "<" ||
            nextChar === ",") {
            response.ignoreMatch();
            return;
          }
          if (nextChar === ">") {
            if (!hasClosingTag(match, { after: afterMatchIndex })) {
              response.ignoreMatch();
            }
          }
          let m;
          const afterMatch = match.input.substring(afterMatchIndex);
          if ((m = afterMatch.match(/^\s+extends\s+/))) {
            if (m.index === 0) {
              response.ignoreMatch();
              return;
            }
          }
        }
      };
      const KEYWORDS$1 = {
        $pattern: IDENT_RE,
        keyword: KEYWORDS,
        literal: LITERALS,
        built_in: BUILT_INS,
        "variable.language": BUILT_IN_VARIABLES
      };
      const decimalDigits = '[0-9](_?[0-9])*';
      const frac = `\\.(${decimalDigits})`;
      const decimalInteger = `0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*`;
      const NUMBER = {
        className: 'number',
        variants: [
          { begin: `(\\b(${decimalInteger})((${frac})|\\.)?|(${frac}))` +
            `[eE][+-]?(${decimalDigits})\\b` },
          { begin: `\\b(${decimalInteger})\\b((${frac})\\b|\\.)?|(${frac})\\b` },
          { begin: `\\b(0|[1-9](_?[0-9])*)n\\b` },
          { begin: "\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b" },
          { begin: "\\b0[bB][0-1](_?[0-1])*n?\\b" },
          { begin: "\\b0[oO][0-7](_?[0-7])*n?\\b" },
          { begin: "\\b0[0-7]+n?\\b" },
        ],
        relevance: 0
      };
      const SUBST = {
        className: 'subst',
        begin: '\\$\\{',
        end: '\\}',
        keywords: KEYWORDS$1,
        contains: []
      };
      const HTML_TEMPLATE = {
        begin: 'html`',
        end: '',
        starts: {
          end: '`',
          returnEnd: false,
          contains: [
            hljs.BACKSLASH_ESCAPE,
            SUBST
          ],
          subLanguage: 'xml'
        }
      };
      const CSS_TEMPLATE = {
        begin: 'css`',
        end: '',
        starts: {
          end: '`',
          returnEnd: false,
          contains: [
            hljs.BACKSLASH_ESCAPE,
            SUBST
          ],
          subLanguage: 'css'
        }
      };
      const TEMPLATE_STRING = {
        className: 'string',
        begin: '`',
        end: '`',
        contains: [
          hljs.BACKSLASH_ESCAPE,
          SUBST
        ]
      };
      const JSDOC_COMMENT = hljs.COMMENT(
        /\/\*\*(?!\/)/,
        '\\*/',
        {
          relevance: 0,
          contains: [
            {
              begin: '(?=@[A-Za-z]+)',
              relevance: 0,
              contains: [
                {
                  className: 'doctag',
                  begin: '@[A-Za-z]+'
                },
                {
                  className: 'type',
                  begin: '\\{',
                  end: '\\}',
                  excludeEnd: true,
                  excludeBegin: true,
                  relevance: 0
                },
                {
                  className: 'variable',
                  begin: IDENT_RE$1 + '(?=\\s*(-)|$)',
                  endsParent: true,
                  relevance: 0
                },
                {
                  begin: /(?=[^\n])\s/,
                  relevance: 0
                }
              ]
            }
          ]
        }
      );
      const COMMENT = {
        className: "comment",
        variants: [
          JSDOC_COMMENT,
          hljs.C_BLOCK_COMMENT_MODE,
          hljs.C_LINE_COMMENT_MODE
        ]
      };
      const SUBST_INTERNALS = [
        hljs.APOS_STRING_MODE,
        hljs.QUOTE_STRING_MODE,
        HTML_TEMPLATE,
        CSS_TEMPLATE,
        TEMPLATE_STRING,
        NUMBER,
      ];
      SUBST.contains = SUBST_INTERNALS
        .concat({
          begin: /\{/,
          end: /\}/,
          keywords: KEYWORDS$1,
          contains: [
            "self"
          ].concat(SUBST_INTERNALS)
        });
      const SUBST_AND_COMMENTS = [].concat(COMMENT, SUBST.contains);
      const PARAMS_CONTAINS = SUBST_AND_COMMENTS.concat([
        {
          begin: /\(/,
          end: /\)/,
          keywords: KEYWORDS$1,
          contains: ["self"].concat(SUBST_AND_COMMENTS)
        }
      ]);
      const PARAMS = {
        className: 'params',
        begin: /\(/,
        end: /\)/,
        excludeBegin: true,
        excludeEnd: true,
        keywords: KEYWORDS$1,
        contains: PARAMS_CONTAINS
      };
      const CLASS_OR_EXTENDS = {
        variants: [
          {
            match: [
              /class/,
              /\s+/,
              IDENT_RE$1,
              /\s+/,
              /extends/,
              /\s+/,
              regex.concat(IDENT_RE$1, "(", regex.concat(/\./, IDENT_RE$1), ")*")
            ],
            scope: {
              1: "keyword",
              3: "title.class",
              5: "keyword",
              7: "title.class.inherited"
            }
          },
          {
            match: [
              /class/,
              /\s+/,
              IDENT_RE$1
            ],
            scope: {
              1: "keyword",
              3: "title.class"
            }
          },
        ]
      };
      const CLASS_REFERENCE = {
        relevance: 0,
        match:
        regex.either(
          /\bJSON/,
          /\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,
          /\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,
          /\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/,
        ),
        className: "title.class",
        keywords: {
          _: [
            ...TYPES,
            ...ERROR_TYPES
          ]
        }
      };
      const USE_STRICT = {
        label: "use_strict",
        className: 'meta',
        relevance: 10,
        begin: /^\s*['"]use (strict|asm)['"]/
      };
      const FUNCTION_DEFINITION = {
        variants: [
          {
            match: [
              /function/,
              /\s+/,
              IDENT_RE$1,
              /(?=\s*\()/
            ]
          },
          {
            match: [
              /function/,
              /\s*(?=\()/
            ]
          }
        ],
        className: {
          1: "keyword",
          3: "title.function"
        },
        label: "func.def",
        contains: [ PARAMS ],
        illegal: /%/
      };
      const UPPER_CASE_CONSTANT = {
        relevance: 0,
        match: /\b[A-Z][A-Z_0-9]+\b/,
        className: "variable.constant"
      };
      function noneOf(list) {
        return regex.concat("(?!", list.join("|"), ")");
      }
      const FUNCTION_CALL = {
        match: regex.concat(
          /\b/,
          noneOf([
            ...BUILT_IN_GLOBALS,
            "super"
          ]),
          IDENT_RE$1, regex.lookahead(/\(/)),
        className: "title.function",
        relevance: 0
      };
      const PROPERTY_ACCESS = {
        begin: regex.concat(/\./, regex.lookahead(
          regex.concat(IDENT_RE$1, /(?![0-9A-Za-z$_(])/)
        )),
        end: IDENT_RE$1,
        excludeBegin: true,
        keywords: "prototype",
        className: "property",
        relevance: 0
      };
      const GETTER_OR_SETTER = {
        match: [
          /get|set/,
          /\s+/,
          IDENT_RE$1,
          /(?=\()/
        ],
        className: {
          1: "keyword",
          3: "title.function"
        },
        contains: [
          {
            begin: /\(\)/
          },
          PARAMS
        ]
      };
      const FUNC_LEAD_IN_RE = '(\\(' +
        '[^()]*(\\(' +
        '[^()]*(\\(' +
        '[^()]*' +
        '\\)[^()]*)*' +
        '\\)[^()]*)*' +
        '\\)|' + hljs.UNDERSCORE_IDENT_RE + ')\\s*=>';
      const FUNCTION_VARIABLE = {
        match: [
          /const|var|let/, /\s+/,
          IDENT_RE$1, /\s*/,
          /=\s*/,
          /(async\s*)?/,
          regex.lookahead(FUNC_LEAD_IN_RE)
        ],
        keywords: "async",
        className: {
          1: "keyword",
          3: "title.function"
        },
        contains: [
          PARAMS
        ]
      };
      return {
        name: 'Javascript',
        aliases: ['js', 'jsx', 'mjs', 'cjs'],
        keywords: KEYWORDS$1,
        exports: { PARAMS_CONTAINS, CLASS_REFERENCE },
        illegal: /#(?![$_A-z])/,
        contains: [
          hljs.SHEBANG({
            label: "shebang",
            binary: "node",
            relevance: 5
          }),
          USE_STRICT,
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          HTML_TEMPLATE,
          CSS_TEMPLATE,
          TEMPLATE_STRING,
          COMMENT,
          NUMBER,
          CLASS_REFERENCE,
          {
            className: 'attr',
            begin: IDENT_RE$1 + regex.lookahead(':'),
            relevance: 0
          },
          FUNCTION_VARIABLE,
          {
            begin: '(' + hljs.RE_STARTERS_RE + '|\\b(case|return|throw)\\b)\\s*',
            keywords: 'return throw case',
            relevance: 0,
            contains: [
              COMMENT,
              hljs.REGEXP_MODE,
              {
                className: 'function',
                begin: FUNC_LEAD_IN_RE,
                returnBegin: true,
                end: '\\s*=>',
                contains: [
                  {
                    className: 'params',
                    variants: [
                      {
                        begin: hljs.UNDERSCORE_IDENT_RE,
                        relevance: 0
                      },
                      {
                        className: null,
                        begin: /\(\s*\)/,
                        skip: true
                      },
                      {
                        begin: /\(/,
                        end: /\)/,
                        excludeBegin: true,
                        excludeEnd: true,
                        keywords: KEYWORDS$1,
                        contains: PARAMS_CONTAINS
                      }
                    ]
                  }
                ]
              },
              {
                begin: /,/,
                relevance: 0
              },
              {
                match: /\s+/,
                relevance: 0
              },
              {
                variants: [
                  { begin: FRAGMENT.begin, end: FRAGMENT.end },
                  { match: XML_SELF_CLOSING },
                  {
                    begin: XML_TAG.begin,
                    'on:begin': XML_TAG.isTrulyOpeningTag,
                    end: XML_TAG.end
                  }
                ],
                subLanguage: 'xml',
                contains: [
                  {
                    begin: XML_TAG.begin,
                    end: XML_TAG.end,
                    skip: true,
                    contains: ['self']
                  }
                ]
              }
            ],
          },
          FUNCTION_DEFINITION,
          {
            beginKeywords: "while if switch catch for"
          },
          {
            begin: '\\b(?!function)' + hljs.UNDERSCORE_IDENT_RE +
              '\\(' +
              '[^()]*(\\(' +
                '[^()]*(\\(' +
                  '[^()]*' +
                '\\)[^()]*)*' +
              '\\)[^()]*)*' +
              '\\)\\s*\\{',
            returnBegin:true,
            label: "func.def",
            contains: [
              PARAMS,
              hljs.inherit(hljs.TITLE_MODE, { begin: IDENT_RE$1, className: "title.function" })
            ]
          },
          {
            match: /\.\.\./,
            relevance: 0
          },
          PROPERTY_ACCESS,
          {
            match: '\\$' + IDENT_RE$1,
            relevance: 0
          },
          {
            match: [ /\bconstructor(?=\s*\()/ ],
            className: { 1: "title.function" },
            contains: [ PARAMS ]
          },
          FUNCTION_CALL,
          UPPER_CASE_CONSTANT,
          CLASS_OR_EXTENDS,
          GETTER_OR_SETTER,
          {
            match: /\$[(.]/
          }
        ]
      };
    }
    function typescript(hljs) {
      const tsLanguage = javascript(hljs);
      const IDENT_RE$1 = IDENT_RE;
      const TYPES = [
        "any",
        "void",
        "number",
        "boolean",
        "string",
        "object",
        "never",
        "symbol",
        "bigint",
        "unknown"
      ];
      const NAMESPACE = {
        beginKeywords: 'namespace',
        end: /\{/,
        excludeEnd: true,
        contains: [ tsLanguage.exports.CLASS_REFERENCE ]
      };
      const INTERFACE = {
        beginKeywords: 'interface',
        end: /\{/,
        excludeEnd: true,
        keywords: {
          keyword: 'interface extends',
          built_in: TYPES
        },
        contains: [ tsLanguage.exports.CLASS_REFERENCE ]
      };
      const USE_STRICT = {
        className: 'meta',
        relevance: 10,
        begin: /^\s*['"]use strict['"]/
      };
      const TS_SPECIFIC_KEYWORDS = [
        "type",
        "namespace",
        "interface",
        "public",
        "private",
        "protected",
        "implements",
        "declare",
        "abstract",
        "readonly",
        "enum",
        "override"
      ];
      const KEYWORDS$1 = {
        $pattern: IDENT_RE,
        keyword: KEYWORDS.concat(TS_SPECIFIC_KEYWORDS),
        literal: LITERALS,
        built_in: BUILT_INS.concat(TYPES),
        "variable.language": BUILT_IN_VARIABLES
      };
      const DECORATOR = {
        className: 'meta',
        begin: '@' + IDENT_RE$1,
      };
      const swapMode = (mode, label, replacement) => {
        const indx = mode.contains.findIndex(m => m.label === label);
        if (indx === -1) { throw new Error("can not find mode to replace"); }
        mode.contains.splice(indx, 1, replacement);
      };
      Object.assign(tsLanguage.keywords, KEYWORDS$1);
      tsLanguage.exports.PARAMS_CONTAINS.push(DECORATOR);
      tsLanguage.contains = tsLanguage.contains.concat([
        DECORATOR,
        NAMESPACE,
        INTERFACE,
      ]);
      swapMode(tsLanguage, "shebang", hljs.SHEBANG());
      swapMode(tsLanguage, "use_strict", USE_STRICT);
      const functionDeclaration = tsLanguage.contains.find(m => m.label === "func.def");
      functionDeclaration.relevance = 0;
      Object.assign(tsLanguage, {
        name: 'TypeScript',
        aliases: [
          'ts',
          'tsx'
        ]
      });
      return tsLanguage;
    }

    function yaml(hljs) {
      const LITERALS = 'true false yes no null';
      const URI_CHARACTERS = '[\\w#;/?:@&=+$,.~*\'()[\\]]+';
      const KEY = {
        className: 'attr',
        variants: [
          { begin: '\\w[\\w :\\/.-]*:(?=[ \t]|$)' },
          {
            begin: '"\\w[\\w :\\/.-]*":(?=[ \t]|$)' },
          {
            begin: '\'\\w[\\w :\\/.-]*\':(?=[ \t]|$)' }
        ]
      };
      const TEMPLATE_VARIABLES = {
        className: 'template-variable',
        variants: [
          {
            begin: /\{\{/,
            end: /\}\}/
          },
          {
            begin: /%\{/,
            end: /\}/
          }
        ]
      };
      const STRING = {
        className: 'string',
        relevance: 0,
        variants: [
          {
            begin: /'/,
            end: /'/
          },
          {
            begin: /"/,
            end: /"/
          },
          { begin: /\S+/ }
        ],
        contains: [
          hljs.BACKSLASH_ESCAPE,
          TEMPLATE_VARIABLES
        ]
      };
      const CONTAINER_STRING = hljs.inherit(STRING, { variants: [
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /"/,
          end: /"/
        },
        { begin: /[^\s,{}[\]]+/ }
      ] });
      const DATE_RE = '[0-9]{4}(-[0-9][0-9]){0,2}';
      const TIME_RE = '([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?';
      const FRACTION_RE = '(\\.[0-9]*)?';
      const ZONE_RE = '([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?';
      const TIMESTAMP = {
        className: 'number',
        begin: '\\b' + DATE_RE + TIME_RE + FRACTION_RE + ZONE_RE + '\\b'
      };
      const VALUE_CONTAINER = {
        end: ',',
        endsWithParent: true,
        excludeEnd: true,
        keywords: LITERALS,
        relevance: 0
      };
      const OBJECT = {
        begin: /\{/,
        end: /\}/,
        contains: [ VALUE_CONTAINER ],
        illegal: '\\n',
        relevance: 0
      };
      const ARRAY = {
        begin: '\\[',
        end: '\\]',
        contains: [ VALUE_CONTAINER ],
        illegal: '\\n',
        relevance: 0
      };
      const MODES = [
        KEY,
        {
          className: 'meta',
          begin: '^---\\s*$',
          relevance: 10
        },
        {
          className: 'string',
          begin: '[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*'
        },
        {
          begin: '<%[%=-]?',
          end: '[%-]?%>',
          subLanguage: 'ruby',
          excludeBegin: true,
          excludeEnd: true,
          relevance: 0
        },
        {
          className: 'type',
          begin: '!\\w+!' + URI_CHARACTERS
        },
        {
          className: 'type',
          begin: '!<' + URI_CHARACTERS + ">"
        },
        {
          className: 'type',
          begin: '!' + URI_CHARACTERS
        },
        {
          className: 'type',
          begin: '!!' + URI_CHARACTERS
        },
        {
          className: 'meta',
          begin: '&' + hljs.UNDERSCORE_IDENT_RE + '$'
        },
        {
          className: 'meta',
          begin: '\\*' + hljs.UNDERSCORE_IDENT_RE + '$'
        },
        {
          className: 'bullet',
          begin: '-(?=[ ]|$)',
          relevance: 0
        },
        hljs.HASH_COMMENT_MODE,
        {
          beginKeywords: LITERALS,
          keywords: { literal: LITERALS }
        },
        TIMESTAMP,
        {
          className: 'number',
          begin: hljs.C_NUMBER_RE + '\\b',
          relevance: 0
        },
        OBJECT,
        ARRAY,
        STRING
      ];
      const VALUE_MODES = [ ...MODES ];
      VALUE_MODES.pop();
      VALUE_MODES.push(CONTAINER_STRING);
      VALUE_CONTAINER.contains = VALUE_MODES;
      return {
        name: 'YAML',
        case_insensitive: true,
        aliases: [ 'yml' ],
        contains: MODES
      };
    }

    core.registerLanguage('python', python);
    core.registerLanguage('markdown', markdown);
    core.registerLanguage('yaml', yaml);
    core.registerLanguage('java', java);
    core.registerLanguage('javascript', javascript$1);
    core.registerLanguage('csharp', csharp);
    core.registerLanguage('cpp', cpp);
    core.registerLanguage('c', c);
    core.registerLanguage('php', php);
    core.registerLanguage('typescript', typescript);
    core.registerLanguage('swift', swift);
    core.registerLanguage('kotlin', kotlin);
    core.registerLanguage('go', go);
    core.registerLanguage('rust', rust);
    core.registerLanguage('ruby', ruby);
    core.registerLanguage('scala', scala);
    core.registerLanguage('dart', dart);
    core.registerLanguage('lua', lua);
    core.registerLanguage('groovy', groovy);
    core.registerLanguage('perl', perl);
    core.registerLanguage('julia', julia);
    core.registerLanguage('haskell', haskell);
    core.registerLanguage('sql', sql);
    core.registerLanguage('bash', bash);
    core.registerLanguage('shell', shell);
    const SUPPORTED_LANGUAGES = [
        'python',
        'markdown',
        'yaml',
        'java',
        'javascript',
        'csharp',
        'cpp',
        'c',
        'php',
        'typescript',
        'swift',
        'kotlin',
        'go',
        'rust',
        'ruby',
        'scala',
        'dart',
        'sql',
        'lua',
        'groovy',
        'perl',
        'julia',
        'haskell',
        'bash',
        'shell',
    ];
    const debug$1 = logger('pano-item-factory');
    const isValidUrl = (text) => {
        try {
            return isUrl_1(text) && glib2.uri_parse(text, glib2.UriFlags.NONE) !== null;
        }
        catch (err) {
            return false;
        }
    };
    const findOrCreateDbItem = async (clip) => {
        const { value, type } = clip.content;
        const queryBuilder = new ClipboardQueryBuilder();
        switch (type) {
            case ContentType.FILE:
                queryBuilder.withItemTypes(['FILE']).withMatchValue(`${value.operation}${value.fileList.sort().join('')}`);
                break;
            case ContentType.IMAGE:
                queryBuilder.withItemTypes(['IMAGE']).withMatchValue(glib2.compute_checksum_for_bytes(glib2.ChecksumType.MD5, value));
                break;
            case ContentType.TEXT:
                queryBuilder.withItemTypes(['LINK', 'TEXT', 'CODE', 'COLOR', 'EMOJI']).withMatchValue(value).build();
                break;
            default:
                return null;
        }
        const result = db.query(queryBuilder.build());
        if (getCurrentExtensionSettings().get_boolean('play-audio-on-copy')) {
            playAudio();
        }
        if (result.length > 0) {
            return db.update({
                ...result[0],
                copyDate: new Date(),
            });
        }
        switch (type) {
            case ContentType.FILE:
                return db.save({
                    content: JSON.stringify(value.fileList),
                    copyDate: new Date(),
                    isFavorite: false,
                    itemType: 'FILE',
                    matchValue: `${value.operation}${value.fileList.sort().join('')}`,
                    searchValue: `${value.fileList
                    .map((f) => {
                    const items = f.split('://').filter((c) => !!c);
                    return items[items.length - 1];
                })
                    .join('')}`,
                    metaData: value.operation,
                });
            case ContentType.IMAGE:
                const checksum = glib2.compute_checksum_for_bytes(glib2.ChecksumType.MD5, value);
                if (!checksum) {
                    return null;
                }
                const imageFilePath = `${getImagesPath()}/${checksum}.png`;
                const imageFile = gio2.File.new_for_path(imageFilePath);
                imageFile.replace_contents(value, null, false, gio2.FileCreateFlags.REPLACE_DESTINATION, null);
                const [, width, height] = gdkpixbuf2.Pixbuf.get_file_info(imageFilePath);
                return db.save({
                    content: checksum,
                    copyDate: new Date(),
                    isFavorite: false,
                    itemType: 'IMAGE',
                    matchValue: checksum,
                    metaData: JSON.stringify({
                        width,
                        height,
                        size: value.length,
                    }),
                });
            case ContentType.TEXT:
                if (value.toLowerCase().startsWith('http') && isValidUrl(value)) {
                    const linkPreviews = getCurrentExtensionSettings().get_boolean('link-previews');
                    let description = '', imageUrl = '', title = '', checksum = '';
                    const copyDate = new Date();
                    let linkDbItem = db.save({
                        content: value,
                        copyDate,
                        isFavorite: false,
                        itemType: 'LINK',
                        matchValue: value,
                        searchValue: `${title}${description}${value}`,
                        metaData: JSON.stringify({
                            title: title ? encodeURI(title) : '',
                            description: description ? encodeURI(description) : '',
                            image: checksum || '',
                        }),
                    });
                    if (linkPreviews && linkDbItem) {
                        const document = await getDocument(value);
                        description = document.description;
                        title = document.title;
                        imageUrl = document.imageUrl;
                        checksum = (await getImage(imageUrl))[0] || '';
                        linkDbItem = db.update({
                            id: linkDbItem.id,
                            content: value,
                            copyDate: copyDate,
                            isFavorite: false,
                            itemType: 'LINK',
                            matchValue: value,
                            searchValue: `${title}${description}${value}`,
                            metaData: JSON.stringify({
                                title: title ? encodeURI(title) : '',
                                description: description ? encodeURI(description) : '',
                                image: checksum || '',
                            }),
                        });
                    }
                    return linkDbItem;
                }
                if (lib$2.validateHTMLColorHex(value) || lib$2.validateHTMLColorRgb(value) || lib$2.validateHTMLColorName(value)) {
                    return db.save({
                        content: value,
                        copyDate: new Date(),
                        isFavorite: false,
                        itemType: 'COLOR',
                        matchValue: value,
                        searchValue: value,
                    });
                }
                const highlightResult = core.highlightAuto(value.slice(0, 2000), SUPPORTED_LANGUAGES);
                if (highlightResult.relevance < 10) {
                    if (/^\p{Extended_Pictographic}*$/u.test(value)) {
                        return db.save({
                            content: value,
                            copyDate: new Date(),
                            isFavorite: false,
                            itemType: 'EMOJI',
                            matchValue: value,
                            searchValue: value,
                        });
                    }
                    else {
                        return db.save({
                            content: value,
                            copyDate: new Date(),
                            isFavorite: false,
                            itemType: 'TEXT',
                            matchValue: value,
                            searchValue: value,
                        });
                    }
                }
                else {
                    return db.save({
                        content: value,
                        copyDate: new Date(),
                        isFavorite: false,
                        itemType: 'CODE',
                        matchValue: value,
                        searchValue: value,
                    });
                }
            default:
                return null;
        }
    };
    const createPanoItem = async (clip) => {
        let dbItem = null;
        try {
            dbItem = await findOrCreateDbItem(clip);
        }
        catch (err) {
            debug$1(`err: ${err}`);
            return null;
        }
        if (dbItem) {
            if (getCurrentExtensionSettings().get_boolean('send-notification-on-copy')) {
                sendNotification(dbItem);
            }
            return createPanoItemFromDb(dbItem);
        }
        return null;
    };
    const createPanoItemFromDb = (dbItem) => {
        if (!dbItem) {
            return null;
        }
        let panoItem;
        switch (dbItem.itemType) {
            case 'TEXT':
                panoItem = new TextPanoItem(dbItem);
                break;
            case 'CODE':
                panoItem = new CodePanoItem(dbItem);
                break;
            case 'LINK':
                panoItem = new LinkPanoItem(dbItem);
                break;
            case 'COLOR':
                panoItem = new ColorPanoItem(dbItem);
                break;
            case 'FILE':
                panoItem = new FilePanoItem(dbItem);
                break;
            case 'IMAGE':
                panoItem = new ImagePanoItem(dbItem);
                break;
            case 'EMOJI':
                panoItem = new EmojiPanoItem(dbItem);
                break;
            default:
                return null;
        }
        panoItem.connect('on-remove', (_, dbItemStr) => {
            const dbItem = JSON.parse(dbItemStr);
            removeItemResources(dbItem);
        });
        panoItem.connect('on-favorite', (_, dbItemStr) => {
            const dbItem = JSON.parse(dbItemStr);
            db.update({
                ...dbItem,
                copyDate: new Date(dbItem.copyDate),
            });
        });
        return panoItem;
    };
    const removeItemResources = (dbItem) => {
        db.delete(dbItem.id);
        if (dbItem.itemType === 'LINK') {
            const { image } = JSON.parse(dbItem.metaData || '{}');
            if (image && gio2.File.new_for_uri(`file://${getCachePath()}/${image}.png`).query_exists(null)) {
                gio2.File.new_for_uri(`file://${getCachePath()}/${image}.png`).delete(null);
            }
        }
        else if (dbItem.itemType === 'IMAGE') {
            const imageFilePath = `file://${getImagesPath()}/${dbItem.content}.png`;
            const imageFile = gio2.File.new_for_uri(imageFilePath);
            if (imageFile.query_exists(null)) {
                imageFile.delete(null);
            }
        }
    };
    const sendNotification = async (dbItem) => {
        return new Promise(() => {
            if (dbItem.itemType === 'IMAGE') {
                const { width, height, size } = JSON.parse(dbItem.metaData || '{}');
                notify(_('Image Copied'), _('Width: %spx, Height: %spx, Size: %s').format(width, height, prettyBytes(size)), gdkpixbuf2.Pixbuf.new_from_file(`${getImagesPath()}/${dbItem.content}.png`));
            }
            else if (dbItem.itemType === 'TEXT') {
                notify(_('Text Copied'), dbItem.content);
            }
            else if (dbItem.itemType === 'CODE') {
                notify(_('Code Copied'), dbItem.content);
            }
            else if (dbItem.itemType === 'EMOJI') {
                notify(_('Emoji Copied'), dbItem.content);
            }
            else if (dbItem.itemType === 'LINK') {
                const { title, description, image } = JSON.parse(dbItem.metaData || '{}');
                const pixbuf = image ? gdkpixbuf2.Pixbuf.new_from_file(`${getCachePath()}/${image}.png`) : undefined;
                notify(decodeURI(`${_('Link Copied')}${title ? ` - ${title}` : ''}`), `${dbItem.content}${description ? `\n\n${decodeURI(description)}` : ''}`, pixbuf, cogl2.PixelFormat.RGB_888);
            }
            else if (dbItem.itemType === 'COLOR') {
                // Create pixbuf from color
                const pixbuf = gdkpixbuf2.Pixbuf.new(gdkpixbuf2.Colorspace.RGB, true, 8, 1, 1);
                let color = null;
                // check if content has alpha
                if (dbItem.content.includes('rgba')) {
                    color = lib(dbItem.content);
                }
                else if (lib$2.validateHTMLColorRgb(dbItem.content)) {
                    color = `${lib(dbItem.content)}ff`;
                }
                else if (lib$2.validateHTMLColorHex(dbItem.content)) {
                    color = `${dbItem.content}ff`;
                }
                if (color) {
                    pixbuf.fill(parseInt(color.replace('#', '0x'), 16));
                    notify(_('Color Copied'), dbItem.content, pixbuf);
                }
            }
            else if (dbItem.itemType === 'FILE') {
                const operation = dbItem.metaData;
                const fileListSize = JSON.parse(dbItem.content).length;
                notify(_('File %s').format(operation === FileOperation.CUT ? 'cut' : 'copied'), _('There are %s file(s)').format(fileListSize));
            }
        });
    };

    let PanoScrollView = class PanoScrollView extends st1.ScrollView {
        constructor() {
            super({
                hscrollbar_policy: st1.PolicyType.EXTERNAL,
                vscrollbar_policy: st1.PolicyType.NEVER,
                overlay_scrollbars: true,
                x_expand: true,
                y_expand: true,
            });
            this.currentFocus = null;
            this.settings = getCurrentExtensionSettings();
            this.list = new st1.BoxLayout({ vertical: false, x_expand: true, y_expand: true });
            this.add_actor(this.list);
            this.connect('key-press-event', (_, event) => {
                if (event.get_key_symbol() === clutter10.KEY_Tab ||
                    event.get_key_symbol() === clutter10.KEY_ISO_Left_Tab ||
                    event.get_key_symbol() === clutter10.KEY_KP_Tab) {
                    this.emit('scroll-tab-press', event.has_shift_modifier());
                    return clutter10.EVENT_STOP;
                }
                if (event.has_control_modifier() && event.get_key_symbol() >= 49 && event.get_key_symbol() <= 57) {
                    this.selectItemByIndex(event.get_key_symbol() - 49);
                    return clutter10.EVENT_STOP;
                }
                if (event.get_state()) {
                    return clutter10.EVENT_PROPAGATE;
                }
                if ((event.get_key_symbol() === clutter10.KEY_Left &&
                    this.getVisibleItems().findIndex((item) => item.dbItem.id === this.currentFocus?.dbItem.id) === 0) ||
                    event.get_key_symbol() === clutter10.KEY_Up) {
                    this.emit('scroll-focus-out');
                    return clutter10.EVENT_STOP;
                }
                if (event.get_key_symbol() === clutter10.KEY_Alt_L || event.get_key_symbol() === clutter10.KEY_Alt_R) {
                    this.emit('scroll-alt-press');
                    return clutter10.EVENT_PROPAGATE;
                }
                if (event.get_key_symbol() == clutter10.KEY_BackSpace) {
                    this.emit('scroll-backspace-press');
                    return clutter10.EVENT_STOP;
                }
                const unicode = clutter10.keysym_to_unicode(event.get_key_symbol());
                if (unicode === 0) {
                    return clutter10.EVENT_PROPAGATE;
                }
                this.emit('scroll-key-press', String.fromCharCode(unicode));
                return clutter10.EVENT_STOP;
            });
            db.query(new ClipboardQueryBuilder().build()).forEach((dbItem) => {
                const panoItem = createPanoItemFromDb(dbItem);
                if (panoItem) {
                    this.connectOnRemove(panoItem);
                    this.connectOnFavorite(panoItem);
                    this.list.add_child(panoItem);
                }
            });
            const firstItem = this.list.get_first_child();
            if (firstItem) {
                firstItem.emit('activated');
            }
            this.settings.connect('changed::history-length', () => {
                this.removeExcessiveItems();
            });
            clipboardManager.connect('changed', async (_, content) => {
                const panoItem = await createPanoItem(content);
                if (panoItem) {
                    this.prependItem(panoItem);
                    this.filter(this.currentFilter, this.currentItemTypeFilter, this.showFavorites);
                }
            });
        }
        prependItem(panoItem) {
            const existingItem = this.getItem(panoItem);
            if (existingItem) {
                this.removeItem(existingItem);
            }
            this.connectOnRemove(panoItem);
            this.connectOnFavorite(panoItem);
            this.list.insert_child_at_index(panoItem, 0);
            this.removeExcessiveItems();
        }
        connectOnFavorite(panoItem) {
            panoItem.connect('on-favorite', () => {
                this.emit('scroll-update-list');
            });
        }
        connectOnRemove(panoItem) {
            panoItem.connect('on-remove', () => {
                if (this.currentFocus === panoItem) {
                    this.focusNext() || this.focusPrev();
                }
                this.removeItem(panoItem);
                this.filter(this.currentFilter, this.currentItemTypeFilter, this.showFavorites);
                if (this.getVisibleItems().length === 0) {
                    this.emit('scroll-focus-out');
                }
                else {
                    this.focusOnClosest();
                }
            });
        }
        removeItem(item) {
            item.hide();
            this.list.remove_child(item);
        }
        getItem(panoItem) {
            return this.getItems().find((item) => item.dbItem.id === panoItem.dbItem.id);
        }
        getItems() {
            return this.list.get_children();
        }
        getVisibleItems() {
            return this.list.get_children().filter((item) => item.is_visible());
        }
        removeExcessiveItems() {
            const historyLength = this.settings.get_int('history-length');
            const items = this.getItems().filter((i) => i.dbItem.isFavorite === false);
            if (historyLength < items.length) {
                items.slice(historyLength).forEach((item) => {
                    this.removeItem(item);
                });
            }
            db.query(new ClipboardQueryBuilder().withFavorites(false).withLimit(-1, this.settings.get_int('history-length')).build()).forEach((dbItem) => {
                removeItemResources(dbItem);
            });
        }
        focusNext() {
            const lastFocus = this.currentFocus;
            if (!lastFocus) {
                return this.focusOnClosest();
            }
            const index = this.getVisibleItems().findIndex((item) => item.dbItem.id === lastFocus.dbItem.id);
            if (index + 1 < this.getVisibleItems().length) {
                this.currentFocus = this.getVisibleItems()[index + 1];
                this.currentFocus.grab_key_focus();
                return true;
            }
            return false;
        }
        focusPrev() {
            const lastFocus = this.currentFocus;
            if (!lastFocus) {
                return this.focusOnClosest();
            }
            const index = this.getVisibleItems().findIndex((item) => item.dbItem.id === lastFocus.dbItem.id);
            if (index - 1 >= 0) {
                this.currentFocus = this.getVisibleItems()[index - 1];
                this.currentFocus.grab_key_focus();
                return true;
            }
            return false;
        }
        filter(text, itemType, showFavorites) {
            this.currentFilter = text;
            this.currentItemTypeFilter = itemType;
            this.showFavorites = showFavorites;
            if (!text && !itemType && null === showFavorites) {
                this.getItems().forEach((i) => i.show());
                return;
            }
            const builder = new ClipboardQueryBuilder();
            if (showFavorites) {
                builder.withFavorites(showFavorites);
            }
            if (itemType) {
                builder.withItemTypes([itemType]);
            }
            if (text) {
                builder.withContainingSearchValue(text);
            }
            const result = db.query(builder.build()).map((dbItem) => dbItem.id);
            this.getItems().forEach((item) => (result.indexOf(item.dbItem.id) >= 0 ? item.show() : item.hide()));
        }
        focusOnClosest() {
            const lastFocus = this.currentFocus;
            if (lastFocus !== null) {
                if (lastFocus.get_parent() === this.list && lastFocus.is_visible()) {
                    lastFocus.grab_key_focus();
                    return true;
                }
                else {
                    let nextFocus = this.getVisibleItems().find((item) => item.dbItem.copyDate <= lastFocus.dbItem.copyDate);
                    if (!nextFocus) {
                        nextFocus = this.getVisibleItems()
                            .reverse()
                            .find((item) => item.dbItem.copyDate >= lastFocus.dbItem.copyDate);
                    }
                    if (nextFocus) {
                        this.currentFocus = nextFocus;
                        nextFocus.grab_key_focus();
                        return true;
                    }
                }
            }
            else if (this.currentFilter && this.getVisibleItems().length > 0) {
                this.currentFocus = this.getVisibleItems()[0];
                this.currentFocus.grab_key_focus();
                return true;
            }
            else if (!this.currentFilter && this.getVisibleItems().length > 1) {
                this.currentFocus = this.getVisibleItems()[1];
                this.currentFocus.grab_key_focus();
                return true;
            }
            else if (this.getVisibleItems().length > 0) {
                this.currentFocus = this.getVisibleItems()[0];
                this.currentFocus.grab_key_focus();
                return true;
            }
            return false;
        }
        scrollToFirstItem() {
            if (this.getVisibleItems().length === 0) {
                return;
            }
            this.scrollToItem(this.getVisibleItems()[0]);
        }
        scrollToFocussedItem() {
            if (!this.currentFocus || !this.currentFocus.is_visible()) {
                return;
            }
            this.scrollToItem(this.currentFocus);
        }
        focusAndScrollToFirst() {
            if (this.getVisibleItems().length === 0) {
                this.emit('scroll-focus-out');
                this.currentFocus = null;
                return;
            }
            this.currentFocus = this.getVisibleItems()[0];
            this.currentFocus.grab_key_focus();
            this.hscroll.adjustment.set_value(this.get_allocation_box().x1);
        }
        beforeHide() {
            this.currentFocus = null;
            this.scrollToFirstItem();
            this.emit('scroll-focus-out');
        }
        scrollToItem(item) {
            const box = item.get_allocation_box();
            const adjustment = this.hscroll.adjustment;
            const value = box.x1 + adjustment.step_increment / 2.0 - adjustment.page_size / 2.0;
            if (!Number.isFinite(value)) {
                return;
            }
            adjustment.ease(value, {
                duration: 150,
                mode: clutter10.AnimationMode.EASE_OUT_QUAD,
            });
        }
        selectFirstItem() {
            const visibleItems = this.getVisibleItems();
            if (visibleItems.length > 0) {
                const item = visibleItems[0];
                item.emit('activated');
            }
        }
        selectItemByIndex(index) {
            const visibleItems = this.getVisibleItems();
            if (visibleItems.length > index) {
                const item = visibleItems[index];
                item.emit('activated');
            }
        }
        vfunc_key_press_event(event) {
            if (event.keyval === clutter10.KEY_Right) {
                this.focusNext();
                this.scrollToFocussedItem();
            }
            else if (event.keyval === clutter10.KEY_Left) {
                this.focusPrev();
                this.scrollToFocussedItem();
            }
            return clutter10.EVENT_PROPAGATE;
        }
        vfunc_scroll_event(event) {
            const adjustment = this.hscroll.adjustment;
            let value = adjustment.value;
            if (event.direction === clutter10.ScrollDirection.SMOOTH) {
                return clutter10.EVENT_STOP;
            }
            if (event.direction === clutter10.ScrollDirection.UP || event.direction === clutter10.ScrollDirection.LEFT) {
                value -= adjustment.step_increment * 2;
            }
            else if (event.direction === clutter10.ScrollDirection.DOWN || event.direction === clutter10.ScrollDirection.RIGHT) {
                value += adjustment.step_increment * 2;
            }
            adjustment.remove_transition('value');
            adjustment.ease(value, {
                duration: 150,
                mode: clutter10.AnimationMode.EASE_OUT_QUAD,
            });
            return clutter10.EVENT_STOP;
        }
    };
    PanoScrollView.metaInfo = {
        GTypeName: 'PanoScrollView',
        Signals: {
            'scroll-focus-out': {},
            'scroll-update-list': {},
            'scroll-alt-press': {},
            'scroll-tab-press': {
                param_types: [gobject2.TYPE_BOOLEAN],
                accumulator: 0,
            },
            'scroll-backspace-press': {},
            'scroll-key-press': {
                param_types: [gobject2.TYPE_STRING],
                accumulator: 0,
            },
        },
    };
    PanoScrollView = __decorate([
        registerGObjectClass
    ], PanoScrollView);

    let SearchBox = class SearchBox extends st1.BoxLayout {
        constructor() {
            super({
                x_align: clutter10.ActorAlign.CENTER,
                style_class: 'search-entry-container',
                vertical: false,
            });
            this.currentIndex = null;
            this.showFavorites = false;
            this.search = new st1.Entry({
                can_focus: true,
                hint_text: _('Type to search, Tab to cycle'),
                track_hover: true,
                width: 300,
                primary_icon: this.createSearchEntryIcon('edit-find-symbolic', 'search-entry-icon'),
                secondary_icon: this.createSearchEntryIcon('starred-symbolic', 'search-entry-fav-icon'),
            });
            this.search.connect('primary-icon-clicked', () => {
                this.focus();
                this.toggleItemType(false);
            });
            this.search.connect('secondary-icon-clicked', () => {
                this.focus();
                this.toggleFavorites();
            });
            this.search.clutter_text.connect('text-changed', () => {
                this.emitSearchTextChange();
            });
            this.search.clutter_text.connect('key-press-event', (_, event) => {
                if (event.get_key_symbol() === clutter10.KEY_Down ||
                    (event.get_key_symbol() === clutter10.KEY_Right &&
                        (this.search.clutter_text.cursor_position === -1 || this.search.text.length === 0))) {
                    this.emit('search-focus-out');
                }
                else if (event.get_key_symbol() === clutter10.KEY_Right &&
                    this.search.clutter_text.get_selection() !== null &&
                    this.search.clutter_text.get_selection() === this.search.text) {
                    this.search.clutter_text.set_cursor_position(this.search.text.length);
                }
                if (event.get_key_symbol() === clutter10.KEY_Return ||
                    event.get_key_symbol() === clutter10.KEY_ISO_Enter ||
                    event.get_key_symbol() === clutter10.KEY_KP_Enter) {
                    this.emit('search-submit');
                }
                if (event.has_control_modifier() && event.get_key_symbol() >= 49 && event.get_key_symbol() <= 57) {
                    this.emit('search-item-select-shortcut', event.get_key_symbol() - 49);
                }
                if (event.get_key_symbol() === clutter10.KEY_Tab ||
                    event.get_key_symbol() === clutter10.KEY_ISO_Left_Tab ||
                    event.get_key_symbol() === clutter10.KEY_KP_Tab) {
                    this.toggleItemType(event.has_shift_modifier());
                }
                if (event.get_key_symbol() === clutter10.KEY_BackSpace && this.search.text.length === 0) {
                    this.search.set_primary_icon(this.createSearchEntryIcon('edit-find-symbolic', 'search-entry-icon'));
                    this.currentIndex = null;
                    this.emitSearchTextChange();
                }
                if (event.get_key_symbol() === clutter10.KEY_Alt_L || event.get_key_symbol() === clutter10.KEY_Alt_R) {
                    this.toggleFavorites();
                    this.emitSearchTextChange();
                }
            });
            this.add_child(this.search);
        }
        toggleItemType(hasShift) {
            // increment or decrement the current index based on the shift modifier
            if (hasShift) {
                this.currentIndex = this.currentIndex === null ? Object.keys(PanoItemTypes).length - 1 : this.currentIndex - 1;
            }
            else {
                this.currentIndex = this.currentIndex === null ? 0 : this.currentIndex + 1;
            }
            // if the index is out of bounds, set it to the other end
            if (this.currentIndex < 0 || this.currentIndex >= Object.keys(PanoItemTypes).length) {
                this.currentIndex = null;
            }
            if (null == this.currentIndex) {
                this.search.set_primary_icon(this.createSearchEntryIcon('edit-find-symbolic', 'search-entry-icon'));
            }
            else {
                this.search.set_primary_icon(this.createSearchEntryIcon(gio2.icon_new_for_string(`${getCurrentExtension().path}/icons/hicolor/scalable/actions/${PanoItemTypes[Object.keys(PanoItemTypes)[this.currentIndex]].iconPath}`), 'search-entry-icon'));
            }
            this.emitSearchTextChange();
        }
        createSearchEntryIcon(iconNameOrProto, styleClass) {
            const icon = new st1.Icon({
                style_class: styleClass,
                icon_size: 13,
                track_hover: true,
            });
            if (typeof iconNameOrProto === 'string') {
                icon.set_icon_name(iconNameOrProto);
            }
            else {
                icon.set_gicon(iconNameOrProto);
            }
            icon.connect('enter-event', () => {
                shell0.Global.get().display.set_cursor(meta10.Cursor.POINTING_HAND);
            });
            icon.connect('motion-event', () => {
                shell0.Global.get().display.set_cursor(meta10.Cursor.POINTING_HAND);
            });
            icon.connect('leave-event', () => {
                shell0.Global.get().display.set_cursor(meta10.Cursor.DEFAULT);
            });
            return icon;
        }
        toggleFavorites() {
            const icon = this.search.get_secondary_icon();
            if (this.showFavorites) {
                icon.remove_style_class_name('active');
            }
            else {
                icon.add_style_class_name('active');
            }
            this.showFavorites = !this.showFavorites;
            this.emitSearchTextChange();
        }
        emitSearchTextChange() {
            let itemType = null;
            if (this.currentIndex !== null) {
                itemType = Object.keys(PanoItemTypes)[this.currentIndex];
            }
            this.emit('search-text-changed', this.search.text, itemType || '', this.showFavorites);
        }
        focus() {
            this.search.grab_key_focus();
        }
        removeChar() {
            this.search.text = this.search.text.slice(0, -1);
        }
        appendText(text) {
            this.search.text += text;
        }
        selectAll() {
            this.search.clutter_text.set_selection(0, this.search.text.length);
        }
        clear() {
            this.search.text = '';
        }
        getText() {
            return this.search.text;
        }
    };
    SearchBox.metaInfo = {
        GTypeName: 'SearchBox',
        Signals: {
            'search-text-changed': {
                param_types: [gobject2.TYPE_STRING, gobject2.TYPE_STRING, gobject2.TYPE_BOOLEAN],
                accumulator: 0,
            },
            'search-item-select-shortcut': {
                param_types: [gobject2.TYPE_INT],
                accumulator: 0,
            },
            'search-focus-out': {},
            'search-submit': {},
        },
    };
    SearchBox = __decorate([
        registerGObjectClass
    ], SearchBox);

    let PanoWindow = class PanoWindow extends st1.BoxLayout {
        constructor() {
            super({
                name: 'pano-window',
                constraints: getMonitorConstraint(),
                style_class: 'pano-window',
                x_align: clutter10.ActorAlign.FILL,
                y_align: clutter10.ActorAlign.END,
                visible: false,
                vertical: true,
                reactive: true,
                opacity: 0,
                can_focus: true,
            });
            this.settings = getCurrentExtensionSettings();
            this.set_height(this.settings.get_int('window-height'));
            this.settings.connect('changed::window-height', () => {
                this.set_height(this.settings.get_int('window-height'));
            });
            this.settings.connect('changed::window-background-color', () => {
                if (this.settings.get_boolean('is-in-incognito')) {
                    this.set_style(`background-color: ${this.settings.get_string('incognito-window-background-color')} !important;`);
                }
                else {
                    this.set_style(`background-color: ${this.settings.get_string('window-background-color')}`);
                }
            });
            this.settings.connect('changed::incognito-window-background-color', () => {
                if (this.settings.get_boolean('is-in-incognito')) {
                    this.set_style(`background-color: ${this.settings.get_string('incognito-window-background-color')} !important;`);
                }
                else {
                    this.set_style(`background-color: ${this.settings.get_string('window-background-color')}`);
                }
            });
            this.monitorBox = new MonitorBox();
            this.scrollView = new PanoScrollView();
            this.searchBox = new SearchBox();
            this.setupMonitorBox();
            this.setupScrollView();
            this.setupSearchBox();
            this.add_actor(this.searchBox);
            this.add_actor(this.scrollView);
            this.settings.connect('changed::is-in-incognito', () => {
                if (this.settings.get_boolean('is-in-incognito')) {
                    this.add_style_class_name('incognito');
                    this.set_style(`background-color: ${this.settings.get_string('incognito-window-background-color')} !important;`);
                }
                else {
                    this.remove_style_class_name('incognito');
                    this.set_style(`background-color: ${this.settings.get_string('window-background-color')}`);
                }
            });
            if (this.settings.get_boolean('is-in-incognito')) {
                this.add_style_class_name('incognito');
                this.set_style(`background-color: ${this.settings.get_string('incognito-window-background-color')} !important;`);
            }
            else {
                this.set_style(`background-color: ${this.settings.get_string('window-background-color')}`);
            }
        }
        setupMonitorBox() {
            this.monitorBox.connect('hide', () => this.hide());
        }
        setupSearchBox() {
            this.searchBox.connect('search-focus-out', () => {
                this.scrollView.focusOnClosest();
                this.scrollView.scrollToFocussedItem();
            });
            this.searchBox.connect('search-submit', () => {
                this.scrollView.selectFirstItem();
            });
            this.searchBox.connect('search-text-changed', (_, text, itemType, showFavorites) => {
                this.scrollView.filter(text, itemType, showFavorites);
            });
            this.searchBox.connect('search-item-select-shortcut', (_, index) => {
                this.scrollView.selectItemByIndex(index);
            });
        }
        setupScrollView() {
            this.scrollView.connect('scroll-update-list', () => {
                this.searchBox.focus();
                this.searchBox.emitSearchTextChange();
                this.scrollView.focusOnClosest();
                this.scrollView.scrollToFocussedItem();
            });
            this.scrollView.connect('scroll-focus-out', () => {
                this.searchBox.focus();
            });
            this.scrollView.connect('scroll-backspace-press', () => {
                this.searchBox.removeChar();
                this.searchBox.focus();
            });
            this.scrollView.connect('scroll-alt-press', () => {
                this.searchBox.focus();
                this.searchBox.toggleFavorites();
                this.scrollView.focusAndScrollToFirst();
            });
            this.scrollView.connect('scroll-tab-press', (_, hasShift) => {
                this.searchBox.focus();
                this.searchBox.toggleItemType(hasShift);
                this.scrollView.focusAndScrollToFirst();
            });
            this.scrollView.connect('scroll-key-press', (_, text) => {
                this.searchBox.focus();
                this.searchBox.appendText(text);
            });
        }
        toggle() {
            this.is_visible() ? this.hide() : this.show();
        }
        show() {
            this.clear_constraints();
            this.add_constraint(getMonitorConstraint());
            super.show();
            if (this.settings.get_boolean('keep-search-entry')) {
                this.searchBox.selectAll();
            }
            else {
                this.searchBox.clear();
            }
            this.searchBox.focus();
            this.ease({
                opacity: 255,
                duration: 250,
                mode: clutter10.AnimationMode.EASE_OUT_QUAD,
            });
            this.monitorBox.open();
            return clutter10.EVENT_PROPAGATE;
        }
        hide() {
            this.monitorBox.close();
            this.ease({
                opacity: 0,
                duration: 200,
                mode: clutter10.AnimationMode.EASE_OUT_QUAD,
                onComplete: () => {
                    if (!this.settings.get_boolean('keep-search-entry')) {
                        this.searchBox.clear();
                    }
                    this.scrollView.beforeHide();
                    super.hide();
                },
            });
            return clutter10.EVENT_PROPAGATE;
        }
        vfunc_key_press_event(event) {
            if (event.keyval === clutter10.KEY_Escape) {
                this.hide();
            }
            return clutter10.EVENT_PROPAGATE;
        }
        destroy() {
            this.monitorBox.destroy();
            this.searchBox.destroy();
            super.destroy();
        }
    };
    PanoWindow = __decorate([
        registerGObjectClass
    ], PanoWindow);

    class KeyManager {
        constructor() {
            this.settings = getCurrentExtensionSettings();
        }
        stopListening(gsettingsField) {
            wm.removeKeybinding(gsettingsField);
        }
        listenFor(gsettingsField, callback) {
            wm.addKeybinding(gsettingsField, this.settings, meta10.KeyBindingFlags.NONE, shell0.ActionMode.ALL, callback);
        }
    }

    const debug = logger('extension');
    class PanoExtension {
        constructor() {
            this.isEnabled = false;
            setupAppDirs();
            db.setup();
            debug('extension is initialized');
            this.keyManager = new KeyManager();
            this.panoWindow = new PanoWindow();
            const iface = loadInterfaceXML('io.elhan.Pano');
            this.dbus = gio2.DBusExportedObject.wrapJSObject(iface, this);
            this.dbus.export(gio2.DBus.session, '/io/elhan/Pano');
            this.settings = getCurrentExtensionSettings();
            this.lastDBpath = getDbPath();
            this.settings.connect('changed::database-location', () => {
                const newDBpath = this.settings.get_string('database-location');
                if (this.isEnabled) {
                    this.disable();
                    moveDbFile(this.lastDBpath, newDBpath);
                    db.setup();
                    this.rerender();
                    this.enable();
                }
                else {
                    moveDbFile(this.lastDBpath, newDBpath);
                    db.setup();
                    this.rerender();
                }
                this.lastDBpath = newDBpath;
            });
            this.settings.connect('changed::show-indicator', () => {
                if (this.settings.get_boolean('show-indicator') && this.isEnabled) {
                    this.createIndicator();
                }
                else {
                    this.removeIndicator();
                }
            });
        }
        async clearSessionHistory() {
            if (this.settings.get_boolean('session-only-mode')) {
                debug('clearing session history');
                db.shutdown();
                clipboardManager.stopTracking();
                await deleteAppDirs();
                debug('deleted session cache and db');
                clipboardManager.setContent(new ClipboardContent({
                    type: ContentType.TEXT,
                    value: '',
                }));
                debug('cleared last clipboard content');
            }
        }
        createIndicator() {
            if (this.settings.get_boolean('show-indicator')) {
                this.settingsMenu = new SettingsMenu(this.clearHistory.bind(this), () => this.panoWindow.toggle());
                addToStatusArea(this.settingsMenu);
            }
        }
        removeIndicator() {
            this.settingsMenu?.destroy();
            this.settingsMenu = null;
        }
        enable() {
            this.isEnabled = true;
            setupAppDirs();
            this.createIndicator();
            db.start();
            this.logoutSignalId = gio2.DBus.session.signal_subscribe(null, 'org.gnome.SessionManager.EndSessionDialog', 'ConfirmedLogout', '/org/gnome/SessionManager/EndSessionDialog', null, gio2.DBusSignalFlags.NONE, this.clearSessionHistory.bind(this));
            this.rebootSignalId = gio2.DBus.session.signal_subscribe(null, 'org.gnome.SessionManager.EndSessionDialog', 'ConfirmedReboot', '/org/gnome/SessionManager/EndSessionDialog', null, gio2.DBusSignalFlags.NONE, this.clearSessionHistory.bind(this));
            this.shutdownSignalId = gio2.DBus.session.signal_subscribe(null, 'org.gnome.SessionManager.EndSessionDialog', 'ConfirmedShutdown', '/org/gnome/SessionManager/EndSessionDialog', null, gio2.DBusSignalFlags.NONE, this.clearSessionHistory.bind(this));
            this.systemdSignalId = gio2.DBus.system.signal_subscribe(null, 'org.freedesktop.login1.Manager', 'PrepareForShutdown', '/org/freedesktop/login1', null, gio2.DBusSignalFlags.NONE, this.clearSessionHistory.bind(this));
            addTopChrome(this.panoWindow);
            this.keyManager.listenFor('global-shortcut', () => this.panoWindow.toggle());
            this.keyManager.listenFor('incognito-shortcut', () => {
                this.settings.set_boolean('is-in-incognito', !this.settings.get_boolean('is-in-incognito'));
            });
            clipboardManager.startTracking();
            this.windowTrackerId = shell0.Global.get().display.connect('notify::focus-window', () => {
                const focussedWindow = shell0.Global.get().display.focus_window;
                if (focussedWindow && this.panoWindow.is_visible()) {
                    this.panoWindow.hide();
                }
                const wmClass = focussedWindow?.get_wm_class();
                if (wmClass &&
                    this.settings.get_boolean('watch-exclusion-list') &&
                    this.settings.get_strv('exclusion-list').indexOf(wmClass) >= 0) {
                    clipboardManager.stopTracking();
                }
                else if (clipboardManager.isTracking === false) {
                    this.timeoutId = glib2.timeout_add(glib2.PRIORITY_DEFAULT, 300, () => {
                        clipboardManager.startTracking();
                        if (this.timeoutId) {
                            glib2.Source.remove(this.timeoutId);
                        }
                        this.timeoutId = null;
                        return glib2.SOURCE_REMOVE;
                    });
                }
            });
            debug('extension is enabled');
        }
        disable() {
            if (this.windowTrackerId) {
                shell0.Global.get().display.disconnect(this.windowTrackerId);
            }
            if (this.timeoutId) {
                glib2.Source.remove(this.timeoutId);
            }
            debounceIds.forEach((debounceId) => {
                glib2.Source.remove(debounceId);
            });
            this.removeIndicator();
            this.windowTrackerId = null;
            this.timeoutId = null;
            removeVirtualKeyboard();
            removeSoundContext();
            this.isEnabled = false;
            this.keyManager.stopListening('global-shortcut');
            this.keyManager.stopListening('incognito-shortcut');
            clipboardManager.stopTracking();
            removeChrome(this.panoWindow);
            debug('extension is disabled');
            db.shutdown();
            if (this.logoutSignalId) {
                gio2.DBus.session.signal_unsubscribe(this.logoutSignalId);
                this.logoutSignalId = null;
            }
            if (this.shutdownSignalId) {
                gio2.DBus.session.signal_unsubscribe(this.shutdownSignalId);
                this.shutdownSignalId = null;
            }
            if (this.rebootSignalId) {
                gio2.DBus.session.signal_unsubscribe(this.rebootSignalId);
                this.rebootSignalId = null;
            }
            if (this.systemdSignalId) {
                gio2.DBus.system.signal_unsubscribe(this.systemdSignalId);
                this.systemdSignalId = null;
            }
        }
        async clearHistory() {
            if (this.isEnabled) {
                this.disable();
                await this.reInitialize();
                this.enable();
            }
            else {
                await this.reInitialize();
            }
        }
        show() {
            this.panoWindow?.show();
        }
        hide() {
            this.panoWindow?.hide();
        }
        toggle() {
            this.panoWindow?.toggle();
        }
        rerender() {
            this.panoWindow.remove_all_children();
            this.panoWindow.destroy();
            this.panoWindow = new PanoWindow();
        }
        async reInitialize() {
            db.shutdown();
            await deleteAppDirs();
            setupAppDirs();
            db.setup();
            this.rerender();
        }
    }
    function extension () {
        initTranslations();
        return new PanoExtension();
    }

    return extension;

})(imports.gi.Gio, imports.gi.GLib, imports.gi.Shell, imports.gi.Clutter, imports.gi.GObject, imports.gi.St, imports.gi.GSound, imports.gi.GdkPixbuf, imports.gi.Cogl, imports.gi.Meta, imports.gi.Gda, imports.gi.Pango, imports.gi.Graphene, imports.gi.Soup);

}
catch(err) {
  log(`[pano] [init] ${err}`);
  imports.ui.main.notify('Pano', `${err}`);
  throw err;
}
